@@ -1,7 +1,7 @@
 #
 #  - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 #  SLEPc - Scalable Library for Eigenvalue Problem Computations
-#  Copyright (c) 2002-2021, Universitat Politecnica de Valencia, Spain
+#  Copyright (c) 2002-, Universitat Politecnica de Valencia, Spain
 #
 #  This file is part of SLEPc.
 #  SLEPc is distributed under a 2-clause BSD license (see LICENSE).
@@ -18,7 +18,7 @@ except ImportError:
 try:
   import urlparse as urlparse_local # novermin
 except ImportError:
-  from urllib import parse as urlparse_local
+  from urllib import parse as urlparse_local # novermin
 if sys.version_info < (3,):
   import commands
 else:
