@@ -1,7 +1,7 @@
 /*
    - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
    SLEPc - Scalable Library for Eigenvalue Problem Computations
-   Copyright (c) 2002-2021, Universitat Politecnica de Valencia, Spain
+   Copyright (c) 2002-, Universitat Politecnica de Valencia, Spain
 
    This file is part of SLEPc.
    SLEPc is distributed under a 2-clause BSD license (see LICENSE).
@@ -17,7 +17,7 @@
 SLEPC_EXTERN PetscBool BVRegisterAllCalled;
 SLEPC_EXTERN PetscErrorCode BVRegisterAll(void);
 
-SLEPC_EXTERN PetscLogEvent BV_Create,BV_Copy,BV_Mult,BV_MultVec,BV_MultInPlace,BV_Dot,BV_DotVec,BV_Orthogonalize,BV_OrthogonalizeVec,BV_Scale,BV_Norm,BV_NormVec,BV_Normalize,BV_SetRandom,BV_MatMult,BV_MatMultVec,BV_MatProject;
+SLEPC_EXTERN PetscLogEvent BV_Create,BV_Copy,BV_Mult,BV_MultVec,BV_MultInPlace,BV_Dot,BV_DotVec,BV_Orthogonalize,BV_OrthogonalizeVec,BV_Scale,BV_Norm,BV_NormVec,BV_Normalize,BV_SetRandom,BV_MatMult,BV_MatMultVec,BV_MatProject,BV_SVDAndRank;
 
 typedef struct _BVOps *BVOps;
 
@@ -113,24 +113,21 @@ struct _p_BV {
     if definite inner product:     res = sqrt(alpha)
     if indefinite inner product:   res = sgn(alpha)*sqrt(abs(alpha))
 */
-PETSC_STATIC_INLINE PetscErrorCode BV_SafeSqrt(BV bv,PetscScalar alpha,PetscReal *res)
+static inline PetscErrorCode BV_SafeSqrt(BV bv,PetscScalar alpha,PetscReal *res)
 {
-  PetscErrorCode ierr;
   PetscReal      absal,realp;
 
   PetscFunctionBegin;
   absal = PetscAbsScalar(alpha);
   realp = PetscRealPart(alpha);
-  if (absal<PETSC_MACHINE_EPSILON) {
-    ierr = PetscInfo(bv,"Zero norm, either the vector is zero or a semi-inner product is being used\n");CHKERRQ(ierr);
-  }
+  if (PetscUnlikely(absal<PETSC_MACHINE_EPSILON)) PetscCall(PetscInfo(bv,"Zero norm, either the vector is zero or a semi-inner product is being used\n"));
 #if defined(PETSC_USE_COMPLEX)
-  if (PetscAbsReal(PetscImaginaryPart(alpha))>bv->deftol && PetscAbsReal(PetscImaginaryPart(alpha))/absal>10*bv->deftol) SETERRQ1(PetscObjectComm((PetscObject)bv),1,"The inner product is not well defined: nonzero imaginary part %g",PetscImaginaryPart(alpha));
+  PetscCheck(PetscAbsReal(PetscImaginaryPart(alpha))<bv->deftol || PetscAbsReal(PetscImaginaryPart(alpha))/absal<10*bv->deftol,PetscObjectComm((PetscObject)bv),PETSC_ERR_USER_INPUT,"The inner product is not well defined: nonzero imaginary part %g",PetscImaginaryPart(alpha));
 #endif
-  if (bv->indef) {
+  if (PetscUnlikely(bv->indef)) {
     *res = (realp<0.0)? -PetscSqrtReal(-realp): PetscSqrtReal(realp);
   } else {
-    if (realp<-bv->deftol) SETERRQ(PetscObjectComm((PetscObject)bv),1,"The inner product is not well defined: indefinite matrix");
+    PetscCheck(realp>-bv->deftol,PetscObjectComm((PetscObject)bv),PETSC_ERR_USER_INPUT,"The inner product is not well defined: indefinite matrix");
     *res = (realp<0.0)? 0.0: PetscSqrtReal(realp);
   }
   PetscFunctionReturn(0);
@@ -140,19 +137,17 @@ PETSC_STATIC_INLINE PetscErrorCode BV_SafeSqrt(BV bv,PetscScalar alpha,PetscReal
   BV_IPMatMult - Multiply a vector x by the inner-product matrix, cache the
   result in Bx.
 */
-PETSC_STATIC_INLINE PetscErrorCode BV_IPMatMult(BV bv,Vec x)
+static inline PetscErrorCode BV_IPMatMult(BV bv,Vec x)
 {
-  PetscErrorCode ierr;
-
   PetscFunctionBegin;
   if (((PetscObject)x)->id != bv->xid || ((PetscObject)x)->state != bv->xstate) {
-    if (!bv->Bx) {
-      ierr = MatCreateVecs(bv->matrix,&bv->Bx,NULL);CHKERRQ(ierr);
-      ierr = PetscLogObjectParent((PetscObject)bv,(PetscObject)bv->Bx);CHKERRQ(ierr);
+    if (PetscUnlikely(!bv->Bx)) {
+      PetscCall(MatCreateVecs(bv->matrix,&bv->Bx,NULL));
+      PetscCall(PetscLogObjectParent((PetscObject)bv,(PetscObject)bv->Bx));
     }
-    ierr = MatMult(bv->matrix,x,bv->Bx);CHKERRQ(ierr);
-    ierr = PetscObjectGetId((PetscObject)x,&bv->xid);CHKERRQ(ierr);
-    ierr = PetscObjectStateGet((PetscObject)x,&bv->xstate);CHKERRQ(ierr);
+    PetscCall(MatMult(bv->matrix,x,bv->Bx));
+    PetscCall(PetscObjectGetId((PetscObject)x,&bv->xid));
+    PetscCall(PetscObjectStateGet((PetscObject)x,&bv->xstate));
   }
   PetscFunctionReturn(0);
 }
@@ -161,19 +156,14 @@ PETSC_STATIC_INLINE PetscErrorCode BV_IPMatMult(BV bv,Vec x)
   BV_IPMatMultBV - Multiply BV by the inner-product matrix, cache the
   result internally in bv->cached.
 */
-PETSC_STATIC_INLINE PetscErrorCode BV_IPMatMultBV(BV bv)
+static inline PetscErrorCode BV_IPMatMultBV(BV bv)
 {
-  PetscErrorCode ierr;
-
   PetscFunctionBegin;
-  ierr = BVGetCachedBV(bv,&bv->cached);CHKERRQ(ierr);
+  PetscCall(BVGetCachedBV(bv,&bv->cached));
   if (((PetscObject)bv)->state != bv->bvstate || bv->l != bv->cached->l || bv->k != bv->cached->k) {
-    ierr = BVSetActiveColumns(bv->cached,bv->l,bv->k);CHKERRQ(ierr);
-    if (bv->matrix) {
-      ierr = BVMatMult(bv,bv->matrix,bv->cached);CHKERRQ(ierr);
-    } else {
-      ierr = BVCopy(bv,bv->cached);CHKERRQ(ierr);
-    }
+    PetscCall(BVSetActiveColumns(bv->cached,bv->l,bv->k));
+    if (bv->matrix) PetscCall(BVMatMult(bv,bv->matrix,bv->cached));
+    else PetscCall(BVCopy(bv,bv->cached));
     bv->bvstate = ((PetscObject)bv)->state;
   }
   PetscFunctionReturn(0);
@@ -182,14 +172,12 @@ PETSC_STATIC_INLINE PetscErrorCode BV_IPMatMultBV(BV bv)
 /*
   BV_AllocateCoeffs - Allocate orthogonalization coefficients if not done already.
 */
-PETSC_STATIC_INLINE PetscErrorCode BV_AllocateCoeffs(BV bv)
+static inline PetscErrorCode BV_AllocateCoeffs(BV bv)
 {
-  PetscErrorCode ierr;
-
   PetscFunctionBegin;
   if (!bv->h) {
-    ierr = PetscMalloc2(bv->nc+bv->m,&bv->h,bv->nc+bv->m,&bv->c);CHKERRQ(ierr);
-    ierr = PetscLogObjectMemory((PetscObject)bv,2*bv->m*sizeof(PetscScalar));CHKERRQ(ierr);
+    PetscCall(PetscMalloc2(bv->nc+bv->m,&bv->h,bv->nc+bv->m,&bv->c));
+    PetscCall(PetscLogObjectMemory((PetscObject)bv,2*bv->m*sizeof(PetscScalar)));
   }
   PetscFunctionReturn(0);
 }
@@ -197,23 +185,19 @@ PETSC_STATIC_INLINE PetscErrorCode BV_AllocateCoeffs(BV bv)
 /*
   BV_AllocateSignature - Allocate signature coefficients if not done already.
 */
-PETSC_STATIC_INLINE PetscErrorCode BV_AllocateSignature(BV bv)
+static inline PetscErrorCode BV_AllocateSignature(BV bv)
 {
-  PetscErrorCode ierr;
-
   PetscFunctionBegin;
   if (bv->indef && !bv->omega) {
     if (bv->cuda) {
 #if defined(PETSC_HAVE_CUDA)
-      ierr = VecCreateSeqCUDA(PETSC_COMM_SELF,bv->nc+bv->m,&bv->omega);CHKERRQ(ierr);
+      PetscCall(VecCreateSeqCUDA(PETSC_COMM_SELF,bv->nc+bv->m,&bv->omega));
 #else
-      SETERRQ(PetscObjectComm((PetscObject)bv),1,"Something wrong happened");
+      SETERRQ(PetscObjectComm((PetscObject)bv),PETSC_ERR_PLIB,"Something wrong happened");
 #endif
-    } else {
-      ierr = VecCreateSeq(PETSC_COMM_SELF,bv->nc+bv->m,&bv->omega);CHKERRQ(ierr);
-    }
-    ierr = PetscLogObjectParent((PetscObject)bv,(PetscObject)bv->omega);CHKERRQ(ierr);
-    ierr = VecSet(bv->omega,1.0);CHKERRQ(ierr);
+    } else PetscCall(VecCreateSeq(PETSC_COMM_SELF,bv->nc+bv->m,&bv->omega));
+    PetscCall(PetscLogObjectParent((PetscObject)bv,(PetscObject)bv->omega));
+    PetscCall(VecSet(bv->omega,1.0));
   }
   PetscFunctionReturn(0);
 }
@@ -236,12 +220,12 @@ PETSC_STATIC_INLINE PetscErrorCode BV_AllocateSignature(BV bv)
 
 #define BVCheckSizes(h,arg) \
   do { \
-    if (!(h)->m) SETERRQ1(PetscObjectComm((PetscObject)(h)),PETSC_ERR_ARG_WRONGSTATE,"BV sizes have not been defined: Parameter #%d",arg); \
+    PetscCheck((h)->m,PetscObjectComm((PetscObject)(h)),PETSC_ERR_ARG_WRONGSTATE,"BV sizes have not been defined: Parameter #%d",arg); \
   } while (0)
 
 #define BVCheckOp(h,arg,op) \
   do { \
-    if (!(h)->ops->op) SETERRQ1(PetscObjectComm((PetscObject)(h)),PETSC_ERR_SUP,"Operation not implemented in this BV type: Parameter #%d",arg); \
+    PetscCheck((h)->ops->op,PetscObjectComm((PetscObject)(h)),PETSC_ERR_SUP,"Operation not implemented in this BV type: Parameter #%d",arg); \
   } while (0)
 
 #endif
@@ -274,19 +258,18 @@ SLEPC_EXTERN void MPIAPI SlepcPythag(void*,void*,PetscMPIInt*,MPI_Datatype*);
 /*
    BV_CleanCoefficients_Default - Sets to zero all entries of column j of the bv buffer
 */
-PETSC_STATIC_INLINE PetscErrorCode BV_CleanCoefficients_Default(BV bv,PetscInt j,PetscScalar *h)
+static inline PetscErrorCode BV_CleanCoefficients_Default(BV bv,PetscInt j,PetscScalar *h)
 {
-  PetscErrorCode ierr;
   PetscScalar    *hh=h,*a;
   PetscInt       i;
 
   PetscFunctionBegin;
   if (!h) {
-    ierr = VecGetArray(bv->buffer,&a);CHKERRQ(ierr);
+    PetscCall(VecGetArray(bv->buffer,&a));
     hh = a + j*(bv->nc+bv->m);
   }
   for (i=0;i<bv->nc+j;i++) hh[i] = 0.0;
-  if (!h) { ierr = VecRestoreArray(bv->buffer,&a);CHKERRQ(ierr); }
+  if (!h) PetscCall(VecRestoreArray(bv->buffer,&a));
   PetscFunctionReturn(0);
 }
 
@@ -294,20 +277,19 @@ PETSC_STATIC_INLINE PetscErrorCode BV_CleanCoefficients_Default(BV bv,PetscInt j
    BV_AddCoefficients_Default - Add the contents of the scratch (0-th column) of the bv buffer
    into column j of the bv buffer
 */
-PETSC_STATIC_INLINE PetscErrorCode BV_AddCoefficients_Default(BV bv,PetscInt j,PetscScalar *h,PetscScalar *c)
+static inline PetscErrorCode BV_AddCoefficients_Default(BV bv,PetscInt j,PetscScalar *h,PetscScalar *c)
 {
-  PetscErrorCode ierr;
   PetscScalar    *hh=h,*cc=c;
   PetscInt       i;
 
   PetscFunctionBegin;
   if (!h) {
-    ierr = VecGetArray(bv->buffer,&cc);CHKERRQ(ierr);
+    PetscCall(VecGetArray(bv->buffer,&cc));
     hh = cc + j*(bv->nc+bv->m);
   }
   for (i=0;i<bv->nc+j;i++) hh[i] += cc[i];
-  if (!h) { ierr = VecRestoreArray(bv->buffer,&cc);CHKERRQ(ierr); }
-  ierr = PetscLogFlops(1.0*(bv->nc+j));CHKERRQ(ierr);
+  if (!h) PetscCall(VecRestoreArray(bv->buffer,&cc));
+  PetscCall(PetscLogFlops(1.0*(bv->nc+j)));
   PetscFunctionReturn(0);
 }
 
@@ -315,18 +297,17 @@ PETSC_STATIC_INLINE PetscErrorCode BV_AddCoefficients_Default(BV bv,PetscInt j,P
    BV_SetValue_Default - Sets value in row j (counted after the constraints) of column k
    of the coefficients array
 */
-PETSC_STATIC_INLINE PetscErrorCode BV_SetValue_Default(BV bv,PetscInt j,PetscInt k,PetscScalar *h,PetscScalar value)
+static inline PetscErrorCode BV_SetValue_Default(BV bv,PetscInt j,PetscInt k,PetscScalar *h,PetscScalar value)
 {
-  PetscErrorCode ierr;
   PetscScalar    *hh=h,*a;
 
   PetscFunctionBegin;
   if (!h) {
-    ierr = VecGetArray(bv->buffer,&a);CHKERRQ(ierr);
+    PetscCall(VecGetArray(bv->buffer,&a));
     hh = a + k*(bv->nc+bv->m);
   }
   hh[bv->nc+j] = value;
-  if (!h) { ierr = VecRestoreArray(bv->buffer,&a);CHKERRQ(ierr); }
+  if (!h) PetscCall(VecRestoreArray(bv->buffer,&a));
   PetscFunctionReturn(0);
 }
 
@@ -334,18 +315,17 @@ PETSC_STATIC_INLINE PetscErrorCode BV_SetValue_Default(BV bv,PetscInt j,PetscInt
    BV_SquareSum_Default - Returns the value h'*h, where h represents the contents of the
    coefficients array (up to position j)
 */
-PETSC_STATIC_INLINE PetscErrorCode BV_SquareSum_Default(BV bv,PetscInt j,PetscScalar *h,PetscReal *sum)
+static inline PetscErrorCode BV_SquareSum_Default(BV bv,PetscInt j,PetscScalar *h,PetscReal *sum)
 {
-  PetscErrorCode ierr;
   PetscScalar    *hh=h;
   PetscInt       i;
 
   PetscFunctionBegin;
   *sum = 0.0;
-  if (!h) { ierr = VecGetArray(bv->buffer,&hh);CHKERRQ(ierr); }
+  if (!h) PetscCall(VecGetArray(bv->buffer,&hh));
   for (i=0;i<bv->nc+j;i++) *sum += PetscRealPart(hh[i]*PetscConj(hh[i]));
-  if (!h) { ierr = VecRestoreArray(bv->buffer,&hh);CHKERRQ(ierr); }
-  ierr = PetscLogFlops(2.0*(bv->nc+j));CHKERRQ(ierr);
+  if (!h) PetscCall(VecRestoreArray(bv->buffer,&hh));
+  PetscCall(PetscLogFlops(2.0*(bv->nc+j)));
   PetscFunctionReturn(0);
 }
 
@@ -354,22 +334,21 @@ PETSC_STATIC_INLINE PetscErrorCode BV_SquareSum_Default(BV bv,PetscInt j,PetscSc
    the contents of the coefficients array (up to position j) and omega is the signature;
    if inverse=TRUE then the operation is h/omega
 */
-PETSC_STATIC_INLINE PetscErrorCode BV_ApplySignature_Default(BV bv,PetscInt j,PetscScalar *h,PetscBool inverse)
+static inline PetscErrorCode BV_ApplySignature_Default(BV bv,PetscInt j,PetscScalar *h,PetscBool inverse)
 {
-  PetscErrorCode    ierr;
   PetscScalar       *hh=h;
   PetscInt          i;
   const PetscScalar *omega;
 
   PetscFunctionBegin;
-  if (!(bv->nc+j)) PetscFunctionReturn(0);
-  if (!h) { ierr = VecGetArray(bv->buffer,&hh);CHKERRQ(ierr); }
-  ierr = VecGetArrayRead(bv->omega,&omega);CHKERRQ(ierr);
+  if (PetscUnlikely(!(bv->nc+j))) PetscFunctionReturn(0);
+  if (!h) PetscCall(VecGetArray(bv->buffer,&hh));
+  PetscCall(VecGetArrayRead(bv->omega,&omega));
   if (inverse) for (i=0;i<bv->nc+j;i++) hh[i] /= PetscRealPart(omega[i]);
   else for (i=0;i<bv->nc+j;i++) hh[i] *= PetscRealPart(omega[i]);
-  ierr = VecRestoreArrayRead(bv->omega,&omega);CHKERRQ(ierr);
-  if (!h) { ierr = VecRestoreArray(bv->buffer,&hh);CHKERRQ(ierr); }
-  ierr = PetscLogFlops(1.0*(bv->nc+j));CHKERRQ(ierr);
+  PetscCall(VecRestoreArrayRead(bv->omega,&omega));
+  if (!h) PetscCall(VecRestoreArray(bv->buffer,&hh));
+  PetscCall(PetscLogFlops(1.0*(bv->nc+j)));
   PetscFunctionReturn(0);
 }
 
@@ -377,15 +356,14 @@ PETSC_STATIC_INLINE PetscErrorCode BV_ApplySignature_Default(BV bv,PetscInt j,Pe
    BV_SquareRoot_Default - Returns the square root of position j (counted after the constraints)
    of the coefficients array
 */
-PETSC_STATIC_INLINE PetscErrorCode BV_SquareRoot_Default(BV bv,PetscInt j,PetscScalar *h,PetscReal *beta)
+static inline PetscErrorCode BV_SquareRoot_Default(BV bv,PetscInt j,PetscScalar *h,PetscReal *beta)
 {
-  PetscErrorCode ierr;
   PetscScalar    *hh=h;
 
   PetscFunctionBegin;
-  if (!h) { ierr = VecGetArray(bv->buffer,&hh);CHKERRQ(ierr); }
-  ierr = BV_SafeSqrt(bv,hh[bv->nc+j],beta);CHKERRQ(ierr);
-  if (!h) { ierr = VecRestoreArray(bv->buffer,&hh);CHKERRQ(ierr); }
+  if (!h) PetscCall(VecGetArray(bv->buffer,&hh));
+  PetscCall(BV_SafeSqrt(bv,hh[bv->nc+j],beta));
+  if (!h) PetscCall(VecRestoreArray(bv->buffer,&hh));
   PetscFunctionReturn(0);
 }
 
@@ -393,19 +371,18 @@ PETSC_STATIC_INLINE PetscErrorCode BV_SquareRoot_Default(BV bv,PetscInt j,PetscS
    BV_StoreCoefficients_Default - Copy the contents of the coefficients array to an array dest
    provided by the caller (only values from l to j are copied)
 */
-PETSC_STATIC_INLINE PetscErrorCode BV_StoreCoefficients_Default(BV bv,PetscInt j,PetscScalar *h,PetscScalar *dest)
+static inline PetscErrorCode BV_StoreCoefficients_Default(BV bv,PetscInt j,PetscScalar *h,PetscScalar *dest)
 {
-  PetscErrorCode ierr;
   PetscScalar    *hh=h,*a;
   PetscInt       i;
 
   PetscFunctionBegin;
   if (!h) {
-    ierr = VecGetArray(bv->buffer,&a);CHKERRQ(ierr);
+    PetscCall(VecGetArray(bv->buffer,&a));
     hh = a + j*(bv->nc+bv->m);
   }
   for (i=bv->l;i<j;i++) dest[i-bv->l] = hh[bv->nc+i];
-  if (!h) { ierr = VecRestoreArray(bv->buffer,&a);CHKERRQ(ierr); }
+  if (!h) PetscCall(VecRestoreArray(bv->buffer,&a));
   PetscFunctionReturn(0);
 }
 
@@ -413,27 +390,25 @@ PETSC_STATIC_INLINE PetscErrorCode BV_StoreCoefficients_Default(BV bv,PetscInt j
   BV_GetEigenvector - retrieves k-th eigenvector from basis vectors V.
   The argument eigi is the imaginary part of the corresponding eigenvalue.
 */
-PETSC_STATIC_INLINE PetscErrorCode BV_GetEigenvector(BV V,PetscInt k,PetscScalar eigi,Vec Vr,Vec Vi)
+static inline PetscErrorCode BV_GetEigenvector(BV V,PetscInt k,PetscScalar eigi,Vec Vr,Vec Vi)
 {
-  PetscErrorCode ierr;
-
   PetscFunctionBegin;
 #if defined(PETSC_USE_COMPLEX)
-  if (Vr) { ierr = BVCopyVec(V,k,Vr);CHKERRQ(ierr); }
-  if (Vi) { ierr = VecSet(Vi,0.0);CHKERRQ(ierr); }
+  if (Vr) PetscCall(BVCopyVec(V,k,Vr));
+  if (Vi) PetscCall(VecSet(Vi,0.0));
 #else
   if (eigi > 0.0) { /* first value of conjugate pair */
-    if (Vr) { ierr = BVCopyVec(V,k,Vr);CHKERRQ(ierr); }
-    if (Vi) { ierr = BVCopyVec(V,k+1,Vi);CHKERRQ(ierr); }
+    if (Vr) PetscCall(BVCopyVec(V,k,Vr));
+    if (Vi) PetscCall(BVCopyVec(V,k+1,Vi));
   } else if (eigi < 0.0) { /* second value of conjugate pair */
-    if (Vr) { ierr = BVCopyVec(V,k-1,Vr);CHKERRQ(ierr); }
+    if (Vr) PetscCall(BVCopyVec(V,k-1,Vr));
     if (Vi) {
-      ierr = BVCopyVec(V,k,Vi);CHKERRQ(ierr);
-      ierr = VecScale(Vi,-1.0);CHKERRQ(ierr);
+      PetscCall(BVCopyVec(V,k,Vi));
+      PetscCall(VecScale(Vi,-1.0));
     }
   } else { /* real eigenvalue */
-    if (Vr) { ierr = BVCopyVec(V,k,Vr);CHKERRQ(ierr); }
-    if (Vi) { ierr = VecSet(Vi,0.0);CHKERRQ(ierr); }
+    if (Vr) PetscCall(BVCopyVec(V,k,Vr));
+    if (Vi) PetscCall(VecSet(Vi,0.0));
   }
 #endif
   PetscFunctionReturn(0);
@@ -445,16 +420,15 @@ PETSC_STATIC_INLINE PetscErrorCode BV_GetEigenvector(BV V,PetscInt k,PetscScalar
    iterative refinement may cause problems in parallel (collective operation
    not being called by all processes)
 */
-PETSC_STATIC_INLINE PetscErrorCode BV_OrthogonalizeColumn_Safe(BV bv,PetscInt j,PetscScalar *H,PetscReal *norm,PetscBool *lindep)
+static inline PetscErrorCode BV_OrthogonalizeColumn_Safe(BV bv,PetscInt j,PetscScalar *H,PetscReal *norm,PetscBool *lindep)
 {
-  PetscErrorCode     ierr;
   BVOrthogRefineType orthog_ref;
 
   PetscFunctionBegin;
-  ierr = PetscInfo1(bv,"Orthogonalizing column %D without refinement\n",j);CHKERRQ(ierr);
+  PetscCall(PetscInfo(bv,"Orthogonalizing column %" PetscInt_FMT " without refinement\n",j));
   orthog_ref     = bv->orthog_ref;
   bv->orthog_ref = BV_ORTHOG_REFINE_NEVER;  /* avoid refinement */
-  ierr = BVOrthogonalizeColumn(bv,j,H,NULL,NULL);CHKERRQ(ierr);
+  PetscCall(BVOrthogonalizeColumn(bv,j,H,NULL,NULL));
   bv->orthog_ref = orthog_ref;  /* restore refinement setting */
   if (norm)   *norm  = 0.0;
   if (lindep) *lindep = PETSC_TRUE;
