@@ -1,7 +1,7 @@
 /*
    - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
    SLEPc - Scalable Library for Eigenvalue Problem Computations
-   Copyright (c) 2002-2021, Universitat Politecnica de Valencia, Spain
+   Copyright (c) 2002-, Universitat Politecnica de Valencia, Spain
 
    This file is part of SLEPc.
    SLEPc is distributed under a 2-clause BSD license (see LICENSE).
@@ -52,9 +52,8 @@ struct _n_SlepcConvMon {
 /*
   SlepcPrintEigenvalueASCII - Print an eigenvalue on an ASCII viewer.
 */
-PETSC_STATIC_INLINE PetscErrorCode SlepcPrintEigenvalueASCII(PetscViewer viewer,PetscScalar eigr,PetscScalar eigi)
+static inline PetscErrorCode SlepcPrintEigenvalueASCII(PetscViewer viewer,PetscScalar eigr,PetscScalar eigi)
 {
-  PetscErrorCode ierr;
   PetscReal      re,im;
 
   PetscFunctionBegin;
@@ -69,11 +68,8 @@ PETSC_STATIC_INLINE PetscErrorCode SlepcPrintEigenvalueASCII(PetscViewer viewer,
   if (PetscAbs(im) && PetscAbs(re)/PetscAbs(im)<PETSC_SMALL) re = 0.0;
   if (PetscAbs(re) && PetscAbs(im)/PetscAbs(re)<PETSC_SMALL) im = 0.0;
   /* print as real if imaginary part is zero */
-  if (im!=0.0) {
-    ierr = PetscViewerASCIIPrintf(viewer,"%.5f%+.5fi",(double)re,(double)im);CHKERRQ(ierr);
-  } else {
-    ierr = PetscViewerASCIIPrintf(viewer,"%.5f",(double)re);CHKERRQ(ierr);
-  }
+  if (im!=0.0) PetscCall(PetscViewerASCIIPrintf(viewer,"%.5f%+.5fi",(double)re,(double)im));
+  else PetscCall(PetscViewerASCIIPrintf(viewer,"%.5f",(double)re));
   PetscFunctionReturn(0);
 }
 
@@ -82,24 +78,23 @@ PETSC_STATIC_INLINE PetscErrorCode SlepcPrintEigenvalueASCII(PetscViewer viewer,
   In complex scalars only xr is written.
   The name of xr,xi is set before writing, based on the label, the index, and the name of obj.
 */
-PETSC_STATIC_INLINE PetscErrorCode SlepcViewEigenvector(PetscViewer viewer,Vec xr,Vec xi,const char *label,PetscInt index,PetscObject obj)
+static inline PetscErrorCode SlepcViewEigenvector(PetscViewer viewer,Vec xr,Vec xi,const char *label,PetscInt index,PetscObject obj)
 {
-  PetscErrorCode ierr;
   size_t         count;
   char           vname[30];
   const char     *pname;
 
   PetscFunctionBegin;
-  ierr = PetscObjectGetName(obj,&pname);CHKERRQ(ierr);
-  ierr = PetscSNPrintfCount(vname,sizeof(vname),"%s%s",&count,label,PetscDefined(USE_COMPLEX)?"":"r");CHKERRQ(ierr);
+  PetscCall(PetscObjectGetName(obj,&pname));
+  PetscCall(PetscSNPrintfCount(vname,sizeof(vname),"%s%s",&count,label,PetscDefined(USE_COMPLEX)?"":"r"));
   count--;
-  ierr = PetscSNPrintf(vname+count,sizeof(vname)-count,"%d_%s",(int)index,pname);CHKERRQ(ierr);
-  ierr = PetscObjectSetName((PetscObject)xr,vname);CHKERRQ(ierr);
-  ierr = VecView(xr,viewer);CHKERRQ(ierr);
+  PetscCall(PetscSNPrintf(vname+count,sizeof(vname)-count,"%" PetscInt_FMT "_%s",index,pname));
+  PetscCall(PetscObjectSetName((PetscObject)xr,vname));
+  PetscCall(VecView(xr,viewer));
 #if !defined(PETSC_USE_COMPLEX)
   vname[count-1] = 'i';
-  ierr = PetscObjectSetName((PetscObject)xi,vname);CHKERRQ(ierr);
-  ierr = VecView(xi,viewer);CHKERRQ(ierr);
+  PetscCall(PetscObjectSetName((PetscObject)xi,vname));
+  PetscCall(VecView(xi,viewer));
 #endif
   PetscFunctionReturn(0);
 }
