@@ -1,7 +1,7 @@
 /*
    - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
    SLEPc - Scalable Library for Eigenvalue Problem Computations
-   Copyright (c) 2002-2021, Universitat Politecnica de Valencia, Spain
+   Copyright (c) 2002-, Universitat Politecnica de Valencia, Spain
 
    This file is part of SLEPc.
    SLEPc is distributed under a 2-clause BSD license (see LICENSE).
@@ -58,6 +58,10 @@ struct _p_ST {
   PetscBool        transform;        /* whether transformed matrices are computed */
   Vec              D;                /* diagonal matrix for balancing */
   Mat              Pmat;             /* user-provided preconditioner matrix */
+  PetscBool        Pmat_set;         /* whether the user provided a preconditioner matrix or not  */
+  Mat              *Psplit;          /* matrices for the split preconditioner */
+  PetscInt         nsplit;           /* number of split preconditioner matrices */
+  MatStructure     strp;             /* pattern of split preconditioner matrices */
 
   /*------------------------- Misc data --------------------------*/
   KSP              ksp;              /* linear solver used in some ST's */
@@ -92,11 +96,11 @@ struct _p_ST {
 
 #define STCheckMatrices(h,arg) \
   do { \
-    if (!(h)->A) SETERRQ1(PetscObjectComm((PetscObject)(h)),PETSC_ERR_ARG_WRONGSTATE,"ST matrices have not been set: Parameter #%d",arg); \
+    PetscCheck((h)->A,PetscObjectComm((PetscObject)(h)),PETSC_ERR_ARG_WRONGSTATE,"ST matrices have not been set: Parameter #%d",arg); \
   } while (0)
 #define STCheckNotSeized(h,arg) \
   do { \
-    if (h->opseized) SETERRQ1(PetscObjectComm((PetscObject)h),PETSC_ERR_ARG_WRONGSTATE,"Must call STRestoreOperator() first: Parameter #%d",arg); \
+    PetscCheck(!(h)->opseized,PetscObjectComm((PetscObject)(h)),PETSC_ERR_ARG_WRONGSTATE,"Must call STRestoreOperator() first: Parameter #%d",arg); \
   } while (0)
 
 #endif
@@ -106,7 +110,7 @@ SLEPC_INTERN PetscErrorCode STCheckNullSpace_Default(ST,BV);
 SLEPC_INTERN PetscErrorCode STMatShellCreate(ST,PetscScalar,PetscInt,PetscInt*,PetscScalar*,Mat*);
 SLEPC_INTERN PetscErrorCode STMatShellShift(Mat,PetscScalar);
 SLEPC_INTERN PetscErrorCode STCheckFactorPackage(ST);
-SLEPC_INTERN PetscErrorCode STMatMAXPY_Private(ST,PetscScalar,PetscScalar,PetscInt,PetscScalar*,PetscBool,Mat*);
+SLEPC_INTERN PetscErrorCode STMatMAXPY_Private(ST,PetscScalar,PetscScalar,PetscInt,PetscScalar*,PetscBool,PetscBool,Mat*);
 SLEPC_INTERN PetscErrorCode STCoeffs_Monomial(ST,PetscScalar*);
 SLEPC_INTERN PetscErrorCode STSetDefaultKSP(ST);
 SLEPC_INTERN PetscErrorCode STSetDefaultKSP_Default(ST);
@@ -118,23 +122,22 @@ SLEPC_INTERN PetscErrorCode STApplyMat_Generic(ST,Mat,Mat);
 SLEPC_INTERN PetscErrorCode STApplyTranspose_Generic(ST,Vec,Vec);
 
 /*
-  STKSPSetOperators - Sets the KSP matrices
+  ST_KSPSetOperators - Sets the KSP matrices
 */
-PETSC_STATIC_INLINE PetscErrorCode STKSPSetOperators(ST st,Mat A,Mat B)
+static inline PetscErrorCode ST_KSPSetOperators(ST st,Mat A,Mat B)
 {
-  PetscErrorCode ierr;
   const char     *prefix;
 
   PetscFunctionBegin;
-  if (!st->ksp) { ierr = STGetKSP(st,&st->ksp);CHKERRQ(ierr); }
-  ierr = STCheckFactorPackage(st);CHKERRQ(ierr);
-  ierr = KSPSetOperators(st->ksp,A,B);CHKERRQ(ierr);
-  ierr = MatGetOptionsPrefix(B,&prefix);CHKERRQ(ierr);
+  if (!st->ksp) PetscCall(STGetKSP(st,&st->ksp));
+  PetscCall(STCheckFactorPackage(st));
+  PetscCall(KSPSetOperators(st->ksp,A,B));
+  PetscCall(MatGetOptionsPrefix(B,&prefix));
   if (!prefix) {
     /* set Mat prefix to be the same as KSP to enable setting command-line options (e.g. MUMPS)
        only applies if the Mat has no user-defined prefix */
-    ierr = KSPGetOptionsPrefix(st->ksp,&prefix);CHKERRQ(ierr);
-    ierr = MatSetOptionsPrefix(B,prefix);CHKERRQ(ierr);
+    PetscCall(KSPGetOptionsPrefix(st->ksp,&prefix));
+    PetscCall(MatSetOptionsPrefix(B,prefix));
   }
   PetscFunctionReturn(0);
 }
