@@ -1,7 +1,7 @@
 /*
    - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
    SLEPc - Scalable Library for Eigenvalue Problem Computations
-   Copyright (c) 2002-2021, Universitat Politecnica de Valencia, Spain
+   Copyright (c) 2002-, Universitat Politecnica de Valencia, Spain
 
    This file is part of SLEPc.
    SLEPc is distributed under a 2-clause BSD license (see LICENSE).
@@ -122,7 +122,7 @@ struct _p_SVD {
 
 #define SVDCheckSolved(h,arg) \
   do { \
-    if ((h)->state<SVD_STATE_SOLVED) SETERRQ1(PetscObjectComm((PetscObject)(h)),PETSC_ERR_ARG_WRONGSTATE,"Must call SVDSolve() first: Parameter #%d",arg); \
+    PetscCheck((h)->state>=SVD_STATE_SOLVED,PetscObjectComm((PetscObject)(h)),PETSC_ERR_ARG_WRONGSTATE,"Must call SVDSolve() first: Parameter #%d",arg); \
   } while (0)
 
 #endif
@@ -135,7 +135,7 @@ struct _p_SVD {
 #define SVDCheckStandardCondition(svd,condition,msg) \
   do { \
     if (condition) { \
-      if ((svd)->isgeneralized) SETERRQ2(PetscObjectComm((PetscObject)(svd)),PETSC_ERR_SUP,"The solver '%s'%s cannot be used for generalized problems",((PetscObject)(svd))->type_name,(msg)); \
+      PetscCheck(!(svd)->isgeneralized,PetscObjectComm((PetscObject)(svd)),PETSC_ERR_SUP,"The solver '%s'%s cannot be used for generalized problems",((PetscObject)(svd))->type_name,(msg)); \
     } \
   } while (0)
 #define SVDCheckStandard(svd) SVDCheckStandardCondition(svd,PETSC_TRUE,"")
@@ -144,8 +144,8 @@ struct _p_SVD {
 #define SVDCheckUnsupportedCondition(svd,mask,condition,msg) \
   do { \
     if (condition) { \
-      if (((mask) & SVD_FEATURE_CONVERGENCE) && (svd)->converged!=SVDConvergedRelative) SETERRQ2(PetscObjectComm((PetscObject)(svd)),PETSC_ERR_SUP,"The solver '%s'%s only supports the default convergence test",((PetscObject)(svd))->type_name,(msg)); \
-      if (((mask) & SVD_FEATURE_STOPPING) && (svd)->stopping!=SVDStoppingBasic) SETERRQ2(PetscObjectComm((PetscObject)(svd)),PETSC_ERR_SUP,"The solver '%s'%s only supports the default stopping test",((PetscObject)(svd))->type_name,(msg)); \
+      PetscCheck(!((mask) & SVD_FEATURE_CONVERGENCE) || (svd)->converged==SVDConvergedRelative,PetscObjectComm((PetscObject)(svd)),PETSC_ERR_SUP,"The solver '%s'%s only supports the default convergence test",((PetscObject)(svd))->type_name,(msg)); \
+      PetscCheck(!((mask) & SVD_FEATURE_STOPPING) || (svd)->stopping==SVDStoppingBasic,PetscObjectComm((PetscObject)(svd)),PETSC_ERR_SUP,"The solver '%s'%s only supports the default stopping test",((PetscObject)(svd))->type_name,(msg)); \
     } \
   } while (0)
 #define SVDCheckUnsupported(svd,mask) SVDCheckUnsupportedCondition(svd,mask,PETSC_TRUE,"")
@@ -153,43 +153,60 @@ struct _p_SVD {
 /* Check for ignored features */
 #define SVDCheckIgnoredCondition(svd,mask,condition,msg) \
   do { \
-    PetscErrorCode __ierr; \
     if (condition) { \
-      if (((mask) & SVD_FEATURE_CONVERGENCE) && (svd)->converged!=SVDConvergedRelative) { __ierr = PetscInfo2((svd),"The solver '%s'%s ignores the convergence test settings\n",((PetscObject)(svd))->type_name,(msg)); } \
-      if (((mask) & SVD_FEATURE_STOPPING) && (svd)->stopping!=SVDStoppingBasic) { __ierr = PetscInfo2((svd),"The solver '%s'%s ignores the stopping test settings\n",((PetscObject)(svd))->type_name,(msg)); } \
+      if (((mask) & SVD_FEATURE_CONVERGENCE) && (svd)->converged!=SVDConvergedRelative) PetscCall(PetscInfo((svd),"The solver '%s'%s ignores the convergence test settings\n",((PetscObject)(svd))->type_name,(msg))); \
+      if (((mask) & SVD_FEATURE_STOPPING) && (svd)->stopping!=SVDStoppingBasic) PetscCall(PetscInfo((svd),"The solver '%s'%s ignores the stopping test settings\n",((PetscObject)(svd))->type_name,(msg))); \
     } \
   } while (0)
 #define SVDCheckIgnored(svd,mask) SVDCheckIgnoredCondition(svd,mask,PETSC_TRUE,"")
 
+/*
+  SVD_KSPSetOperators - Sets the KSP matrices
+*/
+static inline PetscErrorCode SVD_KSPSetOperators(KSP ksp,Mat A,Mat B)
+{
+  const char     *prefix;
+
+  PetscFunctionBegin;
+  PetscCall(KSPSetOperators(ksp,A,B));
+  PetscCall(MatGetOptionsPrefix(B,&prefix));
+  if (!prefix) {
+    /* set Mat prefix to be the same as KSP to enable setting command-line options (e.g. MUMPS)
+       only applies if the Mat has no user-defined prefix */
+    PetscCall(KSPGetOptionsPrefix(ksp,&prefix));
+    PetscCall(MatSetOptionsPrefix(B,prefix));
+  }
+  PetscFunctionReturn(0);
+}
+
 /*
    Create the template vector for the left basis in GSVD, as in
    MatCreateVecsEmpty(Z,NULL,&t) for Z=[A;B] without forming Z.
  */
-PETSC_STATIC_INLINE PetscErrorCode SVDCreateLeftTemplate(SVD svd,Vec *t)
+static inline PetscErrorCode SVDCreateLeftTemplate(SVD svd,Vec *t)
 {
-  PetscErrorCode ierr;
   PetscInt       M,P,m,p;
   Vec            v1,v2;
   VecType        vec_type;
 
   PetscFunctionBegin;
-  ierr = MatCreateVecsEmpty(svd->OP,NULL,&v1);CHKERRQ(ierr);
-  ierr = VecGetSize(v1,&M);CHKERRQ(ierr);
-  ierr = VecGetLocalSize(v1,&m);CHKERRQ(ierr);
-  ierr = VecGetType(v1,&vec_type);CHKERRQ(ierr);
-  ierr = MatCreateVecsEmpty(svd->OPb,NULL,&v2);CHKERRQ(ierr);
-  ierr = VecGetSize(v2,&P);CHKERRQ(ierr);
-  ierr = VecGetLocalSize(v2,&p);CHKERRQ(ierr);
-  ierr = VecCreate(PetscObjectComm((PetscObject)(v1)),t);CHKERRQ(ierr);
-  ierr = VecSetType(*t,vec_type);CHKERRQ(ierr);
-  ierr = VecSetSizes(*t,m+p,M+P);CHKERRQ(ierr);
-  ierr = VecSetUp(*t);CHKERRQ(ierr);
-  ierr = VecDestroy(&v1);CHKERRQ(ierr);
-  ierr = VecDestroy(&v2);CHKERRQ(ierr);
+  PetscCall(MatCreateVecsEmpty(svd->OP,NULL,&v1));
+  PetscCall(VecGetSize(v1,&M));
+  PetscCall(VecGetLocalSize(v1,&m));
+  PetscCall(VecGetType(v1,&vec_type));
+  PetscCall(MatCreateVecsEmpty(svd->OPb,NULL,&v2));
+  PetscCall(VecGetSize(v2,&P));
+  PetscCall(VecGetLocalSize(v2,&p));
+  PetscCall(VecCreate(PetscObjectComm((PetscObject)(v1)),t));
+  PetscCall(VecSetType(*t,vec_type));
+  PetscCall(VecSetSizes(*t,m+p,M+P));
+  PetscCall(VecSetUp(*t));
+  PetscCall(VecDestroy(&v1));
+  PetscCall(VecDestroy(&v2));
   PetscFunctionReturn(0);
 }
 
-SLEPC_INTERN PetscErrorCode SVDKrylovConvergence(SVD,PetscBool,PetscInt,PetscInt,PetscInt*);
+SLEPC_INTERN PetscErrorCode SVDKrylovConvergence(SVD,PetscBool,PetscInt,PetscInt,PetscReal,PetscInt*);
 SLEPC_INTERN PetscErrorCode SVDTwoSideLanczos(SVD,PetscReal*,PetscReal*,BV,BV,PetscInt,PetscInt*,PetscBool*);
 SLEPC_INTERN PetscErrorCode SVDSetDimensions_Default(SVD);
 SLEPC_INTERN PetscErrorCode SVDComputeVectors(SVD);
