@@ -1,7 +1,7 @@
 /*
    - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
    SLEPc - Scalable Library for Eigenvalue Problem Computations
-   Copyright (c) 2002-2021, Universitat Politecnica de Valencia, Spain
+   Copyright (c) 2002-, Universitat Politecnica de Valencia, Spain
 
    This file is part of SLEPc.
    SLEPc is distributed under a 2-clause BSD license (see LICENSE).
@@ -154,7 +154,8 @@ SLEPC_EXTERN PetscErrorCode BVMult(BV,PetscScalar,PetscScalar,BV,Mat);
 SLEPC_EXTERN PetscErrorCode BVMultVec(BV,PetscScalar,PetscScalar,Vec,PetscScalar*);
 SLEPC_EXTERN PetscErrorCode BVMultColumn(BV,PetscScalar,PetscScalar,PetscInt,PetscScalar*);
 SLEPC_EXTERN PetscErrorCode BVMultInPlace(BV,Mat,PetscInt,PetscInt);
-SLEPC_EXTERN PetscErrorCode BVMultInPlaceTranspose(BV,Mat,PetscInt,PetscInt);
+SLEPC_EXTERN PetscErrorCode BVMultInPlaceHermitianTranspose(BV,Mat,PetscInt,PetscInt);
+PETSC_DEPRECATED_FUNCTION("Use BVMultInPlaceHermitianTranspose()") static inline PetscErrorCode BVMultInPlaceTranspose(BV bv,Mat A,PetscInt s,PetscInt e) {return BVMultInPlaceHermitianTranspose(bv,A,s,e);}
 SLEPC_EXTERN PetscErrorCode BVMatMult(BV,Mat,BV);
 SLEPC_EXTERN PetscErrorCode BVMatMultTranspose(BV,Mat,BV);
 SLEPC_EXTERN PetscErrorCode BVMatMultHermitianTranspose(BV,Mat,BV);
@@ -162,7 +163,7 @@ SLEPC_EXTERN PetscErrorCode BVMatMultColumn(BV,Mat,PetscInt);
 SLEPC_EXTERN PetscErrorCode BVMatMultTransposeColumn(BV,Mat,PetscInt);
 SLEPC_EXTERN PetscErrorCode BVMatMultHermitianTransposeColumn(BV,Mat,PetscInt);
 SLEPC_EXTERN PetscErrorCode BVMatProject(BV,Mat,BV,Mat);
-SLEPC_EXTERN PetscErrorCode BVMatArnoldi(BV,Mat,PetscScalar*,PetscInt,PetscInt,PetscInt*,PetscReal*,PetscBool*);
+SLEPC_EXTERN PetscErrorCode BVMatArnoldi(BV,Mat,Mat,PetscInt,PetscInt*,PetscReal*,PetscBool*);
 SLEPC_EXTERN PetscErrorCode BVMatLanczos(BV,Mat,PetscReal*,PetscReal*,PetscInt,PetscInt*,PetscBool*);
 
 SLEPC_EXTERN PetscErrorCode BVDot(BV,BV,Mat);
@@ -184,6 +185,7 @@ SLEPC_EXTERN PetscErrorCode BVNormColumnEnd(BV,PetscInt,NormType,PetscReal*);
 SLEPC_EXTERN PetscErrorCode BVNormalize(BV,PetscScalar*);
 SLEPC_EXTERN PetscErrorCode BVSetRandom(BV);
 SLEPC_EXTERN PetscErrorCode BVSetRandomNormal(BV);
+SLEPC_EXTERN PetscErrorCode BVSetRandomSign(BV);
 SLEPC_EXTERN PetscErrorCode BVSetRandomColumn(BV,PetscInt);
 SLEPC_EXTERN PetscErrorCode BVSetRandomCond(BV,PetscReal);
 SLEPC_EXTERN PetscErrorCode BVSetRandomContext(BV,PetscRandom);
@@ -206,6 +208,32 @@ SLEPC_EXTERN PetscErrorCode BVCreateMat(BV,Mat*);
 SLEPC_EXTERN PetscErrorCode BVGetMat(BV,Mat*);
 SLEPC_EXTERN PetscErrorCode BVRestoreMat(BV,Mat*);
 
+SLEPC_EXTERN PetscErrorCode BVScatter(BV,BV,VecScatter,Vec);
+SLEPC_EXTERN PetscErrorCode BVSumQuadrature(BV,BV,PetscInt,PetscInt,PetscInt,PetscScalar*,PetscScalar*,VecScatter,PetscSubcomm,PetscInt,PetscBool);
+SLEPC_EXTERN PetscErrorCode BVDotQuadrature(BV,BV,PetscScalar*,PetscInt,PetscInt,PetscInt,PetscScalar*,PetscScalar*,PetscSubcomm,PetscInt,PetscBool);
+SLEPC_EXTERN PetscErrorCode BVTraceQuadrature(BV,BV,PetscInt,PetscInt,PetscScalar*,VecScatter,PetscSubcomm,PetscInt,PetscBool,PetscReal*);
+
+/*E
+   BVSVDMethod - Different methods for computing the SVD of a BV
+
+   Notes:
+   Allowed values are
++  BV_SVD_METHOD_REFINE - based on the SVD of the cross product matrix S'*S, with refinement
+.  BV_SVD_METHOD_QR     - based on the SVD of the triangular factor of qr(S)
+-  BV_SVD_METHOD_QR_CAA - variant of QR intended for use in cammunication-avoiding Arnoldi
+
+   Level: developer
+
+.seealso: BVSVDAndRank()
+E*/
+typedef enum { BV_SVD_METHOD_REFINE,
+               BV_SVD_METHOD_QR,
+               BV_SVD_METHOD_QR_CAA } BVSVDMethod;
+SLEPC_EXTERN const char *BVSVDMethods[];
+
+SLEPC_EXTERN PetscErrorCode BVSVDAndRank(BV,PetscInt,PetscInt,PetscReal,BVSVDMethod,PetscScalar*,PetscReal*,PetscInt*);
+SLEPC_EXTERN PetscErrorCode BVCISSResizeBases(BV,BV,BV,PetscInt,PetscInt,PetscInt,PetscInt);
+
 SLEPC_EXTERN PetscErrorCode BVCreateTensor(BV,PetscInt,BV*);
 SLEPC_EXTERN PetscErrorCode BVTensorBuildFirstColumn(BV,PetscInt);
 SLEPC_EXTERN PetscErrorCode BVTensorCompress(BV,PetscInt);
