@@ -1,7 +1,7 @@
 /*
    - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
    SLEPc - Scalable Library for Eigenvalue Problem Computations
-   Copyright (c) 2002-2021, Universitat Politecnica de Valencia, Spain
+   Copyright (c) 2002-, Universitat Politecnica de Valencia, Spain
 
    This file is part of SLEPc.
    SLEPc is distributed under a 2-clause BSD license (see LICENSE).
@@ -13,18 +13,17 @@
 
 #define SLEPC_VERSION_RELEASE    1
 #define SLEPC_VERSION_MAJOR      3
-#define SLEPC_VERSION_MINOR      16
+#define SLEPC_VERSION_MINOR      17
 #define SLEPC_VERSION_SUBMINOR   2
-#define SLEPC_VERSION_PATCH      0
-#define SLEPC_RELEASE_DATE       "September 30, 2021"
-#define SLEPC_VERSION_DATE       "Feb 01, 2022"
+#define SLEPC_RELEASE_DATE       "March 31, 2022"
+#define SLEPC_VERSION_DATE       "Aug 09, 2022"
 
 #if !defined (SLEPC_VERSION_GIT)
-#define SLEPC_VERSION_GIT        "v3.16.2"
+#define SLEPC_VERSION_GIT        "v3.17.2"
 #endif
 
 #if !defined(SLEPC_VERSION_DATE_GIT)
-#define SLEPC_VERSION_DATE_GIT   "2022-02-01 11:25:32 +0100"
+#define SLEPC_VERSION_DATE_GIT   "2022-08-09 11:02:06 +0200"
 #endif
 
 #define SLEPC_VERSION_EQ(MAJOR,MINOR,SUBMINOR) \
