@@ -1,7 +1,7 @@
 /*
    - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
    SLEPc - Scalable Library for Eigenvalue Problem Computations
-   Copyright (c) 2002-2021, Universitat Politecnica de Valencia, Spain
+   Copyright (c) 2002-, Universitat Politecnica de Valencia, Spain
 
    This file is part of SLEPc.
    SLEPc is distributed under a 2-clause BSD license (see LICENSE).
@@ -34,7 +34,6 @@ static const char citation[] =
 
 PetscErrorCode EPSSetUp_XD(EPS eps)
 {
-  PetscErrorCode ierr;
   EPS_DAVIDSON   *data = (EPS_DAVIDSON*)eps->data;
   dvdDashboard   *dvd = &data->ddb;
   dvdBlackboard  b;
@@ -50,41 +49,44 @@ PetscErrorCode EPSSetUp_XD(EPS eps)
   /* Setup EPS options and get the problem specification */
   bs = data->blocksize;
   if (bs <= 0) bs = 1;
-  if (eps->ncv!=PETSC_DEFAULT) {
-    if (eps->ncv<eps->nev) SETERRQ(PetscObjectComm((PetscObject)eps),PETSC_ERR_SUP,"The value of ncv must be at least nev");
-  } else if (eps->mpd!=PETSC_DEFAULT) eps->ncv = eps->mpd + eps->nev + bs;
-  else if (eps->nev<500) eps->ncv = PetscMin(eps->n-bs,PetscMax(2*eps->nev,eps->nev+15))+bs;
-  else eps->ncv = PetscMin(eps->n-bs,eps->nev+500)+bs;
-  if (eps->mpd==PETSC_DEFAULT) eps->mpd = eps->ncv;
-  if (eps->mpd > eps->ncv) SETERRQ(PetscObjectComm((PetscObject)eps),PETSC_ERR_SUP,"The mpd has to be less or equal than ncv");
-  if (eps->mpd < 2) SETERRQ(PetscObjectComm((PetscObject)eps),PETSC_ERR_SUP,"The mpd has to be greater than 2");
-  if (eps->max_it==PETSC_DEFAULT) eps->max_it = PetscMax(100*eps->ncv,2*eps->n);
+  if (eps->ncv!=PETSC_DEFAULT && eps->ncv!=PETSC_DECIDE) {
+    PetscCheck(eps->ncv>=eps->nev,PetscObjectComm((PetscObject)eps),PETSC_ERR_SUP,"The value of ncv must be at least nev");
+  } else if (eps->mpd!=PETSC_DEFAULT && eps->mpd!=PETSC_DECIDE) eps->ncv = eps->mpd + eps->nev + bs;
+  else if (eps->n < 10) eps->ncv = eps->n+eps->nev+bs;
+  else if (eps->nev < 500) eps->ncv = PetscMax(eps->nev,PetscMin(eps->n-bs,PetscMax(2*eps->nev,eps->nev+15))+bs);
+  else eps->ncv = PetscMax(eps->nev,PetscMin(eps->n-bs,eps->nev+500)+bs);
+  if (eps->mpd==PETSC_DEFAULT || eps->mpd==PETSC_DECIDE) eps->mpd = PetscMin(eps->n,eps->ncv);
+  PetscCheck(eps->mpd<=eps->ncv,PetscObjectComm((PetscObject)eps),PETSC_ERR_SUP,"The mpd parameter has to be less than or equal to ncv");
+  PetscCheck(eps->mpd>=2,PetscObjectComm((PetscObject)eps),PETSC_ERR_SUP,"The mpd parameter has to be greater than 2");
+  if (eps->max_it == PETSC_DEFAULT || eps->max_it == PETSC_DECIDE) eps->max_it = PetscMax(100*eps->ncv,2*eps->n);
   if (!eps->which) eps->which = EPS_LARGEST_MAGNITUDE;
-  if (!(eps->nev + bs <= eps->ncv)) SETERRQ(PetscObjectComm((PetscObject)eps),PETSC_ERR_SUP,"The ncv has to be greater than nev plus blocksize");
-  if (eps->trueres) SETERRQ(PetscObjectComm((PetscObject)eps),PETSC_ERR_SUP,"-eps_true_residual is temporally disable in this solver.");
+  PetscCheck(eps->nev+bs<=eps->ncv,PetscObjectComm((PetscObject)eps),PETSC_ERR_SUP,"The value of ncv has to be greater than nev plus blocksize");
+  PetscCheck(!eps->trueres,PetscObjectComm((PetscObject)eps),PETSC_ERR_SUP,"-eps_true_residual is disabled in this solver.");
   EPSCheckUnsupported(eps,EPS_FEATURE_REGION | EPS_FEATURE_TWOSIDED);
 
-  ierr = EPSXDSetRestart_XD(eps,data->minv,data->plusk);CHKERRQ(ierr);
+  if (!data->minv) data->minv = (eps->n && eps->n<10)? 1: PetscMin(PetscMax(bs,6),eps->mpd/2);
   min_size_V = data->minv;
-  if (!min_size_V) min_size_V = PetscMin(PetscMax(bs,5),eps->mpd/2);
-  if (!(min_size_V+bs <= eps->mpd)) SETERRQ(PetscObjectComm((PetscObject)eps),PETSC_ERR_SUP,"The value of minv must be less than mpd minus blocksize");
+  PetscCheck(min_size_V+bs<=eps->mpd,PetscObjectComm((PetscObject)eps),PETSC_ERR_SUP,"The value of minv must be less than mpd minus blocksize");
+  if (data->plusk == PETSC_DEFAULT) {
+    if (eps->problem_type == EPS_GHIEP || eps->nev+bs>eps->ncv) data->plusk = 0;
+    else data->plusk = 1;
+  }
+  if (!data->initialsize) data->initialsize = (eps->n && eps->n<10)? 1: 6;
   initv = data->initialsize;
-  if (eps->mpd < initv) SETERRQ(PetscObjectComm((PetscObject)eps),PETSC_ERR_SUP,"The initv has to be less or equal than mpd");
+  PetscCheck(eps->mpd>=initv,PetscObjectComm((PetscObject)eps),PETSC_ERR_SUP,"The initv parameter has to be less than or equal to mpd");
 
   /* Change the default sigma to inf if necessary */
-  if (eps->which == EPS_LARGEST_MAGNITUDE || eps->which == EPS_LARGEST_REAL || eps->which == EPS_LARGEST_IMAGINARY) {
-    ierr = STSetDefaultShift(eps->st,PETSC_MAX_REAL);CHKERRQ(ierr);
-  }
+  if (eps->which == EPS_LARGEST_MAGNITUDE || eps->which == EPS_LARGEST_REAL || eps->which == EPS_LARGEST_IMAGINARY) PetscCall(STSetDefaultShift(eps->st,PETSC_MAX_REAL));
 
   /* Set up preconditioner */
-  ierr = STSetUp(eps->st);CHKERRQ(ierr);
+  PetscCall(STSetUp(eps->st));
 
   /* Setup problem specification in dvd */
-  ierr = STGetNumMatrices(eps->st,&nmat);CHKERRQ(ierr);
-  ierr = STGetMatrix(eps->st,0,&A);CHKERRQ(ierr);
-  if (nmat>1) { ierr = STGetMatrix(eps->st,1,&B);CHKERRQ(ierr); }
-  ierr = EPSReset_XD(eps);CHKERRQ(ierr);
-  ierr = PetscMemzero(dvd,sizeof(dvdDashboard));CHKERRQ(ierr);
+  PetscCall(STGetNumMatrices(eps->st,&nmat));
+  PetscCall(STGetMatrix(eps->st,0,&A));
+  if (nmat>1) PetscCall(STGetMatrix(eps->st,1,&B));
+  PetscCall(EPSReset_XD(eps));
+  PetscCall(PetscMemzero(dvd,sizeof(dvdDashboard)));
   dvd->A = A; dvd->B = eps->isgeneralized? B: NULL;
   ispositive = eps->ispositive;
   dvd->sA = DVD_MAT_IMPLICIT | (eps->ishermitian? DVD_MAT_HERMITIAN: 0) | ((ispositive && !eps->isgeneralized) ? DVD_MAT_POS_DEF: 0);
@@ -122,7 +124,7 @@ PetscErrorCode EPSSetUp_XD(EPS eps)
       dvd->target[1] = 1.0;
       break;
     case EPS_WHICH_USER:
-      ierr = STGetShift(eps->st,&target);CHKERRQ(ierr);
+      PetscCall(STGetShift(eps->st,&target));
       dvd->target[0] = target;
       dvd->target[1] = 1.0;
       break;
@@ -170,20 +172,18 @@ PetscErrorCode EPSSetUp_XD(EPS eps)
   init = data->krylovstart? DVD_INITV_KRYLOV: DVD_INITV_CLASSIC;
 
   /* Preconfigure dvd */
-  ierr = STGetKSP(eps->st,&ksp);CHKERRQ(ierr);
-  ierr = dvd_schm_basic_preconf(dvd,&b,eps->mpd,min_size_V,bs,initv,PetscAbs(eps->nini),data->plusk,harm,ksp,init,eps->trackall,data->ipB,data->doubleexp);CHKERRQ(ierr);
+  PetscCall(STGetKSP(eps->st,&ksp));
+  PetscCall(dvd_schm_basic_preconf(dvd,&b,eps->mpd,min_size_V,bs,initv,PetscAbs(eps->nini),data->plusk,harm,ksp,init,eps->trackall,data->ipB,data->doubleexp));
 
   /* Allocate memory */
-  ierr = EPSAllocateSolution(eps,0);CHKERRQ(ierr);
+  PetscCall(EPSAllocateSolution(eps,0));
 
   /* Setup orthogonalization */
-  ierr = EPS_SetInnerProduct(eps);CHKERRQ(ierr);
-  if (!(ipB && dvd->B)) {
-    ierr = BVSetMatrix(eps->V,NULL,PETSC_FALSE);CHKERRQ(ierr);
-  }
+  PetscCall(EPS_SetInnerProduct(eps));
+  if (!(ipB && dvd->B)) PetscCall(BVSetMatrix(eps->V,NULL,PETSC_FALSE));
 
   /* Configure dvd for a basic GD */
-  ierr = dvd_schm_basic_conf(dvd,&b,eps->mpd,min_size_V,bs,initv,PetscAbs(eps->nini),data->plusk,harm,dvd->withTarget,target,ksp,data->fix,init,eps->trackall,data->ipB,data->dynamic,data->doubleexp);CHKERRQ(ierr);
+  PetscCall(dvd_schm_basic_conf(dvd,&b,eps->mpd,min_size_V,bs,initv,PetscAbs(eps->nini),data->plusk,harm,dvd->withTarget,target,ksp,data->fix,init,eps->trackall,data->ipB,data->dynamic,data->doubleexp));
   PetscFunctionReturn(0);
 }
 
@@ -192,38 +192,37 @@ PetscErrorCode EPSSolve_XD(EPS eps)
   EPS_DAVIDSON   *data = (EPS_DAVIDSON*)eps->data;
   dvdDashboard   *d = &data->ddb;
   PetscInt       l,k;
-  PetscErrorCode ierr;
 
   PetscFunctionBegin;
-  ierr = PetscCitationsRegister(citation,&cited);CHKERRQ(ierr);
+  PetscCall(PetscCitationsRegister(citation,&cited));
   /* Call the starting routines */
-  ierr = EPSDavidsonFLCall(d->startList,d);CHKERRQ(ierr);
+  PetscCall(EPSDavidsonFLCall(d->startList,d));
 
   while (eps->reason == EPS_CONVERGED_ITERATING) {
 
     /* Initialize V, if it is needed */
-    ierr = BVGetActiveColumns(d->eps->V,&l,&k);CHKERRQ(ierr);
-    if (l == k) { ierr = d->initV(d);CHKERRQ(ierr); }
+    PetscCall(BVGetActiveColumns(d->eps->V,&l,&k));
+    if (PetscUnlikely(l == k)) PetscCall(d->initV(d));
 
     /* Find the best approximated eigenpairs in V, X */
-    ierr = d->calcPairs(d);CHKERRQ(ierr);
+    PetscCall(d->calcPairs(d));
 
     /* Test for convergence */
-    ierr = (*eps->stopping)(eps,eps->its,eps->max_it,eps->nconv,eps->nev,&eps->reason,eps->stoppingctx);CHKERRQ(ierr);
+    PetscCall((*eps->stopping)(eps,eps->its,eps->max_it,eps->nconv,eps->nev,&eps->reason,eps->stoppingctx));
     if (eps->reason != EPS_CONVERGED_ITERATING) break;
 
     /* Expand the subspace */
-    ierr = d->updateV(d);CHKERRQ(ierr);
+    PetscCall(d->updateV(d));
 
     /* Monitor progress */
     eps->nconv = d->nconv;
     eps->its++;
-    ierr = BVGetActiveColumns(d->eps->V,NULL,&k);CHKERRQ(ierr);
-    ierr = EPSMonitor(eps,eps->its,eps->nconv+d->npreconv,eps->eigr,eps->eigi,eps->errest,PetscMin(k,eps->nev));CHKERRQ(ierr);
+    PetscCall(BVGetActiveColumns(d->eps->V,NULL,&k));
+    PetscCall(EPSMonitor(eps,eps->its,eps->nconv+d->npreconv,eps->eigr,eps->eigi,eps->errest,PetscMin(k,eps->nev)));
   }
 
   /* Call the ending routines */
-  ierr = EPSDavidsonFLCall(d->endList,d);CHKERRQ(ierr);
+  PetscCall(EPSDavidsonFLCall(d->endList,d));
   PetscFunctionReturn(0);
 }
 
@@ -231,14 +230,13 @@ PetscErrorCode EPSReset_XD(EPS eps)
 {
   EPS_DAVIDSON   *data = (EPS_DAVIDSON*)eps->data;
   dvdDashboard   *dvd = &data->ddb;
-  PetscErrorCode ierr;
 
   PetscFunctionBegin;
   /* Call step destructors and destroys the list */
-  ierr = EPSDavidsonFLCall(dvd->destroyList,dvd);CHKERRQ(ierr);
-  ierr = EPSDavidsonFLDestroy(&dvd->destroyList);CHKERRQ(ierr);
-  ierr = EPSDavidsonFLDestroy(&dvd->startList);CHKERRQ(ierr);
-  ierr = EPSDavidsonFLDestroy(&dvd->endList);CHKERRQ(ierr);
+  PetscCall(EPSDavidsonFLCall(dvd->destroyList,dvd));
+  PetscCall(EPSDavidsonFLDestroy(&dvd->destroyList));
+  PetscCall(EPSDavidsonFLDestroy(&dvd->startList));
+  PetscCall(EPSDavidsonFLDestroy(&dvd->endList));
   PetscFunctionReturn(0);
 }
 
@@ -266,8 +264,11 @@ PetscErrorCode EPSXDSetBlockSize_XD(EPS eps,PetscInt blocksize)
 
   PetscFunctionBegin;
   if (blocksize == PETSC_DEFAULT || blocksize == PETSC_DECIDE) blocksize = 1;
-  if (blocksize <= 0) SETERRQ(PetscObjectComm((PetscObject)eps),PETSC_ERR_ARG_OUTOFRANGE,"Invalid blocksize value");
-  data->blocksize = blocksize;
+  PetscCheck(blocksize>0,PetscObjectComm((PetscObject)eps),PETSC_ERR_ARG_OUTOFRANGE,"Invalid blocksize value, must be >0");
+  if (data->blocksize != blocksize) {
+    data->blocksize = blocksize;
+    eps->state      = EPS_STATE_INITIAL;
+  }
   PetscFunctionReturn(0);
 }
 
@@ -285,12 +286,15 @@ PetscErrorCode EPSXDSetRestart_XD(EPS eps,PetscInt minv,PetscInt plusk)
   EPS_DAVIDSON *data = (EPS_DAVIDSON*)eps->data;
 
   PetscFunctionBegin;
-  if (minv == PETSC_DEFAULT || minv == PETSC_DECIDE) minv = 5;
-  if (minv <= 0) SETERRQ(PetscObjectComm((PetscObject)eps),PETSC_ERR_ARG_OUTOFRANGE,"Invalid minv value");
-  if (plusk == PETSC_DEFAULT || plusk == PETSC_DECIDE) plusk = eps->problem_type == EPS_GHIEP?0:1;
-  if (plusk < 0) SETERRQ(PetscObjectComm((PetscObject)eps),PETSC_ERR_ARG_OUTOFRANGE,"Invalid plusk value");
-  data->minv = minv;
-  data->plusk = plusk;
+  if (minv == PETSC_DEFAULT || minv == PETSC_DECIDE) minv = 0;
+  else PetscCheck(minv>0,PetscObjectComm((PetscObject)eps),PETSC_ERR_ARG_OUTOFRANGE,"Invalid minv value, must be >0");
+  if (plusk == PETSC_DEFAULT || plusk == PETSC_DECIDE) plusk = PETSC_DEFAULT;
+  else PetscCheck(plusk>=0,PetscObjectComm((PetscObject)eps),PETSC_ERR_ARG_OUTOFRANGE,"Invalid plusk value, must be >0");
+  if (data->minv != minv || data->plusk != plusk) {
+    data->minv  = minv;
+    data->plusk = plusk;
+    eps->state  = EPS_STATE_INITIAL;
+  }
   PetscFunctionReturn(0);
 }
 
@@ -318,9 +322,12 @@ PetscErrorCode EPSXDSetInitialSize_XD(EPS eps,PetscInt initialsize)
   EPS_DAVIDSON *data = (EPS_DAVIDSON*)eps->data;
 
   PetscFunctionBegin;
-  if (initialsize == PETSC_DEFAULT || initialsize == PETSC_DECIDE) initialsize = 5;
-  if (initialsize <= 0) SETERRQ(PetscObjectComm((PetscObject)eps),PETSC_ERR_ARG_OUTOFRANGE,"Invalid initial size value");
-  data->initialsize = initialsize;
+  if (initialsize == PETSC_DEFAULT || initialsize == PETSC_DECIDE) initialsize = 0;
+  else PetscCheck(initialsize>0,PetscObjectComm((PetscObject)eps),PETSC_ERR_ARG_OUTOFRANGE,"Invalid initial size value, must be >0");
+  if (data->initialsize != initialsize) {
+    data->initialsize = initialsize;
+    eps->state        = EPS_STATE_INITIAL;
+  }
   PetscFunctionReturn(0);
 }
 
@@ -352,19 +359,18 @@ PetscErrorCode EPSXDGetBOrth_XD(EPS eps,PetscBool *borth)
  */
 PetscErrorCode EPSComputeVectors_XD(EPS eps)
 {
-  PetscErrorCode ierr;
   Mat            X;
   PetscBool      symm;
 
   PetscFunctionBegin;
-  ierr = PetscObjectTypeCompare((PetscObject)eps->ds,DSHEP,&symm);CHKERRQ(ierr);
+  PetscCall(PetscObjectTypeCompare((PetscObject)eps->ds,DSHEP,&symm));
   if (symm) PetscFunctionReturn(0);
-  ierr = DSVectors(eps->ds,DS_MAT_X,NULL,NULL);CHKERRQ(ierr);
+  PetscCall(DSVectors(eps->ds,DS_MAT_X,NULL,NULL));
 
   /* V <- V * X */
-  ierr = DSGetMat(eps->ds,DS_MAT_X,&X);CHKERRQ(ierr);
-  ierr = BVSetActiveColumns(eps->V,0,eps->nconv);CHKERRQ(ierr);
-  ierr = BVMultInPlace(eps->V,X,0,eps->nconv);CHKERRQ(ierr);
-  ierr = MatDestroy(&X);CHKERRQ(ierr);
+  PetscCall(DSGetMat(eps->ds,DS_MAT_X,&X));
+  PetscCall(BVSetActiveColumns(eps->V,0,eps->nconv));
+  PetscCall(BVMultInPlace(eps->V,X,0,eps->nconv));
+  PetscCall(MatDestroy(&X));
   PetscFunctionReturn(0);
 }
