@@ -1,7 +1,7 @@
 /*
    - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
    SLEPc - Scalable Library for Eigenvalue Problem Computations
-   Copyright (c) 2002-2021, Universitat Politecnica de Valencia, Spain
+   Copyright (c) 2002-, Universitat Politecnica de Valencia, Spain
 
    This file is part of SLEPc.
    SLEPc is distributed under a 2-clause BSD license (see LICENSE).
@@ -20,7 +20,6 @@ typedef struct {
 
 PetscErrorCode EPSSetUp_Elemental(EPS eps)
 {
-  PetscErrorCode ierr;
   EPS_Elemental  *ctx = (EPS_Elemental*)eps->data;
   Mat            A,B;
   PetscInt       nmat;
@@ -29,41 +28,37 @@ PetscErrorCode EPSSetUp_Elemental(EPS eps)
 
   PetscFunctionBegin;
   EPSCheckHermitianDefinite(eps);
-  ierr = PetscObjectTypeCompare((PetscObject)eps->st,STSHIFT,&isshift);CHKERRQ(ierr);
-  if (!isshift) SETERRQ(PetscObjectComm((PetscObject)eps),PETSC_ERR_SUP,"This solver does not support spectral transformations");
+  PetscCall(PetscObjectTypeCompare((PetscObject)eps->st,STSHIFT,&isshift));
+  PetscCheck(isshift,PetscObjectComm((PetscObject)eps),PETSC_ERR_SUP,"This solver does not support spectral transformations");
   eps->ncv = eps->n;
-  if (eps->mpd!=PETSC_DEFAULT) { ierr = PetscInfo(eps,"Warning: parameter mpd ignored\n");CHKERRQ(ierr); }
+  if (eps->mpd!=PETSC_DEFAULT) PetscCall(PetscInfo(eps,"Warning: parameter mpd ignored\n"));
   if (eps->max_it==PETSC_DEFAULT) eps->max_it = 1;
-  if (!eps->which) { ierr = EPSSetWhichEigenpairs_Default(eps);CHKERRQ(ierr); }
-  if (eps->which==EPS_ALL && eps->inta!=eps->intb) SETERRQ(PetscObjectComm((PetscObject)eps),PETSC_ERR_SUP,"This solver does not support interval computation");
+  if (!eps->which) PetscCall(EPSSetWhichEigenpairs_Default(eps));
+  PetscCheck(eps->which!=EPS_ALL || eps->inta==eps->intb,PetscObjectComm((PetscObject)eps),PETSC_ERR_SUP,"This solver does not support interval computation");
   EPSCheckUnsupported(eps,EPS_FEATURE_BALANCE | EPS_FEATURE_ARBITRARY | EPS_FEATURE_REGION | EPS_FEATURE_STOPPING);
   EPSCheckIgnored(eps,EPS_FEATURE_EXTRACTION | EPS_FEATURE_CONVERGENCE);
-  ierr = EPSAllocateSolution(eps,0);CHKERRQ(ierr);
+  PetscCall(EPSAllocateSolution(eps,0));
 
   /* convert matrices */
-  ierr = MatDestroy(&ctx->Ae);CHKERRQ(ierr);
-  ierr = MatDestroy(&ctx->Be);CHKERRQ(ierr);
-  ierr = STGetNumMatrices(eps->st,&nmat);CHKERRQ(ierr);
-  ierr = STGetMatrix(eps->st,0,&A);CHKERRQ(ierr);
-  ierr = MatConvert(A,MATELEMENTAL,MAT_INITIAL_MATRIX,&ctx->Ae);CHKERRQ(ierr);
+  PetscCall(MatDestroy(&ctx->Ae));
+  PetscCall(MatDestroy(&ctx->Be));
+  PetscCall(STGetNumMatrices(eps->st,&nmat));
+  PetscCall(STGetMatrix(eps->st,0,&A));
+  PetscCall(MatConvert(A,MATELEMENTAL,MAT_INITIAL_MATRIX,&ctx->Ae));
   if (nmat>1) {
-    ierr = STGetMatrix(eps->st,1,&B);CHKERRQ(ierr);
-    ierr = MatConvert(B,MATELEMENTAL,MAT_INITIAL_MATRIX,&ctx->Be);CHKERRQ(ierr);
+    PetscCall(STGetMatrix(eps->st,1,&B));
+    PetscCall(MatConvert(B,MATELEMENTAL,MAT_INITIAL_MATRIX,&ctx->Be));
   }
-  ierr = STGetShift(eps->st,&shift);CHKERRQ(ierr);
+  PetscCall(STGetShift(eps->st,&shift));
   if (shift != 0.0) {
-    if (nmat>1) {
-      ierr = MatAXPY(ctx->Ae,-shift,ctx->Be,SAME_NONZERO_PATTERN);CHKERRQ(ierr);
-    } else {
-      ierr = MatShift(ctx->Ae,-shift);CHKERRQ(ierr);
-    }
+    if (nmat>1) PetscCall(MatAXPY(ctx->Ae,-shift,ctx->Be,SAME_NONZERO_PATTERN));
+    else PetscCall(MatShift(ctx->Ae,-shift));
   }
   PetscFunctionReturn(0);
 }
 
 PetscErrorCode EPSSolve_Elemental(EPS eps)
 {
-  PetscErrorCode ierr;
   EPS_Elemental  *ctx = (EPS_Elemental*)eps->data;
   Mat            A = ctx->Ae,B = ctx->Be,Q,V;
   Mat_Elemental  *a = (Mat_Elemental*)A->data,*b,*q;
@@ -71,7 +66,7 @@ PetscErrorCode EPSSolve_Elemental(EPS eps)
 
   PetscFunctionBegin;
   El::DistMatrix<PetscReal,El::VR,El::STAR> w(*a->grid);
-  ierr = MatDuplicate(A,MAT_DO_NOT_COPY_VALUES,&Q);CHKERRQ(ierr);
+  PetscCall(MatDuplicate(A,MAT_DO_NOT_COPY_VALUES,&Q));
   q = (Mat_Elemental*)Q->data;
 
   if (B) {
@@ -84,10 +79,10 @@ PetscErrorCode EPSSolve_Elemental(EPS eps)
     RO2E(A,0,rrank,ridx,&erow);
     eps->eigr[i] = w.Get(erow,0);
   }
-  ierr = BVGetMat(eps->V,&V);CHKERRQ(ierr);
-  ierr = MatConvert(Q,MATDENSE,MAT_REUSE_MATRIX,&V);CHKERRQ(ierr);
-  ierr = BVRestoreMat(eps->V,&V);CHKERRQ(ierr);
-  ierr = MatDestroy(&Q);CHKERRQ(ierr);
+  PetscCall(BVGetMat(eps->V,&V));
+  PetscCall(MatConvert(Q,MATDENSE,MAT_REUSE_MATRIX,&V));
+  PetscCall(BVRestoreMat(eps->V,&V));
+  PetscCall(MatDestroy(&Q));
 
   eps->nconv  = eps->ncv;
   eps->its    = 1;
@@ -97,31 +92,27 @@ PetscErrorCode EPSSolve_Elemental(EPS eps)
 
 PetscErrorCode EPSDestroy_Elemental(EPS eps)
 {
-  PetscErrorCode ierr;
-
   PetscFunctionBegin;
-  ierr = PetscFree(eps->data);CHKERRQ(ierr);
+  PetscCall(PetscFree(eps->data));
   PetscFunctionReturn(0);
 }
 
 PetscErrorCode EPSReset_Elemental(EPS eps)
 {
-  PetscErrorCode ierr;
   EPS_Elemental  *ctx = (EPS_Elemental*)eps->data;
 
   PetscFunctionBegin;
-  ierr = MatDestroy(&ctx->Ae);CHKERRQ(ierr);
-  ierr = MatDestroy(&ctx->Be);CHKERRQ(ierr);
+  PetscCall(MatDestroy(&ctx->Ae));
+  PetscCall(MatDestroy(&ctx->Be));
   PetscFunctionReturn(0);
 }
 
 SLEPC_EXTERN PetscErrorCode EPSCreate_Elemental(EPS eps)
 {
   EPS_Elemental  *ctx;
-  PetscErrorCode ierr;
 
   PetscFunctionBegin;
-  ierr = PetscNewLog(eps,&ctx);CHKERRQ(ierr);
+  PetscCall(PetscNewLog(eps,&ctx));
   eps->data = (void*)ctx;
 
   eps->categ = EPS_CATEGORY_OTHER;
@@ -135,4 +126,3 @@ SLEPC_EXTERN PetscErrorCode EPSCreate_Elemental(EPS eps)
   eps->ops->setdefaultst   = EPSSetDefaultST_NoFactor;
   PetscFunctionReturn(0);
 }
-
