@@ -1,7 +1,7 @@
 /*
    - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
    SLEPc - Scalable Library for Eigenvalue Problem Computations
-   Copyright (c) 2002-2021, Universitat Politecnica de Valencia, Spain
+   Copyright (c) 2002-, Universitat Politecnica de Valencia, Spain
 
    This file is part of SLEPc.
    SLEPc is distributed under a 2-clause BSD license (see LICENSE).
@@ -30,31 +30,26 @@ typedef struct {
 
 PetscErrorCode EPSSetUp_Arnoldi(EPS eps)
 {
-  PetscErrorCode ierr;
-
   PetscFunctionBegin;
   EPSCheckDefinite(eps);
-  ierr = EPSSetDimensions_Default(eps,eps->nev,&eps->ncv,&eps->mpd);CHKERRQ(ierr);
-  if (eps->ncv>eps->nev+eps->mpd) SETERRQ(PetscObjectComm((PetscObject)eps),PETSC_ERR_USER_INPUT,"The value of ncv must not be larger than nev+mpd");
+  PetscCall(EPSSetDimensions_Default(eps,eps->nev,&eps->ncv,&eps->mpd));
+  PetscCheck(eps->ncv<=eps->nev+eps->mpd,PetscObjectComm((PetscObject)eps),PETSC_ERR_USER_INPUT,"The value of ncv must not be larger than nev+mpd");
   if (eps->max_it==PETSC_DEFAULT) eps->max_it = PetscMax(100,2*eps->n/eps->ncv);
-  if (!eps->which) { ierr = EPSSetWhichEigenpairs_Default(eps);CHKERRQ(ierr); }
-  if (eps->which==EPS_ALL) SETERRQ(PetscObjectComm((PetscObject)eps),PETSC_ERR_SUP,"This solver does not support computing all eigenvalues");
+  if (!eps->which) PetscCall(EPSSetWhichEigenpairs_Default(eps));
+  PetscCheck(eps->which!=EPS_ALL,PetscObjectComm((PetscObject)eps),PETSC_ERR_SUP,"This solver does not support computing all eigenvalues");
   EPSCheckUnsupported(eps,EPS_FEATURE_ARBITRARY | EPS_FEATURE_TWOSIDED);
 
-  ierr = EPSAllocateSolution(eps,1);CHKERRQ(ierr);
-  ierr = EPS_SetInnerProduct(eps);CHKERRQ(ierr);
-  ierr = DSSetType(eps->ds,DSNHEP);CHKERRQ(ierr);
-  if (eps->extraction==EPS_REFINED || eps->extraction==EPS_REFINED_HARMONIC) {
-    ierr = DSSetRefined(eps->ds,PETSC_TRUE);CHKERRQ(ierr);
-  }
-  ierr = DSSetExtraRow(eps->ds,PETSC_TRUE);CHKERRQ(ierr);
-  ierr = DSAllocate(eps->ds,eps->ncv+1);CHKERRQ(ierr);
+  PetscCall(EPSAllocateSolution(eps,1));
+  PetscCall(EPS_SetInnerProduct(eps));
+  PetscCall(DSSetType(eps->ds,DSNHEP));
+  if (eps->extraction==EPS_REFINED || eps->extraction==EPS_REFINED_HARMONIC) PetscCall(DSSetRefined(eps->ds,PETSC_TRUE));
+  PetscCall(DSSetExtraRow(eps->ds,PETSC_TRUE));
+  PetscCall(DSAllocate(eps->ds,eps->ncv+1));
   PetscFunctionReturn(0);
 }
 
 PetscErrorCode EPSSolve_Arnoldi(EPS eps)
 {
-  PetscErrorCode     ierr;
   PetscInt           k,nv,ld;
   Mat                U,Op,H;
   PetscScalar        *Harray;
@@ -64,13 +59,13 @@ PetscErrorCode EPSSolve_Arnoldi(EPS eps)
   EPS_ARNOLDI        *arnoldi = (EPS_ARNOLDI*)eps->data;
 
   PetscFunctionBegin;
-  ierr = DSGetLeadingDimension(eps->ds,&ld);CHKERRQ(ierr);
-  ierr = DSGetRefined(eps->ds,&refined);CHKERRQ(ierr);
+  PetscCall(DSGetLeadingDimension(eps->ds,&ld));
+  PetscCall(DSGetRefined(eps->ds,&refined));
   harmonic = (eps->extraction==EPS_HARMONIC || eps->extraction==EPS_REFINED_HARMONIC)?PETSC_TRUE:PETSC_FALSE;
-  ierr = BVGetOrthogonalization(eps->V,NULL,&orthog_ref,NULL,NULL);CHKERRQ(ierr);
+  PetscCall(BVGetOrthogonalization(eps->V,NULL,&orthog_ref,NULL,NULL));
 
   /* Get the starting Arnoldi vector */
-  ierr = EPSGetStartVector(eps,0,NULL);CHKERRQ(ierr);
+  PetscCall(EPSGetStartVector(eps,0,NULL));
 
   /* Restart loop */
   while (eps->reason == EPS_CONVERGED_ITERATING) {
@@ -78,77 +73,74 @@ PetscErrorCode EPSSolve_Arnoldi(EPS eps)
 
     /* Compute an nv-step Arnoldi factorization */
     nv = PetscMin(eps->nconv+eps->mpd,eps->ncv);
-    ierr = DSSetDimensions(eps->ds,nv,eps->nconv,0);CHKERRQ(ierr);
+    PetscCall(DSSetDimensions(eps->ds,nv,eps->nconv,0));
     if (!arnoldi->delayed) {
-      ierr = STGetOperator(eps->st,&Op);CHKERRQ(ierr);
-      ierr = DSGetMat(eps->ds,DS_MAT_A,&H);CHKERRQ(ierr);
-      ierr = BVMatArnoldi(eps->V,Op,H,eps->nconv,&nv,&beta,&breakdown);CHKERRQ(ierr);
-      ierr = DSRestoreMat(eps->ds,DS_MAT_A,&H);CHKERRQ(ierr);
-      ierr = STRestoreOperator(eps->st,&Op);CHKERRQ(ierr);
+      PetscCall(STGetOperator(eps->st,&Op));
+      PetscCall(DSGetMat(eps->ds,DS_MAT_A,&H));
+      PetscCall(BVMatArnoldi(eps->V,Op,H,eps->nconv,&nv,&beta,&breakdown));
+      PetscCall(DSRestoreMat(eps->ds,DS_MAT_A,&H));
+      PetscCall(STRestoreOperator(eps->st,&Op));
     } else if (orthog_ref == BV_ORTHOG_REFINE_NEVER) {
-      ierr = DSGetArray(eps->ds,DS_MAT_A,&Harray);CHKERRQ(ierr);
-      ierr = EPSDelayedArnoldi1(eps,Harray,ld,eps->nconv,&nv,&beta,&breakdown);CHKERRQ(ierr);
-      ierr = DSRestoreArray(eps->ds,DS_MAT_A,&Harray);CHKERRQ(ierr);
+      PetscCall(DSGetArray(eps->ds,DS_MAT_A,&Harray));
+      PetscCall(EPSDelayedArnoldi1(eps,Harray,ld,eps->nconv,&nv,&beta,&breakdown));
+      PetscCall(DSRestoreArray(eps->ds,DS_MAT_A,&Harray));
     } else {
-      ierr = DSGetArray(eps->ds,DS_MAT_A,&Harray);CHKERRQ(ierr);
-      ierr = EPSDelayedArnoldi(eps,Harray,ld,eps->nconv,&nv,&beta,&breakdown);CHKERRQ(ierr);
-      ierr = DSRestoreArray(eps->ds,DS_MAT_A,&Harray);CHKERRQ(ierr);
+      PetscCall(DSGetArray(eps->ds,DS_MAT_A,&Harray));
+      PetscCall(EPSDelayedArnoldi(eps,Harray,ld,eps->nconv,&nv,&beta,&breakdown));
+      PetscCall(DSRestoreArray(eps->ds,DS_MAT_A,&Harray));
     }
-    ierr = DSSetState(eps->ds,DS_STATE_INTERMEDIATE);CHKERRQ(ierr);
-    ierr = BVSetActiveColumns(eps->V,eps->nconv,nv);CHKERRQ(ierr);
+    PetscCall(DSSetState(eps->ds,DS_STATE_INTERMEDIATE));
+    PetscCall(BVSetActiveColumns(eps->V,eps->nconv,nv));
 
     /* Compute translation of Krylov decomposition if harmonic extraction used */
-    if (harmonic) {
-      ierr = DSTranslateHarmonic(eps->ds,eps->target,beta,PETSC_FALSE,NULL,&gamma);CHKERRQ(ierr);
-    }
+    if (harmonic) PetscCall(DSTranslateHarmonic(eps->ds,eps->target,beta,PETSC_FALSE,NULL,&gamma));
 
     /* Solve projected problem */
-    ierr = DSSolve(eps->ds,eps->eigr,eps->eigi);CHKERRQ(ierr);
-    ierr = DSSort(eps->ds,eps->eigr,eps->eigi,NULL,NULL,NULL);CHKERRQ(ierr);
-    ierr = DSUpdateExtraRow(eps->ds);CHKERRQ(ierr);
-    ierr = DSSynchronize(eps->ds,eps->eigr,eps->eigi);CHKERRQ(ierr);
+    PetscCall(DSSolve(eps->ds,eps->eigr,eps->eigi));
+    PetscCall(DSSort(eps->ds,eps->eigr,eps->eigi,NULL,NULL,NULL));
+    PetscCall(DSUpdateExtraRow(eps->ds));
+    PetscCall(DSSynchronize(eps->ds,eps->eigr,eps->eigi));
 
     /* Check convergence */
-    ierr = EPSKrylovConvergence(eps,PETSC_FALSE,eps->nconv,nv-eps->nconv,beta,0.0,gamma,&k);CHKERRQ(ierr);
+    PetscCall(EPSKrylovConvergence(eps,PETSC_FALSE,eps->nconv,nv-eps->nconv,beta,0.0,gamma,&k));
     if (refined) {
-      ierr = DSGetMat(eps->ds,DS_MAT_X,&U);CHKERRQ(ierr);
-      ierr = BVMultInPlace(eps->V,U,eps->nconv,k+1);CHKERRQ(ierr);
-      ierr = MatDestroy(&U);CHKERRQ(ierr);
-      ierr = BVOrthonormalizeColumn(eps->V,k,PETSC_FALSE,NULL,NULL);CHKERRQ(ierr);
+      PetscCall(DSGetMat(eps->ds,DS_MAT_X,&U));
+      PetscCall(BVMultInPlace(eps->V,U,eps->nconv,k+1));
+      PetscCall(MatDestroy(&U));
+      PetscCall(BVOrthonormalizeColumn(eps->V,k,PETSC_FALSE,NULL,NULL));
     } else {
-      ierr = DSGetMat(eps->ds,DS_MAT_Q,&U);CHKERRQ(ierr);
-      ierr = BVMultInPlace(eps->V,U,eps->nconv,PetscMin(k+1,nv));CHKERRQ(ierr);
-      ierr = MatDestroy(&U);CHKERRQ(ierr);
+      PetscCall(DSGetMat(eps->ds,DS_MAT_Q,&U));
+      PetscCall(BVMultInPlace(eps->V,U,eps->nconv,PetscMin(k+1,nv)));
+      PetscCall(MatDestroy(&U));
     }
-    ierr = (*eps->stopping)(eps,eps->its,eps->max_it,k,eps->nev,&eps->reason,eps->stoppingctx);CHKERRQ(ierr);
+    PetscCall((*eps->stopping)(eps,eps->its,eps->max_it,k,eps->nev,&eps->reason,eps->stoppingctx));
     if (eps->reason == EPS_CONVERGED_ITERATING && breakdown) {
-      ierr = PetscInfo2(eps,"Breakdown in Arnoldi method (it=%D norm=%g)\n",eps->its,(double)beta);CHKERRQ(ierr);
-      ierr = EPSGetStartVector(eps,k,&breakdown);CHKERRQ(ierr);
+      PetscCall(PetscInfo(eps,"Breakdown in Arnoldi method (it=%" PetscInt_FMT " norm=%g)\n",eps->its,(double)beta));
+      PetscCall(EPSGetStartVector(eps,k,&breakdown));
       if (breakdown) {
         eps->reason = EPS_DIVERGED_BREAKDOWN;
-        ierr = PetscInfo(eps,"Unable to generate more start vectors\n");CHKERRQ(ierr);
+        PetscCall(PetscInfo(eps,"Unable to generate more start vectors\n"));
       }
     }
     eps->nconv = k;
-    ierr = EPSMonitor(eps,eps->its,eps->nconv,eps->eigr,eps->eigi,eps->errest,nv);CHKERRQ(ierr);
+    PetscCall(EPSMonitor(eps,eps->its,eps->nconv,eps->eigr,eps->eigi,eps->errest,nv));
   }
-  ierr = DSTruncate(eps->ds,eps->nconv,PETSC_TRUE);CHKERRQ(ierr);
+  PetscCall(DSTruncate(eps->ds,eps->nconv,PETSC_TRUE));
   PetscFunctionReturn(0);
 }
 
 PetscErrorCode EPSSetFromOptions_Arnoldi(PetscOptionItems *PetscOptionsObject,EPS eps)
 {
-  PetscErrorCode ierr;
   PetscBool      set,val;
   EPS_ARNOLDI    *arnoldi = (EPS_ARNOLDI*)eps->data;
 
   PetscFunctionBegin;
-  ierr = PetscOptionsHead(PetscOptionsObject,"EPS Arnoldi Options");CHKERRQ(ierr);
+  PetscCall(PetscOptionsHead(PetscOptionsObject,"EPS Arnoldi Options"));
 
-    ierr = PetscOptionsBool("-eps_arnoldi_delayed","Use delayed reorthogonalization","EPSArnoldiSetDelayed",arnoldi->delayed,&val,&set);CHKERRQ(ierr);
-    if (set) { ierr = EPSArnoldiSetDelayed(eps,val);CHKERRQ(ierr); }
+    PetscCall(PetscOptionsBool("-eps_arnoldi_delayed","Use delayed reorthogonalization","EPSArnoldiSetDelayed",arnoldi->delayed,&val,&set));
+    if (set) PetscCall(EPSArnoldiSetDelayed(eps,val));
 
-  ierr = PetscOptionsTail();CHKERRQ(ierr);
+  PetscCall(PetscOptionsTail());
   PetscFunctionReturn(0);
 }
 
@@ -185,12 +177,10 @@ static PetscErrorCode EPSArnoldiSetDelayed_Arnoldi(EPS eps,PetscBool delayed)
 @*/
 PetscErrorCode EPSArnoldiSetDelayed(EPS eps,PetscBool delayed)
 {
-  PetscErrorCode ierr;
-
   PetscFunctionBegin;
   PetscValidHeaderSpecific(eps,EPS_CLASSID,1);
   PetscValidLogicalCollectiveBool(eps,delayed,2);
-  ierr = PetscTryMethod(eps,"EPSArnoldiSetDelayed_C",(EPS,PetscBool),(eps,delayed));CHKERRQ(ierr);
+  PetscTryMethod(eps,"EPSArnoldiSetDelayed_C",(EPS,PetscBool),(eps,delayed));
   PetscFunctionReturn(0);
 }
 
@@ -212,7 +202,7 @@ static PetscErrorCode EPSArnoldiGetDelayed_Arnoldi(EPS eps,PetscBool *delayed)
    Input Parameter:
 .  eps - the eigenproblem solver context
 
-   Input Parameter:
+   Output Parameter:
 .  delayed - boolean flag indicating if delayed reorthogonalization has been enabled
 
    Level: advanced
@@ -221,47 +211,39 @@ static PetscErrorCode EPSArnoldiGetDelayed_Arnoldi(EPS eps,PetscBool *delayed)
 @*/
 PetscErrorCode EPSArnoldiGetDelayed(EPS eps,PetscBool *delayed)
 {
-  PetscErrorCode ierr;
-
   PetscFunctionBegin;
   PetscValidHeaderSpecific(eps,EPS_CLASSID,1);
   PetscValidBoolPointer(delayed,2);
-  ierr = PetscUseMethod(eps,"EPSArnoldiGetDelayed_C",(EPS,PetscBool*),(eps,delayed));CHKERRQ(ierr);
+  PetscUseMethod(eps,"EPSArnoldiGetDelayed_C",(EPS,PetscBool*),(eps,delayed));
   PetscFunctionReturn(0);
 }
 
 PetscErrorCode EPSDestroy_Arnoldi(EPS eps)
 {
-  PetscErrorCode ierr;
-
   PetscFunctionBegin;
-  ierr = PetscFree(eps->data);CHKERRQ(ierr);
-  ierr = PetscObjectComposeFunction((PetscObject)eps,"EPSArnoldiSetDelayed_C",NULL);CHKERRQ(ierr);
-  ierr = PetscObjectComposeFunction((PetscObject)eps,"EPSArnoldiGetDelayed_C",NULL);CHKERRQ(ierr);
+  PetscCall(PetscFree(eps->data));
+  PetscCall(PetscObjectComposeFunction((PetscObject)eps,"EPSArnoldiSetDelayed_C",NULL));
+  PetscCall(PetscObjectComposeFunction((PetscObject)eps,"EPSArnoldiGetDelayed_C",NULL));
   PetscFunctionReturn(0);
 }
 
 PetscErrorCode EPSView_Arnoldi(EPS eps,PetscViewer viewer)
 {
-  PetscErrorCode ierr;
   PetscBool      isascii;
   EPS_ARNOLDI    *arnoldi = (EPS_ARNOLDI*)eps->data;
 
   PetscFunctionBegin;
-  ierr = PetscObjectTypeCompare((PetscObject)viewer,PETSCVIEWERASCII,&isascii);CHKERRQ(ierr);
-  if (isascii && arnoldi->delayed) {
-    ierr = PetscViewerASCIIPrintf(viewer,"  using delayed reorthogonalization\n");CHKERRQ(ierr);
-  }
+  PetscCall(PetscObjectTypeCompare((PetscObject)viewer,PETSCVIEWERASCII,&isascii));
+  if (isascii && arnoldi->delayed) PetscCall(PetscViewerASCIIPrintf(viewer,"  using delayed reorthogonalization\n"));
   PetscFunctionReturn(0);
 }
 
 SLEPC_EXTERN PetscErrorCode EPSCreate_Arnoldi(EPS eps)
 {
   EPS_ARNOLDI    *ctx;
-  PetscErrorCode ierr;
 
   PetscFunctionBegin;
-  ierr = PetscNewLog(eps,&ctx);CHKERRQ(ierr);
+  PetscCall(PetscNewLog(eps,&ctx));
   eps->data = (void*)ctx;
 
   eps->useds = PETSC_TRUE;
@@ -275,8 +257,7 @@ SLEPC_EXTERN PetscErrorCode EPSCreate_Arnoldi(EPS eps)
   eps->ops->backtransform  = EPSBackTransform_Default;
   eps->ops->computevectors = EPSComputeVectors_Schur;
 
-  ierr = PetscObjectComposeFunction((PetscObject)eps,"EPSArnoldiSetDelayed_C",EPSArnoldiSetDelayed_Arnoldi);CHKERRQ(ierr);
-  ierr = PetscObjectComposeFunction((PetscObject)eps,"EPSArnoldiGetDelayed_C",EPSArnoldiGetDelayed_Arnoldi);CHKERRQ(ierr);
+  PetscCall(PetscObjectComposeFunction((PetscObject)eps,"EPSArnoldiSetDelayed_C",EPSArnoldiSetDelayed_Arnoldi));
+  PetscCall(PetscObjectComposeFunction((PetscObject)eps,"EPSArnoldiGetDelayed_C",EPSArnoldiGetDelayed_Arnoldi));
   PetscFunctionReturn(0);
 }
-
