@@ -1,7 +1,7 @@
 /*
    - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
    SLEPc - Scalable Library for Eigenvalue Problem Computations
-   Copyright (c) 2002-2021, Universitat Politecnica de Valencia, Spain
+   Copyright (c) 2002-, Universitat Politecnica de Valencia, Spain
 
    This file is part of SLEPc.
    SLEPc is distributed under a 2-clause BSD license (see LICENSE).
@@ -51,10 +51,11 @@ PetscBool         LMEMonitorRegisterAllCalled = PETSC_FALSE;
    PetscViewerASCIIOpen() - output to a specified file.
 
    Level: beginner
+
+.seealso: LMECreate()
 @*/
 PetscErrorCode LMEView(LME lme,PetscViewer viewer)
 {
-  PetscErrorCode ierr;
   PetscBool      isascii;
   const char     *eqname[] = {
                    "continuous-time Lyapunov",
@@ -67,33 +68,29 @@ PetscErrorCode LMEView(LME lme,PetscViewer viewer)
 
   PetscFunctionBegin;
   PetscValidHeaderSpecific(lme,LME_CLASSID,1);
-  if (!viewer) {
-    ierr = PetscViewerASCIIGetStdout(PetscObjectComm((PetscObject)lme),&viewer);CHKERRQ(ierr);
-  }
+  if (!viewer) PetscCall(PetscViewerASCIIGetStdout(PetscObjectComm((PetscObject)lme),&viewer));
   PetscValidHeaderSpecific(viewer,PETSC_VIEWER_CLASSID,2);
   PetscCheckSameComm(lme,1,viewer,2);
 
-  ierr = PetscObjectTypeCompare((PetscObject)viewer,PETSCVIEWERASCII,&isascii);CHKERRQ(ierr);
+  PetscCall(PetscObjectTypeCompare((PetscObject)viewer,PETSCVIEWERASCII,&isascii));
   if (isascii) {
-    ierr = PetscObjectPrintClassNamePrefixType((PetscObject)lme,viewer);CHKERRQ(ierr);
+    PetscCall(PetscObjectPrintClassNamePrefixType((PetscObject)lme,viewer));
     if (lme->ops->view) {
-      ierr = PetscViewerASCIIPushTab(viewer);CHKERRQ(ierr);
-      ierr = (*lme->ops->view)(lme,viewer);CHKERRQ(ierr);
-      ierr = PetscViewerASCIIPopTab(viewer);CHKERRQ(ierr);
+      PetscCall(PetscViewerASCIIPushTab(viewer));
+      PetscCall((*lme->ops->view)(lme,viewer));
+      PetscCall(PetscViewerASCIIPopTab(viewer));
     }
-    ierr = PetscViewerASCIIPrintf(viewer,"  equation type: %s\n",eqname[lme->problem_type]);CHKERRQ(ierr);
-    ierr = PetscViewerASCIIPrintf(viewer,"  number of column vectors (ncv): %D\n",lme->ncv);CHKERRQ(ierr);
-    ierr = PetscViewerASCIIPrintf(viewer,"  maximum number of iterations: %D\n",lme->max_it);CHKERRQ(ierr);
-    ierr = PetscViewerASCIIPrintf(viewer,"  tolerance: %g\n",(double)lme->tol);CHKERRQ(ierr);
+    PetscCall(PetscViewerASCIIPrintf(viewer,"  equation type: %s\n",eqname[lme->problem_type]));
+    PetscCall(PetscViewerASCIIPrintf(viewer,"  number of column vectors (ncv): %" PetscInt_FMT "\n",lme->ncv));
+    PetscCall(PetscViewerASCIIPrintf(viewer,"  maximum number of iterations: %" PetscInt_FMT "\n",lme->max_it));
+    PetscCall(PetscViewerASCIIPrintf(viewer,"  tolerance: %g\n",(double)lme->tol));
   } else {
-    if (lme->ops->view) {
-      ierr = (*lme->ops->view)(lme,viewer);CHKERRQ(ierr);
-    }
+    if (lme->ops->view) PetscCall((*lme->ops->view)(lme,viewer));
   }
-  ierr = PetscViewerPushFormat(viewer,PETSC_VIEWER_ASCII_INFO);CHKERRQ(ierr);
-  if (!lme->V) { ierr = LMEGetBV(lme,&lme->V);CHKERRQ(ierr); }
-  ierr = BVView(lme->V,viewer);CHKERRQ(ierr);
-  ierr = PetscViewerPopFormat(viewer);CHKERRQ(ierr);
+  PetscCall(PetscViewerPushFormat(viewer,PETSC_VIEWER_ASCII_INFO));
+  if (!lme->V) PetscCall(LMEGetBV(lme,&lme->V));
+  PetscCall(BVView(lme->V,viewer));
+  PetscCall(PetscViewerPopFormat(viewer));
   PetscFunctionReturn(0);
 }
 
@@ -113,11 +110,9 @@ PetscErrorCode LMEView(LME lme,PetscViewer viewer)
 @*/
 PetscErrorCode LMEViewFromOptions(LME lme,PetscObject obj,const char name[])
 {
-  PetscErrorCode ierr;
-
   PetscFunctionBegin;
   PetscValidHeaderSpecific(lme,LME_CLASSID,1);
-  ierr = PetscObjectViewFromOptions((PetscObject)lme,obj,name);CHKERRQ(ierr);
+  PetscCall(PetscObjectViewFromOptions((PetscObject)lme,obj,name));
   PetscFunctionReturn(0);
 }
 /*@C
@@ -144,22 +139,18 @@ PetscErrorCode LMEViewFromOptions(LME lme,PetscObject obj,const char name[])
 @*/
 PetscErrorCode LMEConvergedReasonView(LME lme,PetscViewer viewer)
 {
-  PetscErrorCode    ierr;
   PetscBool         isAscii;
   PetscViewerFormat format;
 
   PetscFunctionBegin;
   if (!viewer) viewer = PETSC_VIEWER_STDOUT_(PetscObjectComm((PetscObject)lme));
-  ierr = PetscObjectTypeCompare((PetscObject)viewer,PETSCVIEWERASCII,&isAscii);CHKERRQ(ierr);
+  PetscCall(PetscObjectTypeCompare((PetscObject)viewer,PETSCVIEWERASCII,&isAscii));
   if (isAscii) {
-    ierr = PetscViewerGetFormat(viewer,&format);CHKERRQ(ierr);
-    ierr = PetscViewerASCIIAddTab(viewer,((PetscObject)lme)->tablevel);CHKERRQ(ierr);
-    if (lme->reason > 0 && format != PETSC_VIEWER_FAILED) {
-      ierr = PetscViewerASCIIPrintf(viewer,"%s Linear matrix equation solve converged due to %s; iterations %D\n",((PetscObject)lme)->prefix?((PetscObject)lme)->prefix:"",LMEConvergedReasons[lme->reason],lme->its);CHKERRQ(ierr);
-    } else if (lme->reason <= 0) {
-      ierr = PetscViewerASCIIPrintf(viewer,"%s Linear matrix equation solve did not converge due to %s; iterations %D\n",((PetscObject)lme)->prefix?((PetscObject)lme)->prefix:"",LMEConvergedReasons[lme->reason],lme->its);CHKERRQ(ierr);
-    }
-    ierr = PetscViewerASCIISubtractTab(viewer,((PetscObject)lme)->tablevel);CHKERRQ(ierr);
+    PetscCall(PetscViewerGetFormat(viewer,&format));
+    PetscCall(PetscViewerASCIIAddTab(viewer,((PetscObject)lme)->tablevel));
+    if (lme->reason > 0 && format != PETSC_VIEWER_FAILED) PetscCall(PetscViewerASCIIPrintf(viewer,"%s Linear matrix equation solve converged due to %s; iterations %" PetscInt_FMT "\n",((PetscObject)lme)->prefix?((PetscObject)lme)->prefix:"",LMEConvergedReasons[lme->reason],lme->its));
+    else if (lme->reason <= 0) PetscCall(PetscViewerASCIIPrintf(viewer,"%s Linear matrix equation solve did not converge due to %s; iterations %" PetscInt_FMT "\n",((PetscObject)lme)->prefix?((PetscObject)lme)->prefix:"",LMEConvergedReasons[lme->reason],lme->its));
+    PetscCall(PetscViewerASCIISubtractTab(viewer,((PetscObject)lme)->tablevel));
   }
   PetscFunctionReturn(0);
 }
@@ -179,7 +170,6 @@ PetscErrorCode LMEConvergedReasonView(LME lme,PetscViewer viewer)
 @*/
 PetscErrorCode LMEConvergedReasonViewFromOptions(LME lme)
 {
-  PetscErrorCode    ierr;
   PetscViewer       viewer;
   PetscBool         flg;
   static PetscBool  incall = PETSC_FALSE;
@@ -188,12 +178,12 @@ PetscErrorCode LMEConvergedReasonViewFromOptions(LME lme)
   PetscFunctionBegin;
   if (incall) PetscFunctionReturn(0);
   incall = PETSC_TRUE;
-  ierr = PetscOptionsGetViewer(PetscObjectComm((PetscObject)lme),((PetscObject)lme)->options,((PetscObject)lme)->prefix,"-lme_converged_reason",&viewer,&format,&flg);CHKERRQ(ierr);
+  PetscCall(PetscOptionsGetViewer(PetscObjectComm((PetscObject)lme),((PetscObject)lme)->options,((PetscObject)lme)->prefix,"-lme_converged_reason",&viewer,&format,&flg));
   if (flg) {
-    ierr = PetscViewerPushFormat(viewer,format);CHKERRQ(ierr);
-    ierr = LMEConvergedReasonView(lme,viewer);CHKERRQ(ierr);
-    ierr = PetscViewerPopFormat(viewer);CHKERRQ(ierr);
-    ierr = PetscViewerDestroy(&viewer);CHKERRQ(ierr);
+    PetscCall(PetscViewerPushFormat(viewer,format));
+    PetscCall(LMEConvergedReasonView(lme,viewer));
+    PetscCall(PetscViewerPopFormat(viewer));
+    PetscCall(PetscViewerDestroy(&viewer));
   }
   incall = PETSC_FALSE;
   PetscFunctionReturn(0);
@@ -208,7 +198,7 @@ PetscErrorCode LMEConvergedReasonViewFromOptions(LME lme)
 .  comm - MPI communicator
 
    Output Parameter:
-.  lme - location to put the LME context
+.  outlme - location to put the LME context
 
    Note:
    The default LME type is LMEKRYLOV
@@ -219,14 +209,13 @@ PetscErrorCode LMEConvergedReasonViewFromOptions(LME lme)
 @*/
 PetscErrorCode LMECreate(MPI_Comm comm,LME *outlme)
 {
-  PetscErrorCode ierr;
   LME            lme;
 
   PetscFunctionBegin;
   PetscValidPointer(outlme,2);
   *outlme = 0;
-  ierr = LMEInitializePackage();CHKERRQ(ierr);
-  ierr = SlepcHeaderCreate(lme,LME_CLASSID,"LME","Linear Matrix Equation","LME",comm,LMEDestroy,LMEView);CHKERRQ(ierr);
+  PetscCall(LMEInitializePackage());
+  PetscCall(SlepcHeaderCreate(lme,LME_CLASSID,"LME","Linear Matrix Equation","LME",comm,LMEDestroy,LMEView));
 
   lme->A               = NULL;
   lme->B               = NULL;
@@ -287,25 +276,25 @@ PetscErrorCode LMECreate(MPI_Comm comm,LME *outlme)
 @*/
 PetscErrorCode LMESetType(LME lme,LMEType type)
 {
-  PetscErrorCode ierr,(*r)(LME);
+  PetscErrorCode (*r)(LME);
   PetscBool      match;
 
   PetscFunctionBegin;
   PetscValidHeaderSpecific(lme,LME_CLASSID,1);
   PetscValidCharPointer(type,2);
 
-  ierr = PetscObjectTypeCompare((PetscObject)lme,type,&match);CHKERRQ(ierr);
+  PetscCall(PetscObjectTypeCompare((PetscObject)lme,type,&match));
   if (match) PetscFunctionReturn(0);
 
-  ierr = PetscFunctionListFind(LMEList,type,&r);CHKERRQ(ierr);
-  if (!r) SETERRQ1(PetscObjectComm((PetscObject)lme),PETSC_ERR_ARG_UNKNOWN_TYPE,"Unknown LME type given: %s",type);
+  PetscCall(PetscFunctionListFind(LMEList,type,&r));
+  PetscCheck(r,PetscObjectComm((PetscObject)lme),PETSC_ERR_ARG_UNKNOWN_TYPE,"Unknown LME type given: %s",type);
 
-  if (lme->ops->destroy) { ierr = (*lme->ops->destroy)(lme);CHKERRQ(ierr); }
-  ierr = PetscMemzero(lme->ops,sizeof(struct _LMEOps));CHKERRQ(ierr);
+  if (lme->ops->destroy) PetscCall((*lme->ops->destroy)(lme));
+  PetscCall(PetscMemzero(lme->ops,sizeof(struct _LMEOps)));
 
   lme->setupcalled = 0;
-  ierr = PetscObjectChangeTypeName((PetscObject)lme,type);CHKERRQ(ierr);
-  ierr = (*r)(lme);CHKERRQ(ierr);
+  PetscCall(PetscObjectChangeTypeName((PetscObject)lme,type));
+  PetscCall((*r)(lme));
   PetscFunctionReturn(0);
 }
 
@@ -318,7 +307,7 @@ PetscErrorCode LMESetType(LME lme,LMEType type)
 .  lme - the linear matrix equation context
 
    Output Parameter:
-.  name - name of LME method
+.  type - name of LME method
 
    Level: intermediate
 
@@ -361,11 +350,9 @@ $     -lme_type my_solver
 @*/
 PetscErrorCode LMERegister(const char *name,PetscErrorCode (*function)(LME))
 {
-  PetscErrorCode ierr;
-
   PetscFunctionBegin;
-  ierr = LMEInitializePackage();CHKERRQ(ierr);
-  ierr = PetscFunctionListAdd(&LMEList,name,function);CHKERRQ(ierr);
+  PetscCall(LMEInitializePackage());
+  PetscCall(PetscFunctionListAdd(&LMEList,name,function));
   PetscFunctionReturn(0);
 }
 
@@ -402,14 +389,13 @@ $      -lme_monitor_my_monitor
 PetscErrorCode LMEMonitorRegister(const char name[],PetscViewerType vtype,PetscViewerFormat format,PetscErrorCode (*monitor)(LME,PetscInt,PetscReal,PetscViewerAndFormat*),PetscErrorCode (*create)(PetscViewer,PetscViewerFormat,void*,PetscViewerAndFormat**),PetscErrorCode (*destroy)(PetscViewerAndFormat**))
 {
   char           key[PETSC_MAX_PATH_LEN];
-  PetscErrorCode ierr;
 
   PetscFunctionBegin;
-  ierr = LMEInitializePackage();CHKERRQ(ierr);
-  ierr = SlepcMonitorMakeKey_Internal(name,vtype,format,key);CHKERRQ(ierr);
-  ierr = PetscFunctionListAdd(&LMEMonitorList,key,monitor);CHKERRQ(ierr);
-  if (create)  { ierr = PetscFunctionListAdd(&LMEMonitorCreateList,key,create);CHKERRQ(ierr); }
-  if (destroy) { ierr = PetscFunctionListAdd(&LMEMonitorDestroyList,key,destroy);CHKERRQ(ierr); }
+  PetscCall(LMEInitializePackage());
+  PetscCall(SlepcMonitorMakeKey_Internal(name,vtype,format,key));
+  PetscCall(PetscFunctionListAdd(&LMEMonitorList,key,monitor));
+  if (create)  PetscCall(PetscFunctionListAdd(&LMEMonitorCreateList,key,create));
+  if (destroy) PetscCall(PetscFunctionListAdd(&LMEMonitorDestroyList,key,destroy));
   PetscFunctionReturn(0);
 }
 
@@ -428,20 +414,18 @@ PetscErrorCode LMEMonitorRegister(const char name[],PetscViewerType vtype,PetscV
 @*/
 PetscErrorCode LMEReset(LME lme)
 {
-  PetscErrorCode ierr;
-
   PetscFunctionBegin;
   if (lme) PetscValidHeaderSpecific(lme,LME_CLASSID,1);
   if (!lme) PetscFunctionReturn(0);
-  if (lme->ops->reset) { ierr = (lme->ops->reset)(lme);CHKERRQ(ierr); }
-  ierr = MatDestroy(&lme->A);CHKERRQ(ierr);
-  ierr = MatDestroy(&lme->B);CHKERRQ(ierr);
-  ierr = MatDestroy(&lme->D);CHKERRQ(ierr);
-  ierr = MatDestroy(&lme->E);CHKERRQ(ierr);
-  ierr = MatDestroy(&lme->C);CHKERRQ(ierr);
-  ierr = MatDestroy(&lme->X);CHKERRQ(ierr);
-  ierr = BVDestroy(&lme->V);CHKERRQ(ierr);
-  ierr = VecDestroyVecs(lme->nwork,&lme->work);CHKERRQ(ierr);
+  if (lme->ops->reset) PetscCall((lme->ops->reset)(lme));
+  PetscCall(MatDestroy(&lme->A));
+  PetscCall(MatDestroy(&lme->B));
+  PetscCall(MatDestroy(&lme->D));
+  PetscCall(MatDestroy(&lme->E));
+  PetscCall(MatDestroy(&lme->C));
+  PetscCall(MatDestroy(&lme->X));
+  PetscCall(BVDestroy(&lme->V));
+  PetscCall(VecDestroyVecs(lme->nwork,&lme->work));
   lme->nwork = 0;
   lme->setupcalled = 0;
   PetscFunctionReturn(0);
@@ -461,16 +445,14 @@ PetscErrorCode LMEReset(LME lme)
 @*/
 PetscErrorCode LMEDestroy(LME *lme)
 {
-  PetscErrorCode ierr;
-
   PetscFunctionBegin;
   if (!*lme) PetscFunctionReturn(0);
   PetscValidHeaderSpecific(*lme,LME_CLASSID,1);
   if (--((PetscObject)(*lme))->refct > 0) { *lme = 0; PetscFunctionReturn(0); }
-  ierr = LMEReset(*lme);CHKERRQ(ierr);
-  if ((*lme)->ops->destroy) { ierr = (*(*lme)->ops->destroy)(*lme);CHKERRQ(ierr); }
-  ierr = LMEMonitorCancel(*lme);CHKERRQ(ierr);
-  ierr = PetscHeaderDestroy(lme);CHKERRQ(ierr);
+  PetscCall(LMEReset(*lme));
+  if ((*lme)->ops->destroy) PetscCall((*(*lme)->ops->destroy)(*lme));
+  PetscCall(LMEMonitorCancel(*lme));
+  PetscCall(PetscHeaderDestroy(lme));
   PetscFunctionReturn(0);
 }
 
@@ -493,16 +475,14 @@ PetscErrorCode LMEDestroy(LME *lme)
 @*/
 PetscErrorCode LMESetBV(LME lme,BV bv)
 {
-  PetscErrorCode ierr;
-
   PetscFunctionBegin;
   PetscValidHeaderSpecific(lme,LME_CLASSID,1);
   PetscValidHeaderSpecific(bv,BV_CLASSID,2);
   PetscCheckSameComm(lme,1,bv,2);
-  ierr = PetscObjectReference((PetscObject)bv);CHKERRQ(ierr);
-  ierr = BVDestroy(&lme->V);CHKERRQ(ierr);
+  PetscCall(PetscObjectReference((PetscObject)bv));
+  PetscCall(BVDestroy(&lme->V));
   lme->V = bv;
-  ierr = PetscLogObjectParent((PetscObject)lme,(PetscObject)lme->V);CHKERRQ(ierr);
+  PetscCall(PetscLogObjectParent((PetscObject)lme,(PetscObject)lme->V));
   PetscFunctionReturn(0);
 }
 
@@ -524,18 +504,15 @@ PetscErrorCode LMESetBV(LME lme,BV bv)
 @*/
 PetscErrorCode LMEGetBV(LME lme,BV *bv)
 {
-  PetscErrorCode ierr;
-
   PetscFunctionBegin;
   PetscValidHeaderSpecific(lme,LME_CLASSID,1);
   PetscValidPointer(bv,2);
   if (!lme->V) {
-    ierr = BVCreate(PetscObjectComm((PetscObject)lme),&lme->V);CHKERRQ(ierr);
-    ierr = PetscObjectIncrementTabLevel((PetscObject)lme->V,(PetscObject)lme,0);CHKERRQ(ierr);
-    ierr = PetscLogObjectParent((PetscObject)lme,(PetscObject)lme->V);CHKERRQ(ierr);
-    ierr = PetscObjectSetOptions((PetscObject)lme->V,((PetscObject)lme)->options);CHKERRQ(ierr);
+    PetscCall(BVCreate(PetscObjectComm((PetscObject)lme),&lme->V));
+    PetscCall(PetscObjectIncrementTabLevel((PetscObject)lme->V,(PetscObject)lme,0));
+    PetscCall(PetscLogObjectParent((PetscObject)lme,(PetscObject)lme->V));
+    PetscCall(PetscObjectSetOptions((PetscObject)lme->V,((PetscObject)lme)->options));
   }
   *bv = lme->V;
   PetscFunctionReturn(0);
 }
-
