@@ -1,7 +1,7 @@
 /*
    - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
    SLEPc - Scalable Library for Eigenvalue Problem Computations
-   Copyright (c) 2002-2021, Universitat Politecnica de Valencia, Spain
+   Copyright (c) 2002-, Universitat Politecnica de Valencia, Spain
 
    This file is part of SLEPc.
    SLEPc is distributed under a 2-clause BSD license (see LICENSE).
@@ -42,24 +42,23 @@ PetscErrorCode LMEMonitorSetFromOptions(LME lme,const char opt[],const char name
   PetscViewerType      vtype;
   char                 key[PETSC_MAX_PATH_LEN];
   PetscBool            flg;
-  PetscErrorCode       ierr;
 
   PetscFunctionBegin;
-  ierr = PetscOptionsGetViewer(PetscObjectComm((PetscObject)lme),((PetscObject)lme)->options,((PetscObject)lme)->prefix,opt,&viewer,&format,&flg);CHKERRQ(ierr);
+  PetscCall(PetscOptionsGetViewer(PetscObjectComm((PetscObject)lme),((PetscObject)lme)->options,((PetscObject)lme)->prefix,opt,&viewer,&format,&flg));
   if (!flg) PetscFunctionReturn(0);
 
-  ierr = PetscViewerGetType(viewer,&vtype);CHKERRQ(ierr);
-  ierr = SlepcMonitorMakeKey_Internal(name,vtype,format,key);CHKERRQ(ierr);
-  ierr = PetscFunctionListFind(LMEMonitorList,key,&mfunc);CHKERRQ(ierr);
-  if (!mfunc) SETERRQ(PetscObjectComm((PetscObject)lme),PETSC_ERR_SUP,"Specified viewer and format not supported");
-  ierr = PetscFunctionListFind(LMEMonitorCreateList,key,&cfunc);CHKERRQ(ierr);
-  ierr = PetscFunctionListFind(LMEMonitorDestroyList,key,&dfunc);CHKERRQ(ierr);
+  PetscCall(PetscViewerGetType(viewer,&vtype));
+  PetscCall(SlepcMonitorMakeKey_Internal(name,vtype,format,key));
+  PetscCall(PetscFunctionListFind(LMEMonitorList,key,&mfunc));
+  PetscCheck(mfunc,PetscObjectComm((PetscObject)lme),PETSC_ERR_SUP,"Specified viewer and format not supported");
+  PetscCall(PetscFunctionListFind(LMEMonitorCreateList,key,&cfunc));
+  PetscCall(PetscFunctionListFind(LMEMonitorDestroyList,key,&dfunc));
   if (!cfunc) cfunc = PetscViewerAndFormatCreate_Internal;
   if (!dfunc) dfunc = PetscViewerAndFormatDestroy;
 
-  ierr = (*cfunc)(viewer,format,ctx,&vf);CHKERRQ(ierr);
-  ierr = PetscObjectDereference((PetscObject)viewer);CHKERRQ(ierr);
-  ierr = LMEMonitorSet(lme,mfunc,vf,(PetscErrorCode(*)(void **))dfunc);CHKERRQ(ierr);
+  PetscCall((*cfunc)(viewer,format,ctx,&vf));
+  PetscCall(PetscObjectDereference((PetscObject)viewer));
+  PetscCall(LMEMonitorSet(lme,mfunc,vf,(PetscErrorCode(*)(void **))dfunc));
   PetscFunctionReturn(0);
 }
 
@@ -77,6 +76,8 @@ PetscErrorCode LMEMonitorSetFromOptions(LME lme,const char opt[],const char name
    To see all options, run your program with the -help option.
 
    Level: beginner
+
+.seealso: LMESetOptionsPrefix()
 @*/
 PetscErrorCode LMESetFromOptions(LME lme)
 {
@@ -88,59 +89,54 @@ PetscErrorCode LMESetFromOptions(LME lme)
 
   PetscFunctionBegin;
   PetscValidHeaderSpecific(lme,LME_CLASSID,1);
-  ierr = LMERegisterAll();CHKERRQ(ierr);
-  ierr = PetscObjectOptionsBegin((PetscObject)lme);CHKERRQ(ierr);
-    ierr = PetscOptionsFList("-lme_type","Linear matrix equation","LMESetType",LMEList,(char*)(((PetscObject)lme)->type_name?((PetscObject)lme)->type_name:LMEKRYLOV),type,sizeof(type),&flg);CHKERRQ(ierr);
-    if (flg) {
-      ierr = LMESetType(lme,type);CHKERRQ(ierr);
-    } else if (!((PetscObject)lme)->type_name) {
-      ierr = LMESetType(lme,LMEKRYLOV);CHKERRQ(ierr);
-    }
+  PetscCall(LMERegisterAll());
+  ierr = PetscObjectOptionsBegin((PetscObject)lme);PetscCall(ierr);
+    PetscCall(PetscOptionsFList("-lme_type","Linear matrix equation","LMESetType",LMEList,(char*)(((PetscObject)lme)->type_name?((PetscObject)lme)->type_name:LMEKRYLOV),type,sizeof(type),&flg));
+    if (flg) PetscCall(LMESetType(lme,type));
+    else if (!((PetscObject)lme)->type_name) PetscCall(LMESetType(lme,LMEKRYLOV));
 
-    ierr = PetscOptionsBoolGroupBegin("-lme_lyapunov","Continuous-time Lyapunov equation","LMESetProblemType",&flg);CHKERRQ(ierr);
-    if (flg) { ierr = LMESetProblemType(lme,LME_LYAPUNOV);CHKERRQ(ierr); }
-    ierr = PetscOptionsBoolGroup("-lme_sylvester","Continuous-time Sylvester equation","LMESetProblemType",&flg);CHKERRQ(ierr);
-    if (flg) { ierr = LMESetProblemType(lme,LME_SYLVESTER);CHKERRQ(ierr); }
-    ierr = PetscOptionsBoolGroup("-lme_gen_lyapunov","Generalized Lyapunov equation","LMESetProblemType",&flg);CHKERRQ(ierr);
-    if (flg) { ierr = LMESetProblemType(lme,LME_GEN_LYAPUNOV);CHKERRQ(ierr); }
-    ierr = PetscOptionsBoolGroup("-lme_gen_sylvester","Generalized Sylvester equation","LMESetProblemType",&flg);CHKERRQ(ierr);
-    if (flg) { ierr = LMESetProblemType(lme,LME_GEN_SYLVESTER);CHKERRQ(ierr); }
-    ierr = PetscOptionsBoolGroup("-lme_dt_lyapunov","Discrete-time Lyapunov equation","LMESetProblemType",&flg);CHKERRQ(ierr);
-    if (flg) { ierr = LMESetProblemType(lme,LME_DT_LYAPUNOV);CHKERRQ(ierr); }
-    ierr = PetscOptionsBoolGroupEnd("-lme_stein","Stein equation","LMESetProblemType",&flg);CHKERRQ(ierr);
-    if (flg) { ierr = LMESetProblemType(lme,LME_STEIN);CHKERRQ(ierr); }
+    PetscCall(PetscOptionsBoolGroupBegin("-lme_lyapunov","Continuous-time Lyapunov equation","LMESetProblemType",&flg));
+    if (flg) PetscCall(LMESetProblemType(lme,LME_LYAPUNOV));
+    PetscCall(PetscOptionsBoolGroup("-lme_sylvester","Continuous-time Sylvester equation","LMESetProblemType",&flg));
+    if (flg) PetscCall(LMESetProblemType(lme,LME_SYLVESTER));
+    PetscCall(PetscOptionsBoolGroup("-lme_gen_lyapunov","Generalized Lyapunov equation","LMESetProblemType",&flg));
+    if (flg) PetscCall(LMESetProblemType(lme,LME_GEN_LYAPUNOV));
+    PetscCall(PetscOptionsBoolGroup("-lme_gen_sylvester","Generalized Sylvester equation","LMESetProblemType",&flg));
+    if (flg) PetscCall(LMESetProblemType(lme,LME_GEN_SYLVESTER));
+    PetscCall(PetscOptionsBoolGroup("-lme_dt_lyapunov","Discrete-time Lyapunov equation","LMESetProblemType",&flg));
+    if (flg) PetscCall(LMESetProblemType(lme,LME_DT_LYAPUNOV));
+    PetscCall(PetscOptionsBoolGroupEnd("-lme_stein","Stein equation","LMESetProblemType",&flg));
+    if (flg) PetscCall(LMESetProblemType(lme,LME_STEIN));
 
     i = lme->max_it;
-    ierr = PetscOptionsInt("-lme_max_it","Maximum number of iterations","LMESetTolerances",lme->max_it,&i,&flg1);CHKERRQ(ierr);
+    PetscCall(PetscOptionsInt("-lme_max_it","Maximum number of iterations","LMESetTolerances",lme->max_it,&i,&flg1));
     if (!flg1) i = PETSC_DEFAULT;
     r = lme->tol;
-    ierr = PetscOptionsReal("-lme_tol","Tolerance","LMESetTolerances",SlepcDefaultTol(lme->tol),&r,&flg2);CHKERRQ(ierr);
-    if (flg1 || flg2) { ierr = LMESetTolerances(lme,r,i);CHKERRQ(ierr); }
+    PetscCall(PetscOptionsReal("-lme_tol","Tolerance","LMESetTolerances",SlepcDefaultTol(lme->tol),&r,&flg2));
+    if (flg1 || flg2) PetscCall(LMESetTolerances(lme,r,i));
 
-    ierr = PetscOptionsInt("-lme_ncv","Number of basis vectors","LMESetDimensions",lme->ncv,&i,&flg);CHKERRQ(ierr);
-    if (flg) { ierr = LMESetDimensions(lme,i);CHKERRQ(ierr); }
+    PetscCall(PetscOptionsInt("-lme_ncv","Number of basis vectors","LMESetDimensions",lme->ncv,&i,&flg));
+    if (flg) PetscCall(LMESetDimensions(lme,i));
 
-    ierr = PetscOptionsBool("-lme_error_if_not_converged","Generate error if solver does not converge","LMESetErrorIfNotConverged",lme->errorifnotconverged,&lme->errorifnotconverged,NULL);CHKERRQ(ierr);
+    PetscCall(PetscOptionsBool("-lme_error_if_not_converged","Generate error if solver does not converge","LMESetErrorIfNotConverged",lme->errorifnotconverged,&lme->errorifnotconverged,NULL));
 
     /* -----------------------------------------------------------------------*/
     /*
       Cancels all monitors hardwired into code before call to LMESetFromOptions()
     */
-    ierr = PetscOptionsBool("-lme_monitor_cancel","Remove any hardwired monitor routines","LMEMonitorCancel",PETSC_FALSE,&flg,&set);CHKERRQ(ierr);
-    if (set && flg) { ierr = LMEMonitorCancel(lme);CHKERRQ(ierr); }
-    ierr = LMEMonitorSetFromOptions(lme,"-lme_monitor","error_estimate",NULL);CHKERRQ(ierr);
+    PetscCall(PetscOptionsBool("-lme_monitor_cancel","Remove any hardwired monitor routines","LMEMonitorCancel",PETSC_FALSE,&flg,&set));
+    if (set && flg) PetscCall(LMEMonitorCancel(lme));
+    PetscCall(LMEMonitorSetFromOptions(lme,"-lme_monitor","error_estimate",NULL));
 
     /* -----------------------------------------------------------------------*/
-    ierr = PetscOptionsName("-lme_view","Print detailed information on solver used","LMEView",NULL);CHKERRQ(ierr);
+    PetscCall(PetscOptionsName("-lme_view","Print detailed information on solver used","LMEView",NULL));
 
-    if (lme->ops->setfromoptions) {
-      ierr = (*lme->ops->setfromoptions)(PetscOptionsObject,lme);CHKERRQ(ierr);
-    }
-    ierr = PetscObjectProcessOptionsHandlers(PetscOptionsObject,(PetscObject)lme);CHKERRQ(ierr);
-  ierr = PetscOptionsEnd();CHKERRQ(ierr);
+    if (lme->ops->setfromoptions) PetscCall((*lme->ops->setfromoptions)(PetscOptionsObject,lme));
+    PetscCall(PetscObjectProcessOptionsHandlers(PetscOptionsObject,(PetscObject)lme));
+  ierr = PetscOptionsEnd();PetscCall(ierr);
 
-  if (!lme->V) { ierr = LMEGetBV(lme,&lme->V);CHKERRQ(ierr); }
-  ierr = BVSetFromOptions(lme->V);CHKERRQ(ierr);
+  if (!lme->V) PetscCall(LMEGetBV(lme,&lme->V));
+  PetscCall(BVSetFromOptions(lme->V));
   PetscFunctionReturn(0);
 }
 
@@ -295,14 +291,14 @@ PetscErrorCode LMESetTolerances(LME lme,PetscReal tol,PetscInt maxits)
     lme->tol = PETSC_DEFAULT;
     lme->setupcalled = 0;
   } else {
-    if (tol <= 0.0) SETERRQ(PetscObjectComm((PetscObject)lme),PETSC_ERR_ARG_OUTOFRANGE,"Illegal value of tol. Must be > 0");
+    PetscCheck(tol>0.0,PetscObjectComm((PetscObject)lme),PETSC_ERR_ARG_OUTOFRANGE,"Illegal value of tol. Must be > 0");
     lme->tol = tol;
   }
   if (maxits == PETSC_DEFAULT || maxits == PETSC_DECIDE) {
     lme->max_it = PETSC_DEFAULT;
     lme->setupcalled = 0;
   } else {
-    if (maxits <= 0) SETERRQ(PetscObjectComm((PetscObject)lme),PETSC_ERR_ARG_OUTOFRANGE,"Illegal value of maxits. Must be > 0");
+    PetscCheck(maxits>0,PetscObjectComm((PetscObject)lme),PETSC_ERR_ARG_OUTOFRANGE,"Illegal value of maxits. Must be > 0");
     lme->max_it = maxits;
   }
   PetscFunctionReturn(0);
@@ -360,7 +356,7 @@ PetscErrorCode LMESetDimensions(LME lme,PetscInt ncv)
   if (ncv == PETSC_DECIDE || ncv == PETSC_DEFAULT) {
     lme->ncv = PETSC_DEFAULT;
   } else {
-    if (ncv<1) SETERRQ(PetscObjectComm((PetscObject)lme),PETSC_ERR_ARG_OUTOFRANGE,"Illegal value of ncv. Must be > 0");
+    PetscCheck(ncv>0,PetscObjectComm((PetscObject)lme),PETSC_ERR_ARG_OUTOFRANGE,"Illegal value of ncv. Must be > 0");
     lme->ncv = ncv;
   }
   lme->setupcalled = 0;
@@ -411,7 +407,7 @@ PetscErrorCode LMESetErrorIfNotConverged(LME lme,PetscBool flg)
 
    Level: intermediate
 
-.seealso:  LMESetErrorIfNotConverged()
+.seealso: LMESetErrorIfNotConverged()
 @*/
 PetscErrorCode LMEGetErrorIfNotConverged(LME lme,PetscBool *flag)
 {
@@ -450,13 +446,11 @@ PetscErrorCode LMEGetErrorIfNotConverged(LME lme,PetscBool *flag)
 @*/
 PetscErrorCode LMESetOptionsPrefix(LME lme,const char *prefix)
 {
-  PetscErrorCode ierr;
-
   PetscFunctionBegin;
   PetscValidHeaderSpecific(lme,LME_CLASSID,1);
-  if (!lme->V) { ierr = LMEGetBV(lme,&lme->V);CHKERRQ(ierr); }
-  ierr = BVSetOptionsPrefix(lme->V,prefix);CHKERRQ(ierr);
-  ierr = PetscObjectSetOptionsPrefix((PetscObject)lme,prefix);CHKERRQ(ierr);
+  if (!lme->V) PetscCall(LMEGetBV(lme,&lme->V));
+  PetscCall(BVSetOptionsPrefix(lme->V,prefix));
+  PetscCall(PetscObjectSetOptionsPrefix((PetscObject)lme,prefix));
   PetscFunctionReturn(0);
 }
 
@@ -480,13 +474,11 @@ PetscErrorCode LMESetOptionsPrefix(LME lme,const char *prefix)
 @*/
 PetscErrorCode LMEAppendOptionsPrefix(LME lme,const char *prefix)
 {
-  PetscErrorCode ierr;
-
   PetscFunctionBegin;
   PetscValidHeaderSpecific(lme,LME_CLASSID,1);
-  if (!lme->V) { ierr = LMEGetBV(lme,&lme->V);CHKERRQ(ierr); }
-  ierr = BVAppendOptionsPrefix(lme->V,prefix);CHKERRQ(ierr);
-  ierr = PetscObjectAppendOptionsPrefix((PetscObject)lme,prefix);CHKERRQ(ierr);
+  if (!lme->V) PetscCall(LMEGetBV(lme,&lme->V));
+  PetscCall(BVAppendOptionsPrefix(lme->V,prefix));
+  PetscCall(PetscObjectAppendOptionsPrefix((PetscObject)lme,prefix));
   PetscFunctionReturn(0);
 }
 
@@ -512,11 +504,9 @@ PetscErrorCode LMEAppendOptionsPrefix(LME lme,const char *prefix)
 @*/
 PetscErrorCode LMEGetOptionsPrefix(LME lme,const char *prefix[])
 {
-  PetscErrorCode ierr;
-
   PetscFunctionBegin;
   PetscValidHeaderSpecific(lme,LME_CLASSID,1);
   PetscValidPointer(prefix,2);
-  ierr = PetscObjectGetOptionsPrefix((PetscObject)lme,prefix);CHKERRQ(ierr);
+  PetscCall(PetscObjectGetOptionsPrefix((PetscObject)lme,prefix));
   PetscFunctionReturn(0);
 }
