@@ -1,7 +1,7 @@
 /*
    - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
    SLEPc - Scalable Library for Eigenvalue Problem Computations
-   Copyright (c) 2002-2021, Universitat Politecnica de Valencia, Spain
+   Copyright (c) 2002-, Universitat Politecnica de Valencia, Spain
 
    This file is part of SLEPc.
    SLEPc is distributed under a 2-clause BSD license (see LICENSE).
@@ -40,34 +40,32 @@
 @*/
 PetscErrorCode LMESolve(LME lme)
 {
-  PetscErrorCode ierr;
-
   PetscFunctionBegin;
   PetscValidHeaderSpecific(lme,LME_CLASSID,1);
 
   /* call setup */
-  ierr = LMESetUp(lme);CHKERRQ(ierr);
+  PetscCall(LMESetUp(lme));
   lme->its    = 0;
   lme->errest = 0.0;
 
-  ierr = LMEViewFromOptions(lme,NULL,"-lme_view_pre");CHKERRQ(ierr);
+  PetscCall(LMEViewFromOptions(lme,NULL,"-lme_view_pre"));
 
   /* call solver */
-  if (!lme->ops->solve[lme->problem_type]) SETERRQ1(PetscObjectComm((PetscObject)lme),PETSC_ERR_SUP,"The specified solver does not support equation type %s",LMEProblemTypes[lme->problem_type]);
-  ierr = PetscLogEventBegin(LME_Solve,lme,0,0,0);CHKERRQ(ierr);
-  ierr = (*lme->ops->solve[lme->problem_type])(lme);CHKERRQ(ierr);
-  ierr = PetscLogEventEnd(LME_Solve,lme,0,0,0);CHKERRQ(ierr);
+  PetscCheck(lme->ops->solve[lme->problem_type],PetscObjectComm((PetscObject)lme),PETSC_ERR_SUP,"The specified solver does not support equation type %s",LMEProblemTypes[lme->problem_type]);
+  PetscCall(PetscLogEventBegin(LME_Solve,lme,0,0,0));
+  PetscCall((*lme->ops->solve[lme->problem_type])(lme));
+  PetscCall(PetscLogEventEnd(LME_Solve,lme,0,0,0));
 
-  if (!lme->reason) SETERRQ(PetscObjectComm((PetscObject)lme),PETSC_ERR_PLIB,"Internal error, solver returned without setting converged reason");
+  PetscCheck(lme->reason,PetscObjectComm((PetscObject)lme),PETSC_ERR_PLIB,"Internal error, solver returned without setting converged reason");
 
-  if (lme->errorifnotconverged && lme->reason < 0) SETERRQ(PetscObjectComm((PetscObject)lme),PETSC_ERR_NOT_CONVERGED,"LMESolve has not converged");
+  PetscCheck(!lme->errorifnotconverged || lme->reason>=0,PetscObjectComm((PetscObject)lme),PETSC_ERR_NOT_CONVERGED,"LMESolve has not converged");
 
   /* various viewers */
-  ierr = LMEViewFromOptions(lme,NULL,"-lme_view");CHKERRQ(ierr);
-  ierr = LMEConvergedReasonViewFromOptions(lme);CHKERRQ(ierr);
-  ierr = MatViewFromOptions(lme->A,(PetscObject)lme,"-lme_view_mat");CHKERRQ(ierr);
-  ierr = MatViewFromOptions(lme->C,(PetscObject)lme,"-lme_view_rhs");CHKERRQ(ierr);
-  ierr = MatViewFromOptions(lme->X,(PetscObject)lme,"-lme_view_solution");CHKERRQ(ierr);
+  PetscCall(LMEViewFromOptions(lme,NULL,"-lme_view"));
+  PetscCall(LMEConvergedReasonViewFromOptions(lme));
+  PetscCall(MatViewFromOptions(lme->A,(PetscObject)lme,"-lme_view_mat"));
+  PetscCall(MatViewFromOptions(lme->C,(PetscObject)lme,"-lme_view_rhs"));
+  PetscCall(MatViewFromOptions(lme->X,(PetscObject)lme,"-lme_view_solution"));
   PetscFunctionReturn(0);
 }
 
@@ -173,7 +171,6 @@ PetscErrorCode LMEGetErrorEstimate(LME lme,PetscReal *errest)
 */
 PetscErrorCode LMEComputeResidualNorm_Lyapunov(LME lme,PetscReal *norm)
 {
-  PetscErrorCode    ierr;
   PetscInt          j,n,N,k,l;
   PetscBLASInt      n_,N_,k_,l_;
   PetscScalar       *Rarray,alpha=1.0,beta=0.0;
@@ -184,99 +181,99 @@ PetscErrorCode LMEComputeResidualNorm_Lyapunov(LME lme,PetscReal *norm)
   VecScatter        vscat;
 
   PetscFunctionBegin;
-  ierr = MatLRCGetMats(lme->C,NULL,&C1m,NULL,NULL);CHKERRQ(ierr);
-  ierr = MatLRCGetMats(lme->X,NULL,&X1m,NULL,NULL);CHKERRQ(ierr);
-  ierr = BVCreateFromMat(C1m,&C1);CHKERRQ(ierr);
-  ierr = BVSetFromOptions(C1);CHKERRQ(ierr);
-  ierr = BVCreateFromMat(X1m,&X1);CHKERRQ(ierr);
-  ierr = BVSetFromOptions(X1);CHKERRQ(ierr);
-  ierr = BVGetSizes(X1,&n,&N,&k);CHKERRQ(ierr);
-  ierr = BVGetSizes(C1,NULL,NULL,&l);CHKERRQ(ierr);
-  ierr = PetscBLASIntCast(n,&n_);CHKERRQ(ierr);
-  ierr = PetscBLASIntCast(N,&N_);CHKERRQ(ierr);
-  ierr = PetscBLASIntCast(k,&k_);CHKERRQ(ierr);
-  ierr = PetscBLASIntCast(l,&l_);CHKERRQ(ierr);
+  PetscCall(MatLRCGetMats(lme->C,NULL,&C1m,NULL,NULL));
+  PetscCall(MatLRCGetMats(lme->X,NULL,&X1m,NULL,NULL));
+  PetscCall(BVCreateFromMat(C1m,&C1));
+  PetscCall(BVSetFromOptions(C1));
+  PetscCall(BVCreateFromMat(X1m,&X1));
+  PetscCall(BVSetFromOptions(X1));
+  PetscCall(BVGetSizes(X1,&n,&N,&k));
+  PetscCall(BVGetSizes(C1,NULL,NULL,&l));
+  PetscCall(PetscBLASIntCast(n,&n_));
+  PetscCall(PetscBLASIntCast(N,&N_));
+  PetscCall(PetscBLASIntCast(k,&k_));
+  PetscCall(PetscBLASIntCast(l,&l_));
 
   /* create W to store a redundant copy of a BV in each process */
-  ierr = BVCreate(PETSC_COMM_SELF,&W);CHKERRQ(ierr);
-  ierr = BVSetSizes(W,N,N,k);CHKERRQ(ierr);
-  ierr = BVSetFromOptions(W);CHKERRQ(ierr);
-  ierr = BVGetColumn(X1,0,&v);CHKERRQ(ierr);
-  ierr = VecScatterCreateToAll(v,&vscat,NULL);CHKERRQ(ierr);
-  ierr = BVRestoreColumn(X1,0,&v);CHKERRQ(ierr);
+  PetscCall(BVCreate(PETSC_COMM_SELF,&W));
+  PetscCall(BVSetSizes(W,N,N,k));
+  PetscCall(BVSetFromOptions(W));
+  PetscCall(BVGetColumn(X1,0,&v));
+  PetscCall(VecScatterCreateToAll(v,&vscat,NULL));
+  PetscCall(BVRestoreColumn(X1,0,&v));
 
   /* create AX to hold the product A*X1 */
-  ierr = BVDuplicate(X1,&AX);CHKERRQ(ierr);
-  ierr = BVMatMult(X1,lme->A,AX);CHKERRQ(ierr);
+  PetscCall(BVDuplicate(X1,&AX));
+  PetscCall(BVMatMult(X1,lme->A,AX));
 
   /* create dense matrix to hold the residual R=C1*C1'+AX*X1'+X1*AX' */
-  ierr = MatCreateDense(PetscObjectComm((PetscObject)lme),n,n,N,N,NULL,&R);CHKERRQ(ierr);
+  PetscCall(MatCreateDense(PetscObjectComm((PetscObject)lme),n,n,N,N,NULL,&R));
 
   /* R=C1*C1' */
-  ierr = MatDenseGetArrayWrite(R,&Rarray);CHKERRQ(ierr);
+  PetscCall(MatDenseGetArrayWrite(R,&Rarray));
   for (j=0;j<l;j++) {
-    ierr = BVGetColumn(C1,j,&v);CHKERRQ(ierr);
-    ierr = BVGetColumn(W,j,&w);CHKERRQ(ierr);
-    ierr = VecScatterBegin(vscat,v,w,INSERT_VALUES,SCATTER_FORWARD);CHKERRQ(ierr);
-    ierr = VecScatterEnd(vscat,v,w,INSERT_VALUES,SCATTER_FORWARD);CHKERRQ(ierr);
-    ierr = BVRestoreColumn(C1,j,&v);CHKERRQ(ierr);
-    ierr = BVRestoreColumn(W,j,&w);CHKERRQ(ierr);
+    PetscCall(BVGetColumn(C1,j,&v));
+    PetscCall(BVGetColumn(W,j,&w));
+    PetscCall(VecScatterBegin(vscat,v,w,INSERT_VALUES,SCATTER_FORWARD));
+    PetscCall(VecScatterEnd(vscat,v,w,INSERT_VALUES,SCATTER_FORWARD));
+    PetscCall(BVRestoreColumn(C1,j,&v));
+    PetscCall(BVRestoreColumn(W,j,&w));
   }
   if (n) {
-    ierr = BVGetArrayRead(C1,&A);CHKERRQ(ierr);
-    ierr = BVGetArrayRead(W,&B);CHKERRQ(ierr);
+    PetscCall(BVGetArrayRead(C1,&A));
+    PetscCall(BVGetArrayRead(W,&B));
     PetscStackCallBLAS("BLASgemm",BLASgemm_("N","C",&n_,&N_,&l_,&alpha,(PetscScalar*)A,&n_,(PetscScalar*)B,&N_,&beta,Rarray,&n_));
-    ierr = BVRestoreArrayRead(C1,&A);CHKERRQ(ierr);
-    ierr = BVRestoreArrayRead(W,&B);CHKERRQ(ierr);
+    PetscCall(BVRestoreArrayRead(C1,&A));
+    PetscCall(BVRestoreArrayRead(W,&B));
   }
   beta = 1.0;
 
   /* R+=AX*X1' */
   for (j=0;j<k;j++) {
-    ierr = BVGetColumn(X1,j,&v);CHKERRQ(ierr);
-    ierr = BVGetColumn(W,j,&w);CHKERRQ(ierr);
-    ierr = VecScatterBegin(vscat,v,w,INSERT_VALUES,SCATTER_FORWARD);CHKERRQ(ierr);
-    ierr = VecScatterEnd(vscat,v,w,INSERT_VALUES,SCATTER_FORWARD);CHKERRQ(ierr);
-    ierr = BVRestoreColumn(X1,j,&v);CHKERRQ(ierr);
-    ierr = BVRestoreColumn(W,j,&w);CHKERRQ(ierr);
+    PetscCall(BVGetColumn(X1,j,&v));
+    PetscCall(BVGetColumn(W,j,&w));
+    PetscCall(VecScatterBegin(vscat,v,w,INSERT_VALUES,SCATTER_FORWARD));
+    PetscCall(VecScatterEnd(vscat,v,w,INSERT_VALUES,SCATTER_FORWARD));
+    PetscCall(BVRestoreColumn(X1,j,&v));
+    PetscCall(BVRestoreColumn(W,j,&w));
   }
   if (n) {
-    ierr = BVGetArrayRead(AX,&A);CHKERRQ(ierr);
-    ierr = BVGetArrayRead(W,&B);CHKERRQ(ierr);
+    PetscCall(BVGetArrayRead(AX,&A));
+    PetscCall(BVGetArrayRead(W,&B));
     PetscStackCallBLAS("BLASgemm",BLASgemm_("N","C",&n_,&N_,&k_,&alpha,(PetscScalar*)A,&n_,(PetscScalar*)B,&N_,&beta,Rarray,&n_));
-    ierr = BVRestoreArrayRead(AX,&A);CHKERRQ(ierr);
-    ierr = BVRestoreArrayRead(W,&B);CHKERRQ(ierr);
+    PetscCall(BVRestoreArrayRead(AX,&A));
+    PetscCall(BVRestoreArrayRead(W,&B));
   }
 
   /* R+=X1*AX' */
   for (j=0;j<k;j++) {
-    ierr = BVGetColumn(AX,j,&v);CHKERRQ(ierr);
-    ierr = BVGetColumn(W,j,&w);CHKERRQ(ierr);
-    ierr = VecScatterBegin(vscat,v,w,INSERT_VALUES,SCATTER_FORWARD);CHKERRQ(ierr);
-    ierr = VecScatterEnd(vscat,v,w,INSERT_VALUES,SCATTER_FORWARD);CHKERRQ(ierr);
-    ierr = BVRestoreColumn(AX,j,&v);CHKERRQ(ierr);
-    ierr = BVRestoreColumn(W,j,&w);CHKERRQ(ierr);
+    PetscCall(BVGetColumn(AX,j,&v));
+    PetscCall(BVGetColumn(W,j,&w));
+    PetscCall(VecScatterBegin(vscat,v,w,INSERT_VALUES,SCATTER_FORWARD));
+    PetscCall(VecScatterEnd(vscat,v,w,INSERT_VALUES,SCATTER_FORWARD));
+    PetscCall(BVRestoreColumn(AX,j,&v));
+    PetscCall(BVRestoreColumn(W,j,&w));
   }
   if (n) {
-    ierr = BVGetArrayRead(X1,&A);CHKERRQ(ierr);
-    ierr = BVGetArrayRead(W,&B);CHKERRQ(ierr);
+    PetscCall(BVGetArrayRead(X1,&A));
+    PetscCall(BVGetArrayRead(W,&B));
     PetscStackCallBLAS("BLASgemm",BLASgemm_("N","C",&n_,&N_,&k_,&alpha,(PetscScalar*)A,&n_,(PetscScalar*)B,&N_,&beta,Rarray,&n_));
-    ierr = BVRestoreArrayRead(X1,&A);CHKERRQ(ierr);
-    ierr = BVRestoreArrayRead(W,&B);CHKERRQ(ierr);
+    PetscCall(BVRestoreArrayRead(X1,&A));
+    PetscCall(BVRestoreArrayRead(W,&B));
   }
-  ierr = MatDenseRestoreArrayWrite(R,&Rarray);CHKERRQ(ierr);
+  PetscCall(MatDenseRestoreArrayWrite(R,&Rarray));
 
   /* compute ||R||_F */
-  ierr = MatAssemblyBegin(R,MAT_FINAL_ASSEMBLY);CHKERRQ(ierr);
-  ierr = MatAssemblyEnd(R,MAT_FINAL_ASSEMBLY);CHKERRQ(ierr);
-  ierr = MatNorm(R,NORM_FROBENIUS,norm);CHKERRQ(ierr);
+  PetscCall(MatAssemblyBegin(R,MAT_FINAL_ASSEMBLY));
+  PetscCall(MatAssemblyEnd(R,MAT_FINAL_ASSEMBLY));
+  PetscCall(MatNorm(R,NORM_FROBENIUS,norm));
 
-  ierr = BVDestroy(&W);CHKERRQ(ierr);
-  ierr = VecScatterDestroy(&vscat);CHKERRQ(ierr);
-  ierr = BVDestroy(&AX);CHKERRQ(ierr);
-  ierr = MatDestroy(&R);CHKERRQ(ierr);
-  ierr = BVDestroy(&C1);CHKERRQ(ierr);
-  ierr = BVDestroy(&X1);CHKERRQ(ierr);
+  PetscCall(BVDestroy(&W));
+  PetscCall(VecScatterDestroy(&vscat));
+  PetscCall(BVDestroy(&AX));
+  PetscCall(MatDestroy(&R));
+  PetscCall(BVDestroy(&C1));
+  PetscCall(BVDestroy(&X1));
   PetscFunctionReturn(0);
 }
 
@@ -303,25 +300,22 @@ PetscErrorCode LMEComputeResidualNorm_Lyapunov(LME lme,PetscReal *norm)
 @*/
 PetscErrorCode LMEComputeError(LME lme,PetscReal *error)
 {
-  PetscErrorCode ierr;
-
   PetscFunctionBegin;
   PetscValidHeaderSpecific(lme,LME_CLASSID,1);
   PetscValidRealPointer(error,2);
 
-  ierr = PetscLogEventBegin(LME_ComputeError,lme,0,0,0);CHKERRQ(ierr);
+  PetscCall(PetscLogEventBegin(LME_ComputeError,lme,0,0,0));
   /* compute residual norm */
   switch (lme->problem_type) {
     case LME_LYAPUNOV:
-      ierr = LMEComputeResidualNorm_Lyapunov(lme,error);CHKERRQ(ierr);
+      PetscCall(LMEComputeResidualNorm_Lyapunov(lme,error));
       break;
     default:
-      SETERRQ1(PetscObjectComm((PetscObject)lme),PETSC_ERR_SUP,"Not implemented for equation type %s",LMEProblemTypes[lme->problem_type]);
+      SETERRQ(PetscObjectComm((PetscObject)lme),PETSC_ERR_SUP,"Not implemented for equation type %s",LMEProblemTypes[lme->problem_type]);
   }
 
   /* compute error */
   /* currently we only support absolute error, so just return the norm */
-  ierr = PetscLogEventEnd(LME_ComputeError,lme,0,0,0);CHKERRQ(ierr);
+  PetscCall(PetscLogEventEnd(LME_ComputeError,lme,0,0,0));
   PetscFunctionReturn(0);
 }
-
