@@ -1,7 +1,7 @@
 /*
    - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
    SLEPc - Scalable Library for Eigenvalue Problem Computations
-   Copyright (c) 2002-2021, Universitat Politecnica de Valencia, Spain
+   Copyright (c) 2002-, Universitat Politecnica de Valencia, Spain
 
    This file is part of SLEPc.
    SLEPc is distributed under a 2-clause BSD license (see LICENSE).
@@ -51,42 +51,39 @@ PetscBool         MFNMonitorRegisterAllCalled = PETSC_FALSE;
    PetscViewerASCIIOpen() - output to a specified file.
 
    Level: beginner
+
+.seealso: MFNCreate()
 @*/
 PetscErrorCode MFNView(MFN mfn,PetscViewer viewer)
 {
-  PetscErrorCode ierr;
   PetscBool      isascii;
 
   PetscFunctionBegin;
   PetscValidHeaderSpecific(mfn,MFN_CLASSID,1);
-  if (!viewer) {
-    ierr = PetscViewerASCIIGetStdout(PetscObjectComm((PetscObject)mfn),&viewer);CHKERRQ(ierr);
-  }
+  if (!viewer) PetscCall(PetscViewerASCIIGetStdout(PetscObjectComm((PetscObject)mfn),&viewer));
   PetscValidHeaderSpecific(viewer,PETSC_VIEWER_CLASSID,2);
   PetscCheckSameComm(mfn,1,viewer,2);
 
-  ierr = PetscObjectTypeCompare((PetscObject)viewer,PETSCVIEWERASCII,&isascii);CHKERRQ(ierr);
+  PetscCall(PetscObjectTypeCompare((PetscObject)viewer,PETSCVIEWERASCII,&isascii));
   if (isascii) {
-    ierr = PetscObjectPrintClassNamePrefixType((PetscObject)mfn,viewer);CHKERRQ(ierr);
+    PetscCall(PetscObjectPrintClassNamePrefixType((PetscObject)mfn,viewer));
     if (mfn->ops->view) {
-      ierr = PetscViewerASCIIPushTab(viewer);CHKERRQ(ierr);
-      ierr = (*mfn->ops->view)(mfn,viewer);CHKERRQ(ierr);
-      ierr = PetscViewerASCIIPopTab(viewer);CHKERRQ(ierr);
+      PetscCall(PetscViewerASCIIPushTab(viewer));
+      PetscCall((*mfn->ops->view)(mfn,viewer));
+      PetscCall(PetscViewerASCIIPopTab(viewer));
     }
-    ierr = PetscViewerASCIIPrintf(viewer,"  number of column vectors (ncv): %D\n",mfn->ncv);CHKERRQ(ierr);
-    ierr = PetscViewerASCIIPrintf(viewer,"  maximum number of iterations: %D\n",mfn->max_it);CHKERRQ(ierr);
-    ierr = PetscViewerASCIIPrintf(viewer,"  tolerance: %g\n",(double)mfn->tol);CHKERRQ(ierr);
+    PetscCall(PetscViewerASCIIPrintf(viewer,"  number of column vectors (ncv): %" PetscInt_FMT "\n",mfn->ncv));
+    PetscCall(PetscViewerASCIIPrintf(viewer,"  maximum number of iterations: %" PetscInt_FMT "\n",mfn->max_it));
+    PetscCall(PetscViewerASCIIPrintf(viewer,"  tolerance: %g\n",(double)mfn->tol));
   } else {
-    if (mfn->ops->view) {
-      ierr = (*mfn->ops->view)(mfn,viewer);CHKERRQ(ierr);
-    }
+    if (mfn->ops->view) PetscCall((*mfn->ops->view)(mfn,viewer));
   }
-  ierr = PetscViewerPushFormat(viewer,PETSC_VIEWER_ASCII_INFO);CHKERRQ(ierr);
-  if (!mfn->V) { ierr = MFNGetFN(mfn,&mfn->fn);CHKERRQ(ierr); }
-  ierr = FNView(mfn->fn,viewer);CHKERRQ(ierr);
-  if (!mfn->V) { ierr = MFNGetBV(mfn,&mfn->V);CHKERRQ(ierr); }
-  ierr = BVView(mfn->V,viewer);CHKERRQ(ierr);
-  ierr = PetscViewerPopFormat(viewer);CHKERRQ(ierr);
+  PetscCall(PetscViewerPushFormat(viewer,PETSC_VIEWER_ASCII_INFO));
+  if (!mfn->V) PetscCall(MFNGetFN(mfn,&mfn->fn));
+  PetscCall(FNView(mfn->fn,viewer));
+  if (!mfn->V) PetscCall(MFNGetBV(mfn,&mfn->V));
+  PetscCall(BVView(mfn->V,viewer));
+  PetscCall(PetscViewerPopFormat(viewer));
   PetscFunctionReturn(0);
 }
 
@@ -106,11 +103,9 @@ PetscErrorCode MFNView(MFN mfn,PetscViewer viewer)
 @*/
 PetscErrorCode MFNViewFromOptions(MFN mfn,PetscObject obj,const char name[])
 {
-  PetscErrorCode ierr;
-
   PetscFunctionBegin;
   PetscValidHeaderSpecific(mfn,MFN_CLASSID,1);
-  ierr = PetscObjectViewFromOptions((PetscObject)mfn,obj,name);CHKERRQ(ierr);
+  PetscCall(PetscObjectViewFromOptions((PetscObject)mfn,obj,name));
   PetscFunctionReturn(0);
 }
 /*@C
@@ -137,22 +132,18 @@ PetscErrorCode MFNViewFromOptions(MFN mfn,PetscObject obj,const char name[])
 @*/
 PetscErrorCode MFNConvergedReasonView(MFN mfn,PetscViewer viewer)
 {
-  PetscErrorCode    ierr;
   PetscBool         isAscii;
   PetscViewerFormat format;
 
   PetscFunctionBegin;
   if (!viewer) viewer = PETSC_VIEWER_STDOUT_(PetscObjectComm((PetscObject)mfn));
-  ierr = PetscObjectTypeCompare((PetscObject)viewer,PETSCVIEWERASCII,&isAscii);CHKERRQ(ierr);
+  PetscCall(PetscObjectTypeCompare((PetscObject)viewer,PETSCVIEWERASCII,&isAscii));
   if (isAscii) {
-    ierr = PetscViewerGetFormat(viewer,&format);CHKERRQ(ierr);
-    ierr = PetscViewerASCIIAddTab(viewer,((PetscObject)mfn)->tablevel);CHKERRQ(ierr);
-    if (mfn->reason > 0 && format != PETSC_VIEWER_FAILED) {
-      ierr = PetscViewerASCIIPrintf(viewer,"%s Matrix function solve converged due to %s; iterations %D\n",((PetscObject)mfn)->prefix?((PetscObject)mfn)->prefix:"",MFNConvergedReasons[mfn->reason],mfn->its);CHKERRQ(ierr);
-    } else if (mfn->reason <= 0) {
-      ierr = PetscViewerASCIIPrintf(viewer,"%s Matrix function solve did not converge due to %s; iterations %D\n",((PetscObject)mfn)->prefix?((PetscObject)mfn)->prefix:"",MFNConvergedReasons[mfn->reason],mfn->its);CHKERRQ(ierr);
-    }
-    ierr = PetscViewerASCIISubtractTab(viewer,((PetscObject)mfn)->tablevel);CHKERRQ(ierr);
+    PetscCall(PetscViewerGetFormat(viewer,&format));
+    PetscCall(PetscViewerASCIIAddTab(viewer,((PetscObject)mfn)->tablevel));
+    if (mfn->reason > 0 && format != PETSC_VIEWER_FAILED) PetscCall(PetscViewerASCIIPrintf(viewer,"%s Matrix function solve converged due to %s; iterations %" PetscInt_FMT "\n",((PetscObject)mfn)->prefix?((PetscObject)mfn)->prefix:"",MFNConvergedReasons[mfn->reason],mfn->its));
+    else if (mfn->reason <= 0) PetscCall(PetscViewerASCIIPrintf(viewer,"%s Matrix function solve did not converge due to %s; iterations %" PetscInt_FMT "\n",((PetscObject)mfn)->prefix?((PetscObject)mfn)->prefix:"",MFNConvergedReasons[mfn->reason],mfn->its));
+    PetscCall(PetscViewerASCIISubtractTab(viewer,((PetscObject)mfn)->tablevel));
   }
   PetscFunctionReturn(0);
 }
@@ -172,7 +163,6 @@ PetscErrorCode MFNConvergedReasonView(MFN mfn,PetscViewer viewer)
 @*/
 PetscErrorCode MFNConvergedReasonViewFromOptions(MFN mfn)
 {
-  PetscErrorCode    ierr;
   PetscViewer       viewer;
   PetscBool         flg;
   static PetscBool  incall = PETSC_FALSE;
@@ -181,12 +171,12 @@ PetscErrorCode MFNConvergedReasonViewFromOptions(MFN mfn)
   PetscFunctionBegin;
   if (incall) PetscFunctionReturn(0);
   incall = PETSC_TRUE;
-  ierr = PetscOptionsGetViewer(PetscObjectComm((PetscObject)mfn),((PetscObject)mfn)->options,((PetscObject)mfn)->prefix,"-mfn_converged_reason",&viewer,&format,&flg);CHKERRQ(ierr);
+  PetscCall(PetscOptionsGetViewer(PetscObjectComm((PetscObject)mfn),((PetscObject)mfn)->options,((PetscObject)mfn)->prefix,"-mfn_converged_reason",&viewer,&format,&flg));
   if (flg) {
-    ierr = PetscViewerPushFormat(viewer,format);CHKERRQ(ierr);
-    ierr = MFNConvergedReasonView(mfn,viewer);CHKERRQ(ierr);
-    ierr = PetscViewerPopFormat(viewer);CHKERRQ(ierr);
-    ierr = PetscViewerDestroy(&viewer);CHKERRQ(ierr);
+    PetscCall(PetscViewerPushFormat(viewer,format));
+    PetscCall(MFNConvergedReasonView(mfn,viewer));
+    PetscCall(PetscViewerPopFormat(viewer));
+    PetscCall(PetscViewerDestroy(&viewer));
   }
   incall = PETSC_FALSE;
   PetscFunctionReturn(0);
@@ -201,7 +191,7 @@ PetscErrorCode MFNConvergedReasonViewFromOptions(MFN mfn)
 .  comm - MPI communicator
 
    Output Parameter:
-.  mfn - location to put the MFN context
+.  outmfn - location to put the MFN context
 
    Note:
    The default MFN type is MFNKRYLOV
@@ -212,14 +202,13 @@ PetscErrorCode MFNConvergedReasonViewFromOptions(MFN mfn)
 @*/
 PetscErrorCode MFNCreate(MPI_Comm comm,MFN *outmfn)
 {
-  PetscErrorCode ierr;
   MFN            mfn;
 
   PetscFunctionBegin;
   PetscValidPointer(outmfn,2);
   *outmfn = 0;
-  ierr = MFNInitializePackage();CHKERRQ(ierr);
-  ierr = SlepcHeaderCreate(mfn,MFN_CLASSID,"MFN","Matrix Function","MFN",comm,MFNDestroy,MFNView);CHKERRQ(ierr);
+  PetscCall(MFNInitializePackage());
+  PetscCall(SlepcHeaderCreate(mfn,MFN_CLASSID,"MFN","Matrix Function","MFN",comm,MFNDestroy,MFNView));
 
   mfn->A               = NULL;
   mfn->fn              = NULL;
@@ -276,25 +265,25 @@ PetscErrorCode MFNCreate(MPI_Comm comm,MFN *outmfn)
 @*/
 PetscErrorCode MFNSetType(MFN mfn,MFNType type)
 {
-  PetscErrorCode ierr,(*r)(MFN);
+  PetscErrorCode (*r)(MFN);
   PetscBool      match;
 
   PetscFunctionBegin;
   PetscValidHeaderSpecific(mfn,MFN_CLASSID,1);
   PetscValidCharPointer(type,2);
 
-  ierr = PetscObjectTypeCompare((PetscObject)mfn,type,&match);CHKERRQ(ierr);
+  PetscCall(PetscObjectTypeCompare((PetscObject)mfn,type,&match));
   if (match) PetscFunctionReturn(0);
 
-  ierr = PetscFunctionListFind(MFNList,type,&r);CHKERRQ(ierr);
-  if (!r) SETERRQ1(PetscObjectComm((PetscObject)mfn),PETSC_ERR_ARG_UNKNOWN_TYPE,"Unknown MFN type given: %s",type);
+  PetscCall(PetscFunctionListFind(MFNList,type,&r));
+  PetscCheck(r,PetscObjectComm((PetscObject)mfn),PETSC_ERR_ARG_UNKNOWN_TYPE,"Unknown MFN type given: %s",type);
 
-  if (mfn->ops->destroy) { ierr = (*mfn->ops->destroy)(mfn);CHKERRQ(ierr); }
-  ierr = PetscMemzero(mfn->ops,sizeof(struct _MFNOps));CHKERRQ(ierr);
+  if (mfn->ops->destroy) PetscCall((*mfn->ops->destroy)(mfn));
+  PetscCall(PetscMemzero(mfn->ops,sizeof(struct _MFNOps)));
 
   mfn->setupcalled = 0;
-  ierr = PetscObjectChangeTypeName((PetscObject)mfn,type);CHKERRQ(ierr);
-  ierr = (*r)(mfn);CHKERRQ(ierr);
+  PetscCall(PetscObjectChangeTypeName((PetscObject)mfn,type));
+  PetscCall((*r)(mfn));
   PetscFunctionReturn(0);
 }
 
@@ -307,7 +296,7 @@ PetscErrorCode MFNSetType(MFN mfn,MFNType type)
 .  mfn - the matrix function context
 
    Output Parameter:
-.  name - name of MFN method
+.  type - name of MFN method
 
    Level: intermediate
 
@@ -350,11 +339,9 @@ $     -mfn_type my_solver
 @*/
 PetscErrorCode MFNRegister(const char *name,PetscErrorCode (*function)(MFN))
 {
-  PetscErrorCode ierr;
-
   PetscFunctionBegin;
-  ierr = MFNInitializePackage();CHKERRQ(ierr);
-  ierr = PetscFunctionListAdd(&MFNList,name,function);CHKERRQ(ierr);
+  PetscCall(MFNInitializePackage());
+  PetscCall(PetscFunctionListAdd(&MFNList,name,function));
   PetscFunctionReturn(0);
 }
 
@@ -391,14 +378,13 @@ $      -mfn_monitor_my_monitor
 PetscErrorCode MFNMonitorRegister(const char name[],PetscViewerType vtype,PetscViewerFormat format,PetscErrorCode (*monitor)(MFN,PetscInt,PetscReal,PetscViewerAndFormat*),PetscErrorCode (*create)(PetscViewer,PetscViewerFormat,void*,PetscViewerAndFormat**),PetscErrorCode (*destroy)(PetscViewerAndFormat**))
 {
   char           key[PETSC_MAX_PATH_LEN];
-  PetscErrorCode ierr;
 
   PetscFunctionBegin;
-  ierr = MFNInitializePackage();CHKERRQ(ierr);
-  ierr = SlepcMonitorMakeKey_Internal(name,vtype,format,key);CHKERRQ(ierr);
-  ierr = PetscFunctionListAdd(&MFNMonitorList,key,monitor);CHKERRQ(ierr);
-  if (create)  { ierr = PetscFunctionListAdd(&MFNMonitorCreateList,key,create);CHKERRQ(ierr); }
-  if (destroy) { ierr = PetscFunctionListAdd(&MFNMonitorDestroyList,key,destroy);CHKERRQ(ierr); }
+  PetscCall(MFNInitializePackage());
+  PetscCall(SlepcMonitorMakeKey_Internal(name,vtype,format,key));
+  PetscCall(PetscFunctionListAdd(&MFNMonitorList,key,monitor));
+  if (create)  PetscCall(PetscFunctionListAdd(&MFNMonitorCreateList,key,create));
+  if (destroy) PetscCall(PetscFunctionListAdd(&MFNMonitorDestroyList,key,destroy));
   PetscFunctionReturn(0);
 }
 
@@ -417,15 +403,13 @@ PetscErrorCode MFNMonitorRegister(const char name[],PetscViewerType vtype,PetscV
 @*/
 PetscErrorCode MFNReset(MFN mfn)
 {
-  PetscErrorCode ierr;
-
   PetscFunctionBegin;
   if (mfn) PetscValidHeaderSpecific(mfn,MFN_CLASSID,1);
   if (!mfn) PetscFunctionReturn(0);
-  if (mfn->ops->reset) { ierr = (mfn->ops->reset)(mfn);CHKERRQ(ierr); }
-  ierr = MatDestroy(&mfn->A);CHKERRQ(ierr);
-  ierr = BVDestroy(&mfn->V);CHKERRQ(ierr);
-  ierr = VecDestroyVecs(mfn->nwork,&mfn->work);CHKERRQ(ierr);
+  if (mfn->ops->reset) PetscCall((mfn->ops->reset)(mfn));
+  PetscCall(MatDestroy(&mfn->A));
+  PetscCall(BVDestroy(&mfn->V));
+  PetscCall(VecDestroyVecs(mfn->nwork,&mfn->work));
   mfn->nwork = 0;
   mfn->setupcalled = 0;
   PetscFunctionReturn(0);
@@ -445,18 +429,16 @@ PetscErrorCode MFNReset(MFN mfn)
 @*/
 PetscErrorCode MFNDestroy(MFN *mfn)
 {
-  PetscErrorCode ierr;
-
   PetscFunctionBegin;
   if (!*mfn) PetscFunctionReturn(0);
   PetscValidHeaderSpecific(*mfn,MFN_CLASSID,1);
   if (--((PetscObject)(*mfn))->refct > 0) { *mfn = 0; PetscFunctionReturn(0); }
-  ierr = MFNReset(*mfn);CHKERRQ(ierr);
-  if ((*mfn)->ops->destroy) { ierr = (*(*mfn)->ops->destroy)(*mfn);CHKERRQ(ierr); }
-  ierr = FNDestroy(&(*mfn)->fn);CHKERRQ(ierr);
-  ierr = MatDestroy(&(*mfn)->AT);CHKERRQ(ierr);
-  ierr = MFNMonitorCancel(*mfn);CHKERRQ(ierr);
-  ierr = PetscHeaderDestroy(mfn);CHKERRQ(ierr);
+  PetscCall(MFNReset(*mfn));
+  if ((*mfn)->ops->destroy) PetscCall((*(*mfn)->ops->destroy)(*mfn));
+  PetscCall(FNDestroy(&(*mfn)->fn));
+  PetscCall(MatDestroy(&(*mfn)->AT));
+  PetscCall(MFNMonitorCancel(*mfn));
+  PetscCall(PetscHeaderDestroy(mfn));
   PetscFunctionReturn(0);
 }
 
@@ -479,16 +461,14 @@ PetscErrorCode MFNDestroy(MFN *mfn)
 @*/
 PetscErrorCode MFNSetBV(MFN mfn,BV bv)
 {
-  PetscErrorCode ierr;
-
   PetscFunctionBegin;
   PetscValidHeaderSpecific(mfn,MFN_CLASSID,1);
   PetscValidHeaderSpecific(bv,BV_CLASSID,2);
   PetscCheckSameComm(mfn,1,bv,2);
-  ierr = PetscObjectReference((PetscObject)bv);CHKERRQ(ierr);
-  ierr = BVDestroy(&mfn->V);CHKERRQ(ierr);
+  PetscCall(PetscObjectReference((PetscObject)bv));
+  PetscCall(BVDestroy(&mfn->V));
   mfn->V = bv;
-  ierr = PetscLogObjectParent((PetscObject)mfn,(PetscObject)mfn->V);CHKERRQ(ierr);
+  PetscCall(PetscLogObjectParent((PetscObject)mfn,(PetscObject)mfn->V));
   PetscFunctionReturn(0);
 }
 
@@ -510,16 +490,14 @@ PetscErrorCode MFNSetBV(MFN mfn,BV bv)
 @*/
 PetscErrorCode MFNGetBV(MFN mfn,BV *bv)
 {
-  PetscErrorCode ierr;
-
   PetscFunctionBegin;
   PetscValidHeaderSpecific(mfn,MFN_CLASSID,1);
   PetscValidPointer(bv,2);
   if (!mfn->V) {
-    ierr = BVCreate(PetscObjectComm((PetscObject)mfn),&mfn->V);CHKERRQ(ierr);
-    ierr = PetscObjectIncrementTabLevel((PetscObject)mfn->V,(PetscObject)mfn,0);CHKERRQ(ierr);
-    ierr = PetscLogObjectParent((PetscObject)mfn,(PetscObject)mfn->V);CHKERRQ(ierr);
-    ierr = PetscObjectSetOptions((PetscObject)mfn->V,((PetscObject)mfn)->options);CHKERRQ(ierr);
+    PetscCall(BVCreate(PetscObjectComm((PetscObject)mfn),&mfn->V));
+    PetscCall(PetscObjectIncrementTabLevel((PetscObject)mfn->V,(PetscObject)mfn,0));
+    PetscCall(PetscLogObjectParent((PetscObject)mfn,(PetscObject)mfn->V));
+    PetscCall(PetscObjectSetOptions((PetscObject)mfn->V,((PetscObject)mfn)->options));
   }
   *bv = mfn->V;
   PetscFunctionReturn(0);
@@ -544,16 +522,14 @@ PetscErrorCode MFNGetBV(MFN mfn,BV *bv)
 @*/
 PetscErrorCode MFNSetFN(MFN mfn,FN fn)
 {
-  PetscErrorCode ierr;
-
   PetscFunctionBegin;
   PetscValidHeaderSpecific(mfn,MFN_CLASSID,1);
   PetscValidHeaderSpecific(fn,FN_CLASSID,2);
   PetscCheckSameComm(mfn,1,fn,2);
-  ierr = PetscObjectReference((PetscObject)fn);CHKERRQ(ierr);
-  ierr = FNDestroy(&mfn->fn);CHKERRQ(ierr);
+  PetscCall(PetscObjectReference((PetscObject)fn));
+  PetscCall(FNDestroy(&mfn->fn));
   mfn->fn = fn;
-  ierr = PetscLogObjectParent((PetscObject)mfn,(PetscObject)mfn->fn);CHKERRQ(ierr);
+  PetscCall(PetscLogObjectParent((PetscObject)mfn,(PetscObject)mfn->fn));
   PetscFunctionReturn(0);
 }
 
@@ -574,18 +550,15 @@ PetscErrorCode MFNSetFN(MFN mfn,FN fn)
 @*/
 PetscErrorCode MFNGetFN(MFN mfn,FN *fn)
 {
-  PetscErrorCode ierr;
-
   PetscFunctionBegin;
   PetscValidHeaderSpecific(mfn,MFN_CLASSID,1);
   PetscValidPointer(fn,2);
   if (!mfn->fn) {
-    ierr = FNCreate(PetscObjectComm((PetscObject)mfn),&mfn->fn);CHKERRQ(ierr);
-    ierr = PetscObjectIncrementTabLevel((PetscObject)mfn->fn,(PetscObject)mfn,0);CHKERRQ(ierr);
-    ierr = PetscLogObjectParent((PetscObject)mfn,(PetscObject)mfn->fn);CHKERRQ(ierr);
-    ierr = PetscObjectSetOptions((PetscObject)mfn->fn,((PetscObject)mfn)->options);CHKERRQ(ierr);
+    PetscCall(FNCreate(PetscObjectComm((PetscObject)mfn),&mfn->fn));
+    PetscCall(PetscObjectIncrementTabLevel((PetscObject)mfn->fn,(PetscObject)mfn,0));
+    PetscCall(PetscLogObjectParent((PetscObject)mfn,(PetscObject)mfn->fn));
+    PetscCall(PetscObjectSetOptions((PetscObject)mfn->fn,((PetscObject)mfn)->options));
   }
   *fn = mfn->fn;
   PetscFunctionReturn(0);
 }
-
