@@ -1,7 +1,7 @@
 /*
    - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
    SLEPc - Scalable Library for Eigenvalue Problem Computations
-   Copyright (c) 2002-2021, Universitat Politecnica de Valencia, Spain
+   Copyright (c) 2002-, Universitat Politecnica de Valencia, Spain
 
    This file is part of SLEPc.
    SLEPc is distributed under a 2-clause BSD license (see LICENSE).
@@ -35,7 +35,6 @@ typedef struct {
 
 PetscErrorCode NEPSetUp_Interpol(NEP nep)
 {
-  PetscErrorCode ierr;
   NEP_INTERPOL   *ctx = (NEP_INTERPOL*)nep->data;
   ST             st;
   RG             rg;
@@ -45,50 +44,50 @@ PetscErrorCode NEPSetUp_Interpol(NEP nep)
   PetscInt       its,in;
 
   PetscFunctionBegin;
-  ierr = NEPSetDimensions_Default(nep,nep->nev,&nep->ncv,&nep->mpd);CHKERRQ(ierr);
-  if (nep->ncv>nep->nev+nep->mpd) SETERRQ(PetscObjectComm((PetscObject)nep),PETSC_ERR_USER_INPUT,"The value of ncv must not be larger than nev+mpd");
+  PetscCall(NEPSetDimensions_Default(nep,nep->nev,&nep->ncv,&nep->mpd));
+  PetscCheck(nep->ncv<=nep->nev+nep->mpd,PetscObjectComm((PetscObject)nep),PETSC_ERR_USER_INPUT,"The value of ncv must not be larger than nev+mpd");
   if (nep->max_it==PETSC_DEFAULT) nep->max_it = PetscMax(5000,2*nep->n/nep->ncv);
   if (!nep->which) nep->which = NEP_TARGET_MAGNITUDE;
-  if (nep->which!=NEP_TARGET_MAGNITUDE) SETERRQ(PetscObjectComm((PetscObject)nep),PETSC_ERR_SUP,"This solver supports only target magnitude eigenvalues");
+  PetscCheck(nep->which==NEP_TARGET_MAGNITUDE,PetscObjectComm((PetscObject)nep),PETSC_ERR_SUP,"This solver supports only target magnitude eigenvalues");
   NEPCheckUnsupported(nep,NEP_FEATURE_CALLBACK | NEP_FEATURE_STOPPING | NEP_FEATURE_TWOSIDED);
 
   /* transfer PEP options */
-  if (!ctx->pep) { ierr = NEPInterpolGetPEP(nep,&ctx->pep);CHKERRQ(ierr); }
-  ierr = PEPSetBasis(ctx->pep,PEP_BASIS_CHEBYSHEV1);CHKERRQ(ierr);
-  ierr = PEPSetWhichEigenpairs(ctx->pep,PEP_TARGET_MAGNITUDE);CHKERRQ(ierr);
-  ierr = PetscObjectTypeCompare((PetscObject)ctx->pep,PEPJD,&flg);CHKERRQ(ierr);
+  if (!ctx->pep) PetscCall(NEPInterpolGetPEP(nep,&ctx->pep));
+  PetscCall(PEPSetBasis(ctx->pep,PEP_BASIS_CHEBYSHEV1));
+  PetscCall(PEPSetWhichEigenpairs(ctx->pep,PEP_TARGET_MAGNITUDE));
+  PetscCall(PetscObjectTypeCompare((PetscObject)ctx->pep,PEPJD,&flg));
   if (!flg) {
-    ierr = PEPGetST(ctx->pep,&st);CHKERRQ(ierr);
-    ierr = STSetType(st,STSINVERT);CHKERRQ(ierr);
+    PetscCall(PEPGetST(ctx->pep,&st));
+    PetscCall(STSetType(st,STSINVERT));
   }
-  ierr = PEPSetDimensions(ctx->pep,nep->nev,nep->ncv,nep->mpd);CHKERRQ(ierr);
-  ierr = PEPGetTolerances(ctx->pep,&tol,&its);CHKERRQ(ierr);
+  PetscCall(PEPSetDimensions(ctx->pep,nep->nev,nep->ncv,nep->mpd));
+  PetscCall(PEPGetTolerances(ctx->pep,&tol,&its));
   if (tol==PETSC_DEFAULT) tol = SlepcDefaultTol(nep->tol);
   if (ctx->tol==PETSC_DEFAULT) ctx->tol = tol;
   if (its==PETSC_DEFAULT) its = nep->max_it;
-  ierr = PEPSetTolerances(ctx->pep,tol,its);CHKERRQ(ierr);
-  ierr = NEPGetTrackAll(nep,&trackall);CHKERRQ(ierr);
-  ierr = PEPSetTrackAll(ctx->pep,trackall);CHKERRQ(ierr);
+  PetscCall(PEPSetTolerances(ctx->pep,tol,its));
+  PetscCall(NEPGetTrackAll(nep,&trackall));
+  PetscCall(PEPSetTrackAll(ctx->pep,trackall));
 
   /* transfer region options */
-  ierr = RGIsTrivial(nep->rg,&istrivial);CHKERRQ(ierr);
-  if (istrivial) SETERRQ(PetscObjectComm((PetscObject)nep),PETSC_ERR_SUP,"NEPINTERPOL requires a nontrivial region");
-  ierr = PetscObjectTypeCompare((PetscObject)nep->rg,RGINTERVAL,&flg);CHKERRQ(ierr);
-  if (!flg) SETERRQ(PetscObjectComm((PetscObject)nep),PETSC_ERR_SUP,"Only implemented for interval regions");
-  ierr = RGIntervalGetEndpoints(nep->rg,&a,&b,&c,&d);CHKERRQ(ierr);
-  if (a<=-PETSC_MAX_REAL || b>=PETSC_MAX_REAL) SETERRQ(PetscObjectComm((PetscObject)nep),PETSC_ERR_SUP,"Only implemented for bounded intervals");
-  ierr = PEPGetRG(ctx->pep,&rg);CHKERRQ(ierr);
-  ierr = RGSetType(rg,RGINTERVAL);CHKERRQ(ierr);
-  if (a==b) SETERRQ(PetscObjectComm((PetscObject)nep),PETSC_ERR_SUP,"Only implemented for intervals on the real axis");
+  PetscCall(RGIsTrivial(nep->rg,&istrivial));
+  PetscCheck(!istrivial,PetscObjectComm((PetscObject)nep),PETSC_ERR_SUP,"NEPINTERPOL requires a nontrivial region");
+  PetscCall(PetscObjectTypeCompare((PetscObject)nep->rg,RGINTERVAL,&flg));
+  PetscCheck(flg,PetscObjectComm((PetscObject)nep),PETSC_ERR_SUP,"Only implemented for interval regions");
+  PetscCall(RGIntervalGetEndpoints(nep->rg,&a,&b,&c,&d));
+  PetscCheck(a>-PETSC_MAX_REAL && b<PETSC_MAX_REAL,PetscObjectComm((PetscObject)nep),PETSC_ERR_SUP,"Only implemented for bounded intervals");
+  PetscCall(PEPGetRG(ctx->pep,&rg));
+  PetscCall(RGSetType(rg,RGINTERVAL));
+  PetscCheck(a!=b,PetscObjectComm((PetscObject)nep),PETSC_ERR_SUP,"Only implemented for intervals on the real axis");
   s = 2.0/(b-a);
   c = c*s;
   d = d*s;
-  ierr = RGIntervalSetEndpoints(rg,-1.0,1.0,c,d);CHKERRQ(ierr);
-  ierr = RGCheckInside(nep->rg,1,&nep->target,&zero,&in);CHKERRQ(ierr);
-  if (in<0) SETERRQ(PetscObjectComm((PetscObject)nep),PETSC_ERR_SUP,"The target is not inside the target set");
-  ierr = PEPSetTarget(ctx->pep,(nep->target-(a+b)/2)*s);CHKERRQ(ierr);
+  PetscCall(RGIntervalSetEndpoints(rg,-1.0,1.0,c,d));
+  PetscCall(RGCheckInside(nep->rg,1,&nep->target,&zero,&in));
+  PetscCheck(in>=0,PetscObjectComm((PetscObject)nep),PETSC_ERR_SUP,"The target is not inside the target set");
+  PetscCall(PEPSetTarget(ctx->pep,(nep->target-(a+b)/2)*s));
 
-  ierr = NEPAllocateSolution(nep,0);CHKERRQ(ierr);
+  PetscCall(NEPAllocateSolution(nep,0));
   PetscFunctionReturn(0);
 }
 
@@ -116,83 +115,86 @@ static PetscErrorCode ChebyshevNodes(PetscInt d,PetscReal a,PetscReal b,PetscSca
 
 PetscErrorCode NEPSolve_Interpol(NEP nep)
 {
-  PetscErrorCode ierr;
   NEP_INTERPOL   *ctx = (NEP_INTERPOL*)nep->data;
-  Mat            *A;
+  Mat            *A,*P;
   PetscScalar    *x,*fx,t;
   PetscReal      *cs,a,b,s,aprox,aprox0=1.0,*matnorm;
   PetscInt       i,j,k,deg=ctx->maxdeg;
   PetscBool      hasmnorm=PETSC_FALSE;
   Vec            vr,vi=NULL;
+  ST             st;
 
   PetscFunctionBegin;
-  ierr = PetscMalloc5(deg+1,&A,(deg+1)*(deg+1),&cs,deg+1,&x,(deg+1)*nep->nt,&fx,nep->nt,&matnorm);CHKERRQ(ierr);
+  PetscCall(PetscMalloc4((deg+1)*(deg+1),&cs,deg+1,&x,(deg+1)*nep->nt,&fx,nep->nt,&matnorm));
   for  (j=0;j<nep->nt;j++) {
-    ierr = MatHasOperation(nep->A[j],MATOP_NORM,&hasmnorm);CHKERRQ(ierr);
+    PetscCall(MatHasOperation(nep->A[j],MATOP_NORM,&hasmnorm));
     if (!hasmnorm) break;
-    ierr = MatNorm(nep->A[j],NORM_INFINITY,matnorm+j);CHKERRQ(ierr);
+    PetscCall(MatNorm(nep->A[j],NORM_INFINITY,matnorm+j));
   }
   if (!hasmnorm) for (j=0;j<nep->nt;j++) matnorm[j] = 1.0;
-  ierr = RGIntervalGetEndpoints(nep->rg,&a,&b,NULL,NULL);CHKERRQ(ierr);
-  ierr = ChebyshevNodes(deg,a,b,x,cs);CHKERRQ(ierr);
+  PetscCall(RGIntervalGetEndpoints(nep->rg,&a,&b,NULL,NULL));
+  PetscCall(ChebyshevNodes(deg,a,b,x,cs));
   for (j=0;j<nep->nt;j++) {
-    for (i=0;i<=deg;i++) {
-      ierr = FNEvaluateFunction(nep->f[j],x[i],&fx[i+j*(deg+1)]);CHKERRQ(ierr);
-    }
+    for (i=0;i<=deg;i++) PetscCall(FNEvaluateFunction(nep->f[j],x[i],&fx[i+j*(deg+1)]));
   }
   /* Polynomial coefficients */
+  PetscCall(PetscMalloc1(deg+1,&A));
+  if (nep->P) PetscCall(PetscMalloc1(deg+1,&P));
   ctx->deg = deg;
   for (k=0;k<=deg;k++) {
-    ierr = MatDuplicate(nep->A[0],MAT_COPY_VALUES,&A[k]);CHKERRQ(ierr);
+    PetscCall(MatDuplicate(nep->A[0],MAT_COPY_VALUES,&A[k]));
+    if (nep->P) PetscCall(MatDuplicate(nep->P[0],MAT_COPY_VALUES,&P[k]));
     t = 0.0;
     for (i=0;i<deg+1;i++) t += fx[i]*cs[i*(deg+1)+k];
     t *= 2.0/(deg+1);
     if (k==0) t /= 2.0;
     aprox = matnorm[0]*PetscAbsScalar(t);
-    ierr = MatScale(A[k],t);CHKERRQ(ierr);
+    PetscCall(MatScale(A[k],t));
+    if (nep->P) PetscCall(MatScale(P[k],t));
     for (j=1;j<nep->nt;j++) {
       t = 0.0;
       for (i=0;i<deg+1;i++) t += fx[i+j*(deg+1)]*cs[i*(deg+1)+k];
       t *= 2.0/(deg+1);
       if (k==0) t /= 2.0;
       aprox += matnorm[j]*PetscAbsScalar(t);
-      ierr = MatAXPY(A[k],t,nep->A[j],nep->mstr);CHKERRQ(ierr);
+      PetscCall(MatAXPY(A[k],t,nep->A[j],nep->mstr));
+      if (nep->P) PetscCall(MatAXPY(P[k],t,nep->P[j],nep->mstrp));
     }
     if (k==0) aprox0 = aprox;
     if (k>1 && aprox/aprox0<ctx->tol) { ctx->deg = k; deg = k; break; }
   }
-
-  ierr = PEPSetOperators(ctx->pep,deg+1,A);CHKERRQ(ierr);
-  for (k=0;k<=deg;k++) {
-    ierr = MatDestroy(&A[k]);CHKERRQ(ierr);
+  PetscCall(PEPSetOperators(ctx->pep,deg+1,A));
+  PetscCall(MatDestroyMatrices(deg+1,&A));
+  if (nep->P) {
+    PetscCall(PEPGetST(ctx->pep,&st));
+    PetscCall(STSetSplitPreconditioner(st,deg+1,P,nep->mstrp));
+    PetscCall(MatDestroyMatrices(deg+1,&P));
   }
-  ierr = PetscFree5(A,cs,x,fx,matnorm);CHKERRQ(ierr);
+  PetscCall(PetscFree4(cs,x,fx,matnorm));
 
   /* Solve polynomial eigenproblem */
-  ierr = PEPSolve(ctx->pep);CHKERRQ(ierr);
-  ierr = PEPGetConverged(ctx->pep,&nep->nconv);CHKERRQ(ierr);
-  ierr = PEPGetIterationNumber(ctx->pep,&nep->its);CHKERRQ(ierr);
-  ierr = PEPGetConvergedReason(ctx->pep,(PEPConvergedReason*)&nep->reason);CHKERRQ(ierr);
-  ierr = BVSetActiveColumns(nep->V,0,nep->nconv);CHKERRQ(ierr);
-  ierr = BVCreateVec(nep->V,&vr);CHKERRQ(ierr);
+  PetscCall(PEPSolve(ctx->pep));
+  PetscCall(PEPGetConverged(ctx->pep,&nep->nconv));
+  PetscCall(PEPGetIterationNumber(ctx->pep,&nep->its));
+  PetscCall(PEPGetConvergedReason(ctx->pep,(PEPConvergedReason*)&nep->reason));
+  PetscCall(BVSetActiveColumns(nep->V,0,nep->nconv));
+  PetscCall(BVCreateVec(nep->V,&vr));
 #if !defined(PETSC_USE_COMPLEX)
-  ierr = VecDuplicate(vr,&vi);CHKERRQ(ierr);
+  PetscCall(VecDuplicate(vr,&vi));
 #endif
   s = 2.0/(b-a);
   for (i=0;i<nep->nconv;i++) {
-    ierr = PEPGetEigenpair(ctx->pep,i,&nep->eigr[i],&nep->eigi[i],vr,vi);CHKERRQ(ierr);
+    PetscCall(PEPGetEigenpair(ctx->pep,i,&nep->eigr[i],&nep->eigi[i],vr,vi));
     nep->eigr[i] /= s;
     nep->eigr[i] += (a+b)/2.0;
     nep->eigi[i] /= s;
-    ierr = BVInsertVec(nep->V,i,vr);CHKERRQ(ierr);
+    PetscCall(BVInsertVec(nep->V,i,vr));
 #if !defined(PETSC_USE_COMPLEX)
-    if (nep->eigi[i]!=0.0) {
-      ierr = BVInsertVec(nep->V,++i,vi);CHKERRQ(ierr);
-    }
+    if (nep->eigi[i]!=0.0) PetscCall(BVInsertVec(nep->V,++i,vi));
 #endif
   }
-  ierr = VecDestroy(&vr);CHKERRQ(ierr);
-  ierr = VecDestroy(&vi);CHKERRQ(ierr);
+  PetscCall(VecDestroy(&vr));
+  PetscCall(VecDestroy(&vi));
 
   nep->state = NEP_STATE_EIGENVECTORS;
   PetscFunctionReturn(0);
@@ -204,7 +206,6 @@ static PetscErrorCode PEPMonitor_Interpol(PEP pep,PetscInt its,PetscInt nconv,Pe
   NEP            nep = (NEP)ctx;
   PetscReal      a,b,s;
   ST             st;
-  PetscErrorCode ierr;
 
   PetscFunctionBegin;
   n = PetscMin(nest,nep->ncv);
@@ -213,46 +214,44 @@ static PetscErrorCode PEPMonitor_Interpol(PEP pep,PetscInt its,PetscInt nconv,Pe
     nep->eigi[i]   = eigi[i];
     nep->errest[i] = errest[i];
   }
-  ierr = PEPGetST(pep,&st);CHKERRQ(ierr);
-  ierr = STBackTransform(st,n,nep->eigr,nep->eigi);CHKERRQ(ierr);
-  ierr = RGIntervalGetEndpoints(nep->rg,&a,&b,NULL,NULL);CHKERRQ(ierr);
+  PetscCall(PEPGetST(pep,&st));
+  PetscCall(STBackTransform(st,n,nep->eigr,nep->eigi));
+  PetscCall(RGIntervalGetEndpoints(nep->rg,&a,&b,NULL,NULL));
   s = 2.0/(b-a);
   for (i=0;i<n;i++) {
     nep->eigr[i] /= s;
     nep->eigr[i] += (a+b)/2.0;
     nep->eigi[i] /= s;
   }
-  ierr = NEPMonitor(nep,its,nconv,nep->eigr,nep->eigi,nep->errest,nest);CHKERRQ(ierr);
+  PetscCall(NEPMonitor(nep,its,nconv,nep->eigr,nep->eigi,nep->errest,nest));
   PetscFunctionReturn(0);
 }
 
 PetscErrorCode NEPSetFromOptions_Interpol(PetscOptionItems *PetscOptionsObject,NEP nep)
 {
-  PetscErrorCode ierr;
   NEP_INTERPOL   *ctx = (NEP_INTERPOL*)nep->data;
   PetscInt       i;
   PetscBool      flg1,flg2;
   PetscReal      r;
 
   PetscFunctionBegin;
-  ierr = PetscOptionsHead(PetscOptionsObject,"NEP Interpol Options");CHKERRQ(ierr);
+  PetscCall(PetscOptionsHead(PetscOptionsObject,"NEP Interpol Options"));
 
-    ierr = NEPInterpolGetInterpolation(nep,&r,&i);CHKERRQ(ierr);
+    PetscCall(NEPInterpolGetInterpolation(nep,&r,&i));
     if (!i) i = PETSC_DEFAULT;
-    ierr = PetscOptionsInt("-nep_interpol_interpolation_degree","Maximum degree of polynomial interpolation","NEPInterpolSetInterpolation",i,&i,&flg1);CHKERRQ(ierr);
-    ierr = PetscOptionsReal("-nep_interpol_interpolation_tol","Tolerance for interpolation coefficients","NEPInterpolSetInterpolation",r,&r,&flg2);CHKERRQ(ierr);
-    if (flg1 || flg2) { ierr = NEPInterpolSetInterpolation(nep,r,i);CHKERRQ(ierr); }
+    PetscCall(PetscOptionsInt("-nep_interpol_interpolation_degree","Maximum degree of polynomial interpolation","NEPInterpolSetInterpolation",i,&i,&flg1));
+    PetscCall(PetscOptionsReal("-nep_interpol_interpolation_tol","Tolerance for interpolation coefficients","NEPInterpolSetInterpolation",r,&r,&flg2));
+    if (flg1 || flg2) PetscCall(NEPInterpolSetInterpolation(nep,r,i));
 
-  ierr = PetscOptionsTail();CHKERRQ(ierr);
+  PetscCall(PetscOptionsTail());
 
-  if (!ctx->pep) { ierr = NEPInterpolGetPEP(nep,&ctx->pep);CHKERRQ(ierr); }
-  ierr = PEPSetFromOptions(ctx->pep);CHKERRQ(ierr);
+  if (!ctx->pep) PetscCall(NEPInterpolGetPEP(nep,&ctx->pep));
+  PetscCall(PEPSetFromOptions(ctx->pep));
   PetscFunctionReturn(0);
 }
 
 static PetscErrorCode NEPInterpolSetInterpolation_Interpol(NEP nep,PetscReal tol,PetscInt degree)
 {
-  PetscErrorCode ierr;
   NEP_INTERPOL   *ctx = (NEP_INTERPOL*)nep->data;
 
   PetscFunctionBegin;
@@ -260,18 +259,18 @@ static PetscErrorCode NEPInterpolSetInterpolation_Interpol(NEP nep,PetscReal tol
     ctx->tol   = PETSC_DEFAULT;
     nep->state = NEP_STATE_INITIAL;
   } else {
-    if (tol <= 0.0) SETERRQ(PetscObjectComm((PetscObject)nep),PETSC_ERR_ARG_OUTOFRANGE,"Illegal value of tol. Must be > 0");
+    PetscCheck(tol>0.0,PetscObjectComm((PetscObject)nep),PETSC_ERR_ARG_OUTOFRANGE,"Illegal value of tol. Must be > 0");
     ctx->tol = tol;
   }
   if (degree == PETSC_DEFAULT || degree == PETSC_DECIDE) {
     ctx->maxdeg = 0;
-    if (nep->state) { ierr = NEPReset(nep);CHKERRQ(ierr); }
+    if (nep->state) PetscCall(NEPReset(nep));
     nep->state = NEP_STATE_INITIAL;
   } else {
-    if (degree <= 0) SETERRQ(PetscObjectComm((PetscObject)nep),PETSC_ERR_ARG_OUTOFRANGE,"Illegal value of degree. Must be > 0");
+    PetscCheck(degree>0,PetscObjectComm((PetscObject)nep),PETSC_ERR_ARG_OUTOFRANGE,"Illegal value of degree. Must be > 0");
     if (ctx->maxdeg != degree) {
       ctx->maxdeg = degree;
-      if (nep->state) { ierr = NEPReset(nep);CHKERRQ(ierr); }
+      if (nep->state) PetscCall(NEPReset(nep));
       nep->state = NEP_STATE_INITIAL;
     }
   }
@@ -302,13 +301,11 @@ static PetscErrorCode NEPInterpolSetInterpolation_Interpol(NEP nep,PetscReal tol
 @*/
 PetscErrorCode NEPInterpolSetInterpolation(NEP nep,PetscReal tol,PetscInt deg)
 {
-  PetscErrorCode ierr;
-
   PetscFunctionBegin;
   PetscValidHeaderSpecific(nep,NEP_CLASSID,1);
   PetscValidLogicalCollectiveReal(nep,tol,2);
   PetscValidLogicalCollectiveInt(nep,deg,3);
-  ierr = PetscTryMethod(nep,"NEPInterpolSetInterpolation_C",(NEP,PetscReal,PetscInt),(nep,tol,deg));CHKERRQ(ierr);
+  PetscTryMethod(nep,"NEPInterpolSetInterpolation_C",(NEP,PetscReal,PetscInt),(nep,tol,deg));
   PetscFunctionReturn(0);
 }
 
@@ -341,24 +338,21 @@ static PetscErrorCode NEPInterpolGetInterpolation_Interpol(NEP nep,PetscReal *to
 @*/
 PetscErrorCode NEPInterpolGetInterpolation(NEP nep,PetscReal *tol,PetscInt *deg)
 {
-  PetscErrorCode ierr;
-
   PetscFunctionBegin;
   PetscValidHeaderSpecific(nep,NEP_CLASSID,1);
-  ierr = PetscUseMethod(nep,"NEPInterpolGetInterpolation_C",(NEP,PetscReal*,PetscInt*),(nep,tol,deg));CHKERRQ(ierr);
+  PetscUseMethod(nep,"NEPInterpolGetInterpolation_C",(NEP,PetscReal*,PetscInt*),(nep,tol,deg));
   PetscFunctionReturn(0);
 }
 
 static PetscErrorCode NEPInterpolSetPEP_Interpol(NEP nep,PEP pep)
 {
-  PetscErrorCode ierr;
   NEP_INTERPOL   *ctx = (NEP_INTERPOL*)nep->data;
 
   PetscFunctionBegin;
-  ierr = PetscObjectReference((PetscObject)pep);CHKERRQ(ierr);
-  ierr = PEPDestroy(&ctx->pep);CHKERRQ(ierr);
+  PetscCall(PetscObjectReference((PetscObject)pep));
+  PetscCall(PEPDestroy(&ctx->pep));
   ctx->pep = pep;
-  ierr = PetscLogObjectParent((PetscObject)nep,(PetscObject)ctx->pep);CHKERRQ(ierr);
+  PetscCall(PetscLogObjectParent((PetscObject)nep,(PetscObject)ctx->pep));
   nep->state = NEP_STATE_INITIAL;
   PetscFunctionReturn(0);
 }
@@ -379,30 +373,27 @@ static PetscErrorCode NEPInterpolSetPEP_Interpol(NEP nep,PEP pep)
 @*/
 PetscErrorCode NEPInterpolSetPEP(NEP nep,PEP pep)
 {
-  PetscErrorCode ierr;
-
   PetscFunctionBegin;
   PetscValidHeaderSpecific(nep,NEP_CLASSID,1);
   PetscValidHeaderSpecific(pep,PEP_CLASSID,2);
   PetscCheckSameComm(nep,1,pep,2);
-  ierr = PetscTryMethod(nep,"NEPInterpolSetPEP_C",(NEP,PEP),(nep,pep));CHKERRQ(ierr);
+  PetscTryMethod(nep,"NEPInterpolSetPEP_C",(NEP,PEP),(nep,pep));
   PetscFunctionReturn(0);
 }
 
 static PetscErrorCode NEPInterpolGetPEP_Interpol(NEP nep,PEP *pep)
 {
-  PetscErrorCode ierr;
   NEP_INTERPOL   *ctx = (NEP_INTERPOL*)nep->data;
 
   PetscFunctionBegin;
   if (!ctx->pep) {
-    ierr = PEPCreate(PetscObjectComm((PetscObject)nep),&ctx->pep);CHKERRQ(ierr);
-    ierr = PetscObjectIncrementTabLevel((PetscObject)ctx->pep,(PetscObject)nep,1);CHKERRQ(ierr);
-    ierr = PEPSetOptionsPrefix(ctx->pep,((PetscObject)nep)->prefix);CHKERRQ(ierr);
-    ierr = PEPAppendOptionsPrefix(ctx->pep,"nep_interpol_");CHKERRQ(ierr);
-    ierr = PetscLogObjectParent((PetscObject)nep,(PetscObject)ctx->pep);CHKERRQ(ierr);
-    ierr = PetscObjectSetOptions((PetscObject)ctx->pep,((PetscObject)nep)->options);CHKERRQ(ierr);
-    ierr = PEPMonitorSet(ctx->pep,PEPMonitor_Interpol,nep,NULL);CHKERRQ(ierr);
+    PetscCall(PEPCreate(PetscObjectComm((PetscObject)nep),&ctx->pep));
+    PetscCall(PetscObjectIncrementTabLevel((PetscObject)ctx->pep,(PetscObject)nep,1));
+    PetscCall(PEPSetOptionsPrefix(ctx->pep,((PetscObject)nep)->prefix));
+    PetscCall(PEPAppendOptionsPrefix(ctx->pep,"nep_interpol_"));
+    PetscCall(PetscLogObjectParent((PetscObject)nep,(PetscObject)ctx->pep));
+    PetscCall(PetscObjectSetOptions((PetscObject)ctx->pep,((PetscObject)nep)->options));
+    PetscCall(PEPMonitorSet(ctx->pep,PEPMonitor_Interpol,nep,NULL));
   }
   *pep = ctx->pep;
   PetscFunctionReturn(0);
@@ -426,66 +417,60 @@ static PetscErrorCode NEPInterpolGetPEP_Interpol(NEP nep,PEP *pep)
 @*/
 PetscErrorCode NEPInterpolGetPEP(NEP nep,PEP *pep)
 {
-  PetscErrorCode ierr;
-
   PetscFunctionBegin;
   PetscValidHeaderSpecific(nep,NEP_CLASSID,1);
   PetscValidPointer(pep,2);
-  ierr = PetscUseMethod(nep,"NEPInterpolGetPEP_C",(NEP,PEP*),(nep,pep));CHKERRQ(ierr);
+  PetscUseMethod(nep,"NEPInterpolGetPEP_C",(NEP,PEP*),(nep,pep));
   PetscFunctionReturn(0);
 }
 
 PetscErrorCode NEPView_Interpol(NEP nep,PetscViewer viewer)
 {
-  PetscErrorCode ierr;
   NEP_INTERPOL   *ctx = (NEP_INTERPOL*)nep->data;
   PetscBool      isascii;
 
   PetscFunctionBegin;
-  ierr = PetscObjectTypeCompare((PetscObject)viewer,PETSCVIEWERASCII,&isascii);CHKERRQ(ierr);
+  PetscCall(PetscObjectTypeCompare((PetscObject)viewer,PETSCVIEWERASCII,&isascii));
   if (isascii) {
-    if (!ctx->pep) { ierr = NEPInterpolGetPEP(nep,&ctx->pep);CHKERRQ(ierr); }
-    ierr = PetscViewerASCIIPrintf(viewer,"  polynomial degree %D, max=%D\n",ctx->deg,ctx->maxdeg);CHKERRQ(ierr);
-    ierr = PetscViewerASCIIPrintf(viewer,"  tolerance for norm of polynomial coefficients %g\n",ctx->tol);CHKERRQ(ierr);
-    ierr = PetscViewerASCIIPushTab(viewer);CHKERRQ(ierr);
-    ierr = PEPView(ctx->pep,viewer);CHKERRQ(ierr);
-    ierr = PetscViewerASCIIPopTab(viewer);CHKERRQ(ierr);
+    if (!ctx->pep) PetscCall(NEPInterpolGetPEP(nep,&ctx->pep));
+    PetscCall(PetscViewerASCIIPrintf(viewer,"  polynomial degree %" PetscInt_FMT ", max=%" PetscInt_FMT "\n",ctx->deg,ctx->maxdeg));
+    PetscCall(PetscViewerASCIIPrintf(viewer,"  tolerance for norm of polynomial coefficients %g\n",(double)ctx->tol));
+    PetscCall(PetscViewerASCIIPushTab(viewer));
+    PetscCall(PEPView(ctx->pep,viewer));
+    PetscCall(PetscViewerASCIIPopTab(viewer));
   }
   PetscFunctionReturn(0);
 }
 
 PetscErrorCode NEPReset_Interpol(NEP nep)
 {
-  PetscErrorCode ierr;
   NEP_INTERPOL   *ctx = (NEP_INTERPOL*)nep->data;
 
   PetscFunctionBegin;
-  ierr = PEPReset(ctx->pep);CHKERRQ(ierr);
+  PetscCall(PEPReset(ctx->pep));
   PetscFunctionReturn(0);
 }
 
 PetscErrorCode NEPDestroy_Interpol(NEP nep)
 {
-  PetscErrorCode ierr;
   NEP_INTERPOL   *ctx = (NEP_INTERPOL*)nep->data;
 
   PetscFunctionBegin;
-  ierr = PEPDestroy(&ctx->pep);CHKERRQ(ierr);
-  ierr = PetscFree(nep->data);CHKERRQ(ierr);
-  ierr = PetscObjectComposeFunction((PetscObject)nep,"NEPInterpolSetInterpolation_C",NULL);CHKERRQ(ierr);
-  ierr = PetscObjectComposeFunction((PetscObject)nep,"NEPInterpolGetInterpolation_C",NULL);CHKERRQ(ierr);
-  ierr = PetscObjectComposeFunction((PetscObject)nep,"NEPInterpolSetPEP_C",NULL);CHKERRQ(ierr);
-  ierr = PetscObjectComposeFunction((PetscObject)nep,"NEPInterpolGetPEP_C",NULL);CHKERRQ(ierr);
+  PetscCall(PEPDestroy(&ctx->pep));
+  PetscCall(PetscFree(nep->data));
+  PetscCall(PetscObjectComposeFunction((PetscObject)nep,"NEPInterpolSetInterpolation_C",NULL));
+  PetscCall(PetscObjectComposeFunction((PetscObject)nep,"NEPInterpolGetInterpolation_C",NULL));
+  PetscCall(PetscObjectComposeFunction((PetscObject)nep,"NEPInterpolSetPEP_C",NULL));
+  PetscCall(PetscObjectComposeFunction((PetscObject)nep,"NEPInterpolGetPEP_C",NULL));
   PetscFunctionReturn(0);
 }
 
 SLEPC_EXTERN PetscErrorCode NEPCreate_Interpol(NEP nep)
 {
-  PetscErrorCode ierr;
   NEP_INTERPOL   *ctx;
 
   PetscFunctionBegin;
-  ierr = PetscNewLog(nep,&ctx);CHKERRQ(ierr);
+  PetscCall(PetscNewLog(nep,&ctx));
   nep->data   = (void*)ctx;
   ctx->maxdeg = 5;
   ctx->tol    = PETSC_DEFAULT;
@@ -497,10 +482,9 @@ SLEPC_EXTERN PetscErrorCode NEPCreate_Interpol(NEP nep)
   nep->ops->destroy        = NEPDestroy_Interpol;
   nep->ops->view           = NEPView_Interpol;
 
-  ierr = PetscObjectComposeFunction((PetscObject)nep,"NEPInterpolSetInterpolation_C",NEPInterpolSetInterpolation_Interpol);CHKERRQ(ierr);
-  ierr = PetscObjectComposeFunction((PetscObject)nep,"NEPInterpolGetInterpolation_C",NEPInterpolGetInterpolation_Interpol);CHKERRQ(ierr);
-  ierr = PetscObjectComposeFunction((PetscObject)nep,"NEPInterpolSetPEP_C",NEPInterpolSetPEP_Interpol);CHKERRQ(ierr);
-  ierr = PetscObjectComposeFunction((PetscObject)nep,"NEPInterpolGetPEP_C",NEPInterpolGetPEP_Interpol);CHKERRQ(ierr);
+  PetscCall(PetscObjectComposeFunction((PetscObject)nep,"NEPInterpolSetInterpolation_C",NEPInterpolSetInterpolation_Interpol));
+  PetscCall(PetscObjectComposeFunction((PetscObject)nep,"NEPInterpolGetInterpolation_C",NEPInterpolGetInterpolation_Interpol));
+  PetscCall(PetscObjectComposeFunction((PetscObject)nep,"NEPInterpolSetPEP_C",NEPInterpolSetPEP_Interpol));
+  PetscCall(PetscObjectComposeFunction((PetscObject)nep,"NEPInterpolGetPEP_C",NEPInterpolGetPEP_Interpol));
   PetscFunctionReturn(0);
 }
-
