@@ -1,7 +1,7 @@
 /*
    - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
    SLEPc - Scalable Library for Eigenvalue Problem Computations
-   Copyright (c) 2002-2021, Universitat Politecnica de Valencia, Spain
+   Copyright (c) 2002-, Universitat Politecnica de Valencia, Spain
 
    This file is part of SLEPc.
    SLEPc is distributed under a 2-clause BSD license (see LICENSE).
@@ -36,13 +36,9 @@ static const char citation[] =
 
 PetscErrorCode NEPComputeVectors(NEP nep)
 {
-  PetscErrorCode ierr;
-
   PetscFunctionBegin;
   NEPCheckSolved(nep,1);
-  if (nep->state==NEP_STATE_SOLVED && nep->ops->computevectors) {
-    ierr = (*nep->ops->computevectors)(nep);CHKERRQ(ierr);
-  }
+  if (nep->state==NEP_STATE_SOLVED && nep->ops->computevectors) PetscCall((*nep->ops->computevectors)(nep));
   nep->state = NEP_STATE_EIGENVECTORS;
   PetscFunctionReturn(0);
 }
@@ -57,11 +53,19 @@ PetscErrorCode NEPComputeVectors(NEP nep)
 
    Options Database Keys:
 +  -nep_view - print information about the solver used
-.  -nep_view_vectors binary - save the computed eigenvectors to the default binary viewer
-.  -nep_view_values - print computed eigenvalues
+.  -nep_view_vectors - view the computed eigenvectors
+.  -nep_view_values - view the computed eigenvalues
 .  -nep_converged_reason - print reason for convergence, and number of iterations
 .  -nep_error_absolute - print absolute errors of each eigenpair
--  -nep_error_relative - print relative errors of each eigenpair
+.  -nep_error_relative - print relative errors of each eigenpair
+-  -nep_error_backward - print backward errors of each eigenpair
+
+   Notes:
+   All the command-line options listed above admit an optional argument specifying
+   the viewer type and options. For instance, use '-nep_view_vectors binary:myvecs.bin'
+   to save the eigenvectors to a binary file, '-nep_view_values draw' to draw the computed
+   eigenvalues graphically, or '-nep_error_relative :myerr.m:ascii_matlab' to save
+   the errors in a file that can be executed in Matlab.
 
    Level: beginner
 
@@ -69,17 +73,16 @@ PetscErrorCode NEPComputeVectors(NEP nep)
 @*/
 PetscErrorCode NEPSolve(NEP nep)
 {
-  PetscErrorCode ierr;
   PetscInt       i;
 
   PetscFunctionBegin;
   PetscValidHeaderSpecific(nep,NEP_CLASSID,1);
   if (nep->state>=NEP_STATE_SOLVED) PetscFunctionReturn(0);
-  ierr = PetscCitationsRegister(citation,&cited);CHKERRQ(ierr);
-  ierr = PetscLogEventBegin(NEP_Solve,nep,0,0,0);CHKERRQ(ierr);
+  PetscCall(PetscCitationsRegister(citation,&cited));
+  PetscCall(PetscLogEventBegin(NEP_Solve,nep,0,0,0));
 
   /* call setup */
-  ierr = NEPSetUp(nep);CHKERRQ(ierr);
+  PetscCall(NEPSetUp(nep));
   nep->nconv = 0;
   nep->its = 0;
   for (i=0;i<nep->ncv;i++) {
@@ -88,40 +91,40 @@ PetscErrorCode NEPSolve(NEP nep)
     nep->errest[i] = 0.0;
     nep->perm[i]   = i;
   }
-  ierr = NEPViewFromOptions(nep,NULL,"-nep_view_pre");CHKERRQ(ierr);
-  ierr = RGViewFromOptions(nep->rg,NULL,"-rg_view");CHKERRQ(ierr);
+  PetscCall(NEPViewFromOptions(nep,NULL,"-nep_view_pre"));
+  PetscCall(RGViewFromOptions(nep->rg,NULL,"-rg_view"));
 
   /* call solver */
-  ierr = (*nep->ops->solve)(nep);CHKERRQ(ierr);
-  if (!nep->reason) SETERRQ(PetscObjectComm((PetscObject)nep),PETSC_ERR_PLIB,"Internal error, solver returned without setting converged reason");
+  PetscCall((*nep->ops->solve)(nep));
+  PetscCheck(nep->reason,PetscObjectComm((PetscObject)nep),PETSC_ERR_PLIB,"Internal error, solver returned without setting converged reason");
   nep->state = NEP_STATE_SOLVED;
 
   /* Only the first nconv columns contain useful information */
-  ierr = BVSetActiveColumns(nep->V,0,nep->nconv);CHKERRQ(ierr);
-  if (nep->twosided) { ierr = BVSetActiveColumns(nep->W,0,nep->nconv);CHKERRQ(ierr); }
+  PetscCall(BVSetActiveColumns(nep->V,0,nep->nconv));
+  if (nep->twosided) PetscCall(BVSetActiveColumns(nep->W,0,nep->nconv));
 
   if (nep->refine==NEP_REFINE_SIMPLE && nep->rits>0 && nep->nconv>0) {
-    ierr = NEPComputeVectors(nep);CHKERRQ(ierr);
-    ierr = NEPNewtonRefinementSimple(nep,&nep->rits,nep->rtol,nep->nconv);CHKERRQ(ierr);
+    PetscCall(NEPComputeVectors(nep));
+    PetscCall(NEPNewtonRefinementSimple(nep,&nep->rits,nep->rtol,nep->nconv));
     nep->state = NEP_STATE_EIGENVECTORS;
   }
 
   /* sort eigenvalues according to nep->which parameter */
-  ierr = SlepcSortEigenvalues(nep->sc,nep->nconv,nep->eigr,nep->eigi,nep->perm);CHKERRQ(ierr);
-  ierr = PetscLogEventEnd(NEP_Solve,nep,0,0,0);CHKERRQ(ierr);
+  PetscCall(SlepcSortEigenvalues(nep->sc,nep->nconv,nep->eigr,nep->eigi,nep->perm));
+  PetscCall(PetscLogEventEnd(NEP_Solve,nep,0,0,0));
 
   /* various viewers */
-  ierr = NEPViewFromOptions(nep,NULL,"-nep_view");CHKERRQ(ierr);
-  ierr = NEPConvergedReasonViewFromOptions(nep);CHKERRQ(ierr);
-  ierr = NEPErrorViewFromOptions(nep);CHKERRQ(ierr);
-  ierr = NEPValuesViewFromOptions(nep);CHKERRQ(ierr);
-  ierr = NEPVectorsViewFromOptions(nep);CHKERRQ(ierr);
+  PetscCall(NEPViewFromOptions(nep,NULL,"-nep_view"));
+  PetscCall(NEPConvergedReasonViewFromOptions(nep));
+  PetscCall(NEPErrorViewFromOptions(nep));
+  PetscCall(NEPValuesViewFromOptions(nep));
+  PetscCall(NEPVectorsViewFromOptions(nep));
 
   /* Remove the initial subspace */
   nep->nini = 0;
 
   /* Reset resolvent information */
-  ierr = MatDestroy(&nep->resolvent);CHKERRQ(ierr);
+  PetscCall(MatDestroy(&nep->resolvent));
   PetscFunctionReturn(0);
 }
 
@@ -151,7 +154,6 @@ PetscErrorCode NEPSolve(NEP nep)
 @*/
 PetscErrorCode NEPProjectOperator(NEP nep,PetscInt j0,PetscInt j1)
 {
-  PetscErrorCode ierr;
   PetscInt       k;
   Mat            G;
 
@@ -161,11 +163,11 @@ PetscErrorCode NEPProjectOperator(NEP nep,PetscInt j0,PetscInt j1)
   PetscValidLogicalCollectiveInt(nep,j1,3);
   NEPCheckProblem(nep,1);
   NEPCheckSplit(nep,1);
-  ierr = BVSetActiveColumns(nep->V,j0,j1);CHKERRQ(ierr);
+  PetscCall(BVSetActiveColumns(nep->V,j0,j1));
   for (k=0;k<nep->nt;k++) {
-    ierr = DSGetMat(nep->ds,DSMatExtra[k],&G);CHKERRQ(ierr);
-    ierr = BVMatProject(nep->V,nep->A[k],nep->V,G);CHKERRQ(ierr);
-    ierr = DSRestoreMat(nep->ds,DSMatExtra[k],&G);CHKERRQ(ierr);
+    PetscCall(DSGetMat(nep->ds,DSMatExtra[k],&G));
+    PetscCall(BVMatProject(nep->V,nep->A[k],nep->V,G));
+    PetscCall(DSRestoreMat(nep->ds,DSMatExtra[k],&G));
   }
   PetscFunctionReturn(0);
 }
@@ -199,7 +201,6 @@ PetscErrorCode NEPProjectOperator(NEP nep,PetscInt j0,PetscInt j1)
 @*/
 PetscErrorCode NEPApplyFunction(NEP nep,PetscScalar lambda,Vec x,Vec v,Vec y,Mat A,Mat B)
 {
-  PetscErrorCode ierr;
   PetscInt       i;
   PetscScalar    alpha;
 
@@ -213,16 +214,16 @@ PetscErrorCode NEPApplyFunction(NEP nep,PetscScalar lambda,Vec x,Vec v,Vec y,Mat
   if (B) PetscValidHeaderSpecific(B,MAT_CLASSID,7);
 
   if (nep->fui==NEP_USER_INTERFACE_SPLIT) {
-    ierr = VecSet(y,0.0);CHKERRQ(ierr);
+    PetscCall(VecSet(y,0.0));
     for (i=0;i<nep->nt;i++) {
-      ierr = FNEvaluateFunction(nep->f[i],lambda,&alpha);CHKERRQ(ierr);
-      ierr = MatMult(nep->A[i],x,v);CHKERRQ(ierr);
-      ierr = VecAXPY(y,alpha,v);CHKERRQ(ierr);
+      PetscCall(FNEvaluateFunction(nep->f[i],lambda,&alpha));
+      PetscCall(MatMult(nep->A[i],x,v));
+      PetscCall(VecAXPY(y,alpha,v));
     }
   } else {
     if (!A) A = nep->function;
-    ierr = NEPComputeFunction(nep,lambda,A,A);CHKERRQ(ierr);
-    ierr = MatMult(A,x,y);CHKERRQ(ierr);
+    PetscCall(NEPComputeFunction(nep,lambda,A,A));
+    PetscCall(MatMult(A,x,y));
   }
   PetscFunctionReturn(0);
 }
@@ -249,7 +250,6 @@ PetscErrorCode NEPApplyFunction(NEP nep,PetscScalar lambda,Vec x,Vec v,Vec y,Mat
 @*/
 PetscErrorCode NEPApplyAdjoint(NEP nep,PetscScalar lambda,Vec x,Vec v,Vec y,Mat A,Mat B)
 {
-  PetscErrorCode ierr;
   PetscInt       i;
   PetscScalar    alpha;
   Vec            w;
@@ -263,23 +263,23 @@ PetscErrorCode NEPApplyAdjoint(NEP nep,PetscScalar lambda,Vec x,Vec v,Vec y,Mat
   if (A) PetscValidHeaderSpecific(A,MAT_CLASSID,6);
   if (B) PetscValidHeaderSpecific(B,MAT_CLASSID,7);
 
-  ierr = VecDuplicate(x,&w);CHKERRQ(ierr);
-  ierr = VecCopy(x,w);CHKERRQ(ierr);
-  ierr = VecConjugate(w);CHKERRQ(ierr);
+  PetscCall(VecDuplicate(x,&w));
+  PetscCall(VecCopy(x,w));
+  PetscCall(VecConjugate(w));
   if (nep->fui==NEP_USER_INTERFACE_SPLIT) {
-    ierr = VecSet(y,0.0);CHKERRQ(ierr);
+    PetscCall(VecSet(y,0.0));
     for (i=0;i<nep->nt;i++) {
-      ierr = FNEvaluateFunction(nep->f[i],lambda,&alpha);CHKERRQ(ierr);
-      ierr = MatMultTranspose(nep->A[i],w,v);CHKERRQ(ierr);
-      ierr = VecAXPY(y,alpha,v);CHKERRQ(ierr);
+      PetscCall(FNEvaluateFunction(nep->f[i],lambda,&alpha));
+      PetscCall(MatMultTranspose(nep->A[i],w,v));
+      PetscCall(VecAXPY(y,alpha,v));
     }
   } else {
     if (!A) A = nep->function;
-    ierr = NEPComputeFunction(nep,lambda,A,A);CHKERRQ(ierr);
-    ierr = MatMultTranspose(A,w,y);CHKERRQ(ierr);
+    PetscCall(NEPComputeFunction(nep,lambda,A,A));
+    PetscCall(MatMultTranspose(A,w,y));
   }
-  ierr = VecDestroy(&w);CHKERRQ(ierr);
-  ierr = VecConjugate(y);CHKERRQ(ierr);
+  PetscCall(VecDestroy(&w));
+  PetscCall(VecConjugate(y));
   PetscFunctionReturn(0);
 }
 
@@ -311,7 +311,6 @@ PetscErrorCode NEPApplyAdjoint(NEP nep,PetscScalar lambda,Vec x,Vec v,Vec y,Mat
 @*/
 PetscErrorCode NEPApplyJacobian(NEP nep,PetscScalar lambda,Vec x,Vec v,Vec y,Mat A)
 {
-  PetscErrorCode ierr;
   PetscInt       i;
   PetscScalar    alpha;
 
@@ -324,16 +323,16 @@ PetscErrorCode NEPApplyJacobian(NEP nep,PetscScalar lambda,Vec x,Vec v,Vec y,Mat
   if (A) PetscValidHeaderSpecific(A,MAT_CLASSID,6);
 
   if (nep->fui==NEP_USER_INTERFACE_SPLIT) {
-    ierr = VecSet(y,0.0);CHKERRQ(ierr);
+    PetscCall(VecSet(y,0.0));
     for (i=0;i<nep->nt;i++) {
-      ierr = FNEvaluateDerivative(nep->f[i],lambda,&alpha);CHKERRQ(ierr);
-      ierr = MatMult(nep->A[i],x,v);CHKERRQ(ierr);
-      ierr = VecAXPY(y,alpha,v);CHKERRQ(ierr);
+      PetscCall(FNEvaluateDerivative(nep->f[i],lambda,&alpha));
+      PetscCall(MatMult(nep->A[i],x,v));
+      PetscCall(VecAXPY(y,alpha,v));
     }
   } else {
     if (!A) A = nep->jacobian;
-    ierr = NEPComputeJacobian(nep,lambda,A);CHKERRQ(ierr);
-    ierr = MatMult(A,x,y);CHKERRQ(ierr);
+    PetscCall(NEPComputeJacobian(nep,lambda,A));
+    PetscCall(MatMult(A,x,y));
   }
   PetscFunctionReturn(0);
 }
@@ -387,7 +386,7 @@ PetscErrorCode NEPGetIterationNumber(NEP nep,PetscInt *its)
 
    Level: beginner
 
-.seealso: NEPSetDimensions(), NEPSolve()
+.seealso: NEPSetDimensions(), NEPSolve(), NEPGetEigenpair()
 @*/
 PetscErrorCode NEPGetConverged(NEP nep,PetscInt *nconv)
 {
@@ -411,8 +410,10 @@ PetscErrorCode NEPGetConverged(NEP nep,PetscInt *nconv)
    Output Parameter:
 .  reason - negative value indicates diverged, positive value converged
 
-   Notes:
+   Options Database Key:
+.  -nep_converged_reason - print the reason to a viewer
 
+   Notes:
    Possible values for reason are
 +  NEP_CONVERGED_TOL - converged up to tolerance
 .  NEP_CONVERGED_USER - converged due to a user-defined condition
@@ -476,7 +477,6 @@ PetscErrorCode NEPGetConvergedReason(NEP nep,NEPConvergedReason *reason)
 PetscErrorCode NEPGetEigenpair(NEP nep,PetscInt i,PetscScalar *eigr,PetscScalar *eigi,Vec Vr,Vec Vi)
 {
   PetscInt       k;
-  PetscErrorCode ierr;
 
   PetscFunctionBegin;
   PetscValidHeaderSpecific(nep,NEP_CLASSID,1);
@@ -484,10 +484,10 @@ PetscErrorCode NEPGetEigenpair(NEP nep,PetscInt i,PetscScalar *eigr,PetscScalar
   if (Vr) { PetscValidHeaderSpecific(Vr,VEC_CLASSID,5); PetscCheckSameComm(nep,1,Vr,5); }
   if (Vi) { PetscValidHeaderSpecific(Vi,VEC_CLASSID,6); PetscCheckSameComm(nep,1,Vi,6); }
   NEPCheckSolved(nep,1);
-  if (i<0) SETERRQ(PetscObjectComm((PetscObject)nep),PETSC_ERR_ARG_OUTOFRANGE,"The index cannot be negative");
-  if (i>=nep->nconv) SETERRQ(PetscObjectComm((PetscObject)nep),PETSC_ERR_ARG_OUTOFRANGE,"The index can be nconv-1 at most, see NEPGetConverged()");
+  PetscCheck(i>=0,PetscObjectComm((PetscObject)nep),PETSC_ERR_ARG_OUTOFRANGE,"The index cannot be negative");
+  PetscCheck(i<nep->nconv,PetscObjectComm((PetscObject)nep),PETSC_ERR_ARG_OUTOFRANGE,"The index can be nconv-1 at most, see NEPGetConverged()");
 
-  ierr = NEPComputeVectors(nep);CHKERRQ(ierr);
+  PetscCall(NEPComputeVectors(nep));
   k = nep->perm[i];
 
   /* eigenvalue */
@@ -500,7 +500,7 @@ PetscErrorCode NEPGetEigenpair(NEP nep,PetscInt i,PetscScalar *eigr,PetscScalar
 #endif
 
   /* eigenvector */
-  ierr = BV_GetEigenvector(nep->V,k,nep->eigi[k],Vr,Vi);CHKERRQ(ierr);
+  PetscCall(BV_GetEigenvector(nep->V,k,nep->eigi[k],Vr,Vi));
   PetscFunctionReturn(0);
 }
 
@@ -539,7 +539,6 @@ PetscErrorCode NEPGetEigenpair(NEP nep,PetscInt i,PetscScalar *eigr,PetscScalar
 @*/
 PetscErrorCode NEPGetLeftEigenvector(NEP nep,PetscInt i,Vec Wr,Vec Wi)
 {
-  PetscErrorCode ierr;
   PetscInt       k;
 
   PetscFunctionBegin;
@@ -548,11 +547,12 @@ PetscErrorCode NEPGetLeftEigenvector(NEP nep,PetscInt i,Vec Wr,Vec Wi)
   if (Wr) { PetscValidHeaderSpecific(Wr,VEC_CLASSID,3); PetscCheckSameComm(nep,1,Wr,3); }
   if (Wi) { PetscValidHeaderSpecific(Wi,VEC_CLASSID,4); PetscCheckSameComm(nep,1,Wi,4); }
   NEPCheckSolved(nep,1);
-  if (!nep->twosided) SETERRQ(PetscObjectComm((PetscObject)nep),PETSC_ERR_ARG_WRONGSTATE,"Must request left vectors with NEPSetTwoSided");
-  if (i<0 || i>=nep->nconv) SETERRQ(PetscObjectComm((PetscObject)nep),PETSC_ERR_ARG_OUTOFRANGE,"Argument 2 out of range");
-  ierr = NEPComputeVectors(nep);CHKERRQ(ierr);
+  PetscCheck(nep->twosided,PetscObjectComm((PetscObject)nep),PETSC_ERR_ARG_WRONGSTATE,"Must request left vectors with NEPSetTwoSided");
+  PetscCheck(i>=0,PetscObjectComm((PetscObject)nep),PETSC_ERR_ARG_OUTOFRANGE,"The index cannot be negative");
+  PetscCheck(i<nep->nconv,PetscObjectComm((PetscObject)nep),PETSC_ERR_ARG_OUTOFRANGE,"The index can be nconv-1 at most, see NEPGetConverged()");
+  PetscCall(NEPComputeVectors(nep));
   k = nep->perm[i];
-  ierr = BV_GetEigenvector(nep->W,k,nep->eigi[k],Wr,Wi);CHKERRQ(ierr);
+  PetscCall(BV_GetEigenvector(nep->W,k,nep->eigi[k],Wr,Wi));
   PetscFunctionReturn(0);
 }
 
@@ -583,7 +583,8 @@ PetscErrorCode NEPGetErrorEstimate(NEP nep,PetscInt i,PetscReal *errest)
   PetscValidHeaderSpecific(nep,NEP_CLASSID,1);
   PetscValidRealPointer(errest,3);
   NEPCheckSolved(nep,1);
-  if (i<0 || i>=nep->nconv) SETERRQ(PetscObjectComm((PetscObject)nep),PETSC_ERR_ARG_OUTOFRANGE,"Argument 2 out of range");
+  PetscCheck(i>=0,PetscObjectComm((PetscObject)nep),PETSC_ERR_ARG_OUTOFRANGE,"The index cannot be negative");
+  PetscCheck(i<nep->nconv,PetscObjectComm((PetscObject)nep),PETSC_ERR_ARG_OUTOFRANGE,"The index can be nconv-1 at most, see NEPGetConverged()");
   *errest = nep->errest[nep->perm[i]];
   PetscFunctionReturn(0);
 }
@@ -600,18 +601,14 @@ PetscErrorCode NEPGetErrorEstimate(NEP nep,PetscInt i,PetscReal *errest)
 */
 PetscErrorCode NEPComputeResidualNorm_Private(NEP nep,PetscBool adj,PetscScalar lambda,Vec x,Vec *w,PetscReal *norm)
 {
-  PetscErrorCode ierr;
   Vec            y,z=NULL;
 
   PetscFunctionBegin;
   y = w[0];
   if (nep->fui==NEP_USER_INTERFACE_SPLIT) z = w[1];
-  if (adj) {
-    ierr = NEPApplyAdjoint(nep,lambda,x,z,y,NULL,NULL);CHKERRQ(ierr);
-  } else {
-    ierr = NEPApplyFunction(nep,lambda,x,z,y,NULL,NULL);CHKERRQ(ierr);
-  }
-  ierr = VecNorm(y,NORM_2,norm);CHKERRQ(ierr);
+  if (adj) PetscCall(NEPApplyAdjoint(nep,lambda,x,z,y,NULL,NULL));
+  else PetscCall(NEPApplyFunction(nep,lambda,x,z,y,NULL,NULL));
+  PetscCall(VecNorm(y,NORM_2,norm));
   PetscFunctionReturn(0);
 }
 
@@ -640,7 +637,6 @@ PetscErrorCode NEPComputeResidualNorm_Private(NEP nep,PetscBool adj,PetscScalar
 @*/
 PetscErrorCode NEPComputeError(NEP nep,PetscInt i,NEPErrorType type,PetscReal *error)
 {
-  PetscErrorCode ierr;
   Vec            xr,xi=NULL;
   PetscInt       j,nwork,issplit=0;
   PetscScalar    kr,ki,s;
@@ -664,24 +660,24 @@ PetscErrorCode NEPComputeError(NEP nep,PetscInt i,NEPErrorType type,PetscReal *e
     issplit = 1;
     nwork++;  /* need an extra work vector for NEPComputeResidualNorm_Private */
   }
-  ierr = NEPSetWorkVecs(nep,nwork);CHKERRQ(ierr);
+  PetscCall(NEPSetWorkVecs(nep,nwork));
   xr = nep->work[issplit+1];
 #if !defined(PETSC_USE_COMPLEX)
   xi = nep->work[issplit+2];
 #endif
 
   /* compute residual norms */
-  ierr = NEPGetEigenpair(nep,i,&kr,&ki,xr,xi);CHKERRQ(ierr);
+  PetscCall(NEPGetEigenpair(nep,i,&kr,&ki,xr,xi));
 #if !defined(PETSC_USE_COMPLEX)
-  if (ki) SETERRQ(PetscObjectComm((PetscObject)nep),PETSC_ERR_SUP,"Not implemented for complex eigenvalues with real scalars");
+  PetscCheck(ki==0.0,PetscObjectComm((PetscObject)nep),PETSC_ERR_SUP,"Not implemented for complex eigenvalues with real scalars");
 #endif
-  ierr = NEPComputeResidualNorm_Private(nep,PETSC_FALSE,kr,xr,nep->work,error);CHKERRQ(ierr);
-  ierr = VecNorm(xr,NORM_2,&er);CHKERRQ(ierr);
+  PetscCall(NEPComputeResidualNorm_Private(nep,PETSC_FALSE,kr,xr,nep->work,error));
+  PetscCall(VecNorm(xr,NORM_2,&er));
 
   /* if two-sided, compute left residual norm and take the maximum */
   if (nep->twosided) {
-    ierr = NEPGetLeftEigenvector(nep,i,xr,xi);CHKERRQ(ierr);
-    ierr = NEPComputeResidualNorm_Private(nep,PETSC_TRUE,kr,xr,nep->work,&errorl);CHKERRQ(ierr);
+    PetscCall(NEPGetLeftEigenvector(nep,i,xr,xi));
+    PetscCall(NEPComputeResidualNorm_Private(nep,PETSC_TRUE,kr,xr,nep->work,&errorl));
     *error = PetscMax(*error,errorl);
   }
 
@@ -694,23 +690,23 @@ PetscErrorCode NEPComputeError(NEP nep,PetscInt i,NEPErrorType type,PetscReal *e
       break;
     case NEP_ERROR_BACKWARD:
       if (nep->fui!=NEP_USER_INTERFACE_SPLIT) {
-        ierr = NEPComputeFunction(nep,kr,nep->function,nep->function);CHKERRQ(ierr);
-        ierr = MatHasOperation(nep->function,MATOP_NORM,&flg);CHKERRQ(ierr);
-        if (!flg) SETERRQ(PetscObjectComm((PetscObject)nep),PETSC_ERR_ARG_WRONG,"The computation of backward errors requires a matrix norm operation");
-        ierr = MatNorm(nep->function,NORM_INFINITY,&nrm);CHKERRQ(ierr);
+        PetscCall(NEPComputeFunction(nep,kr,nep->function,nep->function));
+        PetscCall(MatHasOperation(nep->function,MATOP_NORM,&flg));
+        PetscCheck(flg,PetscObjectComm((PetscObject)nep),PETSC_ERR_ARG_WRONG,"The computation of backward errors requires a matrix norm operation");
+        PetscCall(MatNorm(nep->function,NORM_INFINITY,&nrm));
         *error /= nrm*er;
         break;
       }
       /* initialization of matrix norms */
       if (!nep->nrma[0]) {
         for (j=0;j<nep->nt;j++) {
-          ierr = MatHasOperation(nep->A[j],MATOP_NORM,&flg);CHKERRQ(ierr);
-          if (!flg) SETERRQ(PetscObjectComm((PetscObject)nep),PETSC_ERR_ARG_WRONG,"The computation of backward errors requires a matrix norm operation");
-          ierr = MatNorm(nep->A[j],NORM_INFINITY,&nep->nrma[j]);CHKERRQ(ierr);
+          PetscCall(MatHasOperation(nep->A[j],MATOP_NORM,&flg));
+          PetscCheck(flg,PetscObjectComm((PetscObject)nep),PETSC_ERR_ARG_WRONG,"The computation of backward errors requires a matrix norm operation");
+          PetscCall(MatNorm(nep->A[j],NORM_INFINITY,&nep->nrma[j]));
         }
       }
       for (j=0;j<nep->nt;j++) {
-        ierr = FNEvaluateFunction(nep->f[j],kr,&s);CHKERRQ(ierr);
+        PetscCall(FNEvaluateFunction(nep->f[j],kr,&s));
         z = z + nep->nrma[j]*PetscAbsScalar(s);
       }
       *error /= z*er;
@@ -746,7 +742,6 @@ PetscErrorCode NEPComputeError(NEP nep,PetscInt i,NEPErrorType type,PetscReal *e
 @*/
 PetscErrorCode NEPComputeFunction(NEP nep,PetscScalar lambda,Mat A,Mat B)
 {
-  PetscErrorCode ierr;
   PetscInt       i;
   PetscScalar    alpha;
 
@@ -755,20 +750,21 @@ PetscErrorCode NEPComputeFunction(NEP nep,PetscScalar lambda,Mat A,Mat B)
   NEPCheckProblem(nep,1);
   switch (nep->fui) {
   case NEP_USER_INTERFACE_CALLBACK:
-    if (!nep->computefunction) SETERRQ(PetscObjectComm((PetscObject)nep),PETSC_ERR_USER,"Must call NEPSetFunction() first");
-    ierr = PetscLogEventBegin(NEP_FunctionEval,nep,A,B,0);CHKERRQ(ierr);
+    PetscCheck(nep->computefunction,PetscObjectComm((PetscObject)nep),PETSC_ERR_USER,"Must call NEPSetFunction() first");
+    PetscCall(PetscLogEventBegin(NEP_FunctionEval,nep,A,B,0));
     PetscStackPush("NEP user Function function");
-    ierr = (*nep->computefunction)(nep,lambda,A,B,nep->functionctx);CHKERRQ(ierr);
+    PetscCall((*nep->computefunction)(nep,lambda,A,B,nep->functionctx));
     PetscStackPop;
-    ierr = PetscLogEventEnd(NEP_FunctionEval,nep,A,B,0);CHKERRQ(ierr);
+    PetscCall(PetscLogEventEnd(NEP_FunctionEval,nep,A,B,0));
     break;
   case NEP_USER_INTERFACE_SPLIT:
-    ierr = MatZeroEntries(A);CHKERRQ(ierr);
+    PetscCall(MatZeroEntries(A));
+    if (A != B) PetscCall(MatZeroEntries(B));
     for (i=0;i<nep->nt;i++) {
-      ierr = FNEvaluateFunction(nep->f[i],lambda,&alpha);CHKERRQ(ierr);
-      ierr = MatAXPY(A,alpha,nep->A[i],nep->mstr);CHKERRQ(ierr);
+      PetscCall(FNEvaluateFunction(nep->f[i],lambda,&alpha));
+      PetscCall(MatAXPY(A,alpha,nep->A[i],nep->mstr));
+      if (A != B) PetscCall(MatAXPY(B,alpha,nep->P[i],nep->mstrp));
     }
-    if (A != B) SETERRQ(PetscObjectComm((PetscObject)nep),PETSC_ERR_SUP,"Not implemented");
     break;
   }
   PetscFunctionReturn(0);
@@ -797,7 +793,6 @@ PetscErrorCode NEPComputeFunction(NEP nep,PetscScalar lambda,Mat A,Mat B)
 @*/
 PetscErrorCode NEPComputeJacobian(NEP nep,PetscScalar lambda,Mat A)
 {
-  PetscErrorCode ierr;
   PetscInt       i;
   PetscScalar    alpha;
 
@@ -806,21 +801,20 @@ PetscErrorCode NEPComputeJacobian(NEP nep,PetscScalar lambda,Mat A)
   NEPCheckProblem(nep,1);
   switch (nep->fui) {
   case NEP_USER_INTERFACE_CALLBACK:
-    if (!nep->computejacobian) SETERRQ(PetscObjectComm((PetscObject)nep),PETSC_ERR_USER,"Must call NEPSetJacobian() first");
-    ierr = PetscLogEventBegin(NEP_JacobianEval,nep,A,0,0);CHKERRQ(ierr);
+    PetscCheck(nep->computejacobian,PetscObjectComm((PetscObject)nep),PETSC_ERR_USER,"Must call NEPSetJacobian() first");
+    PetscCall(PetscLogEventBegin(NEP_JacobianEval,nep,A,0,0));
     PetscStackPush("NEP user Jacobian function");
-    ierr = (*nep->computejacobian)(nep,lambda,A,nep->jacobianctx);CHKERRQ(ierr);
+    PetscCall((*nep->computejacobian)(nep,lambda,A,nep->jacobianctx));
     PetscStackPop;
-    ierr = PetscLogEventEnd(NEP_JacobianEval,nep,A,0,0);CHKERRQ(ierr);
+    PetscCall(PetscLogEventEnd(NEP_JacobianEval,nep,A,0,0));
     break;
   case NEP_USER_INTERFACE_SPLIT:
-    ierr = MatZeroEntries(A);CHKERRQ(ierr);
+    PetscCall(MatZeroEntries(A));
     for (i=0;i<nep->nt;i++) {
-      ierr = FNEvaluateDerivative(nep->f[i],lambda,&alpha);CHKERRQ(ierr);
-      ierr = MatAXPY(A,alpha,nep->A[i],nep->mstr);CHKERRQ(ierr);
+      PetscCall(FNEvaluateDerivative(nep->f[i],lambda,&alpha));
+      PetscCall(MatAXPY(A,alpha,nep->A[i],nep->mstr));
     }
     break;
   }
   PetscFunctionReturn(0);
 }
-
