@@ -1,7 +1,7 @@
 /*
    - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
    SLEPc - Scalable Library for Eigenvalue Problem Computations
-   Copyright (c) 2002-2021, Universitat Politecnica de Valencia, Spain
+   Copyright (c) 2002-, Universitat Politecnica de Valencia, Spain
 
    This file is part of SLEPc.
    SLEPc is distributed under a 2-clause BSD license (see LICENSE).
@@ -36,26 +36,18 @@ static const char citation[] =
 
 PetscErrorCode PEPComputeVectors(PEP pep)
 {
-  PetscErrorCode ierr;
-
   PetscFunctionBegin;
   PEPCheckSolved(pep,1);
-  if (pep->state==PEP_STATE_SOLVED && pep->ops->computevectors) {
-    ierr = (*pep->ops->computevectors)(pep);CHKERRQ(ierr);
-  }
+  if (pep->state==PEP_STATE_SOLVED && pep->ops->computevectors) PetscCall((*pep->ops->computevectors)(pep));
   pep->state = PEP_STATE_EIGENVECTORS;
   PetscFunctionReturn(0);
 }
 
 PetscErrorCode PEPExtractVectors(PEP pep)
 {
-  PetscErrorCode ierr;
-
   PetscFunctionBegin;
   PEPCheckSolved(pep,1);
-  if (pep->state==PEP_STATE_SOLVED && pep->ops->extractvectors) {
-    ierr = (*pep->ops->extractvectors)(pep);CHKERRQ(ierr);
-  }
+  if (pep->state==PEP_STATE_SOLVED && pep->ops->extractvectors) PetscCall((*pep->ops->extractvectors)(pep));
   PetscFunctionReturn(0);
 }
 
@@ -69,22 +61,27 @@ PetscErrorCode PEPExtractVectors(PEP pep)
 
    Options Database Keys:
 +  -pep_view - print information about the solver used
-.  -pep_view_matk binary - save any of the coefficient matrices (Ak) to the
-                default binary viewer (replace k by an integer from 0 to nmat-1)
-.  -pep_view_vectors binary - save the computed eigenvectors to the default binary viewer
-.  -pep_view_values - print computed eigenvalues
+.  -pep_view_matk - view the coefficient matrix Ak (replace k by an integer from 0 to nmat-1)
+.  -pep_view_vectors - view the computed eigenvectors
+.  -pep_view_values - view the computed eigenvalues
 .  -pep_converged_reason - print reason for convergence, and number of iterations
 .  -pep_error_absolute - print absolute errors of each eigenpair
 .  -pep_error_relative - print relative errors of each eigenpair
 -  -pep_error_backward - print backward errors of each eigenpair
 
+   Notes:
+   All the command-line options listed above admit an optional argument specifying
+   the viewer type and options. For instance, use '-pep_view_mat0 binary:amatrix.bin'
+   to save the A matrix to a binary file, '-pep_view_values draw' to draw the computed
+   eigenvalues graphically, or '-pep_error_relative :myerr.m:ascii_matlab' to save
+   the errors in a file that can be executed in Matlab.
+
    Level: beginner
 
 .seealso: PEPCreate(), PEPSetUp(), PEPDestroy(), PEPSetTolerances()
 @*/
 PetscErrorCode PEPSolve(PEP pep)
 {
-  PetscErrorCode ierr;
   PetscInt       i,k;
   PetscBool      flg,islinear;
   char           str[16];
@@ -92,10 +89,10 @@ PetscErrorCode PEPSolve(PEP pep)
   PetscFunctionBegin;
   PetscValidHeaderSpecific(pep,PEP_CLASSID,1);
   if (pep->state>=PEP_STATE_SOLVED) PetscFunctionReturn(0);
-  ierr = PetscLogEventBegin(PEP_Solve,pep,0,0,0);CHKERRQ(ierr);
+  PetscCall(PetscLogEventBegin(PEP_Solve,pep,0,0,0));
 
   /* call setup */
-  ierr = PEPSetUp(pep);CHKERRQ(ierr);
+  PetscCall(PEPSetUp(pep));
   pep->nconv = 0;
   pep->its   = 0;
   k = pep->lineariz? pep->ncv: pep->ncv*(pep->nmat-1);
@@ -105,25 +102,23 @@ PetscErrorCode PEPSolve(PEP pep)
     pep->errest[i] = 0.0;
     pep->perm[i]   = i;
   }
-  ierr = PEPViewFromOptions(pep,NULL,"-pep_view_pre");CHKERRQ(ierr);
-  ierr = RGViewFromOptions(pep->rg,NULL,"-rg_view");CHKERRQ(ierr);
+  PetscCall(PEPViewFromOptions(pep,NULL,"-pep_view_pre"));
+  PetscCall(RGViewFromOptions(pep->rg,NULL,"-rg_view"));
 
   /* Call solver */
-  ierr = (*pep->ops->solve)(pep);CHKERRQ(ierr);
-  if (!pep->reason) SETERRQ(PetscObjectComm((PetscObject)pep),PETSC_ERR_PLIB,"Internal error, solver returned without setting converged reason");
+  PetscCall((*pep->ops->solve)(pep));
+  PetscCheck(pep->reason,PetscObjectComm((PetscObject)pep),PETSC_ERR_PLIB,"Internal error, solver returned without setting converged reason");
   pep->state = PEP_STATE_SOLVED;
 
   /* Only the first nconv columns contain useful information */
-  ierr = BVSetActiveColumns(pep->V,0,pep->nconv);CHKERRQ(ierr);
+  PetscCall(BVSetActiveColumns(pep->V,0,pep->nconv));
 
-  ierr = PetscObjectTypeCompare((PetscObject)pep,PEPLINEAR,&islinear);CHKERRQ(ierr);
+  PetscCall(PetscObjectTypeCompare((PetscObject)pep,PEPLINEAR,&islinear));
   if (!islinear) {
-    ierr = STPostSolve(pep->st);CHKERRQ(ierr);
+    PetscCall(STPostSolve(pep->st));
     /* Map eigenvalues back to the original problem */
-    ierr = STGetTransform(pep->st,&flg);CHKERRQ(ierr);
-    if (flg && pep->ops->backtransform) {
-      ierr = (*pep->ops->backtransform)(pep);CHKERRQ(ierr);
-    }
+    PetscCall(STGetTransform(pep->st,&flg));
+    if (flg && pep->ops->backtransform) PetscCall((*pep->ops->backtransform)(pep));
   }
 
 #if !defined(PETSC_USE_COMPLEX)
@@ -134,36 +129,34 @@ PetscErrorCode PEPSolve(PEP pep)
         pep->eigi[i] = -pep->eigi[i];
         pep->eigi[i+1] = -pep->eigi[i+1];
         /* the next correction only works with eigenvectors */
-        ierr = PEPComputeVectors(pep);CHKERRQ(ierr);
-        ierr = BVScaleColumn(pep->V,i+1,-1.0);CHKERRQ(ierr);
+        PetscCall(PEPComputeVectors(pep));
+        PetscCall(BVScaleColumn(pep->V,i+1,-1.0));
       }
       i++;
     }
   }
 #endif
 
-  if (pep->refine!=PEP_REFINE_NONE) {
-    ierr = PetscCitationsRegister(citation,&cited);CHKERRQ(ierr);
-  }
+  if (pep->refine!=PEP_REFINE_NONE) PetscCall(PetscCitationsRegister(citation,&cited));
 
   if (pep->refine==PEP_REFINE_SIMPLE && pep->rits>0 && pep->nconv>0) {
-    ierr = PEPComputeVectors(pep);CHKERRQ(ierr);
-    ierr = PEPNewtonRefinementSimple(pep,&pep->rits,pep->rtol,pep->nconv);CHKERRQ(ierr);
+    PetscCall(PEPComputeVectors(pep));
+    PetscCall(PEPNewtonRefinementSimple(pep,&pep->rits,pep->rtol,pep->nconv));
   }
 
   /* sort eigenvalues according to pep->which parameter */
-  ierr = SlepcSortEigenvalues(pep->sc,pep->nconv,pep->eigr,pep->eigi,pep->perm);CHKERRQ(ierr);
-  ierr = PetscLogEventEnd(PEP_Solve,pep,0,0,0);CHKERRQ(ierr);
+  PetscCall(SlepcSortEigenvalues(pep->sc,pep->nconv,pep->eigr,pep->eigi,pep->perm));
+  PetscCall(PetscLogEventEnd(PEP_Solve,pep,0,0,0));
 
   /* various viewers */
-  ierr = PEPViewFromOptions(pep,NULL,"-pep_view");CHKERRQ(ierr);
-  ierr = PEPConvergedReasonViewFromOptions(pep);CHKERRQ(ierr);
-  ierr = PEPErrorViewFromOptions(pep);CHKERRQ(ierr);
-  ierr = PEPValuesViewFromOptions(pep);CHKERRQ(ierr);
-  ierr = PEPVectorsViewFromOptions(pep);CHKERRQ(ierr);
+  PetscCall(PEPViewFromOptions(pep,NULL,"-pep_view"));
+  PetscCall(PEPConvergedReasonViewFromOptions(pep));
+  PetscCall(PEPErrorViewFromOptions(pep));
+  PetscCall(PEPValuesViewFromOptions(pep));
+  PetscCall(PEPVectorsViewFromOptions(pep));
   for (i=0;i<pep->nmat;i++) {
-    ierr = PetscSNPrintf(str,sizeof(str),"-pep_view_mat%d",(int)i);CHKERRQ(ierr);
-    ierr = MatViewFromOptions(pep->A[i],(PetscObject)pep,str);CHKERRQ(ierr);
+    PetscCall(PetscSNPrintf(str,sizeof(str),"-pep_view_mat%" PetscInt_FMT,i));
+    PetscCall(MatViewFromOptions(pep->A[i],(PetscObject)pep,str));
   }
 
   /* Remove the initial subspace */
@@ -220,7 +213,7 @@ PetscErrorCode PEPGetIterationNumber(PEP pep,PetscInt *its)
 
    Level: beginner
 
-.seealso: PEPSetDimensions(), PEPSolve()
+.seealso: PEPSetDimensions(), PEPSolve(), PEPGetEigenpair()
 @*/
 PetscErrorCode PEPGetConverged(PEP pep,PetscInt *nconv)
 {
@@ -244,8 +237,10 @@ PetscErrorCode PEPGetConverged(PEP pep,PetscInt *nconv)
    Output Parameter:
 .  reason - negative value indicates diverged, positive value converged
 
-   Notes:
+   Options Database Key:
+.  -pep_converged_reason - print the reason to a viewer
 
+   Notes:
    Possible values for reason are
 +  PEP_CONVERGED_TOL - converged up to tolerance
 .  PEP_CONVERGED_USER - converged due to a user-defined condition
@@ -307,7 +302,6 @@ PetscErrorCode PEPGetConvergedReason(PEP pep,PEPConvergedReason *reason)
 PetscErrorCode PEPGetEigenpair(PEP pep,PetscInt i,PetscScalar *eigr,PetscScalar *eigi,Vec Vr,Vec Vi)
 {
   PetscInt       k;
-  PetscErrorCode ierr;
 
   PetscFunctionBegin;
   PetscValidHeaderSpecific(pep,PEP_CLASSID,1);
@@ -315,10 +309,10 @@ PetscErrorCode PEPGetEigenpair(PEP pep,PetscInt i,PetscScalar *eigr,PetscScalar
   if (Vr) { PetscValidHeaderSpecific(Vr,VEC_CLASSID,5); PetscCheckSameComm(pep,1,Vr,5); }
   if (Vi) { PetscValidHeaderSpecific(Vi,VEC_CLASSID,6); PetscCheckSameComm(pep,1,Vi,6); }
   PEPCheckSolved(pep,1);
-  if (i<0) SETERRQ(PetscObjectComm((PetscObject)pep),PETSC_ERR_ARG_OUTOFRANGE,"The index cannot be negative");
-  if (i>=pep->nconv) SETERRQ(PetscObjectComm((PetscObject)pep),PETSC_ERR_ARG_OUTOFRANGE,"The index can be nconv-1 at most, see PEPGetConverged()");
+  PetscCheck(i>=0,PetscObjectComm((PetscObject)pep),PETSC_ERR_ARG_OUTOFRANGE,"The index cannot be negative");
+  PetscCheck(i<pep->nconv,PetscObjectComm((PetscObject)pep),PETSC_ERR_ARG_OUTOFRANGE,"The index can be nconv-1 at most, see PEPGetConverged()");
 
-  ierr = PEPComputeVectors(pep);CHKERRQ(ierr);
+  PetscCall(PEPComputeVectors(pep));
   k = pep->perm[i];
 
   /* eigenvalue */
@@ -331,7 +325,7 @@ PetscErrorCode PEPGetEigenpair(PEP pep,PetscInt i,PetscScalar *eigr,PetscScalar
 #endif
 
   /* eigenvector */
-  ierr = BV_GetEigenvector(pep->V,k,pep->eigi[k],Vr,Vi);CHKERRQ(ierr);
+  PetscCall(BV_GetEigenvector(pep->V,k,pep->eigi[k],Vr,Vi));
   PetscFunctionReturn(0);
 }
 
@@ -363,7 +357,8 @@ PetscErrorCode PEPGetErrorEstimate(PEP pep,PetscInt i,PetscReal *errest)
   PetscValidHeaderSpecific(pep,PEP_CLASSID,1);
   PetscValidRealPointer(errest,3);
   PEPCheckSolved(pep,1);
-  if (i<0 || i>=pep->nconv) SETERRQ(PetscObjectComm((PetscObject)pep),PETSC_ERR_ARG_OUTOFRANGE,"Argument 2 out of range");
+  PetscCheck(i>=0,PetscObjectComm((PetscObject)pep),PETSC_ERR_ARG_OUTOFRANGE,"The index cannot be negative");
+  PetscCheck(i<pep->nconv,PetscObjectComm((PetscObject)pep),PETSC_ERR_ARG_OUTOFRANGE,"The index can be nconv-1 at most, see PEPGetConverged()");
   *errest = pep->errest[pep->perm[i]];
   PetscFunctionReturn(0);
 }
@@ -379,7 +374,6 @@ PetscErrorCode PEPGetErrorEstimate(PEP pep,PetscInt i,PetscReal *errest)
 */
 PetscErrorCode PEPComputeResidualNorm_Private(PEP pep,PetscScalar kr,PetscScalar ki,Vec xr,Vec xi,Vec *z,PetscReal *norm)
 {
-  PetscErrorCode ierr;
   Mat            *A=pep->A;
   PetscInt       i,nmat=pep->nmat;
   PetscScalar    t[20],*vals=t,*ivals=NULL;
@@ -393,60 +387,56 @@ PetscErrorCode PEPComputeResidualNorm_Private(PEP pep,PetscScalar kr,PetscScalar
 
   PetscFunctionBegin;
   u = z[0]; w = z[1];
-  ierr = VecSet(u,0.0);CHKERRQ(ierr);
+  PetscCall(VecSet(u,0.0));
 #if !defined(PETSC_USE_COMPLEX)
   ui = z[2]; wi = z[3];
   ivals = it;
 #endif
   if (nmat>20) {
-    ierr = PetscMalloc1(nmat,&vals);CHKERRQ(ierr);
+    PetscCall(PetscMalloc1(nmat,&vals));
 #if !defined(PETSC_USE_COMPLEX)
-    ierr = PetscMalloc1(nmat,&ivals);CHKERRQ(ierr);
+    PetscCall(PetscMalloc1(nmat,&ivals));
 #endif
   }
-  ierr = PEPEvaluateBasis(pep,kr,ki,vals,ivals);CHKERRQ(ierr);
+  PetscCall(PEPEvaluateBasis(pep,kr,ki,vals,ivals));
 #if !defined(PETSC_USE_COMPLEX)
   if (ki == 0 || PetscAbsScalar(ki) < PetscAbsScalar(kr*PETSC_MACHINE_EPSILON))
     imag = PETSC_FALSE;
   else {
     imag = PETSC_TRUE;
-    ierr = VecSet(ui,0.0);CHKERRQ(ierr);
+    PetscCall(VecSet(ui,0.0));
   }
 #endif
   for (i=0;i<nmat;i++) {
     if (vals[i]!=0.0) {
-      ierr = MatMult(A[i],xr,w);CHKERRQ(ierr);
-      ierr = VecAXPY(u,vals[i],w);CHKERRQ(ierr);
+      PetscCall(MatMult(A[i],xr,w));
+      PetscCall(VecAXPY(u,vals[i],w));
     }
 #if !defined(PETSC_USE_COMPLEX)
     if (imag) {
       if (ivals[i]!=0 || vals[i]!=0) {
-        ierr = MatMult(A[i],xi,wi);CHKERRQ(ierr);
-        if (vals[i]==0) {
-          ierr = MatMult(A[i],xr,w);CHKERRQ(ierr);
-        }
+        PetscCall(MatMult(A[i],xi,wi));
+        if (vals[i]==0) PetscCall(MatMult(A[i],xr,w));
       }
       if (ivals[i]!=0) {
-        ierr = VecAXPY(u,-ivals[i],wi);CHKERRQ(ierr);
-        ierr = VecAXPY(ui,ivals[i],w);CHKERRQ(ierr);
-      }
-      if (vals[i]!=0) {
-        ierr = VecAXPY(ui,vals[i],wi);CHKERRQ(ierr);
+        PetscCall(VecAXPY(u,-ivals[i],wi));
+        PetscCall(VecAXPY(ui,ivals[i],w));
       }
+      if (vals[i]!=0) PetscCall(VecAXPY(ui,vals[i],wi));
     }
 #endif
   }
-  ierr = VecNorm(u,NORM_2,norm);CHKERRQ(ierr);
+  PetscCall(VecNorm(u,NORM_2,norm));
 #if !defined(PETSC_USE_COMPLEX)
   if (imag) {
-    ierr = VecNorm(ui,NORM_2,&ni);CHKERRQ(ierr);
+    PetscCall(VecNorm(ui,NORM_2,&ni));
     *norm = SlepcAbsEigenvalue(*norm,ni);
   }
 #endif
   if (nmat>20) {
-    ierr = PetscFree(vals);CHKERRQ(ierr);
+    PetscCall(PetscFree(vals));
 #if !defined(PETSC_USE_COMPLEX)
-    ierr = PetscFree(ivals);CHKERRQ(ierr);
+    PetscCall(PetscFree(ivals));
 #endif
   }
   PetscFunctionReturn(0);
@@ -477,7 +467,6 @@ PetscErrorCode PEPComputeResidualNorm_Private(PEP pep,PetscScalar kr,PetscScalar
 @*/
 PetscErrorCode PEPComputeError(PEP pep,PetscInt i,PEPErrorType type,PetscReal *error)
 {
-  PetscErrorCode ierr;
   Vec            xr,xi,w[4];
   PetscScalar    kr,ki;
   PetscReal      t,z=0.0;
@@ -493,12 +482,12 @@ PetscErrorCode PEPComputeError(PEP pep,PetscInt i,PEPErrorType type,PetscReal *e
 
   /* allocate work vectors */
 #if defined(PETSC_USE_COMPLEX)
-  ierr = PEPSetWorkVecs(pep,3);CHKERRQ(ierr);
+  PetscCall(PEPSetWorkVecs(pep,3));
   xi   = NULL;
   w[2] = NULL;
   w[3] = NULL;
 #else
-  ierr = PEPSetWorkVecs(pep,6);CHKERRQ(ierr);
+  PetscCall(PEPSetWorkVecs(pep,6));
   xi   = pep->work[3];
   w[2] = pep->work[4];
   w[3] = pep->work[5];
@@ -508,8 +497,8 @@ PetscErrorCode PEPComputeError(PEP pep,PetscInt i,PEPErrorType type,PetscReal *e
   w[1] = pep->work[2];
 
   /* compute residual norms */
-  ierr = PEPGetEigenpair(pep,i,&kr,&ki,xr,xi);CHKERRQ(ierr);
-  ierr = PEPComputeResidualNorm_Private(pep,kr,ki,xr,xi,w,error);CHKERRQ(ierr);
+  PetscCall(PEPGetEigenpair(pep,i,&kr,&ki,xr,xi));
+  PetscCall(PEPComputeResidualNorm_Private(pep,kr,ki,xr,xi,w,error));
 
   /* compute error */
   switch (type) {
@@ -522,9 +511,9 @@ PetscErrorCode PEPComputeError(PEP pep,PetscInt i,PEPErrorType type,PetscReal *e
       /* initialization of matrix norms */
       if (!pep->nrma[pep->nmat-1]) {
         for (j=0;j<pep->nmat;j++) {
-          ierr = MatHasOperation(pep->A[j],MATOP_NORM,&flg);CHKERRQ(ierr);
-          if (!flg) SETERRQ(PetscObjectComm((PetscObject)pep),PETSC_ERR_ARG_WRONG,"The computation of backward errors requires a matrix norm operation");
-          ierr = MatNorm(pep->A[j],NORM_INFINITY,&pep->nrma[j]);CHKERRQ(ierr);
+          PetscCall(MatHasOperation(pep->A[j],MATOP_NORM,&flg));
+          PetscCheck(flg,PetscObjectComm((PetscObject)pep),PETSC_ERR_ARG_WRONG,"The computation of backward errors requires a matrix norm operation");
+          PetscCall(MatNorm(pep->A[j],NORM_INFINITY,&pep->nrma[j]));
         }
       }
       t = SlepcAbsEigenvalue(kr,ki);
@@ -538,4 +527,3 @@ PetscErrorCode PEPComputeError(PEP pep,PetscInt i,PEPErrorType type,PetscReal *e
   }
   PetscFunctionReturn(0);
 }
-
