@@ -1,7 +1,7 @@
 !
 !  - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 !  SLEPc - Scalable Library for Eigenvalue Problem Computations
-!  Copyright (c) 2002-2021, Universitat Politecnica de Valencia, Spain
+!  Copyright (c) 2002-, Universitat Politecnica de Valencia, Spain
 !
 !  This file is part of SLEPc.
 !  SLEPc is distributed under a 2-clause BSD license (see LICENSE).
@@ -32,6 +32,7 @@
 
       PetscEnum, parameter :: SVD_ERROR_ABSOLUTE         =  0
       PetscEnum, parameter :: SVD_ERROR_RELATIVE         =  1
+      PetscEnum, parameter :: SVD_ERROR_NORM             =  2
 
       PetscEnum, parameter :: SVD_CONV_ABS               =  0
       PetscEnum, parameter :: SVD_CONV_REL               =  1
@@ -42,6 +43,10 @@
       PetscEnum, parameter :: SVD_STOP_BASIC             =  0
       PetscEnum, parameter :: SVD_STOP_USER              =  1
 
+      PetscEnum, parameter :: SVD_TRLANCZOS_GBIDIAG_SINGLE =  0
+      PetscEnum, parameter :: SVD_TRLANCZOS_GBIDIAG_UPPER  =  1
+      PetscEnum, parameter :: SVD_TRLANCZOS_GBIDIAG_LOWER  =  2
+
       PetscEnum, parameter :: SVD_PRIMME_HYBRID          =  1
       PetscEnum, parameter :: SVD_PRIMME_NORMALEQUATIONS =  2
       PetscEnum, parameter :: SVD_PRIMME_AUGMENTED       =  3
@@ -55,3 +60,6 @@
 
       external SVDMonitorConvergedDestroy
 
+#if defined(_WIN32) && defined(PETSC_USE_SHARED_LIBRARIES)
+!DEC$ ATTRIBUTES DLLEXPORT::SLEPC_NULL_SVD
+#endif
