@@ -1,7 +1,7 @@
 /*
    - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
    SLEPc - Scalable Library for Eigenvalue Problem Computations
-   Copyright (c) 2002-2021, Universitat Politecnica de Valencia, Spain
+   Copyright (c) 2002-, Universitat Politecnica de Valencia, Spain
 
    This file is part of SLEPc.
    SLEPc is distributed under a 2-clause BSD license (see LICENSE).
@@ -39,7 +39,7 @@ PetscErrorCode SVDConvergedRelative(SVD svd,PetscReal sigma,PetscReal res,PetscR
 PetscErrorCode SVDConvergedNorm(SVD svd,PetscReal sigma,PetscReal res,PetscReal *errest,void *ctx)
 {
   PetscFunctionBegin;
-  *errest = res/SlepcAbs(svd->nrma,svd->nrmb);
+  *errest = res/PetscMax(svd->nrma,svd->nrmb);
   PetscFunctionReturn(0);
 }
 
@@ -87,18 +87,16 @@ PetscErrorCode SVDConvergedMaxIt(SVD svd,PetscReal sigma,PetscReal res,PetscReal
 @*/
 PetscErrorCode SVDStoppingBasic(SVD svd,PetscInt its,PetscInt max_it,PetscInt nconv,PetscInt nsv,SVDConvergedReason *reason,void *ctx)
 {
-  PetscErrorCode ierr;
-
   PetscFunctionBegin;
   *reason = SVD_CONVERGED_ITERATING;
   if (nconv >= nsv) {
-    ierr = PetscInfo2(svd,"Singular value solver finished successfully: %D singular triplets converged at iteration %D\n",nconv,its);CHKERRQ(ierr);
+    PetscCall(PetscInfo(svd,"Singular value solver finished successfully: %" PetscInt_FMT " singular triplets converged at iteration %" PetscInt_FMT "\n",nconv,its));
     *reason = SVD_CONVERGED_TOL;
   } else if (its >= max_it) {
     if (svd->conv == SVD_CONV_MAXIT) *reason = SVD_CONVERGED_MAXIT;
     else {
       *reason = SVD_DIVERGED_ITS;
-      ierr = PetscInfo1(svd,"Singular value solver iteration reached maximum number of iterations (%D)\n",its);CHKERRQ(ierr);
+      PetscCall(PetscInfo(svd,"Singular value solver iteration reached maximum number of iterations (%" PetscInt_FMT ")\n",its));
     }
   }
   PetscFunctionReturn(0);
@@ -114,40 +112,40 @@ PetscErrorCode SVDStoppingBasic(SVD svd,PetscInt its,PetscInt max_it,PetscInt nc
 .  nleft  - number of work vectors of dimension equal to left singular vector
 -  nright - number of work vectors of dimension equal to right singular vector
 
-   Developers Note:
+   Developer Notes:
    This is SLEPC_EXTERN because it may be required by user plugin SVD
    implementations.
 
    Level: developer
+
+.seealso: SVDSetUp()
 @*/
 PetscErrorCode SVDSetWorkVecs(SVD svd,PetscInt nleft,PetscInt nright)
 {
-  PetscErrorCode ierr;
   Vec            t;
 
   PetscFunctionBegin;
   PetscValidHeaderSpecific(svd,SVD_CLASSID,1);
   PetscValidLogicalCollectiveInt(svd,nleft,2);
   PetscValidLogicalCollectiveInt(svd,nright,3);
-  if (nleft <= 0) SETERRQ1(PetscObjectComm((PetscObject)svd),PETSC_ERR_ARG_OUTOFRANGE,"nleft must be > 0: nleft = %D",nleft);
-  if (nright <= 0) SETERRQ1(PetscObjectComm((PetscObject)svd),PETSC_ERR_ARG_OUTOFRANGE,"nright must be > 0: nright = %D",nright);
+  PetscCheck(nleft>0,PetscObjectComm((PetscObject)svd),PETSC_ERR_ARG_OUTOFRANGE,"nleft must be > 0: nleft = %" PetscInt_FMT,nleft);
+  PetscCheck(nright>0,PetscObjectComm((PetscObject)svd),PETSC_ERR_ARG_OUTOFRANGE,"nright must be > 0: nright = %" PetscInt_FMT,nright);
   if (svd->nworkl < nleft) {
-    ierr = VecDestroyVecs(svd->nworkl,&svd->workl);CHKERRQ(ierr);
+    PetscCall(VecDestroyVecs(svd->nworkl,&svd->workl));
     svd->nworkl = nleft;
-    if (svd->isgeneralized) { ierr = SVDCreateLeftTemplate(svd,&t);CHKERRQ(ierr); }
-    else { ierr = MatCreateVecsEmpty(svd->OP,NULL,&t);CHKERRQ(ierr); }
-    ierr = VecDuplicateVecs(t,nleft,&svd->workl);CHKERRQ(ierr);
-    ierr = VecDestroy(&t);CHKERRQ(ierr);
-    ierr = PetscLogObjectParents(svd,nleft,svd->workl);CHKERRQ(ierr);
+    if (svd->isgeneralized) PetscCall(SVDCreateLeftTemplate(svd,&t));
+    else PetscCall(MatCreateVecsEmpty(svd->OP,NULL,&t));
+    PetscCall(VecDuplicateVecs(t,nleft,&svd->workl));
+    PetscCall(VecDestroy(&t));
+    PetscCall(PetscLogObjectParents(svd,nleft,svd->workl));
   }
   if (svd->nworkr < nright) {
-    ierr = VecDestroyVecs(svd->nworkr,&svd->workr);CHKERRQ(ierr);
+    PetscCall(VecDestroyVecs(svd->nworkr,&svd->workr));
     svd->nworkr = nright;
-    ierr = MatCreateVecsEmpty(svd->OP,&t,NULL);CHKERRQ(ierr);
-    ierr = VecDuplicateVecs(t,nright,&svd->workr);CHKERRQ(ierr);
-    ierr = VecDestroy(&t);CHKERRQ(ierr);
-    ierr = PetscLogObjectParents(svd,nright,svd->workr);CHKERRQ(ierr);
+    PetscCall(MatCreateVecsEmpty(svd->OP,&t,NULL));
+    PetscCall(VecDuplicateVecs(t,nright,&svd->workr));
+    PetscCall(VecDestroy(&t));
+    PetscCall(PetscLogObjectParents(svd,nright,svd->workr));
   }
   PetscFunctionReturn(0);
 }
-
