@@ -1,7 +1,7 @@
 /*
    - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
    SLEPc - Scalable Library for Eigenvalue Problem Computations
-   Copyright (c) 2002-2021, Universitat Politecnica de Valencia, Spain
+   Copyright (c) 2002-, Universitat Politecnica de Valencia, Spain
 
    This file is part of SLEPc.
    SLEPc is distributed under a 2-clause BSD license (see LICENSE).
@@ -110,14 +110,14 @@ PetscErrorCode SVDSetTolerances(SVD svd,PetscReal tol,PetscInt maxits)
     svd->tol   = PETSC_DEFAULT;
     svd->state = SVD_STATE_INITIAL;
   } else {
-    if (tol <= 0.0) SETERRQ(PetscObjectComm((PetscObject)svd),PETSC_ERR_ARG_OUTOFRANGE,"Illegal value of tol. Must be > 0");
+    PetscCheck(tol>0.0,PetscObjectComm((PetscObject)svd),PETSC_ERR_ARG_OUTOFRANGE,"Illegal value of tol. Must be > 0");
     svd->tol = tol;
   }
   if (maxits == PETSC_DEFAULT || maxits == PETSC_DECIDE) {
     svd->max_it = PETSC_DEFAULT;
     svd->state  = SVD_STATE_INITIAL;
   } else {
-    if (maxits <= 0) SETERRQ(PetscObjectComm((PetscObject)svd),PETSC_ERR_ARG_OUTOFRANGE,"Illegal value of maxits. Must be > 0");
+    PetscCheck(maxits>0,PetscObjectComm((PetscObject)svd),PETSC_ERR_ARG_OUTOFRANGE,"Illegal value of maxits. Must be > 0");
     svd->max_it = maxits;
   }
   PetscFunctionReturn(0);
@@ -193,18 +193,18 @@ PetscErrorCode SVDSetDimensions(SVD svd,PetscInt nsv,PetscInt ncv,PetscInt mpd)
   PetscValidLogicalCollectiveInt(svd,nsv,2);
   PetscValidLogicalCollectiveInt(svd,ncv,3);
   PetscValidLogicalCollectiveInt(svd,mpd,4);
-  if (nsv<1) SETERRQ(PetscObjectComm((PetscObject)svd),PETSC_ERR_ARG_OUTOFRANGE,"Illegal value of nsv. Must be > 0");
+  PetscCheck(nsv>0,PetscObjectComm((PetscObject)svd),PETSC_ERR_ARG_OUTOFRANGE,"Illegal value of nsv. Must be > 0");
   svd->nsv = nsv;
   if (ncv == PETSC_DEFAULT || ncv == PETSC_DECIDE) {
     svd->ncv = PETSC_DEFAULT;
   } else {
-    if (ncv<1) SETERRQ(PetscObjectComm((PetscObject)svd),PETSC_ERR_ARG_OUTOFRANGE,"Illegal value of ncv. Must be > 0");
+    PetscCheck(ncv>0,PetscObjectComm((PetscObject)svd),PETSC_ERR_ARG_OUTOFRANGE,"Illegal value of ncv. Must be > 0");
     svd->ncv = ncv;
   }
   if (mpd == PETSC_DECIDE || mpd == PETSC_DEFAULT) {
     svd->mpd = PETSC_DEFAULT;
   } else {
-    if (mpd<1) SETERRQ(PetscObjectComm((PetscObject)svd),PETSC_ERR_ARG_OUTOFRANGE,"Illegal value of mpd. Must be > 0");
+    PetscCheck(mpd>0,PetscObjectComm((PetscObject)svd),PETSC_ERR_ARG_OUTOFRANGE,"Illegal value of mpd. Must be > 0");
     svd->mpd = mpd;
   }
   svd->state = SVD_STATE_INITIAL;
@@ -346,13 +346,9 @@ $   func(SVD svd,PetscReal sigma,PetscReal res,PetscReal *errest,void *ctx)
 @*/
 PetscErrorCode SVDSetConvergenceTestFunction(SVD svd,PetscErrorCode (*func)(SVD,PetscReal,PetscReal,PetscReal*,void*),void* ctx,PetscErrorCode (*destroy)(void*))
 {
-  PetscErrorCode ierr;
-
   PetscFunctionBegin;
   PetscValidHeaderSpecific(svd,SVD_CLASSID,1);
-  if (svd->convergeddestroy) {
-    ierr = (*svd->convergeddestroy)(svd->convergedctx);CHKERRQ(ierr);
-  }
+  if (svd->convergeddestroy) PetscCall((*svd->convergeddestroy)(svd->convergedctx));
   svd->convergeduser    = func;
   svd->convergeddestroy = destroy;
   svd->convergedctx     = ctx;
@@ -380,18 +376,20 @@ PetscErrorCode SVDSetConvergenceTestFunction(SVD svd,PetscErrorCode (*func)(SVD,
    Options Database Keys:
 +  -svd_conv_abs   - Sets the absolute convergence test
 .  -svd_conv_rel   - Sets the convergence test relative to the singular value
-.  -svd_conv_norm  - Sets the convergence test relative to the matrix norms
+.  -svd_conv_norm  - Sets the convergence test relative to the matrix norm
 .  -svd_conv_maxit - Forces the maximum number of iterations as set by -svd_max_it
 -  -svd_conv_user  - Selects the user-defined convergence test
 
-   Note:
+   Notes:
    The parameter 'conv' can have one of these values
 +     SVD_CONV_ABS   - absolute error ||r||
-.     SVD_CONV_REL   - error relative to the singular value l, ||r||/sigma
-.     SVD_CONV_NORM  - error relative to the matrix norms, ||r||/||A||
+.     SVD_CONV_REL   - error relative to the singular value sigma, ||r||/sigma
+.     SVD_CONV_NORM  - error relative to the matrix norms, ||r||/||Z||, with Z=A or Z=[A;B]
 .     SVD_CONV_MAXIT - no convergence until maximum number of iterations has been reached
 -     SVD_CONV_USER  - function set by SVDSetConvergenceTestFunction()
 
+   The default in standard SVD is SVD_CONV_REL, while in GSVD the default is SVD_CONV_NORM.
+
    Level: intermediate
 
 .seealso: SVDGetConvergenceTest(), SVDSetConvergenceTestFunction(), SVDSetStoppingTest(), SVDConv
@@ -407,7 +405,7 @@ PetscErrorCode SVDSetConvergenceTest(SVD svd,SVDConv conv)
     case SVD_CONV_NORM:  svd->converged = SVDConvergedNorm; break;
     case SVD_CONV_MAXIT: svd->converged = SVDConvergedMaxIt; break;
     case SVD_CONV_USER:
-      if (!svd->convergeduser) SETERRQ(PetscObjectComm((PetscObject)svd),PETSC_ERR_ORDER,"Must call SVDSetConvergenceTestFunction() first");
+      PetscCheck(svd->convergeduser,PetscObjectComm((PetscObject)svd),PETSC_ERR_ORDER,"Must call SVDSetConvergenceTestFunction() first");
       svd->converged = svd->convergeduser;
       break;
     default:
@@ -477,13 +475,9 @@ $   func(SVD svd,PetscInt its,PetscInt max_it,PetscInt nconv,PetscInt nsv,SVDCon
 @*/
 PetscErrorCode SVDSetStoppingTestFunction(SVD svd,PetscErrorCode (*func)(SVD,PetscInt,PetscInt,PetscInt,PetscInt,SVDConvergedReason*,void*),void* ctx,PetscErrorCode (*destroy)(void*))
 {
-  PetscErrorCode ierr;
-
   PetscFunctionBegin;
   PetscValidHeaderSpecific(svd,SVD_CLASSID,1);
-  if (svd->stoppingdestroy) {
-    ierr = (*svd->stoppingdestroy)(svd->stoppingctx);CHKERRQ(ierr);
-  }
+  if (svd->stoppingdestroy) PetscCall((*svd->stoppingdestroy)(svd->stoppingctx));
   svd->stoppinguser    = func;
   svd->stoppingdestroy = destroy;
   svd->stoppingctx     = ctx;
@@ -526,7 +520,7 @@ PetscErrorCode SVDSetStoppingTest(SVD svd,SVDStop stop)
   switch (stop) {
     case SVD_STOP_BASIC: svd->stopping = SVDStoppingBasic; break;
     case SVD_STOP_USER:
-      if (!svd->stoppinguser) SETERRQ(PetscObjectComm((PetscObject)svd),PETSC_ERR_ORDER,"Must call SVDSetStoppingTestFunction() first");
+      PetscCheck(svd->stoppinguser,PetscObjectComm((PetscObject)svd),PETSC_ERR_ORDER,"Must call SVDSetStoppingTestFunction() first");
       svd->stopping = svd->stoppinguser;
       break;
     default:
@@ -589,27 +583,24 @@ PetscErrorCode SVDMonitorSetFromOptions(SVD svd,const char opt[],const char name
   PetscViewerType      vtype;
   char                 key[PETSC_MAX_PATH_LEN];
   PetscBool            flg;
-  PetscErrorCode       ierr;
 
   PetscFunctionBegin;
-  ierr = PetscOptionsGetViewer(PetscObjectComm((PetscObject)svd),((PetscObject)svd)->options,((PetscObject)svd)->prefix,opt,&viewer,&format,&flg);CHKERRQ(ierr);
+  PetscCall(PetscOptionsGetViewer(PetscObjectComm((PetscObject)svd),((PetscObject)svd)->options,((PetscObject)svd)->prefix,opt,&viewer,&format,&flg));
   if (!flg) PetscFunctionReturn(0);
 
-  ierr = PetscViewerGetType(viewer,&vtype);CHKERRQ(ierr);
-  ierr = SlepcMonitorMakeKey_Internal(name,vtype,format,key);CHKERRQ(ierr);
-  ierr = PetscFunctionListFind(SVDMonitorList,key,&mfunc);CHKERRQ(ierr);
-  if (!mfunc) SETERRQ(PetscObjectComm((PetscObject)svd),PETSC_ERR_SUP,"Specified viewer and format not supported");
-  ierr = PetscFunctionListFind(SVDMonitorCreateList,key,&cfunc);CHKERRQ(ierr);
-  ierr = PetscFunctionListFind(SVDMonitorDestroyList,key,&dfunc);CHKERRQ(ierr);
+  PetscCall(PetscViewerGetType(viewer,&vtype));
+  PetscCall(SlepcMonitorMakeKey_Internal(name,vtype,format,key));
+  PetscCall(PetscFunctionListFind(SVDMonitorList,key,&mfunc));
+  PetscCheck(mfunc,PetscObjectComm((PetscObject)svd),PETSC_ERR_SUP,"Specified viewer and format not supported");
+  PetscCall(PetscFunctionListFind(SVDMonitorCreateList,key,&cfunc));
+  PetscCall(PetscFunctionListFind(SVDMonitorDestroyList,key,&dfunc));
   if (!cfunc) cfunc = PetscViewerAndFormatCreate_Internal;
   if (!dfunc) dfunc = PetscViewerAndFormatDestroy;
 
-  ierr = (*cfunc)(viewer,format,ctx,&vf);CHKERRQ(ierr);
-  ierr = PetscObjectDereference((PetscObject)viewer);CHKERRQ(ierr);
-  ierr = SVDMonitorSet(svd,mfunc,vf,(PetscErrorCode(*)(void **))dfunc);CHKERRQ(ierr);
-  if (trackall) {
-    ierr = SVDSetTrackAll(svd,PETSC_TRUE);CHKERRQ(ierr);
-  }
+  PetscCall((*cfunc)(viewer,format,ctx,&vf));
+  PetscCall(PetscObjectDereference((PetscObject)viewer));
+  PetscCall(SVDMonitorSet(svd,mfunc,vf,(PetscErrorCode(*)(void **))dfunc));
+  if (trackall) PetscCall(SVDSetTrackAll(svd,PETSC_TRUE));
   PetscFunctionReturn(0);
 }
 
@@ -628,7 +619,7 @@ PetscErrorCode SVDMonitorSetFromOptions(SVD svd,const char opt[],const char name
 
    Level: beginner
 
-.seealso:
+.seealso: SVDSetOptionsPrefix()
 @*/
 PetscErrorCode SVDSetFromOptions(SVD svd)
 {
@@ -640,88 +631,84 @@ PetscErrorCode SVDSetFromOptions(SVD svd)
 
   PetscFunctionBegin;
   PetscValidHeaderSpecific(svd,SVD_CLASSID,1);
-  ierr = SVDRegisterAll();CHKERRQ(ierr);
-  ierr = PetscObjectOptionsBegin((PetscObject)svd);CHKERRQ(ierr);
-    ierr = PetscOptionsFList("-svd_type","SVD solver method","SVDSetType",SVDList,(char*)(((PetscObject)svd)->type_name?((PetscObject)svd)->type_name:SVDCROSS),type,sizeof(type),&flg);CHKERRQ(ierr);
-    if (flg) {
-      ierr = SVDSetType(svd,type);CHKERRQ(ierr);
-    } else if (!((PetscObject)svd)->type_name) {
-      ierr = SVDSetType(svd,SVDCROSS);CHKERRQ(ierr);
-    }
+  PetscCall(SVDRegisterAll());
+  ierr = PetscObjectOptionsBegin((PetscObject)svd);PetscCall(ierr);
+    PetscCall(PetscOptionsFList("-svd_type","SVD solver method","SVDSetType",SVDList,(char*)(((PetscObject)svd)->type_name?((PetscObject)svd)->type_name:SVDCROSS),type,sizeof(type),&flg));
+    if (flg) PetscCall(SVDSetType(svd,type));
+    else if (!((PetscObject)svd)->type_name) PetscCall(SVDSetType(svd,SVDCROSS));
 
-    ierr = PetscOptionsBoolGroupBegin("-svd_standard","Singular value decomposition (SVD)","SVDSetProblemType",&flg);CHKERRQ(ierr);
-    if (flg) { ierr = SVDSetProblemType(svd,SVD_STANDARD);CHKERRQ(ierr); }
-    ierr = PetscOptionsBoolGroupEnd("-svd_generalized","Generalized singular value decomposition (GSVD)","SVDSetProblemType",&flg);CHKERRQ(ierr);
-    if (flg) { ierr = SVDSetProblemType(svd,SVD_GENERALIZED);CHKERRQ(ierr); }
+    PetscCall(PetscOptionsBoolGroupBegin("-svd_standard","Singular value decomposition (SVD)","SVDSetProblemType",&flg));
+    if (flg) PetscCall(SVDSetProblemType(svd,SVD_STANDARD));
+    PetscCall(PetscOptionsBoolGroupEnd("-svd_generalized","Generalized singular value decomposition (GSVD)","SVDSetProblemType",&flg));
+    if (flg) PetscCall(SVDSetProblemType(svd,SVD_GENERALIZED));
 
-    ierr = PetscOptionsBool("-svd_implicittranspose","Handle matrix transpose implicitly","SVDSetImplicitTranspose",svd->impltrans,&val,&flg);CHKERRQ(ierr);
-    if (flg) { ierr = SVDSetImplicitTranspose(svd,val);CHKERRQ(ierr); }
+    PetscCall(PetscOptionsBool("-svd_implicittranspose","Handle matrix transpose implicitly","SVDSetImplicitTranspose",svd->impltrans,&val,&flg));
+    if (flg) PetscCall(SVDSetImplicitTranspose(svd,val));
 
     i = svd->max_it;
-    ierr = PetscOptionsInt("-svd_max_it","Maximum number of iterations","SVDSetTolerances",svd->max_it,&i,&flg1);CHKERRQ(ierr);
+    PetscCall(PetscOptionsInt("-svd_max_it","Maximum number of iterations","SVDSetTolerances",svd->max_it,&i,&flg1));
     r = svd->tol;
-    ierr = PetscOptionsReal("-svd_tol","Tolerance","SVDSetTolerances",SlepcDefaultTol(svd->tol),&r,&flg2);CHKERRQ(ierr);
-    if (flg1 || flg2) { ierr = SVDSetTolerances(svd,r,i);CHKERRQ(ierr); }
+    PetscCall(PetscOptionsReal("-svd_tol","Tolerance","SVDSetTolerances",SlepcDefaultTol(svd->tol),&r,&flg2));
+    if (flg1 || flg2) PetscCall(SVDSetTolerances(svd,r,i));
 
-    ierr = PetscOptionsBoolGroupBegin("-svd_conv_abs","Absolute error convergence test","SVDSetConvergenceTest",&flg);CHKERRQ(ierr);
-    if (flg) { ierr = SVDSetConvergenceTest(svd,SVD_CONV_ABS);CHKERRQ(ierr); }
-    ierr = PetscOptionsBoolGroup("-svd_conv_rel","Relative error convergence test","SVDSetConvergenceTest",&flg);CHKERRQ(ierr);
-    if (flg) { ierr = SVDSetConvergenceTest(svd,SVD_CONV_REL);CHKERRQ(ierr); }
-    ierr = PetscOptionsBoolGroup("-svd_conv_norm","Convergence test relative to the matrix norms","SVDSetConvergenceTest",&flg);CHKERRQ(ierr);
-    if (flg) { ierr = SVDSetConvergenceTest(svd,SVD_CONV_NORM);CHKERRQ(ierr); }
-    ierr = PetscOptionsBoolGroup("-svd_conv_maxit","Maximum iterations convergence test","SVDSetConvergenceTest",&flg);CHKERRQ(ierr);
-    if (flg) { ierr = SVDSetConvergenceTest(svd,SVD_CONV_MAXIT);CHKERRQ(ierr); }
-    ierr = PetscOptionsBoolGroupEnd("-svd_conv_user","User-defined convergence test","SVDSetConvergenceTest",&flg);CHKERRQ(ierr);
-    if (flg) { ierr = SVDSetConvergenceTest(svd,SVD_CONV_USER);CHKERRQ(ierr); }
+    PetscCall(PetscOptionsBoolGroupBegin("-svd_conv_abs","Absolute error convergence test","SVDSetConvergenceTest",&flg));
+    if (flg) PetscCall(SVDSetConvergenceTest(svd,SVD_CONV_ABS));
+    PetscCall(PetscOptionsBoolGroup("-svd_conv_rel","Relative error convergence test","SVDSetConvergenceTest",&flg));
+    if (flg) PetscCall(SVDSetConvergenceTest(svd,SVD_CONV_REL));
+    PetscCall(PetscOptionsBoolGroup("-svd_conv_norm","Convergence test relative to the matrix norms","SVDSetConvergenceTest",&flg));
+    if (flg) PetscCall(SVDSetConvergenceTest(svd,SVD_CONV_NORM));
+    PetscCall(PetscOptionsBoolGroup("-svd_conv_maxit","Maximum iterations convergence test","SVDSetConvergenceTest",&flg));
+    if (flg) PetscCall(SVDSetConvergenceTest(svd,SVD_CONV_MAXIT));
+    PetscCall(PetscOptionsBoolGroupEnd("-svd_conv_user","User-defined convergence test","SVDSetConvergenceTest",&flg));
+    if (flg) PetscCall(SVDSetConvergenceTest(svd,SVD_CONV_USER));
 
-    ierr = PetscOptionsBoolGroupBegin("-svd_stop_basic","Stop iteration if all singular values converged or max_it reached","SVDSetStoppingTest",&flg);CHKERRQ(ierr);
-    if (flg) { ierr = SVDSetStoppingTest(svd,SVD_STOP_BASIC);CHKERRQ(ierr); }
-    ierr = PetscOptionsBoolGroupEnd("-svd_stop_user","User-defined stopping test","SVDSetStoppingTest",&flg);CHKERRQ(ierr);
-    if (flg) { ierr = SVDSetStoppingTest(svd,SVD_STOP_USER);CHKERRQ(ierr); }
+    PetscCall(PetscOptionsBoolGroupBegin("-svd_stop_basic","Stop iteration if all singular values converged or max_it reached","SVDSetStoppingTest",&flg));
+    if (flg) PetscCall(SVDSetStoppingTest(svd,SVD_STOP_BASIC));
+    PetscCall(PetscOptionsBoolGroupEnd("-svd_stop_user","User-defined stopping test","SVDSetStoppingTest",&flg));
+    if (flg) PetscCall(SVDSetStoppingTest(svd,SVD_STOP_USER));
 
     i = svd->nsv;
-    ierr = PetscOptionsInt("-svd_nsv","Number of singular values to compute","SVDSetDimensions",svd->nsv,&i,&flg1);CHKERRQ(ierr);
+    PetscCall(PetscOptionsInt("-svd_nsv","Number of singular values to compute","SVDSetDimensions",svd->nsv,&i,&flg1));
     j = svd->ncv;
-    ierr = PetscOptionsInt("-svd_ncv","Number of basis vectors","SVDSetDimensions",svd->ncv,&j,&flg2);CHKERRQ(ierr);
+    PetscCall(PetscOptionsInt("-svd_ncv","Number of basis vectors","SVDSetDimensions",svd->ncv,&j,&flg2));
     k = svd->mpd;
-    ierr = PetscOptionsInt("-svd_mpd","Maximum dimension of projected problem","SVDSetDimensions",svd->mpd,&k,&flg3);CHKERRQ(ierr);
-    if (flg1 || flg2 || flg3) { ierr = SVDSetDimensions(svd,i,j,k);CHKERRQ(ierr); }
+    PetscCall(PetscOptionsInt("-svd_mpd","Maximum dimension of projected problem","SVDSetDimensions",svd->mpd,&k,&flg3));
+    if (flg1 || flg2 || flg3) PetscCall(SVDSetDimensions(svd,i,j,k));
 
-    ierr = PetscOptionsBoolGroupBegin("-svd_largest","Compute largest singular values","SVDSetWhichSingularTriplets",&flg);CHKERRQ(ierr);
-    if (flg) { ierr = SVDSetWhichSingularTriplets(svd,SVD_LARGEST);CHKERRQ(ierr); }
-    ierr = PetscOptionsBoolGroupEnd("-svd_smallest","Compute smallest singular values","SVDSetWhichSingularTriplets",&flg);CHKERRQ(ierr);
-    if (flg) { ierr = SVDSetWhichSingularTriplets(svd,SVD_SMALLEST);CHKERRQ(ierr); }
+    PetscCall(PetscOptionsBoolGroupBegin("-svd_largest","Compute largest singular values","SVDSetWhichSingularTriplets",&flg));
+    if (flg) PetscCall(SVDSetWhichSingularTriplets(svd,SVD_LARGEST));
+    PetscCall(PetscOptionsBoolGroupEnd("-svd_smallest","Compute smallest singular values","SVDSetWhichSingularTriplets",&flg));
+    if (flg) PetscCall(SVDSetWhichSingularTriplets(svd,SVD_SMALLEST));
 
     /* -----------------------------------------------------------------------*/
     /*
       Cancels all monitors hardwired into code before call to SVDSetFromOptions()
     */
-    ierr = PetscOptionsBool("-svd_monitor_cancel","Remove any hardwired monitor routines","SVDMonitorCancel",PETSC_FALSE,&flg,&set);CHKERRQ(ierr);
-    if (set && flg) { ierr = SVDMonitorCancel(svd);CHKERRQ(ierr); }
-    ierr = SVDMonitorSetFromOptions(svd,"-svd_monitor","first_approximation",NULL,PETSC_FALSE);CHKERRQ(ierr);
-    ierr = SVDMonitorSetFromOptions(svd,"-svd_monitor_all","all_approximations",NULL,PETSC_TRUE);CHKERRQ(ierr);
-    ierr = SVDMonitorSetFromOptions(svd,"-svd_monitor_conv","convergence_history",NULL,PETSC_FALSE);CHKERRQ(ierr);
+    PetscCall(PetscOptionsBool("-svd_monitor_cancel","Remove any hardwired monitor routines","SVDMonitorCancel",PETSC_FALSE,&flg,&set));
+    if (set && flg) PetscCall(SVDMonitorCancel(svd));
+    PetscCall(SVDMonitorSetFromOptions(svd,"-svd_monitor","first_approximation",NULL,PETSC_FALSE));
+    PetscCall(SVDMonitorSetFromOptions(svd,"-svd_monitor_all","all_approximations",NULL,PETSC_TRUE));
+    PetscCall(SVDMonitorSetFromOptions(svd,"-svd_monitor_conv","convergence_history",NULL,PETSC_FALSE));
 
     /* -----------------------------------------------------------------------*/
-    ierr = PetscOptionsName("-svd_view","Print detailed information on solver used","SVDView",NULL);CHKERRQ(ierr);
-    ierr = PetscOptionsName("-svd_view_vectors","View computed singular vectors","SVDVectorsView",NULL);CHKERRQ(ierr);
-    ierr = PetscOptionsName("-svd_view_values","View computed singular values","SVDValuesView",NULL);CHKERRQ(ierr);
-    ierr = PetscOptionsName("-svd_converged_reason","Print reason for convergence, and number of iterations","SVDConvergedReasonView",NULL);CHKERRQ(ierr);
-    ierr = PetscOptionsName("-svd_error_absolute","Print absolute errors of each singular triplet","SVDErrorView",NULL);CHKERRQ(ierr);
-    ierr = PetscOptionsName("-svd_error_relative","Print relative errors of each singular triplet","SVDErrorView",NULL);CHKERRQ(ierr);
+    PetscCall(PetscOptionsName("-svd_view","Print detailed information on solver used","SVDView",NULL));
+    PetscCall(PetscOptionsName("-svd_view_vectors","View computed singular vectors","SVDVectorsView",NULL));
+    PetscCall(PetscOptionsName("-svd_view_values","View computed singular values","SVDValuesView",NULL));
+    PetscCall(PetscOptionsName("-svd_converged_reason","Print reason for convergence, and number of iterations","SVDConvergedReasonView",NULL));
+    PetscCall(PetscOptionsName("-svd_error_absolute","Print absolute errors of each singular triplet","SVDErrorView",NULL));
+    PetscCall(PetscOptionsName("-svd_error_relative","Print relative errors of each singular triplet","SVDErrorView",NULL));
+    PetscCall(PetscOptionsName("-svd_error_norm","Print errors relative to the matrix norms of each singular triplet","SVDErrorView",NULL));
 
-    if (svd->ops->setfromoptions) {
-      ierr = (*svd->ops->setfromoptions)(PetscOptionsObject,svd);CHKERRQ(ierr);
-    }
-    ierr = PetscObjectProcessOptionsHandlers(PetscOptionsObject,(PetscObject)svd);CHKERRQ(ierr);
-  ierr = PetscOptionsEnd();CHKERRQ(ierr);
+    if (svd->ops->setfromoptions) PetscCall((*svd->ops->setfromoptions)(PetscOptionsObject,svd));
+    PetscCall(PetscObjectProcessOptionsHandlers(PetscOptionsObject,(PetscObject)svd));
+  ierr = PetscOptionsEnd();PetscCall(ierr);
 
-  if (!svd->V) { ierr = SVDGetBV(svd,&svd->V,NULL);CHKERRQ(ierr); }
-  ierr = BVSetFromOptions(svd->V);CHKERRQ(ierr);
-  if (!svd->U) { ierr = SVDGetBV(svd,NULL,&svd->U);CHKERRQ(ierr); }
-  ierr = BVSetFromOptions(svd->U);CHKERRQ(ierr);
-  if (!svd->ds) { ierr = SVDGetDS(svd,&svd->ds);CHKERRQ(ierr); }
-  ierr = DSSetFromOptions(svd->ds);CHKERRQ(ierr);
+  if (!svd->V) PetscCall(SVDGetBV(svd,&svd->V,NULL));
+  PetscCall(BVSetFromOptions(svd->V));
+  if (!svd->U) PetscCall(SVDGetBV(svd,NULL,&svd->U));
+  PetscCall(BVSetFromOptions(svd->U));
+  if (!svd->ds) PetscCall(SVDGetDS(svd,&svd->ds));
+  PetscCall(DSSetFromOptions(svd->ds));
   PetscFunctionReturn(0);
 }
 
@@ -899,16 +886,14 @@ PetscErrorCode SVDGetTrackAll(SVD svd,PetscBool *trackall)
 @*/
 PetscErrorCode SVDSetOptionsPrefix(SVD svd,const char *prefix)
 {
-  PetscErrorCode ierr;
-
   PetscFunctionBegin;
   PetscValidHeaderSpecific(svd,SVD_CLASSID,1);
-  if (!svd->V) { ierr = SVDGetBV(svd,&svd->V,&svd->U);CHKERRQ(ierr); }
-  ierr = BVSetOptionsPrefix(svd->V,prefix);CHKERRQ(ierr);
-  ierr = BVSetOptionsPrefix(svd->U,prefix);CHKERRQ(ierr);
-  if (!svd->ds) { ierr = SVDGetDS(svd,&svd->ds);CHKERRQ(ierr); }
-  ierr = DSSetOptionsPrefix(svd->ds,prefix);CHKERRQ(ierr);
-  ierr = PetscObjectSetOptionsPrefix((PetscObject)svd,prefix);CHKERRQ(ierr);
+  if (!svd->V) PetscCall(SVDGetBV(svd,&svd->V,&svd->U));
+  PetscCall(BVSetOptionsPrefix(svd->V,prefix));
+  PetscCall(BVSetOptionsPrefix(svd->U,prefix));
+  if (!svd->ds) PetscCall(SVDGetDS(svd,&svd->ds));
+  PetscCall(DSSetOptionsPrefix(svd->ds,prefix));
+  PetscCall(PetscObjectSetOptionsPrefix((PetscObject)svd,prefix));
   PetscFunctionReturn(0);
 }
 
@@ -932,16 +917,14 @@ PetscErrorCode SVDSetOptionsPrefix(SVD svd,const char *prefix)
 @*/
 PetscErrorCode SVDAppendOptionsPrefix(SVD svd,const char *prefix)
 {
-  PetscErrorCode ierr;
-
   PetscFunctionBegin;
   PetscValidHeaderSpecific(svd,SVD_CLASSID,1);
-  if (!svd->V) { ierr = SVDGetBV(svd,&svd->V,&svd->U);CHKERRQ(ierr); }
-  ierr = BVAppendOptionsPrefix(svd->V,prefix);CHKERRQ(ierr);
-  ierr = BVAppendOptionsPrefix(svd->U,prefix);CHKERRQ(ierr);
-  if (!svd->ds) { ierr = SVDGetDS(svd,&svd->ds);CHKERRQ(ierr); }
-  ierr = DSAppendOptionsPrefix(svd->ds,prefix);CHKERRQ(ierr);
-  ierr = PetscObjectAppendOptionsPrefix((PetscObject)svd,prefix);CHKERRQ(ierr);
+  if (!svd->V) PetscCall(SVDGetBV(svd,&svd->V,&svd->U));
+  PetscCall(BVAppendOptionsPrefix(svd->V,prefix));
+  PetscCall(BVAppendOptionsPrefix(svd->U,prefix));
+  if (!svd->ds) PetscCall(SVDGetDS(svd,&svd->ds));
+  PetscCall(DSAppendOptionsPrefix(svd->ds,prefix));
+  PetscCall(PetscObjectAppendOptionsPrefix((PetscObject)svd,prefix));
   PetscFunctionReturn(0);
 }
 
@@ -967,12 +950,9 @@ PetscErrorCode SVDAppendOptionsPrefix(SVD svd,const char *prefix)
 @*/
 PetscErrorCode SVDGetOptionsPrefix(SVD svd,const char *prefix[])
 {
-  PetscErrorCode ierr;
-
   PetscFunctionBegin;
   PetscValidHeaderSpecific(svd,SVD_CLASSID,1);
   PetscValidPointer(prefix,2);
-  ierr = PetscObjectGetOptionsPrefix((PetscObject)svd,prefix);CHKERRQ(ierr);
+  PetscCall(PetscObjectGetOptionsPrefix((PetscObject)svd,prefix));
   PetscFunctionReturn(0);
 }
-
