@@ -1,7 +1,7 @@
 /*
    - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
    SLEPc - Scalable Library for Eigenvalue Problem Computations
-   Copyright (c) 2002-2021, Universitat Politecnica de Valencia, Spain
+   Copyright (c) 2002-, Universitat Politecnica de Valencia, Spain
 
    This file is part of SLEPc.
    SLEPc is distributed under a 2-clause BSD license (see LICENSE).
@@ -33,29 +33,27 @@ SLEPC_EXTERN PetscErrorCode SVDCreate_PRIMME(SVD);
 
    Level: advanced
 
-.seealso:  SVDRegister()
+.seealso: SVDRegister()
 @*/
 PetscErrorCode SVDRegisterAll(void)
 {
-  PetscErrorCode ierr;
-
   PetscFunctionBegin;
   if (SVDRegisterAllCalled) PetscFunctionReturn(0);
   SVDRegisterAllCalled = PETSC_TRUE;
-  ierr = SVDRegister(SVDCROSS,SVDCreate_Cross);CHKERRQ(ierr);
-  ierr = SVDRegister(SVDCYCLIC,SVDCreate_Cyclic);CHKERRQ(ierr);
-  ierr = SVDRegister(SVDLAPACK,SVDCreate_LAPACK);CHKERRQ(ierr);
-  ierr = SVDRegister(SVDLANCZOS,SVDCreate_Lanczos);CHKERRQ(ierr);
-  ierr = SVDRegister(SVDTRLANCZOS,SVDCreate_TRLanczos);CHKERRQ(ierr);
-  ierr = SVDRegister(SVDRANDOMIZED,SVDCreate_Randomized);CHKERRQ(ierr);
+  PetscCall(SVDRegister(SVDCROSS,SVDCreate_Cross));
+  PetscCall(SVDRegister(SVDCYCLIC,SVDCreate_Cyclic));
+  PetscCall(SVDRegister(SVDLAPACK,SVDCreate_LAPACK));
+  PetscCall(SVDRegister(SVDLANCZOS,SVDCreate_Lanczos));
+  PetscCall(SVDRegister(SVDTRLANCZOS,SVDCreate_TRLanczos));
+  PetscCall(SVDRegister(SVDRANDOMIZED,SVDCreate_Randomized));
 #if defined(SLEPC_HAVE_SCALAPACK)
-  ierr = SVDRegister(SVDSCALAPACK,SVDCreate_ScaLAPACK);CHKERRQ(ierr);
+  PetscCall(SVDRegister(SVDSCALAPACK,SVDCreate_ScaLAPACK));
 #endif
 #if defined(SLEPC_HAVE_ELEMENTAL)
-  ierr = SVDRegister(SVDELEMENTAL,SVDCreate_Elemental);CHKERRQ(ierr);
+  PetscCall(SVDRegister(SVDELEMENTAL,SVDCreate_Elemental));
 #endif
 #if defined(SLEPC_HAVE_PRIMME)
-  ierr = SVDRegister(SVDPRIMME,SVDCreate_PRIMME);CHKERRQ(ierr);
+  PetscCall(SVDRegister(SVDPRIMME,SVDCreate_PRIMME));
 #endif
   PetscFunctionReturn(0);
 }
@@ -66,21 +64,20 @@ PetscErrorCode SVDRegisterAll(void)
   Not Collective
 
   Level: advanced
+
+.seealso: SVDMonitorRegister()
 @*/
 PetscErrorCode SVDMonitorRegisterAll(void)
 {
-  PetscErrorCode ierr;
-
   PetscFunctionBegin;
   if (SVDMonitorRegisterAllCalled) PetscFunctionReturn(0);
   SVDMonitorRegisterAllCalled = PETSC_TRUE;
 
-  ierr = SVDMonitorRegister("first_approximation",PETSCVIEWERASCII,PETSC_VIEWER_DEFAULT,SVDMonitorFirst,NULL,NULL);CHKERRQ(ierr);
-  ierr = SVDMonitorRegister("first_approximation",PETSCVIEWERDRAW,PETSC_VIEWER_DRAW_LG,SVDMonitorFirstDrawLG,SVDMonitorFirstDrawLGCreate,NULL);CHKERRQ(ierr);
-  ierr = SVDMonitorRegister("all_approximations",PETSCVIEWERASCII,PETSC_VIEWER_DEFAULT,SVDMonitorAll,NULL,NULL);CHKERRQ(ierr);
-  ierr = SVDMonitorRegister("all_approximations",PETSCVIEWERDRAW,PETSC_VIEWER_DRAW_LG,SVDMonitorAllDrawLG,SVDMonitorAllDrawLGCreate,NULL);CHKERRQ(ierr);
-  ierr = SVDMonitorRegister("convergence_history",PETSCVIEWERASCII,PETSC_VIEWER_DEFAULT,SVDMonitorConverged,SVDMonitorConvergedCreate,SVDMonitorConvergedDestroy);CHKERRQ(ierr);
-  ierr = SVDMonitorRegister("convergence_history",PETSCVIEWERDRAW,PETSC_VIEWER_DRAW_LG,SVDMonitorConvergedDrawLG,SVDMonitorConvergedDrawLGCreate,SVDMonitorConvergedDestroy);CHKERRQ(ierr);
+  PetscCall(SVDMonitorRegister("first_approximation",PETSCVIEWERASCII,PETSC_VIEWER_DEFAULT,SVDMonitorFirst,NULL,NULL));
+  PetscCall(SVDMonitorRegister("first_approximation",PETSCVIEWERDRAW,PETSC_VIEWER_DRAW_LG,SVDMonitorFirstDrawLG,SVDMonitorFirstDrawLGCreate,NULL));
+  PetscCall(SVDMonitorRegister("all_approximations",PETSCVIEWERASCII,PETSC_VIEWER_DEFAULT,SVDMonitorAll,NULL,NULL));
+  PetscCall(SVDMonitorRegister("all_approximations",PETSCVIEWERDRAW,PETSC_VIEWER_DRAW_LG,SVDMonitorAllDrawLG,SVDMonitorAllDrawLGCreate,NULL));
+  PetscCall(SVDMonitorRegister("convergence_history",PETSCVIEWERASCII,PETSC_VIEWER_DEFAULT,SVDMonitorConverged,SVDMonitorConvergedCreate,SVDMonitorConvergedDestroy));
+  PetscCall(SVDMonitorRegister("convergence_history",PETSCVIEWERDRAW,PETSC_VIEWER_DRAW_LG,SVDMonitorConvergedDrawLG,SVDMonitorConvergedDrawLGCreate,SVDMonitorConvergedDestroy));
   PetscFunctionReturn(0);
 }
-
