@@ -1,7 +1,7 @@
 /*
    - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
    SLEPc - Scalable Library for Eigenvalue Problem Computations
-   Copyright (c) 2002-2021, Universitat Politecnica de Valencia, Spain
+   Copyright (c) 2002-, Universitat Politecnica de Valencia, Spain
 
    This file is part of SLEPc.
    SLEPc is distributed under a 2-clause BSD license (see LICENSE).
@@ -21,229 +21,201 @@ typedef struct {
 
 PetscErrorCode BVMult_Contiguous(BV Y,PetscScalar alpha,PetscScalar beta,BV X,Mat Q)
 {
-  PetscErrorCode    ierr;
   BV_CONTIGUOUS     *y = (BV_CONTIGUOUS*)Y->data,*x = (BV_CONTIGUOUS*)X->data;
   const PetscScalar *q;
   PetscInt          ldq;
 
   PetscFunctionBegin;
   if (Q) {
-    ierr = MatGetSize(Q,&ldq,NULL);CHKERRQ(ierr);
-    ierr = MatDenseGetArrayRead(Q,&q);CHKERRQ(ierr);
-    ierr = BVMult_BLAS_Private(Y,Y->n,Y->k-Y->l,X->k-X->l,ldq,alpha,x->array+(X->nc+X->l)*X->n,q+Y->l*ldq+X->l,beta,y->array+(Y->nc+Y->l)*Y->n);CHKERRQ(ierr);
-    ierr = MatDenseRestoreArrayRead(Q,&q);CHKERRQ(ierr);
-  } else {
-    ierr = BVAXPY_BLAS_Private(Y,Y->n,Y->k-Y->l,alpha,x->array+(X->nc+X->l)*X->n,beta,y->array+(Y->nc+Y->l)*Y->n);CHKERRQ(ierr);
-  }
+    PetscCall(MatDenseGetLDA(Q,&ldq));
+    PetscCall(MatDenseGetArrayRead(Q,&q));
+    PetscCall(BVMult_BLAS_Private(Y,Y->n,Y->k-Y->l,X->k-X->l,ldq,alpha,x->array+(X->nc+X->l)*X->n,q+Y->l*ldq+X->l,beta,y->array+(Y->nc+Y->l)*Y->n));
+    PetscCall(MatDenseRestoreArrayRead(Q,&q));
+  } else PetscCall(BVAXPY_BLAS_Private(Y,Y->n,Y->k-Y->l,alpha,x->array+(X->nc+X->l)*X->n,beta,y->array+(Y->nc+Y->l)*Y->n));
   PetscFunctionReturn(0);
 }
 
 PetscErrorCode BVMultVec_Contiguous(BV X,PetscScalar alpha,PetscScalar beta,Vec y,PetscScalar *q)
 {
-  PetscErrorCode ierr;
   BV_CONTIGUOUS  *x = (BV_CONTIGUOUS*)X->data;
   PetscScalar    *py,*qq=q;
 
   PetscFunctionBegin;
-  ierr = VecGetArray(y,&py);CHKERRQ(ierr);
-  if (!q) { ierr = VecGetArray(X->buffer,&qq);CHKERRQ(ierr); }
-  ierr = BVMultVec_BLAS_Private(X,X->n,X->k-X->l,alpha,x->array+(X->nc+X->l)*X->n,qq,beta,py);CHKERRQ(ierr);
-  if (!q) { ierr = VecRestoreArray(X->buffer,&qq);CHKERRQ(ierr); }
-  ierr = VecRestoreArray(y,&py);CHKERRQ(ierr);
+  PetscCall(VecGetArray(y,&py));
+  if (!q) PetscCall(VecGetArray(X->buffer,&qq));
+  PetscCall(BVMultVec_BLAS_Private(X,X->n,X->k-X->l,alpha,x->array+(X->nc+X->l)*X->n,qq,beta,py));
+  if (!q) PetscCall(VecRestoreArray(X->buffer,&qq));
+  PetscCall(VecRestoreArray(y,&py));
   PetscFunctionReturn(0);
 }
 
 PetscErrorCode BVMultInPlace_Contiguous(BV V,Mat Q,PetscInt s,PetscInt e)
 {
-  PetscErrorCode    ierr;
   BV_CONTIGUOUS     *ctx = (BV_CONTIGUOUS*)V->data;
   const PetscScalar *q;
   PetscInt          ldq;
 
   PetscFunctionBegin;
-  ierr = MatGetSize(Q,&ldq,NULL);CHKERRQ(ierr);
-  ierr = MatDenseGetArrayRead(Q,&q);CHKERRQ(ierr);
-  ierr = BVMultInPlace_BLAS_Private(V,V->n,V->k-V->l,ldq,s-V->l,e-V->l,ctx->array+(V->nc+V->l)*V->n,q+V->l*ldq+V->l,PETSC_FALSE);CHKERRQ(ierr);
-  ierr = MatDenseRestoreArrayRead(Q,&q);CHKERRQ(ierr);
+  PetscCall(MatDenseGetLDA(Q,&ldq));
+  PetscCall(MatDenseGetArrayRead(Q,&q));
+  PetscCall(BVMultInPlace_BLAS_Private(V,V->n,V->k-V->l,ldq,s-V->l,e-V->l,ctx->array+(V->nc+V->l)*V->n,q+V->l*ldq+V->l,PETSC_FALSE));
+  PetscCall(MatDenseRestoreArrayRead(Q,&q));
   PetscFunctionReturn(0);
 }
 
 PetscErrorCode BVMultInPlaceHermitianTranspose_Contiguous(BV V,Mat Q,PetscInt s,PetscInt e)
 {
-  PetscErrorCode    ierr;
   BV_CONTIGUOUS     *ctx = (BV_CONTIGUOUS*)V->data;
   const PetscScalar *q;
   PetscInt          ldq;
 
   PetscFunctionBegin;
-  ierr = MatGetSize(Q,&ldq,NULL);CHKERRQ(ierr);
-  ierr = MatDenseGetArrayRead(Q,&q);CHKERRQ(ierr);
-  ierr = BVMultInPlace_BLAS_Private(V,V->n,V->k-V->l,ldq,s-V->l,e-V->l,ctx->array+(V->nc+V->l)*V->n,q+V->l*ldq+V->l,PETSC_TRUE);CHKERRQ(ierr);
-  ierr = MatDenseRestoreArrayRead(Q,&q);CHKERRQ(ierr);
+  PetscCall(MatDenseGetLDA(Q,&ldq));
+  PetscCall(MatDenseGetArrayRead(Q,&q));
+  PetscCall(BVMultInPlace_BLAS_Private(V,V->n,V->k-V->l,ldq,s-V->l,e-V->l,ctx->array+(V->nc+V->l)*V->n,q+V->l*ldq+V->l,PETSC_TRUE));
+  PetscCall(MatDenseRestoreArrayRead(Q,&q));
   PetscFunctionReturn(0);
 }
 
 PetscErrorCode BVDot_Contiguous(BV X,BV Y,Mat M)
 {
-  PetscErrorCode ierr;
   BV_CONTIGUOUS  *x = (BV_CONTIGUOUS*)X->data,*y = (BV_CONTIGUOUS*)Y->data;
   PetscScalar    *m;
   PetscInt       ldm;
 
   PetscFunctionBegin;
-  ierr = MatGetSize(M,&ldm,NULL);CHKERRQ(ierr);
-  ierr = MatDenseGetArray(M,&m);CHKERRQ(ierr);
-  ierr = BVDot_BLAS_Private(X,Y->k-Y->l,X->k-X->l,X->n,ldm,y->array+(Y->nc+Y->l)*Y->n,x->array+(X->nc+X->l)*X->n,m+X->l*ldm+Y->l,x->mpi);CHKERRQ(ierr);
-  ierr = MatDenseRestoreArray(M,&m);CHKERRQ(ierr);
+  PetscCall(MatDenseGetLDA(M,&ldm));
+  PetscCall(MatDenseGetArray(M,&m));
+  PetscCall(BVDot_BLAS_Private(X,Y->k-Y->l,X->k-X->l,X->n,ldm,y->array+(Y->nc+Y->l)*Y->n,x->array+(X->nc+X->l)*X->n,m+X->l*ldm+Y->l,x->mpi));
+  PetscCall(MatDenseRestoreArray(M,&m));
   PetscFunctionReturn(0);
 }
 
 PetscErrorCode BVDotVec_Contiguous(BV X,Vec y,PetscScalar *q)
 {
-  PetscErrorCode    ierr;
   BV_CONTIGUOUS     *x = (BV_CONTIGUOUS*)X->data;
   const PetscScalar *py;
   PetscScalar       *qq=q;
   Vec               z = y;
 
   PetscFunctionBegin;
-  if (X->matrix) {
-    ierr = BV_IPMatMult(X,y);CHKERRQ(ierr);
+  if (PetscUnlikely(X->matrix)) {
+    PetscCall(BV_IPMatMult(X,y));
     z = X->Bx;
   }
-  ierr = VecGetArrayRead(z,&py);CHKERRQ(ierr);
-  if (!q) { ierr = VecGetArray(X->buffer,&qq);CHKERRQ(ierr); }
-  ierr = BVDotVec_BLAS_Private(X,X->n,X->k-X->l,x->array+(X->nc+X->l)*X->n,py,qq,x->mpi);CHKERRQ(ierr);
-  if (!q) { ierr = VecRestoreArray(X->buffer,&qq);CHKERRQ(ierr); }
-  ierr = VecRestoreArrayRead(z,&py);CHKERRQ(ierr);
+  PetscCall(VecGetArrayRead(z,&py));
+  if (!q) PetscCall(VecGetArray(X->buffer,&qq));
+  PetscCall(BVDotVec_BLAS_Private(X,X->n,X->k-X->l,x->array+(X->nc+X->l)*X->n,py,qq,x->mpi));
+  if (!q) PetscCall(VecRestoreArray(X->buffer,&qq));
+  PetscCall(VecRestoreArrayRead(z,&py));
   PetscFunctionReturn(0);
 }
 
 PetscErrorCode BVDotVec_Local_Contiguous(BV X,Vec y,PetscScalar *m)
 {
-  PetscErrorCode ierr;
   BV_CONTIGUOUS  *x = (BV_CONTIGUOUS*)X->data;
   PetscScalar    *py;
   Vec            z = y;
 
   PetscFunctionBegin;
-  if (X->matrix) {
-    ierr = BV_IPMatMult(X,y);CHKERRQ(ierr);
+  if (PetscUnlikely(X->matrix)) {
+    PetscCall(BV_IPMatMult(X,y));
     z = X->Bx;
   }
-  ierr = VecGetArray(z,&py);CHKERRQ(ierr);
-  ierr = BVDotVec_BLAS_Private(X,X->n,X->k-X->l,x->array+(X->nc+X->l)*X->n,py,m,PETSC_FALSE);CHKERRQ(ierr);
-  ierr = VecRestoreArray(z,&py);CHKERRQ(ierr);
+  PetscCall(VecGetArray(z,&py));
+  PetscCall(BVDotVec_BLAS_Private(X,X->n,X->k-X->l,x->array+(X->nc+X->l)*X->n,py,m,PETSC_FALSE));
+  PetscCall(VecRestoreArray(z,&py));
   PetscFunctionReturn(0);
 }
 
 PetscErrorCode BVScale_Contiguous(BV bv,PetscInt j,PetscScalar alpha)
 {
-  PetscErrorCode ierr;
   BV_CONTIGUOUS  *ctx = (BV_CONTIGUOUS*)bv->data;
 
   PetscFunctionBegin;
-  if (j<0) {
-    ierr = BVScale_BLAS_Private(bv,(bv->k-bv->l)*bv->n,ctx->array+(bv->nc+bv->l)*bv->n,alpha);CHKERRQ(ierr);
-  } else {
-    ierr = BVScale_BLAS_Private(bv,bv->n,ctx->array+(bv->nc+j)*bv->n,alpha);CHKERRQ(ierr);
-  }
+  if (PetscUnlikely(j<0)) PetscCall(BVScale_BLAS_Private(bv,(bv->k-bv->l)*bv->n,ctx->array+(bv->nc+bv->l)*bv->n,alpha));
+  else PetscCall(BVScale_BLAS_Private(bv,bv->n,ctx->array+(bv->nc+j)*bv->n,alpha));
   PetscFunctionReturn(0);
 }
 
 PetscErrorCode BVNorm_Contiguous(BV bv,PetscInt j,NormType type,PetscReal *val)
 {
-  PetscErrorCode ierr;
   BV_CONTIGUOUS  *ctx = (BV_CONTIGUOUS*)bv->data;
 
   PetscFunctionBegin;
-  if (j<0) {
-    ierr = BVNorm_LAPACK_Private(bv,bv->n,bv->k-bv->l,ctx->array+(bv->nc+bv->l)*bv->n,type,val,ctx->mpi);CHKERRQ(ierr);
-  } else {
-    ierr = BVNorm_LAPACK_Private(bv,bv->n,1,ctx->array+(bv->nc+j)*bv->n,type,val,ctx->mpi);CHKERRQ(ierr);
-  }
+  if (PetscUnlikely(j<0)) PetscCall(BVNorm_LAPACK_Private(bv,bv->n,bv->k-bv->l,ctx->array+(bv->nc+bv->l)*bv->n,type,val,ctx->mpi));
+  else PetscCall(BVNorm_LAPACK_Private(bv,bv->n,1,ctx->array+(bv->nc+j)*bv->n,type,val,ctx->mpi));
   PetscFunctionReturn(0);
 }
 
 PetscErrorCode BVNorm_Local_Contiguous(BV bv,PetscInt j,NormType type,PetscReal *val)
 {
-  PetscErrorCode ierr;
   BV_CONTIGUOUS  *ctx = (BV_CONTIGUOUS*)bv->data;
 
   PetscFunctionBegin;
-  if (j<0) {
-    ierr = BVNorm_LAPACK_Private(bv,bv->n,bv->k-bv->l,ctx->array+(bv->nc+bv->l)*bv->n,type,val,PETSC_FALSE);CHKERRQ(ierr);
-  } else {
-    ierr = BVNorm_LAPACK_Private(bv,bv->n,1,ctx->array+(bv->nc+j)*bv->n,type,val,PETSC_FALSE);CHKERRQ(ierr);
-  }
+  if (PetscUnlikely(j<0)) PetscCall(BVNorm_LAPACK_Private(bv,bv->n,bv->k-bv->l,ctx->array+(bv->nc+bv->l)*bv->n,type,val,PETSC_FALSE));
+  else PetscCall(BVNorm_LAPACK_Private(bv,bv->n,1,ctx->array+(bv->nc+j)*bv->n,type,val,PETSC_FALSE));
   PetscFunctionReturn(0);
 }
 
 PetscErrorCode BVNormalize_Contiguous(BV bv,PetscScalar *eigi)
 {
-  PetscErrorCode ierr;
   BV_CONTIGUOUS  *ctx = (BV_CONTIGUOUS*)bv->data;
   PetscScalar    *wi=NULL;
 
   PetscFunctionBegin;
   if (eigi) wi = eigi+bv->l;
-  ierr = BVNormalize_LAPACK_Private(bv,bv->n,bv->k-bv->l,ctx->array+(bv->nc+bv->l)*bv->n,wi,ctx->mpi);CHKERRQ(ierr);
+  PetscCall(BVNormalize_LAPACK_Private(bv,bv->n,bv->k-bv->l,ctx->array+(bv->nc+bv->l)*bv->n,wi,ctx->mpi));
   PetscFunctionReturn(0);
 }
 
 PetscErrorCode BVMatMult_Contiguous(BV V,Mat A,BV W)
 {
-  PetscErrorCode ierr;
   BV_CONTIGUOUS  *v = (BV_CONTIGUOUS*)V->data,*w = (BV_CONTIGUOUS*)W->data;
   PetscInt       j;
   Mat            Vmat,Wmat;
 
   PetscFunctionBegin;
   if (V->vmm) {
-    ierr = BVGetMat(V,&Vmat);CHKERRQ(ierr);
-    ierr = BVGetMat(W,&Wmat);CHKERRQ(ierr);
-    ierr = MatProductCreateWithMat(A,Vmat,NULL,Wmat);CHKERRQ(ierr);
-    ierr = MatProductSetType(Wmat,MATPRODUCT_AB);CHKERRQ(ierr);
-    ierr = MatProductSetFromOptions(Wmat);CHKERRQ(ierr);
-    ierr = MatProductSymbolic(Wmat);CHKERRQ(ierr);
-    ierr = MatProductNumeric(Wmat);CHKERRQ(ierr);
-    ierr = MatProductClear(Wmat);CHKERRQ(ierr);
-    ierr = BVRestoreMat(V,&Vmat);CHKERRQ(ierr);
-    ierr = BVRestoreMat(W,&Wmat);CHKERRQ(ierr);
+    PetscCall(BVGetMat(V,&Vmat));
+    PetscCall(BVGetMat(W,&Wmat));
+    PetscCall(MatProductCreateWithMat(A,Vmat,NULL,Wmat));
+    PetscCall(MatProductSetType(Wmat,MATPRODUCT_AB));
+    PetscCall(MatProductSetFromOptions(Wmat));
+    PetscCall(MatProductSymbolic(Wmat));
+    PetscCall(MatProductNumeric(Wmat));
+    PetscCall(MatProductClear(Wmat));
+    PetscCall(BVRestoreMat(V,&Vmat));
+    PetscCall(BVRestoreMat(W,&Wmat));
   } else {
-    for (j=0;j<V->k-V->l;j++) {
-      ierr = MatMult(A,v->V[V->nc+V->l+j],w->V[W->nc+W->l+j]);CHKERRQ(ierr);
-    }
+    for (j=0;j<V->k-V->l;j++) PetscCall(MatMult(A,v->V[V->nc+V->l+j],w->V[W->nc+W->l+j]));
   }
   PetscFunctionReturn(0);
 }
 
 PetscErrorCode BVCopy_Contiguous(BV V,BV W)
 {
-  PetscErrorCode ierr;
   BV_CONTIGUOUS  *v = (BV_CONTIGUOUS*)V->data,*w = (BV_CONTIGUOUS*)W->data;
   PetscScalar    *pvc,*pwc;
 
   PetscFunctionBegin;
   pvc = v->array+(V->nc+V->l)*V->n;
   pwc = w->array+(W->nc+W->l)*W->n;
-  ierr = PetscArraycpy(pwc,pvc,(V->k-V->l)*V->n);CHKERRQ(ierr);
+  PetscCall(PetscArraycpy(pwc,pvc,(V->k-V->l)*V->n));
   PetscFunctionReturn(0);
 }
 
 PetscErrorCode BVCopyColumn_Contiguous(BV V,PetscInt j,PetscInt i)
 {
-  PetscErrorCode ierr;
   BV_CONTIGUOUS  *v = (BV_CONTIGUOUS*)V->data;
 
   PetscFunctionBegin;
-  ierr = PetscArraycpy(v->array+(V->nc+i)*V->n,v->array+(V->nc+j)*V->n,V->n);CHKERRQ(ierr);
+  PetscCall(PetscArraycpy(v->array+(V->nc+i)*V->n,v->array+(V->nc+j)*V->n,V->n));
   PetscFunctionReturn(0);
 }
 
 PetscErrorCode BVResize_Contiguous(BV bv,PetscInt m,PetscBool copy)
 {
-  PetscErrorCode ierr;
   BV_CONTIGUOUS  *ctx = (BV_CONTIGUOUS*)bv->data;
   PetscInt       j,bs;
   PetscScalar    *newarray;
@@ -251,30 +223,25 @@ PetscErrorCode BVResize_Contiguous(BV bv,PetscInt m,PetscBool copy)
   char           str[50];
 
   PetscFunctionBegin;
-  ierr = VecGetBlockSize(bv->t,&bs);CHKERRQ(ierr);
-  ierr = PetscMalloc1(m*bv->n,&newarray);CHKERRQ(ierr);
-  ierr = PetscArrayzero(newarray,m*bv->n);CHKERRQ(ierr);
-  ierr = PetscMalloc1(m,&newV);CHKERRQ(ierr);
+  PetscCall(VecGetBlockSize(bv->t,&bs));
+  PetscCall(PetscMalloc1(m*bv->n,&newarray));
+  PetscCall(PetscArrayzero(newarray,m*bv->n));
+  PetscCall(PetscMalloc1(m,&newV));
   for (j=0;j<m;j++) {
-    if (ctx->mpi) {
-      ierr = VecCreateMPIWithArray(PetscObjectComm((PetscObject)bv->t),bs,bv->n,PETSC_DECIDE,newarray+j*bv->n,newV+j);CHKERRQ(ierr);
-    } else {
-      ierr = VecCreateSeqWithArray(PetscObjectComm((PetscObject)bv->t),bs,bv->n,newarray+j*bv->n,newV+j);CHKERRQ(ierr);
-    }
+    if (ctx->mpi) PetscCall(VecCreateMPIWithArray(PetscObjectComm((PetscObject)bv->t),bs,bv->n,PETSC_DECIDE,newarray+j*bv->n,newV+j));
+    else PetscCall(VecCreateSeqWithArray(PetscObjectComm((PetscObject)bv->t),bs,bv->n,newarray+j*bv->n,newV+j));
   }
-  ierr = PetscLogObjectParents(bv,m,newV);CHKERRQ(ierr);
+  PetscCall(PetscLogObjectParents(bv,m,newV));
   if (((PetscObject)bv)->name) {
     for (j=0;j<m;j++) {
-      ierr = PetscSNPrintf(str,sizeof(str),"%s_%d",((PetscObject)bv)->name,(int)j);CHKERRQ(ierr);
-      ierr = PetscObjectSetName((PetscObject)newV[j],str);CHKERRQ(ierr);
+      PetscCall(PetscSNPrintf(str,sizeof(str),"%s_%" PetscInt_FMT,((PetscObject)bv)->name,j));
+      PetscCall(PetscObjectSetName((PetscObject)newV[j],str));
     }
   }
-  if (copy) {
-    ierr = PetscArraycpy(newarray,ctx->array,PetscMin(m,bv->m)*bv->n);CHKERRQ(ierr);
-  }
-  ierr = VecDestroyVecs(bv->m,&ctx->V);CHKERRQ(ierr);
+  if (copy) PetscCall(PetscArraycpy(newarray,ctx->array,PetscMin(m,bv->m)*bv->n));
+  PetscCall(VecDestroyVecs(bv->m,&ctx->V));
   ctx->V = newV;
-  ierr = PetscFree(ctx->array);CHKERRQ(ierr);
+  PetscCall(PetscFree(ctx->array));
   ctx->array = newarray;
   PetscFunctionReturn(0);
 }
@@ -310,21 +277,19 @@ PetscErrorCode BVGetArrayRead_Contiguous(BV bv,const PetscScalar **a)
 
 PetscErrorCode BVDestroy_Contiguous(BV bv)
 {
-  PetscErrorCode ierr;
   BV_CONTIGUOUS  *ctx = (BV_CONTIGUOUS*)bv->data;
 
   PetscFunctionBegin;
   if (!bv->issplit) {
-    ierr = VecDestroyVecs(bv->nc+bv->m,&ctx->V);CHKERRQ(ierr);
-    ierr = PetscFree(ctx->array);CHKERRQ(ierr);
+    PetscCall(VecDestroyVecs(bv->nc+bv->m,&ctx->V));
+    PetscCall(PetscFree(ctx->array));
   }
-  ierr = PetscFree(bv->data);CHKERRQ(ierr);
+  PetscCall(PetscFree(bv->data));
   PetscFunctionReturn(0);
 }
 
 SLEPC_EXTERN PetscErrorCode BVCreate_Contiguous(BV bv)
 {
-  PetscErrorCode ierr;
   BV_CONTIGUOUS  *ctx;
   PetscInt       j,nloc,bs,lsplit;
   PetscBool      seq;
@@ -335,19 +300,19 @@ SLEPC_EXTERN PetscErrorCode BVCreate_Contiguous(BV bv)
   Vec            *Vpar;
 
   PetscFunctionBegin;
-  ierr = PetscNewLog(bv,&ctx);CHKERRQ(ierr);
+  PetscCall(PetscNewLog(bv,&ctx));
   bv->data = (void*)ctx;
 
-  ierr = PetscObjectTypeCompare((PetscObject)bv->t,VECMPI,&ctx->mpi);CHKERRQ(ierr);
+  PetscCall(PetscObjectTypeCompare((PetscObject)bv->t,VECMPI,&ctx->mpi));
   if (!ctx->mpi) {
-    ierr = PetscObjectTypeCompare((PetscObject)bv->t,VECSEQ,&seq);CHKERRQ(ierr);
-    if (!seq) SETERRQ(PetscObjectComm((PetscObject)bv),PETSC_ERR_SUP,"Cannot create a contiguous BV from a non-standard template vector");
+    PetscCall(PetscObjectTypeCompare((PetscObject)bv->t,VECSEQ,&seq));
+    PetscCheck(seq,PetscObjectComm((PetscObject)bv),PETSC_ERR_SUP,"Cannot create a contiguous BV from a non-standard template vector");
   }
 
-  ierr = VecGetLocalSize(bv->t,&nloc);CHKERRQ(ierr);
-  ierr = VecGetBlockSize(bv->t,&bs);CHKERRQ(ierr);
+  PetscCall(VecGetLocalSize(bv->t,&nloc));
+  PetscCall(VecGetBlockSize(bv->t,&bs));
 
-  if (bv->issplit) {
+  if (PetscUnlikely(bv->issplit)) {
     /* split BV: share memory and Vecs of the parent BV */
     parent = bv->splitparent;
     lsplit = parent->lsplit;
@@ -357,29 +322,26 @@ SLEPC_EXTERN PetscErrorCode BVCreate_Contiguous(BV bv)
     ctx->array = (bv->issplit==1)? array: array+lsplit*nloc;
   } else {
     /* regular BV: allocate memory and Vecs for the BV entries */
-    ierr = PetscCalloc1(bv->m*nloc,&ctx->array);CHKERRQ(ierr);
-    ierr = PetscMalloc1(bv->m,&ctx->V);CHKERRQ(ierr);
+    PetscCall(PetscCalloc1(bv->m*nloc,&ctx->array));
+    PetscCall(PetscMalloc1(bv->m,&ctx->V));
     for (j=0;j<bv->m;j++) {
-      if (ctx->mpi) {
-        ierr = VecCreateMPIWithArray(PetscObjectComm((PetscObject)bv->t),bs,nloc,PETSC_DECIDE,ctx->array+j*nloc,ctx->V+j);CHKERRQ(ierr);
-      } else {
-        ierr = VecCreateSeqWithArray(PetscObjectComm((PetscObject)bv->t),bs,nloc,ctx->array+j*nloc,ctx->V+j);CHKERRQ(ierr);
-      }
+      if (ctx->mpi) PetscCall(VecCreateMPIWithArray(PetscObjectComm((PetscObject)bv->t),bs,nloc,PETSC_DECIDE,ctx->array+j*nloc,ctx->V+j));
+      else PetscCall(VecCreateSeqWithArray(PetscObjectComm((PetscObject)bv->t),bs,nloc,ctx->array+j*nloc,ctx->V+j));
     }
-    ierr = PetscLogObjectParents(bv,bv->m,ctx->V);CHKERRQ(ierr);
+    PetscCall(PetscLogObjectParents(bv,bv->m,ctx->V));
   }
   if (((PetscObject)bv)->name) {
     for (j=0;j<bv->m;j++) {
-      ierr = PetscSNPrintf(str,sizeof(str),"%s_%d",((PetscObject)bv)->name,(int)j);CHKERRQ(ierr);
-      ierr = PetscObjectSetName((PetscObject)ctx->V[j],str);CHKERRQ(ierr);
+      PetscCall(PetscSNPrintf(str,sizeof(str),"%s_%" PetscInt_FMT,((PetscObject)bv)->name,j));
+      PetscCall(PetscObjectSetName((PetscObject)ctx->V[j],str));
     }
   }
 
-  if (bv->Acreate) {
-    ierr = MatDenseGetArray(bv->Acreate,&aa);CHKERRQ(ierr);
-    ierr = PetscArraycpy(ctx->array,aa,bv->m*nloc);CHKERRQ(ierr);
-    ierr = MatDenseRestoreArray(bv->Acreate,&aa);CHKERRQ(ierr);
-    ierr = MatDestroy(&bv->Acreate);CHKERRQ(ierr);
+  if (PetscUnlikely(bv->Acreate)) {
+    PetscCall(MatDenseGetArray(bv->Acreate,&aa));
+    PetscCall(PetscArraycpy(ctx->array,aa,bv->m*nloc));
+    PetscCall(MatDenseRestoreArray(bv->Acreate,&aa));
+    PetscCall(MatDestroy(&bv->Acreate));
   }
 
   bv->ops->mult             = BVMult_Contiguous;
@@ -403,4 +365,3 @@ SLEPC_EXTERN PetscErrorCode BVCreate_Contiguous(BV bv)
   bv->ops->destroy          = BVDestroy_Contiguous;
   PetscFunctionReturn(0);
 }
-
