@@ -1,7 +1,7 @@
 /*
    - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
    SLEPc - Scalable Library for Eigenvalue Problem Computations
-   Copyright (c) 2002-2021, Universitat Politecnica de Valencia, Spain
+   Copyright (c) 2002-, Universitat Politecnica de Valencia, Spain
 
    This file is part of SLEPc.
    SLEPc is distributed under a 2-clause BSD license (see LICENSE).
@@ -27,115 +27,102 @@ typedef struct {
 
 PetscErrorCode BVMultInPlace_Tensor(BV V,Mat Q,PetscInt s,PetscInt e)
 {
-  PetscErrorCode    ierr;
   BV_TENSOR         *ctx = (BV_TENSOR*)V->data;
   PetscScalar       *pS;
   const PetscScalar *q;
   PetscInt          ldq,lds = ctx->ld*ctx->d;
 
   PetscFunctionBegin;
-  ierr = MatGetSize(Q,&ldq,NULL);CHKERRQ(ierr);
-  ierr = MatDenseGetArray(ctx->S,&pS);CHKERRQ(ierr);
-  ierr = MatDenseGetArrayRead(Q,&q);CHKERRQ(ierr);
-  ierr = BVMultInPlace_BLAS_Private(V,lds,V->k-V->l,ldq,s-V->l,e-V->l,pS+(V->nc+V->l)*lds,q+V->l*ldq+V->l,PETSC_FALSE);CHKERRQ(ierr);
-  ierr = MatDenseRestoreArrayRead(Q,&q);CHKERRQ(ierr);
-  ierr = MatDenseRestoreArray(ctx->S,&pS);CHKERRQ(ierr);
+  PetscCall(MatDenseGetLDA(Q,&ldq));
+  PetscCall(MatDenseGetArray(ctx->S,&pS));
+  PetscCall(MatDenseGetArrayRead(Q,&q));
+  PetscCall(BVMultInPlace_BLAS_Private(V,lds,V->k-V->l,ldq,s-V->l,e-V->l,pS+(V->nc+V->l)*lds,q+V->l*ldq+V->l,PETSC_FALSE));
+  PetscCall(MatDenseRestoreArrayRead(Q,&q));
+  PetscCall(MatDenseRestoreArray(ctx->S,&pS));
   PetscFunctionReturn(0);
 }
 
 PetscErrorCode BVMultInPlaceHermitianTranspose_Tensor(BV V,Mat Q,PetscInt s,PetscInt e)
 {
-  PetscErrorCode    ierr;
   BV_TENSOR         *ctx = (BV_TENSOR*)V->data;
   PetscScalar       *pS;
   const PetscScalar *q;
   PetscInt          ldq,lds = ctx->ld*ctx->d;
 
   PetscFunctionBegin;
-  ierr = MatGetSize(Q,&ldq,NULL);CHKERRQ(ierr);
-  ierr = MatDenseGetArray(ctx->S,&pS);CHKERRQ(ierr);
-  ierr = MatDenseGetArrayRead(Q,&q);CHKERRQ(ierr);
-  ierr = BVMultInPlace_BLAS_Private(V,lds,V->k-V->l,ldq,s-V->l,e-V->l,pS+(V->nc+V->l)*lds,q+V->l*ldq+V->l,PETSC_TRUE);CHKERRQ(ierr);
-  ierr = MatDenseRestoreArrayRead(Q,&q);CHKERRQ(ierr);
-  ierr = MatDenseRestoreArray(ctx->S,&pS);CHKERRQ(ierr);
+  PetscCall(MatDenseGetLDA(Q,&ldq));
+  PetscCall(MatDenseGetArray(ctx->S,&pS));
+  PetscCall(MatDenseGetArrayRead(Q,&q));
+  PetscCall(BVMultInPlace_BLAS_Private(V,lds,V->k-V->l,ldq,s-V->l,e-V->l,pS+(V->nc+V->l)*lds,q+V->l*ldq+V->l,PETSC_TRUE));
+  PetscCall(MatDenseRestoreArrayRead(Q,&q));
+  PetscCall(MatDenseRestoreArray(ctx->S,&pS));
   PetscFunctionReturn(0);
 }
 
 PetscErrorCode BVDot_Tensor(BV X,BV Y,Mat M)
 {
-  PetscErrorCode ierr;
   BV_TENSOR         *x = (BV_TENSOR*)X->data,*y = (BV_TENSOR*)Y->data;
   PetscScalar       *m;
   const PetscScalar *px,*py;
   PetscInt          ldm,lds = x->ld*x->d;
 
   PetscFunctionBegin;
-  if (x->U!=y->U) SETERRQ(PetscObjectComm((PetscObject)X),PETSC_ERR_SUP,"BVDot() in BVTENSOR requires that both operands have the same U factor");
-  if (lds!=y->ld*y->d) SETERRQ2(PetscObjectComm((PetscObject)X),PETSC_ERR_ARG_SIZ,"Mismatching dimensions ld*d %D %D",lds,y->ld*y->d);
-  ierr = MatGetSize(M,&ldm,NULL);CHKERRQ(ierr);
-  ierr = MatDenseGetArrayRead(x->S,&px);CHKERRQ(ierr);
-  ierr = MatDenseGetArrayRead(y->S,&py);CHKERRQ(ierr);
-  ierr = MatDenseGetArray(M,&m);CHKERRQ(ierr);
-  ierr = BVDot_BLAS_Private(X,Y->k-Y->l,X->k-X->l,lds,ldm,py+(Y->nc+Y->l)*lds,px+(X->nc+X->l)*lds,m+X->l*ldm+Y->l,PETSC_FALSE);CHKERRQ(ierr);
-  ierr = MatDenseRestoreArray(M,&m);CHKERRQ(ierr);
-  ierr = MatDenseRestoreArrayRead(x->S,&px);CHKERRQ(ierr);
-  ierr = MatDenseRestoreArrayRead(y->S,&py);CHKERRQ(ierr);
+  PetscCheck(x->U==y->U,PetscObjectComm((PetscObject)X),PETSC_ERR_SUP,"BVDot() in BVTENSOR requires that both operands have the same U factor");
+  PetscCheck(lds==y->ld*y->d,PetscObjectComm((PetscObject)X),PETSC_ERR_ARG_SIZ,"Mismatching dimensions ld*d %" PetscInt_FMT " %" PetscInt_FMT,lds,y->ld*y->d);
+  PetscCall(MatDenseGetLDA(M,&ldm));
+  PetscCall(MatDenseGetArrayRead(x->S,&px));
+  PetscCall(MatDenseGetArrayRead(y->S,&py));
+  PetscCall(MatDenseGetArray(M,&m));
+  PetscCall(BVDot_BLAS_Private(X,Y->k-Y->l,X->k-X->l,lds,ldm,py+(Y->nc+Y->l)*lds,px+(X->nc+X->l)*lds,m+X->l*ldm+Y->l,PETSC_FALSE));
+  PetscCall(MatDenseRestoreArray(M,&m));
+  PetscCall(MatDenseRestoreArrayRead(x->S,&px));
+  PetscCall(MatDenseRestoreArrayRead(y->S,&py));
   PetscFunctionReturn(0);
 }
 
 PetscErrorCode BVScale_Tensor(BV bv,PetscInt j,PetscScalar alpha)
 {
-  PetscErrorCode ierr;
   BV_TENSOR      *ctx = (BV_TENSOR*)bv->data;
   PetscScalar    *pS;
   PetscInt       lds = ctx->ld*ctx->d;
 
   PetscFunctionBegin;
-  ierr = MatDenseGetArray(ctx->S,&pS);CHKERRQ(ierr);
-  if (j<0) {
-    ierr = BVScale_BLAS_Private(bv,(bv->k-bv->l)*lds,pS+(bv->nc+bv->l)*lds,alpha);CHKERRQ(ierr);
-  } else {
-    ierr = BVScale_BLAS_Private(bv,lds,pS+(bv->nc+j)*lds,alpha);CHKERRQ(ierr);
-  }
-  ierr = MatDenseRestoreArray(ctx->S,&pS);CHKERRQ(ierr);
+  PetscCall(MatDenseGetArray(ctx->S,&pS));
+  if (PetscUnlikely(j<0)) PetscCall(BVScale_BLAS_Private(bv,(bv->k-bv->l)*lds,pS+(bv->nc+bv->l)*lds,alpha));
+  else PetscCall(BVScale_BLAS_Private(bv,lds,pS+(bv->nc+j)*lds,alpha));
+  PetscCall(MatDenseRestoreArray(ctx->S,&pS));
   PetscFunctionReturn(0);
 }
 
 PetscErrorCode BVNorm_Tensor(BV bv,PetscInt j,NormType type,PetscReal *val)
 {
-  PetscErrorCode    ierr;
   BV_TENSOR         *ctx = (BV_TENSOR*)bv->data;
   const PetscScalar *pS;
   PetscInt          lds = ctx->ld*ctx->d;
 
   PetscFunctionBegin;
-  ierr = MatDenseGetArrayRead(ctx->S,&pS);CHKERRQ(ierr);
-  if (j<0) {
-    ierr = BVNorm_LAPACK_Private(bv,lds,bv->k-bv->l,pS+(bv->nc+bv->l)*lds,type,val,PETSC_FALSE);CHKERRQ(ierr);
-  } else {
-    ierr = BVNorm_LAPACK_Private(bv,lds,1,pS+(bv->nc+j)*lds,type,val,PETSC_FALSE);CHKERRQ(ierr);
-  }
-  ierr = MatDenseRestoreArrayRead(ctx->S,&pS);CHKERRQ(ierr);
+  PetscCall(MatDenseGetArrayRead(ctx->S,&pS));
+  if (j<0) PetscCall(BVNorm_LAPACK_Private(bv,lds,bv->k-bv->l,pS+(bv->nc+bv->l)*lds,type,val,PETSC_FALSE));
+  else PetscCall(BVNorm_LAPACK_Private(bv,lds,1,pS+(bv->nc+j)*lds,type,val,PETSC_FALSE));
+  PetscCall(MatDenseRestoreArrayRead(ctx->S,&pS));
   PetscFunctionReturn(0);
 }
 
 PetscErrorCode BVCopyColumn_Tensor(BV V,PetscInt j,PetscInt i)
 {
-  PetscErrorCode ierr;
   BV_TENSOR      *ctx = (BV_TENSOR*)V->data;
   PetscScalar    *pS;
   PetscInt       lds = ctx->ld*ctx->d;
 
   PetscFunctionBegin;
-  ierr = MatDenseGetArray(ctx->S,&pS);CHKERRQ(ierr);
-  ierr = PetscArraycpy(pS+(V->nc+i)*lds,pS+(V->nc+j)*lds,lds);CHKERRQ(ierr);
-  ierr = MatDenseRestoreArray(ctx->S,&pS);CHKERRQ(ierr);
+  PetscCall(MatDenseGetArray(ctx->S,&pS));
+  PetscCall(PetscArraycpy(pS+(V->nc+i)*lds,pS+(V->nc+j)*lds,lds));
+  PetscCall(MatDenseRestoreArray(ctx->S,&pS));
   PetscFunctionReturn(0);
 }
 
 static PetscErrorCode BVTensorNormColumn(BV bv,PetscInt j,PetscReal *norm)
 {
-  PetscErrorCode    ierr;
   BV_TENSOR         *ctx = (BV_TENSOR*)bv->data;
   PetscBLASInt      one=1,lds_;
   PetscScalar       sone=1.0,szero=0.0,*x,dot;
@@ -145,13 +132,13 @@ static PetscErrorCode BVTensorNormColumn(BV bv,PetscInt j,PetscReal *norm)
 
   PetscFunctionBegin;
   lds = ld*ctx->d;
-  ierr = MatDenseGetArrayRead(ctx->S,&S);CHKERRQ(ierr);
-  ierr = PetscBLASIntCast(lds,&lds_);CHKERRQ(ierr);
-  if (ctx->qB) {
+  PetscCall(MatDenseGetArrayRead(ctx->S,&S));
+  PetscCall(PetscBLASIntCast(lds,&lds_));
+  if (PetscUnlikely(ctx->qB)) {
     x = ctx->sw;
     PetscStackCallBLAS("BLASgemv",BLASgemv_("N",&lds_,&lds_,&sone,ctx->qB,&lds_,S+j*lds,&one,&szero,x,&one));
     dot = PetscRealPart(BLASdot_(&lds_,S+j*lds,&one,x,&one));
-    ierr = BV_SafeSqrt(bv,dot,norm);CHKERRQ(ierr);
+    PetscCall(BV_SafeSqrt(bv,dot,norm));
   } else {
     /* Compute *norm = BLASnrm2_(&lds_,S+j*lds,&one); */
     if (lds==1) *norm = PetscAbsScalar(S[j*lds]);
@@ -159,7 +146,7 @@ static PetscErrorCode BVTensorNormColumn(BV bv,PetscInt j,PetscReal *norm)
       for (i=0;i<lds;i++) {
         aval = PetscAbsScalar(S[i+j*lds]);
         if (aval!=0.0) {
-          if (scale<aval) {
+          if (PetscUnlikely(scale<aval)) {
             alpha = 1.0 + alpha*PetscSqr(scale/aval);
             scale = aval;
           } else alpha += PetscSqr(aval/scale);
@@ -168,13 +155,12 @@ static PetscErrorCode BVTensorNormColumn(BV bv,PetscInt j,PetscReal *norm)
       *norm = scale*PetscSqrtReal(alpha);
     }
   }
-  ierr = MatDenseRestoreArrayRead(ctx->S,&S);CHKERRQ(ierr);
+  PetscCall(MatDenseRestoreArrayRead(ctx->S,&S));
   PetscFunctionReturn(0);
 }
 
 PetscErrorCode BVOrthogonalizeGS1_Tensor(BV bv,PetscInt k,Vec v,PetscBool *which,PetscScalar *h,PetscScalar *c,PetscReal *onorm,PetscReal *norm)
 {
-  PetscErrorCode    ierr;
   BV_TENSOR         *ctx = (BV_TENSOR*)bv->data;
   PetscScalar       *pS,*cc,*x,dot,sonem=-1.0,sone=1.0,szero=0.0;
   PetscInt          i,lds = ctx->ld*ctx->d;
@@ -182,23 +168,22 @@ PetscErrorCode BVOrthogonalizeGS1_Tensor(BV bv,PetscInt k,Vec v,PetscBool *which
   const PetscScalar *omega;
 
   PetscFunctionBegin;
-  if (v) SETERRQ(PetscObjectComm((PetscObject)bv),PETSC_ERR_SUP,"Orthogonalization against an external vector is not allowed in BVTENSOR");
-  ierr = MatDenseGetArray(ctx->S,&pS);CHKERRQ(ierr);
-  if (!c) {
-    ierr = VecGetArray(bv->buffer,&cc);CHKERRQ(ierr);
-  } else cc = c;
-  ierr = PetscBLASIntCast(lds,&lds_);CHKERRQ(ierr);
-  ierr = PetscBLASIntCast(k,&k_);CHKERRQ(ierr);
+  PetscCheck(!v,PetscObjectComm((PetscObject)bv),PETSC_ERR_SUP,"Orthogonalization against an external vector is not allowed in BVTENSOR");
+  PetscCall(MatDenseGetArray(ctx->S,&pS));
+  if (!c) PetscCall(VecGetArray(bv->buffer,&cc));
+  else cc = c;
+  PetscCall(PetscBLASIntCast(lds,&lds_));
+  PetscCall(PetscBLASIntCast(k,&k_));
 
-  if (onorm) { ierr = BVTensorNormColumn(bv,k,onorm);CHKERRQ(ierr); }
+  if (onorm) PetscCall(BVTensorNormColumn(bv,k,onorm));
 
   if (ctx->qB) x = ctx->sw;
   else x = pS+k*lds;
 
-  if (bv->orthog_type==BV_ORTHOG_MGS) {  /* modified Gram-Schmidt */
+  if (PetscUnlikely(bv->orthog_type==BV_ORTHOG_MGS)) {  /* modified Gram-Schmidt */
 
-    if (bv->indef) { /* signature */
-      ierr = VecGetArrayRead(bv->omega,&omega);CHKERRQ(ierr);
+    if (PetscUnlikely(bv->indef)) { /* signature */
+      PetscCall(VecGetArrayRead(bv->omega,&omega));
     }
     for (i=-bv->nc;i<k;i++) {
       if (which && i>=0 && !which[i]) continue;
@@ -206,14 +191,12 @@ PetscErrorCode BVOrthogonalizeGS1_Tensor(BV bv,PetscInt k,Vec v,PetscBool *which
       /* c_i = (s_k, s_i) */
       dot = PetscRealPart(BLASdot_(&lds_,pS+i*lds,&one,x,&one));
       if (bv->indef) dot /= PetscRealPart(omega[i]);
-      ierr = BV_SetValue(bv,i,0,cc,dot);CHKERRQ(ierr);
+      PetscCall(BV_SetValue(bv,i,0,cc,dot));
       /* s_k = s_k - c_i s_i */
       dot = -dot;
       PetscStackCallBLAS("BLASaxpy",BLASaxpy_(&lds_,&dot,pS+i*lds,&one,pS+k*lds,&one));
     }
-    if (bv->indef) {
-      ierr = VecRestoreArrayRead(bv->omega,&omega);CHKERRQ(ierr);
-    }
+    if (PetscUnlikely(bv->indef)) PetscCall(VecRestoreArrayRead(bv->omega,&omega));
 
   } else {  /* classical Gram-Schmidt */
     if (ctx->qB) PetscStackCallBLAS("BLASgemv",BLASgemv_("N",&lds_,&lds_,&sone,ctx->qB,&lds_,pS+k*lds,&one,&szero,x,&one));
@@ -222,53 +205,51 @@ PetscErrorCode BVOrthogonalizeGS1_Tensor(BV bv,PetscInt k,Vec v,PetscBool *which
     PetscStackCallBLAS("BLASgemv",BLASgemv_("C",&lds_,&k_,&sone,pS,&lds_,x,&one,&szero,cc,&one));
 
     /* s_k = s_k - S_{0:k-1} cc */
-    if (bv->indef) { ierr = BV_ApplySignature(bv,k,cc,PETSC_TRUE);CHKERRQ(ierr); }
-     PetscStackCallBLAS("BLASgemv",BLASgemv_("N",&lds_,&k_,&sonem,pS,&lds_,cc,&one,&sone,pS+k*lds,&one));
-    if (bv->indef) { ierr = BV_ApplySignature(bv,k,cc,PETSC_FALSE);CHKERRQ(ierr); }
+    if (PetscUnlikely(bv->indef)) PetscCall(BV_ApplySignature(bv,k,cc,PETSC_TRUE));
+    PetscStackCallBLAS("BLASgemv",BLASgemv_("N",&lds_,&k_,&sonem,pS,&lds_,cc,&one,&sone,pS+k*lds,&one));
+    if (PetscUnlikely(bv->indef)) PetscCall(BV_ApplySignature(bv,k,cc,PETSC_FALSE));
   }
 
-  if (norm) { ierr = BVTensorNormColumn(bv,k,norm);CHKERRQ(ierr); }
-  ierr = BV_AddCoefficients(bv,k,h,cc);CHKERRQ(ierr);
-  ierr = MatDenseRestoreArray(ctx->S,&pS);CHKERRQ(ierr);
-  ierr = VecRestoreArray(bv->buffer,&cc);CHKERRQ(ierr);
+  if (norm) PetscCall(BVTensorNormColumn(bv,k,norm));
+  PetscCall(BV_AddCoefficients(bv,k,h,cc));
+  PetscCall(MatDenseRestoreArray(ctx->S,&pS));
+  PetscCall(VecRestoreArray(bv->buffer,&cc));
   PetscFunctionReturn(0);
 }
 
 PetscErrorCode BVView_Tensor(BV bv,PetscViewer viewer)
 {
-  PetscErrorCode    ierr;
   BV_TENSOR         *ctx = (BV_TENSOR*)bv->data;
   PetscViewerFormat format;
   PetscBool         isascii;
   const char        *bvname,*uname,*sname;
 
   PetscFunctionBegin;
-  ierr = PetscObjectTypeCompare((PetscObject)viewer,PETSCVIEWERASCII,&isascii);CHKERRQ(ierr);
+  PetscCall(PetscObjectTypeCompare((PetscObject)viewer,PETSCVIEWERASCII,&isascii));
   if (isascii) {
-    ierr = PetscViewerGetFormat(viewer,&format);CHKERRQ(ierr);
+    PetscCall(PetscViewerGetFormat(viewer,&format));
     if (format == PETSC_VIEWER_ASCII_INFO || format == PETSC_VIEWER_ASCII_INFO_DETAIL) {
-      ierr = PetscViewerASCIIPrintf(viewer,"number of tensor blocks (degree): %D\n",ctx->d);CHKERRQ(ierr);
-      ierr = PetscViewerASCIIPrintf(viewer,"number of columns of U factor: %D\n",ctx->ld);CHKERRQ(ierr);
+      PetscCall(PetscViewerASCIIPrintf(viewer,"number of tensor blocks (degree): %" PetscInt_FMT "\n",ctx->d));
+      PetscCall(PetscViewerASCIIPrintf(viewer,"number of columns of U factor: %" PetscInt_FMT "\n",ctx->ld));
       PetscFunctionReturn(0);
     }
-    ierr = BVView(ctx->U,viewer);CHKERRQ(ierr);
-    ierr = MatView(ctx->S,viewer);CHKERRQ(ierr);
+    PetscCall(BVView(ctx->U,viewer));
+    PetscCall(MatView(ctx->S,viewer));
     if (format == PETSC_VIEWER_ASCII_MATLAB) {
-      ierr = PetscObjectGetName((PetscObject)bv,&bvname);CHKERRQ(ierr);
-      ierr = PetscObjectGetName((PetscObject)ctx->U,&uname);CHKERRQ(ierr);
-      ierr = PetscObjectGetName((PetscObject)ctx->S,&sname);CHKERRQ(ierr);
-      ierr = PetscViewerASCIIPrintf(viewer,"%s=kron(eye(%D),%s)*%s(:,1:%D);\n",bvname,ctx->d,uname,sname,bv->k);CHKERRQ(ierr);
+      PetscCall(PetscObjectGetName((PetscObject)bv,&bvname));
+      PetscCall(PetscObjectGetName((PetscObject)ctx->U,&uname));
+      PetscCall(PetscObjectGetName((PetscObject)ctx->S,&sname));
+      PetscCall(PetscViewerASCIIPrintf(viewer,"%s=kron(eye(%" PetscInt_FMT "),%s)*%s(:,1:%" PetscInt_FMT ");\n",bvname,ctx->d,uname,sname,bv->k));
     }
   } else {
-    ierr = BVView(ctx->U,viewer);CHKERRQ(ierr);
-    ierr = MatView(ctx->S,viewer);CHKERRQ(ierr);
+    PetscCall(BVView(ctx->U,viewer));
+    PetscCall(MatView(ctx->S,viewer));
   }
   PetscFunctionReturn(0);
 }
 
 static PetscErrorCode BVTensorUpdateMatrix(BV V,PetscInt ini,PetscInt end)
 {
-  PetscErrorCode ierr;
   BV_TENSOR      *ctx = (BV_TENSOR*)V->data;
   PetscInt       i,j,r,c,l,k,ld=ctx->ld,lds=ctx->d*ctx->ld;
   PetscScalar    *qB,*sqB;
@@ -280,25 +261,25 @@ static PetscErrorCode BVTensorUpdateMatrix(BV V,PetscInt ini,PetscInt end)
   l = ctx->U->l; k = ctx->U->k;
   /* update inner product matrix */
   if (!ctx->qB) {
-    ierr = PetscCalloc2(lds*lds,&ctx->qB,lds,&ctx->sw);CHKERRQ(ierr);
-    ierr = VecDuplicate(ctx->U->t,&ctx->u);CHKERRQ(ierr);
+    PetscCall(PetscCalloc2(lds*lds,&ctx->qB,lds,&ctx->sw));
+    PetscCall(VecDuplicate(ctx->U->t,&ctx->u));
   }
   ctx->U->l = 0;
   for (r=0;r<ctx->d;r++) {
     for (c=0;c<=r;c++) {
-      ierr = MatNestGetSubMat(V->matrix,r,c,&A);CHKERRQ(ierr);
+      PetscCall(MatNestGetSubMat(V->matrix,r,c,&A));
       if (A) {
         qB = ctx->qB+c*ld*lds+r*ld;
         for (i=ini;i<end;i++) {
-          ierr = BVGetColumn(ctx->U,i,&u);CHKERRQ(ierr);
-          ierr = MatMult(A,u,ctx->u);CHKERRQ(ierr);
+          PetscCall(BVGetColumn(ctx->U,i,&u));
+          PetscCall(MatMult(A,u,ctx->u));
           ctx->U->k = i+1;
-          ierr = BVDotVec(ctx->U,ctx->u,qB+i*lds);CHKERRQ(ierr);
-          ierr = BVRestoreColumn(ctx->U,i,&u);CHKERRQ(ierr);
+          PetscCall(BVDotVec(ctx->U,ctx->u,qB+i*lds));
+          PetscCall(BVRestoreColumn(ctx->U,i,&u));
           for (j=0;j<i;j++) qB[i+j*lds] = PetscConj(qB[j+i*lds]);
           qB[i*lds+i] = PetscRealPart(qB[i+i*lds]);
         }
-        if (c!=r) {
+        if (PetscUnlikely(c!=r)) {
           sqB = ctx->qB+r*ld*lds+c*ld;
           for (i=ini;i<end;i++) for (j=0;j<=i;j++) {
             sqB[i+j*lds] = PetscConj(qB[j+i*lds]);
@@ -314,7 +295,6 @@ static PetscErrorCode BVTensorUpdateMatrix(BV V,PetscInt ini,PetscInt end)
 
 static PetscErrorCode BVTensorBuildFirstColumn_Tensor(BV V,PetscInt k)
 {
-  PetscErrorCode ierr;
   BV_TENSOR      *ctx = (BV_TENSOR*)V->data;
   PetscInt       i,nq=0;
   PetscScalar    *pS,*omega;
@@ -322,30 +302,27 @@ static PetscErrorCode BVTensorBuildFirstColumn_Tensor(BV V,PetscInt k)
   PetscBool      breakdown=PETSC_FALSE;
 
   PetscFunctionBegin;
-  ierr = MatDenseGetArray(ctx->S,&pS);CHKERRQ(ierr);
+  PetscCall(MatDenseGetArray(ctx->S,&pS));
   for (i=0;i<ctx->d;i++) {
-    if (i>=k) {
-      ierr = BVSetRandomColumn(ctx->U,nq);CHKERRQ(ierr);
-    } else {
-      ierr = BVCopyColumn(ctx->U,i,nq);CHKERRQ(ierr);
-    }
-    ierr = BVOrthogonalizeColumn(ctx->U,nq,pS+i*ctx->ld,&norm,&breakdown);CHKERRQ(ierr);
+    if (i>=k) PetscCall(BVSetRandomColumn(ctx->U,nq));
+    else PetscCall(BVCopyColumn(ctx->U,i,nq));
+    PetscCall(BVOrthogonalizeColumn(ctx->U,nq,pS+i*ctx->ld,&norm,&breakdown));
     if (!breakdown) {
-      ierr = BVScaleColumn(ctx->U,nq,1.0/norm);CHKERRQ(ierr);
+      PetscCall(BVScaleColumn(ctx->U,nq,1.0/norm));
       pS[nq+i*ctx->ld] = norm;
       nq++;
     }
   }
-  ierr = MatDenseRestoreArray(ctx->S,&pS);CHKERRQ(ierr);
-  if (!nq) SETERRQ1(PetscObjectComm((PetscObject)V),1,"Cannot build first column of tensor BV; U should contain k=%D nonzero columns",k);
-  ierr = BVTensorUpdateMatrix(V,0,nq);CHKERRQ(ierr);
-  ierr = BVTensorNormColumn(V,0,&norm);CHKERRQ(ierr);
-  ierr = BVScale_Tensor(V,0,1.0/norm);CHKERRQ(ierr);
+  PetscCall(MatDenseRestoreArray(ctx->S,&pS));
+  PetscCheck(nq,PetscObjectComm((PetscObject)V),PETSC_ERR_ARG_SIZ,"Cannot build first column of tensor BV; U should contain k=%" PetscInt_FMT " nonzero columns",k);
+  PetscCall(BVTensorUpdateMatrix(V,0,nq));
+  PetscCall(BVTensorNormColumn(V,0,&norm));
+  PetscCall(BVScale_Tensor(V,0,1.0/norm));
   if (V->indef) {
-    ierr = BV_AllocateSignature(V);CHKERRQ(ierr);
-    ierr = VecGetArray(V->omega,&omega);CHKERRQ(ierr);
+    PetscCall(BV_AllocateSignature(V));
+    PetscCall(VecGetArray(V->omega,&omega));
     omega[0] = (norm<0.0)? -1.0: 1.0;
-    ierr = VecRestoreArray(V->omega,&omega);CHKERRQ(ierr);
+    PetscCall(VecRestoreArray(V->omega,&omega));
   }
   /* set active columns */
   ctx->U->l = 0;
@@ -378,18 +355,15 @@ static PetscErrorCode BVTensorBuildFirstColumn_Tensor(BV V,PetscInt k)
 @*/
 PetscErrorCode BVTensorBuildFirstColumn(BV V,PetscInt k)
 {
-  PetscErrorCode ierr;
-
   PetscFunctionBegin;
   PetscValidHeaderSpecific(V,BV_CLASSID,1);
   PetscValidLogicalCollectiveInt(V,k,2);
-  ierr = PetscUseMethod(V,"BVTensorBuildFirstColumn_C",(BV,PetscInt),(V,k));CHKERRQ(ierr);
+  PetscUseMethod(V,"BVTensorBuildFirstColumn_C",(BV,PetscInt),(V,k));
   PetscFunctionReturn(0);
 }
 
 static PetscErrorCode BVTensorCompress_Tensor(BV V,PetscInt newc)
 {
-  PetscErrorCode ierr;
   BV_TENSOR      *ctx = (BV_TENSOR*)V->data;
   PetscInt       nwu=0,nnc,nrow,lwa,r,c;
   PetscInt       i,j,k,n,lds=ctx->ld*ctx->d,deg=ctx->d,lock,cs1=V->k,rs1=ctx->U->k,rk=0,offu;
@@ -405,41 +379,39 @@ static PetscErrorCode BVTensorCompress_Tensor(BV V,PetscInt newc)
   lock = ctx->U->l;
   nnc = cs1-lock-newc;
   nrow = rs1-lock;
-  ierr = PetscCalloc6(deg*newc*nnc,&SS,newc*nnc,&SS2,(rs1+lock+newc)*n,&pQ,deg*rs1,&tau,lwa,&work,6*n,&rwork);CHKERRQ(ierr);
+  PetscCall(PetscCalloc6(deg*newc*nnc,&SS,newc*nnc,&SS2,(rs1+lock+newc)*n,&pQ,deg*rs1,&tau,lwa,&work,6*n,&rwork));
   offu = lock*(rs1+1);
   M = work+nwu;
   nwu += rs1*cs1*deg;
   sg = rwork;
   Z = work+nwu;
   nwu += deg*cs1*n;
-  ierr = PetscBLASIntCast(n,&n_);CHKERRQ(ierr);
-  ierr = PetscBLASIntCast(nnc,&nnc_);CHKERRQ(ierr);
-  ierr = PetscBLASIntCast(cs1,&cs1_);CHKERRQ(ierr);
-  ierr = PetscBLASIntCast(rs1,&rs1_);CHKERRQ(ierr);
-  ierr = PetscBLASIntCast(newc,&newc_);CHKERRQ(ierr);
-  ierr = PetscBLASIntCast(newc*deg,&newctdeg);CHKERRQ(ierr);
-  ierr = PetscBLASIntCast(nnc*deg,&nnctdeg);CHKERRQ(ierr);
-  ierr = PetscBLASIntCast(cs1*deg,&cs1tdeg);CHKERRQ(ierr);
-  ierr = PetscBLASIntCast(lwa-nwu,&lw_);CHKERRQ(ierr);
-  ierr = PetscBLASIntCast(nrow,&nrow_);CHKERRQ(ierr);
-  ierr = PetscBLASIntCast(lds,&lds_);CHKERRQ(ierr);
-  ierr = MatDenseGetArray(ctx->S,&S);CHKERRQ(ierr);
+  PetscCall(PetscBLASIntCast(n,&n_));
+  PetscCall(PetscBLASIntCast(nnc,&nnc_));
+  PetscCall(PetscBLASIntCast(cs1,&cs1_));
+  PetscCall(PetscBLASIntCast(rs1,&rs1_));
+  PetscCall(PetscBLASIntCast(newc,&newc_));
+  PetscCall(PetscBLASIntCast(newc*deg,&newctdeg));
+  PetscCall(PetscBLASIntCast(nnc*deg,&nnctdeg));
+  PetscCall(PetscBLASIntCast(cs1*deg,&cs1tdeg));
+  PetscCall(PetscBLASIntCast(lwa-nwu,&lw_));
+  PetscCall(PetscBLASIntCast(nrow,&nrow_));
+  PetscCall(PetscBLASIntCast(lds,&lds_));
+  PetscCall(MatDenseGetArray(ctx->S,&S));
 
   if (newc>0) {
     /* truncate columns associated with new converged eigenpairs */
     for (j=0;j<deg;j++) {
-      for (i=lock;i<lock+newc;i++) {
-        ierr = PetscArraycpy(M+(i-lock+j*newc)*nrow,S+i*lds+j*ctx->ld+lock,nrow);CHKERRQ(ierr);
-      }
+      for (i=lock;i<lock+newc;i++) PetscCall(PetscArraycpy(M+(i-lock+j*newc)*nrow,S+i*lds+j*ctx->ld+lock,nrow));
     }
-    ierr = PetscFPTrapPush(PETSC_FP_TRAP_OFF);CHKERRQ(ierr);
+    PetscCall(PetscFPTrapPush(PETSC_FP_TRAP_OFF));
 #if !defined (PETSC_USE_COMPLEX)
     PetscStackCallBLAS("LAPACKgesvd",LAPACKgesvd_("S","S",&nrow_,&newctdeg,M,&nrow_,sg,pQ+offu,&rs1_,Z,&n_,work+nwu,&lw_,&info));
 #else
     PetscStackCallBLAS("LAPACKgesvd",LAPACKgesvd_("S","S",&nrow_,&newctdeg,M,&nrow_,sg,pQ+offu,&rs1_,Z,&n_,work+nwu,&lw_,rwork+n,&info));
 #endif
     SlepcCheckLapackInfo("gesvd",info);
-    ierr = PetscFPTrapPop();CHKERRQ(ierr);
+    PetscCall(PetscFPTrapPop());
     /* SVD has rank min(newc,nrow) */
     rk = PetscMin(newc,nrow);
     for (i=0;i<rk;i++) {
@@ -448,8 +420,8 @@ static PetscErrorCode BVTensorCompress_Tensor(BV V,PetscInt newc)
     }
     for (i=0;i<deg;i++) {
       for (j=lock;j<lock+newc;j++) {
-        ierr = PetscArraycpy(S+j*lds+i*ctx->ld+lock,Z+(newc*i+j-lock)*n,rk);CHKERRQ(ierr);
-        ierr = PetscArrayzero(S+j*lds+i*ctx->ld+lock+rk,(ctx->ld-lock-rk));CHKERRQ(ierr);
+        PetscCall(PetscArraycpy(S+j*lds+i*ctx->ld+lock,Z+(newc*i+j-lock)*n,rk));
+        PetscCall(PetscArrayzero(S+j*lds+i*ctx->ld+lock+rk,(ctx->ld-lock-rk)));
       }
     }
     /*
@@ -468,18 +440,16 @@ static PetscErrorCode BVTensorCompress_Tensor(BV V,PetscInt newc)
 
   /* truncate columns associated with non-converged eigenpairs */
   for (j=0;j<deg;j++) {
-    for (i=lock+newc;i<cs1;i++) {
-      ierr = PetscArraycpy(M+(i-lock-newc+j*nnc)*nrow,S+i*lds+j*ctx->ld+lock,nrow);CHKERRQ(ierr);
-    }
+    for (i=lock+newc;i<cs1;i++) PetscCall(PetscArraycpy(M+(i-lock-newc+j*nnc)*nrow,S+i*lds+j*ctx->ld+lock,nrow));
   }
-  ierr = PetscFPTrapPush(PETSC_FP_TRAP_OFF);CHKERRQ(ierr);
+  PetscCall(PetscFPTrapPush(PETSC_FP_TRAP_OFF));
 #if !defined (PETSC_USE_COMPLEX)
   PetscStackCallBLAS("LAPACKgesvd",LAPACKgesvd_("S","S",&nrow_,&nnctdeg,M,&nrow_,sg,pQ+offu+newc*rs1,&rs1_,Z,&n_,work+nwu,&lw_,&info));
 #else
   PetscStackCallBLAS("LAPACKgesvd",LAPACKgesvd_("S","S",&nrow_,&nnctdeg,M,&nrow_,sg,pQ+offu+newc*rs1,&rs1_,Z,&n_,work+nwu,&lw_,rwork+n,&info));
 #endif
   SlepcCheckLapackInfo("gesvd",info);
-  ierr = PetscFPTrapPop();CHKERRQ(ierr);
+  PetscCall(PetscFPTrapPop());
   tol = PetscMax(rs1,deg*cs1)*PETSC_MACHINE_EPSILON*sg[0];
   rk = 0;
   for (i=0;i<PetscMin(nrow,nnctdeg);i++) if (sg[i]>tol) rk++;
@@ -490,12 +460,12 @@ static PetscErrorCode BVTensorCompress_Tensor(BV V,PetscInt newc)
     PetscStackCallBLAS("BLASscal",BLASscal_(&nnctdeg,&t,Z+i,&n_));
   }
   /* update S */
-  ierr = PetscArrayzero(S+cs1*lds,(V->m-cs1)*lds);CHKERRQ(ierr);
+  PetscCall(PetscArrayzero(S+cs1*lds,(V->m-cs1)*lds));
   k = ctx->ld-lock-newc-rk;
   for (i=0;i<deg;i++) {
     for (j=lock+newc;j<cs1;j++) {
-      ierr = PetscArraycpy(S+j*lds+i*ctx->ld+lock+newc,Z+(nnc*i+j-lock-newc)*n,rk);CHKERRQ(ierr);
-      ierr = PetscArrayzero(S+j*lds+i*ctx->ld+lock+newc+rk,k);CHKERRQ(ierr);
+      PetscCall(PetscArraycpy(S+j*lds+i*ctx->ld+lock+newc,Z+(nnc*i+j-lock-newc)*n,rk));
+      PetscCall(PetscArrayzero(S+j*lds+i*ctx->ld+lock+newc+rk,k));
     }
   }
   if (newc>0) {
@@ -509,9 +479,9 @@ static PetscErrorCode BVTensorCompress_Tensor(BV V,PetscInt newc)
 
   /* orthogonalize pQ */
   rk = rk+newc;
-  ierr = PetscBLASIntCast(rk,&rk_);CHKERRQ(ierr);
-  ierr = PetscBLASIntCast(cs1-lock,&nnc_);CHKERRQ(ierr);
-  ierr = PetscFPTrapPush(PETSC_FP_TRAP_OFF);CHKERRQ(ierr);
+  PetscCall(PetscBLASIntCast(rk,&rk_));
+  PetscCall(PetscBLASIntCast(cs1-lock,&nnc_));
+  PetscCall(PetscFPTrapPush(PETSC_FP_TRAP_OFF));
   PetscStackCallBLAS("LAPACKgeqrf",LAPACKgeqrf_(&nrow_,&rk_,pQ+offu,&rs1_,tau,work+nwu,&lw_,&info));
   SlepcCheckLapackInfo("geqrf",info);
   for (i=0;i<deg;i++) {
@@ -519,23 +489,23 @@ static PetscErrorCode BVTensorCompress_Tensor(BV V,PetscInt newc)
   }
   PetscStackCallBLAS("LAPACKorgqr",LAPACKorgqr_(&nrow_,&rk_,&rk_,pQ+offu,&rs1_,tau,work+nwu,&lw_,&info));
   SlepcCheckLapackInfo("orgqr",info);
-  ierr = PetscFPTrapPop();CHKERRQ(ierr);
+  PetscCall(PetscFPTrapPop());
 
   /* update vectors U(:,idx) = U*Q(:,idx) */
   rk = rk+lock;
   for (i=0;i<lock;i++) pQ[i*(1+rs1)] = 1.0;
-  ierr = MatCreateSeqDense(PETSC_COMM_SELF,rs1,rk,pQ,&Q);CHKERRQ(ierr);
+  PetscCall(MatCreateSeqDense(PETSC_COMM_SELF,rs1,rk,pQ,&Q));
   ctx->U->k = rs1;
-  ierr = BVMultInPlace(ctx->U,Q,lock,rk);CHKERRQ(ierr);
-  ierr = MatDestroy(&Q);CHKERRQ(ierr);
+  PetscCall(BVMultInPlace(ctx->U,Q,lock,rk));
+  PetscCall(MatDestroy(&Q));
 
   if (ctx->qB) {
    /* update matrix qB */
-    ierr = PetscBLASIntCast(ctx->ld,&ld_);CHKERRQ(ierr);
-    ierr = PetscBLASIntCast(rk,&rk_);CHKERRQ(ierr);
+    PetscCall(PetscBLASIntCast(ctx->ld,&ld_));
+    PetscCall(PetscBLASIntCast(rk,&rk_));
     for (r=0;r<ctx->d;r++) {
       for (c=0;c<=r;c++) {
-        ierr = MatNestGetSubMat(V->matrix,r,c,&A);CHKERRQ(ierr);
+        PetscCall(MatNestGetSubMat(V->matrix,r,c,&A));
         if (A) {
           qB = ctx->qB+r*ctx->ld+c*ctx->ld*lds;
           PetscStackCallBLAS("BLASgemm",BLASgemm_("N","N",&rs1_,&rk_,&rs1_,&sone,qB,&lds_,pQ,&rs1_,&zero,work+nwu,&rs1_));
@@ -544,12 +514,8 @@ static PetscErrorCode BVTensorCompress_Tensor(BV V,PetscInt newc)
             for (j=0;j<i;j++) qB[i+j*lds] = PetscConj(qB[j+i*lds]);
             qB[i+i*lds] = PetscRealPart(qB[i+i*lds]);
           }
-          for (i=rk;i<ctx->ld;i++) {
-            ierr = PetscArrayzero(qB+i*lds,ctx->ld);CHKERRQ(ierr);
-          }
-          for (i=0;i<rk;i++) {
-            ierr = PetscArrayzero(qB+i*lds+rk,(ctx->ld-rk));CHKERRQ(ierr);
-          }
+          for (i=rk;i<ctx->ld;i++) PetscCall(PetscArrayzero(qB+i*lds,ctx->ld));
+          for (i=0;i<rk;i++) PetscCall(PetscArrayzero(qB+i*lds+rk,(ctx->ld-rk)));
           if (c!=r) {
             sqB = ctx->qB+r*ctx->ld*lds+c*ctx->ld;
             for (i=0;i<ctx->ld;i++) for (j=0;j<ctx->ld;j++) sqB[i+j*lds] = PetscConj(qB[j+i*lds]);
@@ -560,8 +526,8 @@ static PetscErrorCode BVTensorCompress_Tensor(BV V,PetscInt newc)
   }
 
   /* free work space */
-  ierr = PetscFree6(SS,SS2,pQ,tau,work,rwork);CHKERRQ(ierr);
-  ierr = MatDenseRestoreArray(ctx->S,&S);CHKERRQ(ierr);
+  PetscCall(PetscFree6(SS,SS2,pQ,tau,work,rwork));
+  PetscCall(MatDenseRestoreArray(ctx->S,&S));
 
   /* set active columns */
   if (newc) ctx->U->l += newc;
@@ -597,12 +563,10 @@ static PetscErrorCode BVTensorCompress_Tensor(BV V,PetscInt newc)
 @*/
 PetscErrorCode BVTensorCompress(BV V,PetscInt newc)
 {
-  PetscErrorCode ierr;
-
   PetscFunctionBegin;
   PetscValidHeaderSpecific(V,BV_CLASSID,1);
   PetscValidLogicalCollectiveInt(V,newc,2);
-  ierr = PetscUseMethod(V,"BVTensorCompress_C",(BV,PetscInt),(V,newc));CHKERRQ(ierr);
+  PetscUseMethod(V,"BVTensorCompress_C",(BV,PetscInt),(V,newc));
   PetscFunctionReturn(0);
 }
 
@@ -632,12 +596,10 @@ static PetscErrorCode BVTensorGetDegree_Tensor(BV bv,PetscInt *d)
 @*/
 PetscErrorCode BVTensorGetDegree(BV bv,PetscInt *d)
 {
-  PetscErrorCode ierr;
-
   PetscFunctionBegin;
   PetscValidHeaderSpecific(bv,BV_CLASSID,1);
   PetscValidIntPointer(d,2);
-  ierr = PetscUseMethod(bv,"BVTensorGetDegree_C",(BV,PetscInt*),(bv,d));CHKERRQ(ierr);
+  PetscUseMethod(bv,"BVTensorGetDegree_C",(BV,PetscInt*),(bv,d));
   PetscFunctionReturn(0);
 }
 
@@ -646,7 +608,7 @@ static PetscErrorCode BVTensorGetFactors_Tensor(BV V,BV *U,Mat *S)
   BV_TENSOR *ctx = (BV_TENSOR*)V->data;
 
   PetscFunctionBegin;
-  if (ctx->puk>-1) SETERRQ(PetscObjectComm((PetscObject)V),PETSC_ERR_ORDER,"Previous call to BVTensonGetFactors without a BVTensorRestoreFactors call");
+  PetscCheck(ctx->puk==-1,PetscObjectComm((PetscObject)V),PETSC_ERR_ORDER,"Previous call to BVTensonGetFactors without a BVTensorRestoreFactors call");
   ctx->puk = ctx->U->k;
   if (U) *U = ctx->U;
   if (S) *S = ctx->S;
@@ -683,24 +645,21 @@ static PetscErrorCode BVTensorGetFactors_Tensor(BV V,BV *U,Mat *S)
 @*/
 PetscErrorCode BVTensorGetFactors(BV V,BV *U,Mat *S)
 {
-  PetscErrorCode ierr;
-
   PetscFunctionBegin;
   PetscValidHeaderSpecific(V,BV_CLASSID,1);
-  ierr = PetscUseMethod(V,"BVTensorGetFactors_C",(BV,BV*,Mat*),(V,U,S));CHKERRQ(ierr);
+  PetscUseMethod(V,"BVTensorGetFactors_C",(BV,BV*,Mat*),(V,U,S));
   PetscFunctionReturn(0);
 }
 
 static PetscErrorCode BVTensorRestoreFactors_Tensor(BV V,BV *U,Mat *S)
 {
-  PetscErrorCode ierr;
   BV_TENSOR      *ctx = (BV_TENSOR*)V->data;
 
   PetscFunctionBegin;
-  ierr = PetscObjectStateIncrease((PetscObject)V);CHKERRQ(ierr);
+  PetscCall(PetscObjectStateIncrease((PetscObject)V));
   if (U) *U = NULL;
   if (S) *S = NULL;
-  ierr = BVTensorUpdateMatrix(V,ctx->puk,ctx->U->k);CHKERRQ(ierr);
+  PetscCall(BVTensorUpdateMatrix(V,ctx->puk,ctx->U->k));
   ctx->puk = -1;
   PetscFunctionReturn(0);
 }
@@ -716,7 +675,7 @@ static PetscErrorCode BVTensorRestoreFactors_Tensor(BV V,BV *U,Mat *S)
 .  U - the BV factor (or NULL)
 -  S - the Mat factor (or NULL)
 
-   Nots:
+   Notes:
    The arguments must match the corresponding call to BVTensorGetFactors().
 
    Level: advanced
@@ -725,44 +684,40 @@ static PetscErrorCode BVTensorRestoreFactors_Tensor(BV V,BV *U,Mat *S)
 @*/
 PetscErrorCode BVTensorRestoreFactors(BV V,BV *U,Mat *S)
 {
-  PetscErrorCode ierr;
-
   PetscFunctionBegin;
   PetscValidHeaderSpecific(V,BV_CLASSID,1);
   if (U) PetscValidHeaderSpecific(*U,BV_CLASSID,2);
   if (S) PetscValidHeaderSpecific(*S,MAT_CLASSID,3);
-  ierr = PetscUseMethod(V,"BVTensorRestoreFactors_C",(BV,BV*,Mat*),(V,U,S));CHKERRQ(ierr);
+  PetscUseMethod(V,"BVTensorRestoreFactors_C",(BV,BV*,Mat*),(V,U,S));
   PetscFunctionReturn(0);
 }
 
 PetscErrorCode BVDestroy_Tensor(BV bv)
 {
-  PetscErrorCode ierr;
   BV_TENSOR      *ctx = (BV_TENSOR*)bv->data;
 
   PetscFunctionBegin;
-  ierr = BVDestroy(&ctx->U);CHKERRQ(ierr);
-  ierr = MatDestroy(&ctx->S);CHKERRQ(ierr);
+  PetscCall(BVDestroy(&ctx->U));
+  PetscCall(MatDestroy(&ctx->S));
   if (ctx->u) {
-    ierr = PetscFree2(ctx->qB,ctx->sw);CHKERRQ(ierr);
-    ierr = VecDestroy(&ctx->u);CHKERRQ(ierr);
+    PetscCall(PetscFree2(ctx->qB,ctx->sw));
+    PetscCall(VecDestroy(&ctx->u));
   }
-  ierr = PetscFree(bv->data);CHKERRQ(ierr);
-  ierr = PetscObjectComposeFunction((PetscObject)bv,"BVTensorBuildFirstColumn_C",NULL);CHKERRQ(ierr);
-  ierr = PetscObjectComposeFunction((PetscObject)bv,"BVTensorCompress_C",NULL);CHKERRQ(ierr);
-  ierr = PetscObjectComposeFunction((PetscObject)bv,"BVTensorGetDegree_C",NULL);CHKERRQ(ierr);
-  ierr = PetscObjectComposeFunction((PetscObject)bv,"BVTensorGetFactors_C",NULL);CHKERRQ(ierr);
-  ierr = PetscObjectComposeFunction((PetscObject)bv,"BVTensorRestoreFactors_C",NULL);CHKERRQ(ierr);
+  PetscCall(PetscFree(bv->data));
+  PetscCall(PetscObjectComposeFunction((PetscObject)bv,"BVTensorBuildFirstColumn_C",NULL));
+  PetscCall(PetscObjectComposeFunction((PetscObject)bv,"BVTensorCompress_C",NULL));
+  PetscCall(PetscObjectComposeFunction((PetscObject)bv,"BVTensorGetDegree_C",NULL));
+  PetscCall(PetscObjectComposeFunction((PetscObject)bv,"BVTensorGetFactors_C",NULL));
+  PetscCall(PetscObjectComposeFunction((PetscObject)bv,"BVTensorRestoreFactors_C",NULL));
   PetscFunctionReturn(0);
 }
 
 SLEPC_EXTERN PetscErrorCode BVCreate_Tensor(BV bv)
 {
-  PetscErrorCode ierr;
   BV_TENSOR      *ctx;
 
   PetscFunctionBegin;
-  ierr = PetscNewLog(bv,&ctx);CHKERRQ(ierr);
+  PetscCall(PetscNewLog(bv,&ctx));
   bv->data = (void*)ctx;
   ctx->puk = -1;
 
@@ -776,11 +731,11 @@ SLEPC_EXTERN PetscErrorCode BVCreate_Tensor(BV bv)
   bv->ops->destroy          = BVDestroy_Tensor;
   bv->ops->view             = BVView_Tensor;
 
-  ierr = PetscObjectComposeFunction((PetscObject)bv,"BVTensorBuildFirstColumn_C",BVTensorBuildFirstColumn_Tensor);CHKERRQ(ierr);
-  ierr = PetscObjectComposeFunction((PetscObject)bv,"BVTensorCompress_C",BVTensorCompress_Tensor);CHKERRQ(ierr);
-  ierr = PetscObjectComposeFunction((PetscObject)bv,"BVTensorGetDegree_C",BVTensorGetDegree_Tensor);CHKERRQ(ierr);
-  ierr = PetscObjectComposeFunction((PetscObject)bv,"BVTensorGetFactors_C",BVTensorGetFactors_Tensor);CHKERRQ(ierr);
-  ierr = PetscObjectComposeFunction((PetscObject)bv,"BVTensorRestoreFactors_C",BVTensorRestoreFactors_Tensor);CHKERRQ(ierr);
+  PetscCall(PetscObjectComposeFunction((PetscObject)bv,"BVTensorBuildFirstColumn_C",BVTensorBuildFirstColumn_Tensor));
+  PetscCall(PetscObjectComposeFunction((PetscObject)bv,"BVTensorCompress_C",BVTensorCompress_Tensor));
+  PetscCall(PetscObjectComposeFunction((PetscObject)bv,"BVTensorGetDegree_C",BVTensorGetDegree_Tensor));
+  PetscCall(PetscObjectComposeFunction((PetscObject)bv,"BVTensorGetFactors_C",BVTensorGetFactors_Tensor));
+  PetscCall(PetscObjectComposeFunction((PetscObject)bv,"BVTensorRestoreFactors_C",BVTensorRestoreFactors_Tensor));
   PetscFunctionReturn(0);
 }
 
@@ -819,7 +774,6 @@ SLEPC_EXTERN PetscErrorCode BVCreate_Tensor(BV bv)
 @*/
 PetscErrorCode BVCreateTensor(BV U,PetscInt d,BV *V)
 {
-  PetscErrorCode ierr;
   PetscBool      match;
   PetscInt       n,N,m;
   BV_TENSOR      *ctx;
@@ -827,27 +781,27 @@ PetscErrorCode BVCreateTensor(BV U,PetscInt d,BV *V)
   PetscFunctionBegin;
   PetscValidHeaderSpecific(U,BV_CLASSID,1);
   PetscValidLogicalCollectiveInt(U,d,2);
-  ierr = PetscObjectTypeCompare((PetscObject)U,BVTENSOR,&match);CHKERRQ(ierr);
-  if (match) SETERRQ(PetscObjectComm((PetscObject)U),PETSC_ERR_SUP,"U cannot be of type tensor");
+  PetscCall(PetscObjectTypeCompare((PetscObject)U,BVTENSOR,&match));
+  PetscCheck(!match,PetscObjectComm((PetscObject)U),PETSC_ERR_SUP,"U cannot be of type tensor");
 
-  ierr = BVCreate(PetscObjectComm((PetscObject)U),V);CHKERRQ(ierr);
-  ierr = BVGetSizes(U,&n,&N,&m);CHKERRQ(ierr);
-  if (m<d) SETERRQ2(PetscObjectComm((PetscObject)U),PETSC_ERR_ARG_SIZ,"U has %D columns, it should have at least d=%D",m,d);
-  ierr = BVSetSizes(*V,d*n,d*N,m-d+1);CHKERRQ(ierr);
-  ierr = PetscObjectChangeTypeName((PetscObject)*V,BVTENSOR);CHKERRQ(ierr);
-  ierr = PetscLogEventBegin(BV_Create,*V,0,0,0);CHKERRQ(ierr);
-  ierr = BVCreate_Tensor(*V);CHKERRQ(ierr);
-  ierr = PetscLogEventEnd(BV_Create,*V,0,0,0);CHKERRQ(ierr);
+  PetscCall(BVCreate(PetscObjectComm((PetscObject)U),V));
+  PetscCall(BVGetSizes(U,&n,&N,&m));
+  PetscCheck(m>=d,PetscObjectComm((PetscObject)U),PETSC_ERR_ARG_SIZ,"U has %" PetscInt_FMT " columns, it should have at least d=%" PetscInt_FMT,m,d);
+  PetscCall(BVSetSizes(*V,d*n,d*N,m-d+1));
+  PetscCall(PetscObjectChangeTypeName((PetscObject)*V,BVTENSOR));
+  PetscCall(PetscLogEventBegin(BV_Create,*V,0,0,0));
+  PetscCall(BVCreate_Tensor(*V));
+  PetscCall(PetscLogEventEnd(BV_Create,*V,0,0,0));
 
   ctx = (BV_TENSOR*)(*V)->data;
   ctx->U  = U;
   ctx->d  = d;
   ctx->ld = m;
-  ierr = PetscObjectReference((PetscObject)U);CHKERRQ(ierr);
-  ierr = PetscLogObjectParent((PetscObject)*V,(PetscObject)U);CHKERRQ(ierr);
-  ierr = MatCreateSeqDense(PETSC_COMM_SELF,d*m,m-d+1,NULL,&ctx->S);CHKERRQ(ierr);
-  ierr = PetscLogObjectParent((PetscObject)*V,(PetscObject)ctx->S);CHKERRQ(ierr);
-  ierr = PetscObjectSetName((PetscObject)ctx->S,"S");CHKERRQ(ierr);
+  PetscCall(PetscObjectReference((PetscObject)U));
+  PetscCall(PetscLogObjectParent((PetscObject)*V,(PetscObject)U));
+  PetscCall(MatCreateSeqDense(PETSC_COMM_SELF,d*m,m-d+1,NULL,&ctx->S));
+  PetscCall(PetscLogObjectParent((PetscObject)*V,(PetscObject)ctx->S));
+  PetscCall(PetscObjectSetName((PetscObject)ctx->S,"S"));
 
   /* Copy user-provided attributes of U */
   (*V)->orthog_type  = U->orthog_type;
@@ -858,4 +812,3 @@ PetscErrorCode BVCreateTensor(BV U,PetscInt d,BV *V)
   (*V)->rrandom      = U->rrandom;
   PetscFunctionReturn(0);
 }
-
