@@ -1,7 +1,7 @@
 /*
    - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
    SLEPc - Scalable Library for Eigenvalue Problem Computations
-   Copyright (c) 2002-2021, Universitat Politecnica de Valencia, Spain
+   Copyright (c) 2002-, Universitat Politecnica de Valencia, Spain
 
    This file is part of SLEPc.
    SLEPc is distributed under a 2-clause BSD license (see LICENSE).
@@ -36,51 +36,48 @@ SLEPC_EXTERN void MPIAPI SlepcPythag(void *in,void *inout,PetscMPIInt *len,MPI_D
 */
 PetscErrorCode BVNorm_LAPACK_Private(BV bv,PetscInt m_,PetscInt n_,const PetscScalar *A,NormType type,PetscReal *nrm,PetscBool mpi)
 {
-  PetscErrorCode ierr;
   PetscBLASInt   m,n,i,j;
   PetscMPIInt    len;
   PetscReal      lnrm,*rwork=NULL,*rwork2=NULL;
 
   PetscFunctionBegin;
-  ierr = PetscFPTrapPush(PETSC_FP_TRAP_OFF);CHKERRQ(ierr);
-  ierr = PetscBLASIntCast(m_,&m);CHKERRQ(ierr);
-  ierr = PetscBLASIntCast(n_,&n);CHKERRQ(ierr);
+  PetscCall(PetscFPTrapPush(PETSC_FP_TRAP_OFF));
+  PetscCall(PetscBLASIntCast(m_,&m));
+  PetscCall(PetscBLASIntCast(n_,&n));
   if (type==NORM_FROBENIUS || type==NORM_2) {
     lnrm = LAPACKlange_("F",&m,&n,(PetscScalar*)A,&m,rwork);
-    if (mpi) {
-      ierr = MPIU_Allreduce(&lnrm,nrm,1,MPIU_REAL,MPIU_LAPY2,PetscObjectComm((PetscObject)bv));CHKERRQ(ierr);
-    } else *nrm = lnrm;
-    ierr = PetscLogFlops(2.0*m*n);CHKERRQ(ierr);
+    if (mpi) PetscCall(MPIU_Allreduce(&lnrm,nrm,1,MPIU_REAL,MPIU_LAPY2,PetscObjectComm((PetscObject)bv)));
+    else *nrm = lnrm;
+    PetscCall(PetscLogFlops(2.0*m*n));
   } else if (type==NORM_1) {
     if (mpi) {
-      ierr = BVAllocateWork_Private(bv,2*n_);CHKERRQ(ierr);
+      PetscCall(BVAllocateWork_Private(bv,2*n_));
       rwork = (PetscReal*)bv->work;
       rwork2 = rwork+n_;
-      ierr = PetscArrayzero(rwork,n_);CHKERRQ(ierr);
-      ierr = PetscArrayzero(rwork2,n_);CHKERRQ(ierr);
+      PetscCall(PetscArrayzero(rwork,n_));
+      PetscCall(PetscArrayzero(rwork2,n_));
       for (j=0;j<n_;j++) {
         for (i=0;i<m_;i++) {
           rwork[j] += PetscAbsScalar(A[i+j*m_]);
         }
       }
-      ierr = PetscMPIIntCast(n_,&len);CHKERRQ(ierr);
-      ierr = MPIU_Allreduce(rwork,rwork2,len,MPIU_REAL,MPIU_SUM,PetscObjectComm((PetscObject)bv));CHKERRQ(ierr);
+      PetscCall(PetscMPIIntCast(n_,&len));
+      PetscCall(MPIU_Allreduce(rwork,rwork2,len,MPIU_REAL,MPIU_SUM,PetscObjectComm((PetscObject)bv)));
       *nrm = 0.0;
       for (j=0;j<n_;j++) if (rwork2[j] > *nrm) *nrm = rwork2[j];
     } else {
       *nrm = LAPACKlange_("O",&m,&n,(PetscScalar*)A,&m,rwork);
     }
-    ierr = PetscLogFlops(1.0*m*n);CHKERRQ(ierr);
+    PetscCall(PetscLogFlops(1.0*m*n));
   } else if (type==NORM_INFINITY) {
-    ierr = BVAllocateWork_Private(bv,m_);CHKERRQ(ierr);
+    PetscCall(BVAllocateWork_Private(bv,m_));
     rwork = (PetscReal*)bv->work;
     lnrm = LAPACKlange_("I",&m,&n,(PetscScalar*)A,&m,rwork);
-    if (mpi) {
-      ierr = MPIU_Allreduce(&lnrm,nrm,1,MPIU_REAL,MPIU_MAX,PetscObjectComm((PetscObject)bv));CHKERRQ(ierr);
-    } else *nrm = lnrm;
-    ierr = PetscLogFlops(1.0*m*n);CHKERRQ(ierr);
+    if (mpi) PetscCall(MPIU_Allreduce(&lnrm,nrm,1,MPIU_REAL,MPIU_MAX,PetscObjectComm((PetscObject)bv)));
+    else *nrm = lnrm;
+    PetscCall(PetscLogFlops(1.0*m*n));
   }
-  ierr = PetscFPTrapPop();CHKERRQ(ierr);
+  PetscCall(PetscFPTrapPop());
   PetscFunctionReturn(0);
 }
 
@@ -89,15 +86,14 @@ PetscErrorCode BVNorm_LAPACK_Private(BV bv,PetscInt m_,PetscInt n_,const PetscSc
 */
 PetscErrorCode BVNormalize_LAPACK_Private(BV bv,PetscInt m_,PetscInt n_,const PetscScalar *A,PetscScalar *eigi,PetscBool mpi)
 {
-  PetscErrorCode ierr;
   PetscBLASInt   m,j,k,info,zero=0;
   PetscMPIInt    len;
   PetscReal      *norms,*rwork=NULL,*rwork2=NULL,done=1.0;
 
   PetscFunctionBegin;
-  ierr = PetscFPTrapPush(PETSC_FP_TRAP_OFF);CHKERRQ(ierr);
-  ierr = PetscBLASIntCast(m_,&m);CHKERRQ(ierr);
-  ierr = BVAllocateWork_Private(bv,2*n_);CHKERRQ(ierr);
+  PetscCall(PetscFPTrapPush(PETSC_FP_TRAP_OFF));
+  PetscCall(PetscBLASIntCast(m_,&m));
+  PetscCall(BVAllocateWork_Private(bv,2*n_));
   rwork = (PetscReal*)bv->work;
   rwork2 = rwork+n_;
   /* compute local norms */
@@ -111,9 +107,9 @@ PetscErrorCode BVNormalize_LAPACK_Private(BV bv,PetscInt m_,PetscInt n_,const Pe
   }
   /* reduction to get global norms */
   if (mpi) {
-    ierr = PetscMPIIntCast(n_,&len);CHKERRQ(ierr);
-    ierr = PetscArrayzero(rwork2,n_);CHKERRQ(ierr);
-    ierr = MPIU_Allreduce(rwork,rwork2,len,MPIU_REAL,MPIU_LAPY2,PetscObjectComm((PetscObject)bv));CHKERRQ(ierr);
+    PetscCall(PetscMPIIntCast(n_,&len));
+    PetscCall(PetscArrayzero(rwork2,n_));
+    PetscCall(MPIU_Allreduce(rwork,rwork2,len,MPIU_REAL,MPIU_LAPY2,PetscObjectComm((PetscObject)bv)));
     norms = rwork2;
   } else norms = rwork;
   /* scale columns */
@@ -126,8 +122,8 @@ PetscErrorCode BVNormalize_LAPACK_Private(BV bv,PetscInt m_,PetscInt n_,const Pe
     SlepcCheckLapackInfo("lascl",info);
     if (k==2) j++;
   }
-  ierr = PetscLogFlops(3.0*m*n_);CHKERRQ(ierr);
-  ierr = PetscFPTrapPop();CHKERRQ(ierr);
+  PetscCall(PetscLogFlops(3.0*m*n_));
+  PetscCall(PetscFPTrapPop());
   PetscFunctionReturn(0);
 }
 
@@ -137,7 +133,6 @@ PetscErrorCode BVNormalize_LAPACK_Private(BV bv,PetscInt m_,PetscInt n_,const Pe
  */
 PetscErrorCode BVMatCholInv_LAPACK_Private(BV bv,Mat R,Mat S)
 {
-  PetscErrorCode ierr;
   PetscInt       i,k,l,n,m,ld,lds;
   PetscScalar    *pR,*pS;
   PetscBLASInt   info,n_ = 0,m_ = 0,ld_,lds_;
@@ -145,66 +140,62 @@ PetscErrorCode BVMatCholInv_LAPACK_Private(BV bv,Mat R,Mat S)
   PetscFunctionBegin;
   l = bv->l;
   k = bv->k;
-  ierr = MatGetSize(R,&m,NULL);CHKERRQ(ierr);
+  PetscCall(MatGetSize(R,&m,NULL));
   n = k-l;
-  ierr = PetscBLASIntCast(m,&m_);CHKERRQ(ierr);
-  ierr = PetscBLASIntCast(n,&n_);CHKERRQ(ierr);
+  PetscCall(PetscBLASIntCast(m,&m_));
+  PetscCall(PetscBLASIntCast(n,&n_));
   ld  = m;
   ld_ = m_;
-  ierr = MatDenseGetArray(R,&pR);CHKERRQ(ierr);
+  PetscCall(MatDenseGetArray(R,&pR));
 
   if (S==R) {
-    ierr = BVAllocateWork_Private(bv,m*k);CHKERRQ(ierr);
+    PetscCall(BVAllocateWork_Private(bv,m*k));
     pS = bv->work;
     lds = ld;
     lds_ = ld_;
   } else {
-    ierr = MatDenseGetArray(S,&pS);CHKERRQ(ierr);
-    ierr = MatGetSize(S,&lds,NULL);CHKERRQ(ierr);
-    ierr = PetscBLASIntCast(lds,&lds_);CHKERRQ(ierr);
+    PetscCall(MatDenseGetArray(S,&pS));
+    PetscCall(MatGetSize(S,&lds,NULL));
+    PetscCall(PetscBLASIntCast(lds,&lds_));
   }
 
   /* save a copy of matrix in S */
-  for (i=l;i<k;i++) {
-    ierr = PetscArraycpy(pS+i*lds+l,pR+i*ld+l,n);CHKERRQ(ierr);
-  }
+  for (i=l;i<k;i++) PetscCall(PetscArraycpy(pS+i*lds+l,pR+i*ld+l,n));
 
   /* compute upper Cholesky factor in R */
-  ierr = PetscFPTrapPush(PETSC_FP_TRAP_OFF);CHKERRQ(ierr);
+  PetscCall(PetscFPTrapPush(PETSC_FP_TRAP_OFF));
   PetscStackCallBLAS("LAPACKpotrf",LAPACKpotrf_("U",&n_,pR+l*ld+l,&ld_,&info));
-  ierr = PetscLogFlops((1.0*n*n*n)/3.0);CHKERRQ(ierr);
+  PetscCall(PetscLogFlops((1.0*n*n*n)/3.0));
 
   if (info) {  /* LAPACKpotrf failed, retry on diagonally perturbed matrix */
     for (i=l;i<k;i++) {
-      ierr = PetscArraycpy(pR+i*ld+l,pS+i*lds+l,n);CHKERRQ(ierr);
+      PetscCall(PetscArraycpy(pR+i*ld+l,pS+i*lds+l,n));
       pR[i+i*ld] += 50.0*PETSC_MACHINE_EPSILON;
     }
     PetscStackCallBLAS("LAPACKpotrf",LAPACKpotrf_("U",&n_,pR+l*ld+l,&ld_,&info));
     SlepcCheckLapackInfo("potrf",info);
-    ierr = PetscLogFlops((1.0*n*n*n)/3.0);CHKERRQ(ierr);
+    PetscCall(PetscLogFlops((1.0*n*n*n)/3.0));
   }
 
   /* compute S = inv(R) */
   if (S==R) {
     PetscStackCallBLAS("LAPACKtrtri",LAPACKtrtri_("U","N",&n_,pR+l*ld+l,&ld_,&info));
   } else {
-    ierr = PetscArrayzero(pS+l*lds,(k-l)*k);CHKERRQ(ierr);
-    for (i=l;i<k;i++) {
-      ierr = PetscArraycpy(pS+i*lds+l,pR+i*ld+l,n);CHKERRQ(ierr);
-    }
+    PetscCall(PetscArrayzero(pS+l*lds,(k-l)*k));
+    for (i=l;i<k;i++) PetscCall(PetscArraycpy(pS+i*lds+l,pR+i*ld+l,n));
     PetscStackCallBLAS("LAPACKtrtri",LAPACKtrtri_("U","N",&n_,pS+l*lds+l,&lds_,&info));
   }
   SlepcCheckLapackInfo("trtri",info);
-  ierr = PetscFPTrapPop();CHKERRQ(ierr);
-  ierr = PetscLogFlops(0.33*n*n*n);CHKERRQ(ierr);
+  PetscCall(PetscFPTrapPop());
+  PetscCall(PetscLogFlops(0.33*n*n*n));
 
   /* Zero out entries below the diagonal */
   for (i=l;i<k-1;i++) {
-    ierr = PetscArrayzero(pR+i*ld+i+1,(k-i-1));CHKERRQ(ierr);
-    if (S!=R) { ierr = PetscArrayzero(pS+i*lds+i+1,(k-i-1));CHKERRQ(ierr); }
+    PetscCall(PetscArrayzero(pR+i*ld+i+1,(k-i-1)));
+    if (S!=R) PetscCall(PetscArrayzero(pS+i*lds+i+1,(k-i-1)));
   }
-  ierr = MatDenseRestoreArray(R,&pR);CHKERRQ(ierr);
-  if (S!=R) { ierr = MatDenseRestoreArray(S,&pS);CHKERRQ(ierr); }
+  PetscCall(MatDenseRestoreArray(R,&pR));
+  if (S!=R) PetscCall(MatDenseRestoreArray(S,&pS));
   PetscFunctionReturn(0);
 }
 
@@ -214,7 +205,6 @@ PetscErrorCode BVMatCholInv_LAPACK_Private(BV bv,Mat R,Mat S)
  */
 PetscErrorCode BVMatTriInv_LAPACK_Private(BV bv,Mat R,Mat S)
 {
-  PetscErrorCode ierr;
   PetscInt       i,k,l,n,m,ld,lds;
   PetscScalar    *pR,*pS;
   PetscBLASInt   info,n_,m_ = 0,ld_,lds_;
@@ -222,42 +212,40 @@ PetscErrorCode BVMatTriInv_LAPACK_Private(BV bv,Mat R,Mat S)
   PetscFunctionBegin;
   l = bv->l;
   k = bv->k;
-  ierr = MatGetSize(R,&m,NULL);CHKERRQ(ierr);
+  PetscCall(MatGetSize(R,&m,NULL));
   n = k-l;
-  ierr = PetscBLASIntCast(m,&m_);CHKERRQ(ierr);
-  ierr = PetscBLASIntCast(n,&n_);CHKERRQ(ierr);
+  PetscCall(PetscBLASIntCast(m,&m_));
+  PetscCall(PetscBLASIntCast(n,&n_));
   ld  = m;
   ld_ = m_;
-  ierr = MatDenseGetArray(R,&pR);CHKERRQ(ierr);
+  PetscCall(MatDenseGetArray(R,&pR));
 
   if (S==R) {
-    ierr = BVAllocateWork_Private(bv,m*k);CHKERRQ(ierr);
+    PetscCall(BVAllocateWork_Private(bv,m*k));
     pS = bv->work;
     lds = ld;
     lds_ = ld_;
   } else {
-    ierr = MatDenseGetArray(S,&pS);CHKERRQ(ierr);
-    ierr = MatGetSize(S,&lds,NULL);CHKERRQ(ierr);
-    ierr = PetscBLASIntCast(lds,&lds_);CHKERRQ(ierr);
+    PetscCall(MatDenseGetArray(S,&pS));
+    PetscCall(MatGetSize(S,&lds,NULL));
+    PetscCall(PetscBLASIntCast(lds,&lds_));
   }
 
   /* compute S = inv(R) */
-  ierr = PetscFPTrapPush(PETSC_FP_TRAP_OFF);CHKERRQ(ierr);
+  PetscCall(PetscFPTrapPush(PETSC_FP_TRAP_OFF));
   if (S==R) {
     PetscStackCallBLAS("LAPACKtrtri",LAPACKtrtri_("U","N",&n_,pR+l*ld+l,&ld_,&info));
   } else {
-    ierr = PetscArrayzero(pS+l*lds,(k-l)*k);CHKERRQ(ierr);
-    for (i=l;i<k;i++) {
-      ierr = PetscArraycpy(pS+i*lds+l,pR+i*ld+l,n);CHKERRQ(ierr);
-    }
+    PetscCall(PetscArrayzero(pS+l*lds,(k-l)*k));
+    for (i=l;i<k;i++) PetscCall(PetscArraycpy(pS+i*lds+l,pR+i*ld+l,n));
     PetscStackCallBLAS("LAPACKtrtri",LAPACKtrtri_("U","N",&n_,pS+l*lds+l,&lds_,&info));
   }
   SlepcCheckLapackInfo("trtri",info);
-  ierr = PetscFPTrapPop();CHKERRQ(ierr);
-  ierr = PetscLogFlops(0.33*n*n*n);CHKERRQ(ierr);
+  PetscCall(PetscFPTrapPop());
+  PetscCall(PetscLogFlops(0.33*n*n*n));
 
-  ierr = MatDenseRestoreArray(R,&pR);CHKERRQ(ierr);
-  if (S!=R) { ierr = MatDenseRestoreArray(S,&pS);CHKERRQ(ierr); }
+  PetscCall(MatDenseRestoreArray(R,&pR));
+  if (S!=R) PetscCall(MatDenseRestoreArray(S,&pS));
   PetscFunctionReturn(0);
 }
 
@@ -270,7 +258,6 @@ PetscErrorCode BVMatTriInv_LAPACK_Private(BV bv,Mat R,Mat S)
  */
 PetscErrorCode BVMatSVQB_LAPACK_Private(BV bv,Mat R,Mat S)
 {
-  PetscErrorCode ierr;
   PetscInt       i,j,k,l,n,m,ld,lds;
   PetscScalar    *pR,*pS,*D,*work,a;
   PetscReal      *eig,dummy;
@@ -282,35 +269,35 @@ PetscErrorCode BVMatSVQB_LAPACK_Private(BV bv,Mat R,Mat S)
   PetscFunctionBegin;
   l = bv->l;
   k = bv->k;
-  ierr = MatGetSize(R,&m,NULL);CHKERRQ(ierr);
+  PetscCall(MatGetSize(R,&m,NULL));
+  PetscCall(MatDenseGetLDA(R,&ld));
   n = k-l;
-  ierr = PetscBLASIntCast(m,&m_);CHKERRQ(ierr);
-  ierr = PetscBLASIntCast(n,&n_);CHKERRQ(ierr);
-  ld  = m;
+  PetscCall(PetscBLASIntCast(m,&m_));
+  PetscCall(PetscBLASIntCast(n,&n_));
   ld_ = m_;
-  ierr = MatDenseGetArray(R,&pR);CHKERRQ(ierr);
+  PetscCall(MatDenseGetArray(R,&pR));
 
   if (S==R) {
     pS = pR;
     lds = ld;
     lds_ = ld_;
   } else {
-    ierr = MatDenseGetArray(S,&pS);CHKERRQ(ierr);
-    ierr = MatGetSize(S,&lds,NULL);CHKERRQ(ierr);
-    ierr = PetscBLASIntCast(lds,&lds_);CHKERRQ(ierr);
+    PetscCall(MatDenseGetArray(S,&pS));
+    PetscCall(MatDenseGetLDA(S,&lds));
+    PetscCall(PetscBLASIntCast(lds,&lds_));
   }
-  ierr = PetscFPTrapPush(PETSC_FP_TRAP_OFF);CHKERRQ(ierr);
+  PetscCall(PetscFPTrapPush(PETSC_FP_TRAP_OFF));
 
   /* workspace query and memory allocation */
   lwork = -1;
 #if defined(PETSC_USE_COMPLEX)
   PetscStackCallBLAS("LAPACKsyev",LAPACKsyev_("V","L",&n_,pS,&lds_,&dummy,&a,&lwork,&rdummy,&info));
-  ierr = PetscBLASIntCast((PetscInt)PetscRealPart(a),&lwork);CHKERRQ(ierr);
-  ierr = PetscMalloc4(n,&eig,n,&D,lwork,&work,PetscMax(1,3*n-2),&rwork);CHKERRQ(ierr);
+  PetscCall(PetscBLASIntCast((PetscInt)PetscRealPart(a),&lwork));
+  PetscCall(PetscMalloc4(n,&eig,n,&D,lwork,&work,PetscMax(1,3*n-2),&rwork));
 #else
   PetscStackCallBLAS("LAPACKsyev",LAPACKsyev_("V","L",&n_,pS,&lds_,&dummy,&a,&lwork,&info));
-  ierr = PetscBLASIntCast((PetscInt)a,&lwork);CHKERRQ(ierr);
-  ierr = PetscMalloc3(n,&eig,n,&D,lwork,&work);CHKERRQ(ierr);
+  PetscCall(PetscBLASIntCast((PetscInt)a,&lwork));
+  PetscCall(PetscMalloc3(n,&eig,n,&D,lwork,&work));
 #endif
 
   /* copy and scale matrix */
@@ -340,15 +327,15 @@ PetscErrorCode BVMatSVQB_LAPACK_Private(BV bv,Mat R,Mat S)
   }
 
 #if defined(PETSC_USE_COMPLEX)
-  ierr = PetscFree4(eig,D,work,rwork);CHKERRQ(ierr);
+  PetscCall(PetscFree4(eig,D,work,rwork));
 #else
-  ierr = PetscFree3(eig,D,work);CHKERRQ(ierr);
+  PetscCall(PetscFree3(eig,D,work));
 #endif
-  ierr = PetscLogFlops(9.0*n*n*n);CHKERRQ(ierr);
-  ierr = PetscFPTrapPop();CHKERRQ(ierr);
+  PetscCall(PetscLogFlops(9.0*n*n*n));
+  PetscCall(PetscFPTrapPop());
 
-  ierr = MatDenseRestoreArray(R,&pR);CHKERRQ(ierr);
-  if (S!=R) { ierr = MatDenseRestoreArray(S,&pS);CHKERRQ(ierr); }
+  PetscCall(MatDenseRestoreArray(R,&pR));
+  if (S!=R) PetscCall(MatDenseRestoreArray(S,&pS));
   PetscFunctionReturn(0);
 }
 
@@ -357,7 +344,6 @@ PetscErrorCode BVMatSVQB_LAPACK_Private(BV bv,Mat R,Mat S)
 */
 PetscErrorCode BVOrthogonalize_LAPACK_TSQR(BV bv,PetscInt m_,PetscInt n_,PetscScalar *Q,PetscScalar *R,PetscInt ldr)
 {
-  PetscErrorCode ierr;
   PetscInt       level,plevel,nlevels,powtwo,lda,worklen;
   PetscBLASInt   m,n,i,j,k,l,s = 0,nb,sz,lwork,info;
   PetscScalar    *tau,*work,*A=NULL,*QQ=NULL,*Qhalf,*C=NULL,one=1.0,zero=0.0;
@@ -365,22 +351,22 @@ PetscErrorCode BVOrthogonalize_LAPACK_TSQR(BV bv,PetscInt m_,PetscInt n_,PetscSc
   MPI_Datatype   tmat;
 
   PetscFunctionBegin;
-  ierr = PetscFPTrapPush(PETSC_FP_TRAP_OFF);CHKERRQ(ierr);
-  ierr = PetscBLASIntCast(m_,&m);CHKERRQ(ierr);
-  ierr = PetscBLASIntCast(n_,&n);CHKERRQ(ierr);
+  PetscCall(PetscFPTrapPush(PETSC_FP_TRAP_OFF));
+  PetscCall(PetscBLASIntCast(m_,&m));
+  PetscCall(PetscBLASIntCast(n_,&n));
   k  = PetscMin(m,n);
   nb = 16;
   lda = 2*n;
-  ierr = MPI_Comm_size(PetscObjectComm((PetscObject)bv),&size);CHKERRMPI(ierr);
-  ierr = MPI_Comm_rank(PetscObjectComm((PetscObject)bv),&rank);CHKERRMPI(ierr);
+  PetscCallMPI(MPI_Comm_size(PetscObjectComm((PetscObject)bv),&size));
+  PetscCallMPI(MPI_Comm_rank(PetscObjectComm((PetscObject)bv),&rank));
   nlevels = (PetscInt)PetscCeilReal(PetscLog2Real((PetscReal)size));
   powtwo  = PetscPowInt(2,(PetscInt)PetscFloorReal(PetscLog2Real((PetscReal)size)));
   worklen = n+n*nb;
   if (nlevels) worklen += n*lda+n*lda*nlevels+n*lda;
-  ierr = BVAllocateWork_Private(bv,worklen);CHKERRQ(ierr);
+  PetscCall(BVAllocateWork_Private(bv,worklen));
   tau  = bv->work;
   work = bv->work+n;
-  ierr = PetscBLASIntCast(n*nb,&lwork);CHKERRQ(ierr);
+  PetscCall(PetscBLASIntCast(n*nb,&lwork));
   if (nlevels) {
     A  = bv->work+n+n*nb;
     QQ = bv->work+n+n*nb+n*lda;
@@ -411,43 +397,43 @@ PetscErrorCode BVOrthogonalize_LAPACK_TSQR(BV bv,PetscInt m_,PetscInt n_,PetscSc
 
   if (nlevels) {
 
-    ierr = PetscMPIIntCast(n,&count);CHKERRQ(ierr);
-    ierr = PetscMPIIntCast(lda,&stride);CHKERRQ(ierr);
-    ierr = PetscBLASIntCast(lda,&l);CHKERRQ(ierr);
-    ierr = MPI_Type_vector(count,count,stride,MPIU_SCALAR,&tmat);CHKERRMPI(ierr);
-    ierr = MPI_Type_commit(&tmat);CHKERRMPI(ierr);
+    PetscCall(PetscMPIIntCast(n,&count));
+    PetscCall(PetscMPIIntCast(lda,&stride));
+    PetscCall(PetscBLASIntCast(lda,&l));
+    PetscCallMPI(MPI_Type_vector(count,count,stride,MPIU_SCALAR,&tmat));
+    PetscCallMPI(MPI_Type_commit(&tmat));
 
     for (level=nlevels;level>=1;level--) {
 
       plevel = PetscPowInt(2,level);
-      ierr = PetscBLASIntCast(plevel*PetscFloorReal(rank/(PetscReal)plevel)+(rank+PetscPowInt(2,level-1))%plevel,&s);CHKERRQ(ierr);
+      PetscCall(PetscBLASIntCast(plevel*PetscFloorReal(rank/(PetscReal)plevel)+(rank+PetscPowInt(2,level-1))%plevel,&s));
 
       /* Stack triangular matrices */
       if (rank<s && s<size) {  /* send top part, receive bottom part */
-        ierr = MPI_Sendrecv(A,1,tmat,s,111,A+n,1,tmat,s,111,PetscObjectComm((PetscObject)bv),MPI_STATUS_IGNORE);CHKERRMPI(ierr);
+        PetscCallMPI(MPI_Sendrecv(A,1,tmat,s,111,A+n,1,tmat,s,111,PetscObjectComm((PetscObject)bv),MPI_STATUS_IGNORE));
       } else if (s<size) {  /* copy top to bottom, receive top part */
-        ierr = MPI_Sendrecv(A,1,tmat,rank,111,A+n,1,tmat,rank,111,PetscObjectComm((PetscObject)bv),MPI_STATUS_IGNORE);CHKERRMPI(ierr);
-        ierr = MPI_Sendrecv(A+n,1,tmat,s,111,A,1,tmat,s,111,PetscObjectComm((PetscObject)bv),MPI_STATUS_IGNORE);CHKERRMPI(ierr);
+        PetscCallMPI(MPI_Sendrecv(A,1,tmat,rank,111,A+n,1,tmat,rank,111,PetscObjectComm((PetscObject)bv),MPI_STATUS_IGNORE));
+        PetscCallMPI(MPI_Sendrecv(A+n,1,tmat,s,111,A,1,tmat,s,111,PetscObjectComm((PetscObject)bv),MPI_STATUS_IGNORE));
       }
       if (level<nlevels && size!=powtwo) {  /* for cases when size is not a power of 2 */
         if (rank<size-powtwo) {  /* send bottom part */
-          ierr = MPI_Send(A+n,1,tmat,rank+powtwo,111,PetscObjectComm((PetscObject)bv));CHKERRMPI(ierr);
+          PetscCallMPI(MPI_Send(A+n,1,tmat,rank+powtwo,111,PetscObjectComm((PetscObject)bv)));
         } else if (rank>=powtwo) {  /* receive bottom part */
-          ierr = MPI_Recv(A+n,1,tmat,rank-powtwo,111,PetscObjectComm((PetscObject)bv),MPI_STATUS_IGNORE);CHKERRMPI(ierr);
+          PetscCallMPI(MPI_Recv(A+n,1,tmat,rank-powtwo,111,PetscObjectComm((PetscObject)bv),MPI_STATUS_IGNORE));
         }
       }
       /* Compute QR and build orthogonal matrix */
       if (level<nlevels || (level==nlevels && s<size)) {
         PetscStackCallBLAS("LAPACKgeqrf",LAPACKgeqrf_(&l,&n,A,&l,tau,work,&lwork,&info));
         SlepcCheckLapackInfo("geqrf",info);
-        ierr = PetscArraycpy(QQ+(level-1)*n*lda,A,n*lda);CHKERRQ(ierr);
+        PetscCall(PetscArraycpy(QQ+(level-1)*n*lda,A,n*lda));
         PetscStackCallBLAS("LAPACKorgqr",LAPACKorgqr_(&l,&n,&n,QQ+(level-1)*n*lda,&l,tau,work,&lwork,&info));
         SlepcCheckLapackInfo("orgqr",info);
         for (j=0;j<n;j++) {
           for (i=j+1;i<n;i++) A[i+j*lda] = 0.0;
         }
       } else if (level==nlevels) {  /* only one triangular matrix, set Q=I */
-        ierr = PetscArrayzero(QQ+(level-1)*n*lda,n*lda);CHKERRQ(ierr);
+        PetscCall(PetscArrayzero(QQ+(level-1)*n*lda,n*lda));
         for (j=0;j<n;j++) QQ[j+j*lda+(level-1)*n*lda] = 1.0;
       }
     }
@@ -463,29 +449,29 @@ PetscErrorCode BVOrthogonalize_LAPACK_TSQR(BV bv,PetscInt m_,PetscInt n_,PetscSc
     /* Accumulate orthogonal matrices */
     for (level=1;level<=nlevels;level++) {
       plevel = PetscPowInt(2,level);
-      ierr = PetscBLASIntCast(plevel*PetscFloorReal(rank/(PetscReal)plevel)+(rank+PetscPowInt(2,level-1))%plevel,&s);CHKERRQ(ierr);
+      PetscCall(PetscBLASIntCast(plevel*PetscFloorReal(rank/(PetscReal)plevel)+(rank+PetscPowInt(2,level-1))%plevel,&s));
       Qhalf = (rank<s)? QQ+(level-1)*n*lda: QQ+(level-1)*n*lda+n;
       if (level<nlevels) {
         PetscStackCallBLAS("BLASgemm",BLASgemm_("N","N",&l,&n,&n,&one,QQ+level*n*lda,&l,Qhalf,&l,&zero,C,&l));
-        ierr = PetscArraycpy(QQ+level*n*lda,C,n*lda);CHKERRQ(ierr);
+        PetscCall(PetscArraycpy(QQ+level*n*lda,C,n*lda));
       } else {
         for (i=0;i<m/l;i++) {
           PetscStackCallBLAS("BLASgemm",BLASgemm_("N","N",&l,&n,&n,&one,Q+i*l,&m,Qhalf,&l,&zero,C,&l));
-          for (j=0;j<n;j++) { ierr = PetscArraycpy(Q+i*l+j*m,C+j*l,l);CHKERRQ(ierr); }
+          for (j=0;j<n;j++) PetscCall(PetscArraycpy(Q+i*l+j*m,C+j*l,l));
         }
         sz = m%l;
         if (sz) {
           PetscStackCallBLAS("BLASgemm",BLASgemm_("N","N",&sz,&n,&n,&one,Q+(m/l)*l,&m,Qhalf,&l,&zero,C,&l));
-          for (j=0;j<n;j++) { ierr = PetscArraycpy(Q+(m/l)*l+j*m,C+j*l,sz);CHKERRQ(ierr); }
+          for (j=0;j<n;j++) PetscCall(PetscArraycpy(Q+(m/l)*l+j*m,C+j*l,sz));
         }
       }
     }
 
-    ierr = MPI_Type_free(&tmat);CHKERRMPI(ierr);
+    PetscCallMPI(MPI_Type_free(&tmat));
   }
 
-  ierr = PetscLogFlops(3.0*m*n*n);CHKERRQ(ierr);
-  ierr = PetscFPTrapPop();CHKERRQ(ierr);
+  PetscCall(PetscLogFlops(3.0*m*n*n));
+  PetscCall(PetscFPTrapPop());
   PetscFunctionReturn(0);
 }
 
@@ -495,14 +481,13 @@ PetscErrorCode BVOrthogonalize_LAPACK_TSQR(BV bv,PetscInt m_,PetscInt n_,PetscSc
 */
 SLEPC_EXTERN void MPIAPI SlepcGivensPacked(void *in,void *inout,PetscMPIInt *len,MPI_Datatype *datatype)
 {
-  PetscErrorCode ierr;
   PetscBLASInt   n,i,j,k,one=1;
   PetscMPIInt    tsize;
   PetscScalar    v,s,*R2=(PetscScalar*)in,*R1=(PetscScalar*)inout;
   PetscReal      c;
 
   PetscFunctionBegin;
-  ierr = MPI_Type_size(*datatype,&tsize);CHKERRABORT(PETSC_COMM_SELF,ierr);  /* we assume len=1 */
+  PetscCallAbort(PETSC_COMM_SELF,MPI_Type_size(*datatype,&tsize));  /* we assume len=1 */
   tsize /= sizeof(PetscScalar);
   n = (-1+(PetscBLASInt)PetscSqrtReal(1+8*tsize))/2;
   for (j=0;j<n;j++) {
@@ -521,7 +506,6 @@ SLEPC_EXTERN void MPIAPI SlepcGivensPacked(void *in,void *inout,PetscMPIInt *len
 */
 PetscErrorCode BVOrthogonalize_LAPACK_TSQR_OnlyR(BV bv,PetscInt m_,PetscInt n_,PetscScalar *Q,PetscScalar *R,PetscInt ldr)
 {
-  PetscErrorCode ierr;
   PetscInt       worklen;
   PetscBLASInt   m,n,i,j,s,nb,lwork,info;
   PetscScalar    *tau,*work,*A=NULL,*R1=NULL,*R2=NULL;
@@ -529,21 +513,21 @@ PetscErrorCode BVOrthogonalize_LAPACK_TSQR_OnlyR(BV bv,PetscInt m_,PetscInt n_,P
   MPI_Datatype   tmat;
 
   PetscFunctionBegin;
-  ierr = PetscFPTrapPush(PETSC_FP_TRAP_OFF);CHKERRQ(ierr);
-  ierr = PetscBLASIntCast(m_,&m);CHKERRQ(ierr);
-  ierr = PetscBLASIntCast(n_,&n);CHKERRQ(ierr);
+  PetscCall(PetscFPTrapPush(PETSC_FP_TRAP_OFF));
+  PetscCall(PetscBLASIntCast(m_,&m));
+  PetscCall(PetscBLASIntCast(n_,&n));
   nb = 16;
   s  = n+n*(n-1)/2;  /* length of packed triangular matrix */
-  ierr = MPI_Comm_size(PetscObjectComm((PetscObject)bv),&size);CHKERRMPI(ierr);
+  PetscCallMPI(MPI_Comm_size(PetscObjectComm((PetscObject)bv),&size));
   worklen = n+n*nb+2*s+m*n;
-  ierr = BVAllocateWork_Private(bv,worklen);CHKERRQ(ierr);
+  PetscCall(BVAllocateWork_Private(bv,worklen));
   tau  = bv->work;
   work = bv->work+n;
   R1   = bv->work+n+n*nb;
   R2   = bv->work+n+n*nb+s;
   A    = bv->work+n+n*nb+2*s;
-  ierr = PetscBLASIntCast(n*nb,&lwork);CHKERRQ(ierr);
-  ierr = PetscArraycpy(A,Q,m*n);CHKERRQ(ierr);
+  PetscCall(PetscBLASIntCast(n*nb,&lwork));
+  PetscCall(PetscArraycpy(A,Q,m*n));
 
   /* Compute QR */
   PetscStackCallBLAS("LAPACKgeqrf",LAPACKgeqrf_(&m,&n,A,&m,tau,work,&lwork,&info));
@@ -557,22 +541,21 @@ PetscErrorCode BVOrthogonalize_LAPACK_TSQR_OnlyR(BV bv,PetscInt m_,PetscInt n_,P
     }
   } else {
     /* Use MPI reduction operation to obtain global R */
-    ierr = PetscMPIIntCast(s,&count);CHKERRQ(ierr);
-    ierr = MPI_Type_contiguous(count,MPIU_SCALAR,&tmat);CHKERRMPI(ierr);
-    ierr = MPI_Type_commit(&tmat);CHKERRMPI(ierr);
+    PetscCall(PetscMPIIntCast(s,&count));
+    PetscCallMPI(MPI_Type_contiguous(count,MPIU_SCALAR,&tmat));
+    PetscCallMPI(MPI_Type_commit(&tmat));
     for (i=0;i<n;i++) {
       for (j=i;j<n;j++) R1[(2*n-i-1)*i/2+j] = (i<m)?A[i+j*m]:0.0;
     }
-    ierr = MPIU_Allreduce(R1,R2,1,tmat,MPIU_TSQR,PetscObjectComm((PetscObject)bv));CHKERRQ(ierr);
+    PetscCall(MPIU_Allreduce(R1,R2,1,tmat,MPIU_TSQR,PetscObjectComm((PetscObject)bv)));
     for (i=0;i<n;i++) {
       for (j=0;j<i;j++) R[i+j*ldr] = 0.0;
       for (j=i;j<n;j++) R[i+j*ldr] = R2[(2*n-i-1)*i/2+j];
     }
-    ierr = MPI_Type_free(&tmat);CHKERRMPI(ierr);
+    PetscCallMPI(MPI_Type_free(&tmat));
   }
 
-  ierr = PetscLogFlops(3.0*m*n*n);CHKERRQ(ierr);
-  ierr = PetscFPTrapPop();CHKERRQ(ierr);
+  PetscCall(PetscLogFlops(3.0*m*n*n));
+  PetscCall(PetscFPTrapPop());
   PetscFunctionReturn(0);
 }
-
