@@ -1,7 +1,7 @@
 /*
    - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
    SLEPc - Scalable Library for Eigenvalue Problem Computations
-   Copyright (c) 2002-2021, Universitat Politecnica de Valencia, Spain
+   Copyright (c) 2002-, Universitat Politecnica de Valencia, Spain
 
    This file is part of SLEPc.
    SLEPc is distributed under a 2-clause BSD license (see LICENSE).
@@ -19,19 +19,17 @@ typedef struct {
 
 PetscErrorCode DSAllocate_GSVD(DS ds,PetscInt ld)
 {
-  PetscErrorCode ierr;
-
   PetscFunctionBegin;
-  ierr = DSAllocateMat_Private(ds,DS_MAT_A);CHKERRQ(ierr);
-  ierr = DSAllocateMat_Private(ds,DS_MAT_B);CHKERRQ(ierr);
-  ierr = DSAllocateMat_Private(ds,DS_MAT_X);CHKERRQ(ierr);
-  ierr = DSAllocateMat_Private(ds,DS_MAT_U);CHKERRQ(ierr);
-  ierr = DSAllocateMat_Private(ds,DS_MAT_V);CHKERRQ(ierr);
-  ierr = DSAllocateMatReal_Private(ds,DS_MAT_T);CHKERRQ(ierr);
-  ierr = DSAllocateMatReal_Private(ds,DS_MAT_D);CHKERRQ(ierr);
-  ierr = PetscFree(ds->perm);CHKERRQ(ierr);
-  ierr = PetscMalloc1(ld,&ds->perm);CHKERRQ(ierr);
-  ierr = PetscLogObjectMemory((PetscObject)ds,ld*sizeof(PetscInt));CHKERRQ(ierr);
+  PetscCall(DSAllocateMat_Private(ds,DS_MAT_A));
+  PetscCall(DSAllocateMat_Private(ds,DS_MAT_B));
+  PetscCall(DSAllocateMat_Private(ds,DS_MAT_X));
+  PetscCall(DSAllocateMat_Private(ds,DS_MAT_U));
+  PetscCall(DSAllocateMat_Private(ds,DS_MAT_V));
+  PetscCall(DSAllocateMatReal_Private(ds,DS_MAT_T));
+  PetscCall(DSAllocateMatReal_Private(ds,DS_MAT_D));
+  PetscCall(PetscFree(ds->perm));
+  PetscCall(PetscMalloc1(ld,&ds->perm));
+  PetscCall(PetscLogObjectMemory((PetscObject)ds,ld*sizeof(PetscInt)));
   PetscFunctionReturn(0);
 }
 
@@ -93,60 +91,49 @@ p-1 |                                      x|
 */
 PetscErrorCode DSView_GSVD(DS ds,PetscViewer viewer)
 {
-  PetscErrorCode    ierr;
   DS_GSVD           *ctx = (DS_GSVD*)ds->data;
   PetscViewerFormat format;
   PetscInt          i,j,r,k=ds->k,n=ds->n,m=ctx->m,p=ctx->p,rowsa,rowsb,colsa,colsb;
   PetscReal         value;
 
   PetscFunctionBegin;
-  ierr = PetscViewerGetFormat(viewer,&format);CHKERRQ(ierr);
+  PetscCall(PetscViewerGetFormat(viewer,&format));
   if (format == PETSC_VIEWER_ASCII_INFO) PetscFunctionReturn(0);
   if (format == PETSC_VIEWER_ASCII_INFO_DETAIL) {
-    ierr = PetscViewerASCIIPrintf(viewer,"number of columns: %D\n",m);CHKERRQ(ierr);
-    ierr = PetscViewerASCIIPrintf(viewer,"number of rows of B: %D\n",p);CHKERRQ(ierr);
+    PetscCall(PetscViewerASCIIPrintf(viewer,"number of columns: %" PetscInt_FMT "\n",m));
+    PetscCall(PetscViewerASCIIPrintf(viewer,"number of rows of B: %" PetscInt_FMT "\n",p));
     PetscFunctionReturn(0);
   }
-  if (!ctx->m) SETERRQ(PetscObjectComm((PetscObject)ds),PETSC_ERR_ORDER,"You should set the other dimensions with DSGSVDSetDimensions()");
+  PetscCheck(ctx->m,PetscObjectComm((PetscObject)ds),PETSC_ERR_ORDER,"You should set the other dimensions with DSGSVDSetDimensions()");
   if (ds->compact) {
-    ierr = PetscViewerASCIIUseTabs(viewer,PETSC_FALSE);CHKERRQ(ierr);
+    PetscCall(PetscViewerASCIIUseTabs(viewer,PETSC_FALSE));
     rowsa = n;
     colsa = ds->extrarow? m+1: m;
     rowsb = p;
     colsb = ds->extrarow? m+1: m;
     if (format == PETSC_VIEWER_ASCII_MATLAB) {
-      ierr = PetscViewerASCIIPrintf(viewer,"%% Size = %D %D\n",rowsa,colsa);CHKERRQ(ierr);
-      ierr = PetscViewerASCIIPrintf(viewer,"zzz = zeros(%D,3);\n",2*ds->n);CHKERRQ(ierr);
-      ierr = PetscViewerASCIIPrintf(viewer,"zzz = [\n");CHKERRQ(ierr);
-      for (i=0;i<PetscMin(rowsa,colsa);i++) {
-        ierr = PetscViewerASCIIPrintf(viewer,"%D %D  %18.16e\n",i+1,i+1,(double)*(ds->rmat[DS_MAT_T]+i));CHKERRQ(ierr);
-      }
-      for (i=0;i<k;i++) {
-        ierr = PetscViewerASCIIPrintf(viewer,"%D %D  %18.16e\n",i+1,k+1,(double)*(ds->rmat[DS_MAT_T]+ds->ld+i));CHKERRQ(ierr);
-      }
+      PetscCall(PetscViewerASCIIPrintf(viewer,"%% Size = %" PetscInt_FMT " %" PetscInt_FMT "\n",rowsa,colsa));
+      PetscCall(PetscViewerASCIIPrintf(viewer,"zzz = zeros(%" PetscInt_FMT ",3);\n",2*ds->n));
+      PetscCall(PetscViewerASCIIPrintf(viewer,"zzz = [\n"));
+      for (i=0;i<PetscMin(rowsa,colsa);i++) PetscCall(PetscViewerASCIIPrintf(viewer,"%" PetscInt_FMT " %" PetscInt_FMT "  %18.16e\n",i+1,i+1,(double)*(ds->rmat[DS_MAT_T]+i)));
+      for (i=0;i<k;i++) PetscCall(PetscViewerASCIIPrintf(viewer,"%" PetscInt_FMT " %" PetscInt_FMT "  %18.16e\n",i+1,k+1,(double)*(ds->rmat[DS_MAT_T]+ds->ld+i)));
       if (n>m) { /* A lower bidiagonal */
-        for (i=k;i<rowsa-1;i++) {
-          ierr = PetscViewerASCIIPrintf(viewer,"%D %D  %18.16e\n",i+2,i+1,(double)*(ds->rmat[DS_MAT_T]+ds->ld+i));CHKERRQ(ierr);
-        }
+        for (i=k;i<rowsa-1;i++) PetscCall(PetscViewerASCIIPrintf(viewer,"%" PetscInt_FMT " %" PetscInt_FMT "  %18.16e\n",i+2,i+1,(double)*(ds->rmat[DS_MAT_T]+ds->ld+i)));
       } else { /* A (square) upper bidiagonal */
-        for (i=k;i<colsa-1;i++) {
-          ierr = PetscViewerASCIIPrintf(viewer,"%D %D  %18.16e\n",i+1,i+2,(double)*(ds->rmat[DS_MAT_T]+ds->ld+i));CHKERRQ(ierr);
-        }
-      }
-      ierr = PetscViewerASCIIPrintf(viewer,"];\n%s = spconvert(zzz);\n",DSMatName[DS_MAT_T]);CHKERRQ(ierr);
-      ierr = PetscViewerASCIIPrintf(viewer,"%% Size = %D %D\n",rowsb,colsb);CHKERRQ(ierr);
-      ierr = PetscViewerASCIIPrintf(viewer,"zzz = zeros(%D,3);\n",2*ds->n);CHKERRQ(ierr);
-      ierr = PetscViewerASCIIPrintf(viewer,"zzz = [\n");CHKERRQ(ierr);
-      for (i=0;i<rowsb;i++) {
-        ierr = PetscViewerASCIIPrintf(viewer,"%D %D  %18.16e\n",i+1,i+1,(double)*(ds->rmat[DS_MAT_D]+i));CHKERRQ(ierr);
+        for (i=k;i<colsa-1;i++) PetscCall(PetscViewerASCIIPrintf(viewer,"%" PetscInt_FMT " %" PetscInt_FMT "  %18.16e\n",i+1,i+2,(double)*(ds->rmat[DS_MAT_T]+ds->ld+i)));
       }
+      PetscCall(PetscViewerASCIIPrintf(viewer,"];\n%s = spconvert(zzz);\n",DSMatName[DS_MAT_T]));
+      PetscCall(PetscViewerASCIIPrintf(viewer,"%% Size = %" PetscInt_FMT " %" PetscInt_FMT "\n",rowsb,colsb));
+      PetscCall(PetscViewerASCIIPrintf(viewer,"zzz = zeros(%" PetscInt_FMT ",3);\n",2*ds->n));
+      PetscCall(PetscViewerASCIIPrintf(viewer,"zzz = [\n"));
+      for (i=0;i<rowsb;i++) PetscCall(PetscViewerASCIIPrintf(viewer,"%" PetscInt_FMT " %" PetscInt_FMT "  %18.16e\n",i+1,i+1,(double)*(ds->rmat[DS_MAT_D]+i)));
       for (i=0;i<colsb-1;i++) {
         r = PetscMax(i+2,ds->k+1);
-        ierr = PetscViewerASCIIPrintf(viewer,"%D %D  %18.16e\n",i+1,r,(double)*(ds->rmat[DS_MAT_T]+2*ds->ld+i));CHKERRQ(ierr);
+        PetscCall(PetscViewerASCIIPrintf(viewer,"%" PetscInt_FMT " %" PetscInt_FMT "  %18.16e\n",i+1,r,(double)*(ds->rmat[DS_MAT_T]+2*ds->ld+i)));
       }
-      ierr = PetscViewerASCIIPrintf(viewer,"];\n%s = spconvert(zzz);\n",DSMatName[DS_MAT_D]);CHKERRQ(ierr);
+      PetscCall(PetscViewerASCIIPrintf(viewer,"];\n%s = spconvert(zzz);\n",DSMatName[DS_MAT_D]));
     } else {
-      ierr = PetscViewerASCIIPrintf(viewer,"Matrix %s =\n",DSMatName[DS_MAT_T]);CHKERRQ(ierr);
+      PetscCall(PetscViewerASCIIPrintf(viewer,"Matrix %s =\n",DSMatName[DS_MAT_T]));
       for (i=0;i<rowsa;i++) {
         for (j=0;j<colsa;j++) {
           if (i==j) value = *(ds->rmat[DS_MAT_T]+i);
@@ -154,32 +141,32 @@ PetscErrorCode DSView_GSVD(DS ds,PetscViewer viewer)
           else if (n>m && i==j+1 && i>ds->k) value = *(ds->rmat[DS_MAT_T]+ds->ld+j);
           else if (n<=m && i+1==j && i>=ds->k) value = *(ds->rmat[DS_MAT_T]+ds->ld+i);
           else value = 0.0;
-          ierr = PetscViewerASCIIPrintf(viewer," %18.16e ",(double)value);CHKERRQ(ierr);
+          PetscCall(PetscViewerASCIIPrintf(viewer," %18.16e ",(double)value));
         }
-        ierr = PetscViewerASCIIPrintf(viewer,"\n");CHKERRQ(ierr);
+        PetscCall(PetscViewerASCIIPrintf(viewer,"\n"));
       }
-      ierr = PetscViewerASCIIPrintf(viewer,"Matrix %s =\n",DSMatName[DS_MAT_D]);CHKERRQ(ierr);
+      PetscCall(PetscViewerASCIIPrintf(viewer,"Matrix %s =\n",DSMatName[DS_MAT_D]));
       for (i=0;i<rowsb;i++) {
         for (j=0;j<colsb;j++) {
           if (i==j) value = *(ds->rmat[DS_MAT_D]+i);
           else if (i<ds->k && j==ds->k) value = *(ds->rmat[DS_MAT_T]+2*ds->ld+PetscMin(i,j));
           else if (i+1==j && i>=ds->k) value = *(ds->rmat[DS_MAT_T]+2*ds->ld+i);
           else value = 0.0;
-          ierr = PetscViewerASCIIPrintf(viewer," %18.16e ",(double)value);CHKERRQ(ierr);
+          PetscCall(PetscViewerASCIIPrintf(viewer," %18.16e ",(double)value));
         }
-        ierr = PetscViewerASCIIPrintf(viewer,"\n");CHKERRQ(ierr);
+        PetscCall(PetscViewerASCIIPrintf(viewer,"\n"));
       }
     }
-    ierr = PetscViewerASCIIUseTabs(viewer,PETSC_TRUE);CHKERRQ(ierr);
-    ierr = PetscViewerFlush(viewer);CHKERRQ(ierr);
+    PetscCall(PetscViewerASCIIUseTabs(viewer,PETSC_TRUE));
+    PetscCall(PetscViewerFlush(viewer));
   } else {
-    ierr = DSViewMat(ds,viewer,DS_MAT_A);CHKERRQ(ierr);
-    ierr = DSViewMat(ds,viewer,DS_MAT_B);CHKERRQ(ierr);
+    PetscCall(DSViewMat(ds,viewer,DS_MAT_A));
+    PetscCall(DSViewMat(ds,viewer,DS_MAT_B));
   }
   if (ds->state>DS_STATE_INTERMEDIATE) {
-    ierr = DSViewMat(ds,viewer,DS_MAT_X);CHKERRQ(ierr);
-    ierr = DSViewMat(ds,viewer,DS_MAT_U);CHKERRQ(ierr);
-    ierr = DSViewMat(ds,viewer,DS_MAT_V);CHKERRQ(ierr);
+    PetscCall(DSViewMat(ds,viewer,DS_MAT_X));
+    PetscCall(DSViewMat(ds,viewer,DS_MAT_U));
+    PetscCall(DSViewMat(ds,viewer,DS_MAT_V));
   }
   PetscFunctionReturn(0);
 }
@@ -202,20 +189,20 @@ PetscErrorCode DSVectors_GSVD(DS ds,DSMatType mat,PetscInt *j,PetscReal *rnorm)
 
 PetscErrorCode DSSort_GSVD(DS ds,PetscScalar *wr,PetscScalar *wi,PetscScalar *rr,PetscScalar *ri,PetscInt *k)
 {
-  PetscErrorCode ierr;
   DS_GSVD        *ctx = (DS_GSVD*)ds->data;
   PetscInt       t,l,ld=ds->ld,i,*perm,*perm2;
   PetscReal      *T=NULL,*D=NULL,*eig;
   PetscScalar    *A=NULL,*B=NULL;
+  PetscBool      compact=ds->compact;
 
   PetscFunctionBegin;
   if (!ds->sc) PetscFunctionReturn(0);
-  if (!ctx->m) SETERRQ(PetscObjectComm((PetscObject)ds),PETSC_ERR_ORDER,"You should set the other dimensions with DSGSVDSetDimensions()");
+  PetscCheck(ctx->m,PetscObjectComm((PetscObject)ds),PETSC_ERR_ORDER,"You should set the other dimensions with DSGSVDSetDimensions()");
   l = ds->l;
   t = ds->t;
   perm = ds->perm;
-  ierr = PetscMalloc2(t,&eig,t,&perm2);CHKERRQ(ierr);
-  if (ds->compact) {
+  PetscCall(PetscMalloc2(t,&eig,t,&perm2));
+  if (compact) {
     T = ds->rmat[DS_MAT_T];
     D = ds->rmat[DS_MAT_D];
     for (i=0;i<t;i++) eig[i] = (D[i]==0)?PETSC_INFINITY:T[i]/D[i];
@@ -224,13 +211,13 @@ PetscErrorCode DSSort_GSVD(DS ds,PetscScalar *wr,PetscScalar *wi,PetscScalar *rr
     B = ds->mat[DS_MAT_B];
     for (i=0;i<t;i++) eig[i] = (B[i+i*ld]==0)?PETSC_INFINITY:PetscRealPart(A[i+i*ld])/PetscRealPart(B[i*(1+ld)]);
   }
-  ierr = DSSortEigenvaluesReal_Private(ds,eig,perm);CHKERRQ(ierr);
-  ierr = PetscArraycpy(perm2,perm,t);CHKERRQ(ierr);
+  PetscCall(DSSortEigenvaluesReal_Private(ds,eig,perm));
+  PetscCall(PetscArraycpy(perm2,perm,t));
   for (i=l;i<t;i++) wr[i] = eig[perm[i]];
-  if (ds->compact) {
-    ierr = PetscArraycpy(eig,T,t);CHKERRQ(ierr);
+  if (compact) {
+    PetscCall(PetscArraycpy(eig,T,t));
     for (i=l;i<t;i++) T[i] = eig[perm[i]];
-    ierr = PetscArraycpy(eig,D,t);CHKERRQ(ierr);
+    PetscCall(PetscArraycpy(eig,D,t));
     for (i=l;i<t;i++) D[i] = eig[perm[i]];
   } else {
     for (i=l;i<t;i++) eig[i] = PetscRealPart(A[i*(1+ld)]);
@@ -238,17 +225,16 @@ PetscErrorCode DSSort_GSVD(DS ds,PetscScalar *wr,PetscScalar *wi,PetscScalar *rr
     for (i=l;i<t;i++) eig[i] = PetscRealPart(B[i*(1+ld)]);
     for (i=l;i<t;i++) B[i*(1+ld)] = eig[perm[i]];
   }
-  ierr = DSPermuteColumns_Private(ds,l,t,ds->n,DS_MAT_U,perm2);CHKERRQ(ierr);
-  ierr = PetscArraycpy(perm2,perm,t);CHKERRQ(ierr);
-  ierr = DSPermuteColumns_Private(ds,l,t,ctx->m,DS_MAT_X,perm2);CHKERRQ(ierr);
-  ierr = DSPermuteColumns_Private(ds,l,t,ctx->p,DS_MAT_V,perm);CHKERRQ(ierr);
-  ierr = PetscFree2(eig,perm2);CHKERRQ(ierr);
+  PetscCall(DSPermuteColumns_Private(ds,l,t,ds->n,DS_MAT_U,perm2));
+  PetscCall(PetscArraycpy(perm2,perm,t));
+  PetscCall(DSPermuteColumns_Private(ds,l,t,ctx->m,DS_MAT_X,perm2));
+  PetscCall(DSPermuteColumns_Private(ds,l,t,ctx->p,DS_MAT_V,perm));
+  PetscCall(PetscFree2(eig,perm2));
   PetscFunctionReturn(0);
 }
 
 PetscErrorCode DSUpdateExtraRow_GSVD(DS ds)
 {
-  PetscErrorCode ierr;
   DS_GSVD        *ctx = (DS_GSVD*)ds->data;
   PetscInt       i;
   PetscBLASInt   n=0,m=0,ld=0;
@@ -256,10 +242,10 @@ PetscErrorCode DSUpdateExtraRow_GSVD(DS ds)
   PetscReal      *T,*e,*f,alpha,beta,betah;
 
   PetscFunctionBegin;
-  if (!ctx->m) SETERRQ(PetscObjectComm((PetscObject)ds),PETSC_ERR_ORDER,"You should set the other dimensions with DSGSVDSetDimensions()");
-  ierr = PetscBLASIntCast(ds->n,&n);CHKERRQ(ierr);
-  ierr = PetscBLASIntCast(ctx->m,&m);CHKERRQ(ierr);
-  ierr = PetscBLASIntCast(ds->ld,&ld);CHKERRQ(ierr);
+  PetscCheck(ctx->m,PetscObjectComm((PetscObject)ds),PETSC_ERR_ORDER,"You should set the other dimensions with DSGSVDSetDimensions()");
+  PetscCall(PetscBLASIntCast(ds->n,&n));
+  PetscCall(PetscBLASIntCast(ctx->m,&m));
+  PetscCall(PetscBLASIntCast(ds->ld,&ld));
   U = ds->mat[DS_MAT_U];
   V = ds->mat[DS_MAT_V];
   T = ds->rmat[DS_MAT_T];
@@ -297,7 +283,7 @@ PetscErrorCode DSTruncate_GSVD(DS ds,PetscInt n,PetscBool trim)
   PetscBool   lower=(ds->n>ctx->m)?PETSC_TRUE:PETSC_FALSE;
 
   PetscFunctionBegin;
-  if (!ds->compact) SETERRQ(PetscObjectComm((PetscObject)ds),PETSC_ERR_SUP,"Not implemented for non-compact storage");
+  PetscCheck(ds->compact,PetscObjectComm((PetscObject)ds),PETSC_ERR_SUP,"Not implemented for non-compact storage");
   if (trim) {
     ds->l   = 0;
     ds->k   = 0;
@@ -327,7 +313,6 @@ PetscErrorCode DSTruncate_GSVD(DS ds,PetscInt n,PetscBool trim)
 
 static PetscErrorCode DSSwitchFormat_GSVD(DS ds)
 {
-  PetscErrorCode ierr;
   DS_GSVD        *ctx = (DS_GSVD*)ds->data;
   PetscReal      *T = ds->rmat[DS_MAT_T];
   PetscReal      *D = ds->rmat[DS_MAT_D];
@@ -336,11 +321,11 @@ static PetscErrorCode DSSwitchFormat_GSVD(DS ds)
   PetscInt       i,n=ds->n,k=ds->k,ld=ds->ld,m=ctx->m;
 
   PetscFunctionBegin;
-  if (!ctx->m) SETERRQ(PetscObjectComm((PetscObject)ds),PETSC_ERR_ORDER,"You should set the other dimensions with DSGSVDSetDimensions()");
+  PetscCheck(ctx->m,PetscObjectComm((PetscObject)ds),PETSC_ERR_ORDER,"You should set the other dimensions with DSGSVDSetDimensions()");
   /* switch from compact (arrow) to dense storage */
   /* bidiagonal associated to B is stored in D and T+2*ld */
-  ierr = PetscArrayzero(A,ld*ld);CHKERRQ(ierr);
-  ierr = PetscArrayzero(B,ld*ld);CHKERRQ(ierr);
+  PetscCall(PetscArrayzero(A,ld*ld));
+  PetscCall(PetscArrayzero(B,ld*ld));
   for (i=0;i<k;i++) {
     A[i+i*ld] = T[i];
     A[i+k*ld] = T[i+ld];
@@ -366,7 +351,6 @@ static PetscErrorCode DSSwitchFormat_GSVD(DS ds)
 */
 PetscErrorCode DSSolve_GSVD(DS ds,PetscScalar *wr,PetscScalar *wi)
 {
-  PetscErrorCode ierr;
   DS_GSVD        *ctx = (DS_GSVD*)ds->data;
   PetscInt       i,j;
   PetscBLASInt   n1,m1,info,lc = 0,n = 0,m = 0,p = 0,p1,l,k,q,ld,off,lwork,r;
@@ -379,16 +363,16 @@ PetscErrorCode DSSolve_GSVD(DS ds,PetscScalar *wr,PetscScalar *wi)
 #endif
 
   PetscFunctionBegin;
-  if (!ctx->m) SETERRQ(PetscObjectComm((PetscObject)ds),PETSC_ERR_ORDER,"You should set the other dimensions with DSGSVDSetDimensions()");
-  ierr = PetscBLASIntCast(ds->n,&m);CHKERRQ(ierr);
-  ierr = PetscBLASIntCast(ctx->m,&n);CHKERRQ(ierr);
-  ierr = PetscBLASIntCast(ctx->p,&p);CHKERRQ(ierr);
-  ierr = PetscBLASIntCast(ds->l,&lc);CHKERRQ(ierr);
+  PetscCheck(ctx->m,PetscObjectComm((PetscObject)ds),PETSC_ERR_ORDER,"You should set the other dimensions with DSGSVDSetDimensions()");
+  PetscCall(PetscBLASIntCast(ds->n,&m));
+  PetscCall(PetscBLASIntCast(ctx->m,&n));
+  PetscCall(PetscBLASIntCast(ctx->p,&p));
+  PetscCall(PetscBLASIntCast(ds->l,&lc));
   /* In compact storage B is always nxn and A can be either nxn or (n+1)xn */
   if (!ds->compact) {
-    if (lc!=0) SETERRQ(PetscObjectComm((PetscObject)ds),PETSC_ERR_SUP,"DSGSVD with non-compact format does not support locking");
-  } else if (p!=n || (m!=p && m!=p+1)) SETERRQ(PetscObjectComm((PetscObject)ds),PETSC_ERR_SUP,"Dimensions not supported in compact format");
-  ierr = PetscBLASIntCast(ds->ld,&ld);CHKERRQ(ierr);
+    PetscCheck(lc==0,PetscObjectComm((PetscObject)ds),PETSC_ERR_SUP,"DSGSVD with non-compact format does not support locking");
+  } else PetscCheck(p==n && (m==p || m==p+1),PetscObjectComm((PetscObject)ds),PETSC_ERR_SUP,"Dimensions not supported in compact format");
+  PetscCall(PetscBLASIntCast(ds->ld,&ld));
   n1 = n-lc;     /* n1 = size of leading block, excl. locked + size of trailing block */
   m1 = m-lc;
   p1 = p-lc;
@@ -398,63 +382,63 @@ PetscErrorCode DSSolve_GSVD(DS ds,PetscScalar *wr,PetscScalar *wi)
   X = ds->mat[DS_MAT_X];
   U = ds->mat[DS_MAT_U];
   V = ds->mat[DS_MAT_V];
-  ierr = PetscArrayzero(X,ld*ld);CHKERRQ(ierr);
+  PetscCall(PetscArrayzero(X,ld*ld));
   for (i=0;i<lc;i++) X[i+i*ld] = 1.0;
-  ierr = PetscArrayzero(U,ld*ld);CHKERRQ(ierr);
+  PetscCall(PetscArrayzero(U,ld*ld));
   for (i=0;i<lc;i++) U[i+i*ld] = 1.0;
-  ierr = PetscArrayzero(V,ld*ld);CHKERRQ(ierr);
+  PetscCall(PetscArrayzero(V,ld*ld));
   for (i=0;i<lc;i++) V[i+i*ld] = 1.0;
-  if (ds->compact) { ierr = DSSwitchFormat_GSVD(ds);CHKERRQ(ierr); }
+  if (ds->compact) PetscCall(DSSwitchFormat_GSVD(ds));
   T = ds->rmat[DS_MAT_T];
   D = ds->rmat[DS_MAT_D];
 
 #if !defined(SLEPC_MISSING_LAPACK_GGSVD3)
-  ierr = PetscFPTrapPush(PETSC_FP_TRAP_OFF);CHKERRQ(ierr);
+  PetscCall(PetscFPTrapPush(PETSC_FP_TRAP_OFF));
   /* workspace query and memory allocation */
   lwork = -1;
 #if !defined (PETSC_USE_COMPLEX)
   PetscStackCallBLAS("LAPACKggsvd3",LAPACKggsvd3_("U","V","Q",&m1,&n1,&p1,&k,&l,&dummy,&ld,&dummy,&ld,&rdummy,&rdummy,&dummy,&ld,&dummy,&ld,&dummy,&ld,&a,&lwork,&idummy,&info));
-  ierr = PetscBLASIntCast((PetscInt)a,&lwork);CHKERRQ(ierr);
+  PetscCall(PetscBLASIntCast((PetscInt)a,&lwork));
 #else
   PetscStackCallBLAS("LAPACKggsvd3",LAPACKggsvd3_("U","V","Q",&m1,&n1,&p1,&k,&l,&dummy,&ld,&dummy,&ld,&rdummy,&rdummy,&dummy,&ld,&dummy,&ld,&dummy,&ld,&a,&lwork,&rdummy,&idummy,&info));
-  ierr = PetscBLASIntCast((PetscInt)PetscRealPart(a),&lwork);CHKERRQ(ierr);
+  PetscCall(PetscBLASIntCast((PetscInt)PetscRealPart(a),&lwork));
 #endif
 
 #if !defined (PETSC_USE_COMPLEX)
-  ierr = DSAllocateWork_Private(ds,lwork,2*ds->ld,ds->ld);CHKERRQ(ierr);
+  PetscCall(DSAllocateWork_Private(ds,lwork,2*ds->ld,ds->ld));
   alpha = ds->rwork;
   beta  = ds->rwork+ds->ld;
   PetscStackCallBLAS("LAPACKggsvd3",LAPACKggsvd3_("U","V","Q",&m1,&n1,&p1,&k,&l,A+off,&ld,B+off,&ld,alpha,beta,U+off,&ld,V+off,&ld,X+off,&ld,ds->work,&lwork,ds->iwork,&info));
 #else
-  ierr = DSAllocateWork_Private(ds,lwork,4*ds->ld,ds->ld);CHKERRQ(ierr);
+  PetscCall(DSAllocateWork_Private(ds,lwork,4*ds->ld,ds->ld));
   alpha = ds->rwork+2*ds->ld;
   beta  = ds->rwork+3*ds->ld;
   PetscStackCallBLAS("LAPACKggsvd3",LAPACKggsvd3_("U","V","Q",&m1,&n1,&p1,&k,&l,A+off,&ld,B+off,&ld,alpha,beta,U+off,&ld,V+off,&ld,X+off,&ld,ds->work,&lwork,ds->rwork,ds->iwork,&info));
 #endif
-  ierr = PetscFPTrapPop();CHKERRQ(ierr);
+  PetscCall(PetscFPTrapPop());
   SlepcCheckLapackInfo("ggsvd3",info);
 
 #else  // defined(SLEPC_MISSING_LAPACK_GGSVD3)
 
   lwork = PetscMax(PetscMax(3*n,m),p)+n;
-  ierr = PetscFPTrapPush(PETSC_FP_TRAP_OFF);CHKERRQ(ierr);
+  PetscCall(PetscFPTrapPush(PETSC_FP_TRAP_OFF));
 #if !defined (PETSC_USE_COMPLEX)
-  ierr = DSAllocateWork_Private(ds,lwork,2*ds->ld,ds->ld);CHKERRQ(ierr);
+  PetscCall(DSAllocateWork_Private(ds,lwork,2*ds->ld,ds->ld));
   alpha = ds->rwork;
   beta  = ds->rwork+ds->ld;
   PetscStackCallBLAS("LAPACKggsvd",LAPACKggsvd_("U","V","Q",&m1,&n1,&p1,&k,&l,A+off,&ld,B+off,&ld,alpha,beta,U+off,&ld,V+off,&ld,X+off,&ld,ds->work,ds->iwork,&info));
 #else
-  ierr = DSAllocateWork_Private(ds,lwork,4*ds->ld,ds->ld);CHKERRQ(ierr);
+  PetscCall(DSAllocateWork_Private(ds,lwork,4*ds->ld,ds->ld));
   alpha = ds->rwork+2*ds->ld;
   beta  = ds->rwork+3*ds->ld;
   PetscStackCallBLAS("LAPACKggsvd",LAPACKggsvd_("U","V","Q",&m1,&n1,&p1,&k,&l,A+off,&ld,B+off,&ld,alpha,beta,U+off,&ld,V+off,&ld,X+off,&ld,ds->work,ds->rwork,ds->iwork,&info));
 #endif
-  ierr = PetscFPTrapPop();CHKERRQ(ierr);
+  PetscCall(PetscFPTrapPop());
   SlepcCheckLapackInfo("ggsvd",info);
 
 #endif
 
-  if (k+l<n1) SETERRQ(PetscObjectComm((PetscObject)ds),PETSC_ERR_SUP,"The rank deficient case not supported yet");
+  PetscCheck(k+l>=n1,PetscObjectComm((PetscObject)ds),PETSC_ERR_SUP,"The rank deficient case not supported yet");
   if (ds->compact) {
     /* R is the identity matrix (except the sign) */
     for (i=lc;i<n;i++) {
@@ -462,8 +446,8 @@ PetscErrorCode DSSolve_GSVD(DS ds,PetscScalar *wr,PetscScalar *wi)
         for (j=lc;j<n;j++) X[j+i*ld] = -X[j+i*ld];
       }
     }
-    ierr = PetscArrayzero(T+ld,m-1);CHKERRQ(ierr);
-    ierr = PetscArrayzero(T+2*ld,n-1);CHKERRQ(ierr);
+    PetscCall(PetscArrayzero(T+ld,m-1));
+    PetscCall(PetscArrayzero(T+2*ld,n-1));
     for (i=lc;i<n;i++) {
       T[i] = alpha[i-lc];
       D[i] = beta[i-lc];
@@ -482,13 +466,13 @@ PetscErrorCode DSSolve_GSVD(DS ds,PetscScalar *wr,PetscScalar *wi)
     }
     if (k>0) {
       for (i=k;i<PetscMin(m,k+l);i++) {
-        ierr = PetscArraycpy(X+(i-k)*ld,X+i*ld,ld);CHKERRQ(ierr);
-        ierr = PetscArraycpy(U+(i-k)*ld,U+i*ld,ld);CHKERRQ(ierr);
+        PetscCall(PetscArraycpy(X+(i-k)*ld,X+i*ld,ld));
+        PetscCall(PetscArraycpy(U+(i-k)*ld,U+i*ld,ld));
       }
     }
     /* singular values */
-    ierr = PetscArrayzero(A,ld*ld);CHKERRQ(ierr);
-    ierr = PetscArrayzero(B,ld*ld);CHKERRQ(ierr);
+    PetscCall(PetscArrayzero(A,ld*ld));
+    PetscCall(PetscArrayzero(B,ld*ld));
     for (j=k;j<PetscMin(m,k+l);j++) {
       A[(j-k)*(1+ld)] = alpha[j];
       B[(j-k)*(1+ld)] = beta[j];
@@ -501,7 +485,6 @@ PetscErrorCode DSSolve_GSVD(DS ds,PetscScalar *wr,PetscScalar *wi)
 
 PetscErrorCode DSSynchronize_GSVD(DS ds,PetscScalar eigr[],PetscScalar eigi[])
 {
-  PetscErrorCode ierr;
   DS_GSVD        *ctx = (DS_GSVD*)ds->data;
   PetscInt       ld=ds->ld,l=ds->l,k=0,kr=0;
   PetscMPIInt    m=ctx->m,rank,off=0,size,n,ldn,ld3;
@@ -511,41 +494,32 @@ PetscErrorCode DSSynchronize_GSVD(DS ds,PetscScalar eigr[],PetscScalar eigi[])
   else k = 2*(m-l)*ld;
   if (ds->state>DS_STATE_RAW) k += 3*(m-l)*ld;
   if (eigr) k += m-l;
-  ierr = DSAllocateWork_Private(ds,k+kr,0,0);CHKERRQ(ierr);
-  ierr = PetscMPIIntCast(k*sizeof(PetscScalar)+kr*sizeof(PetscReal),&size);CHKERRQ(ierr);
-  ierr = PetscMPIIntCast(m-l,&n);CHKERRQ(ierr);
-  ierr = PetscMPIIntCast(ld*(m-l),&ldn);CHKERRQ(ierr);
-  ierr = PetscMPIIntCast(3*ld,&ld3);CHKERRQ(ierr);
-  ierr = MPI_Comm_rank(PetscObjectComm((PetscObject)ds),&rank);CHKERRMPI(ierr);
+  PetscCall(DSAllocateWork_Private(ds,k+kr,0,0));
+  PetscCall(PetscMPIIntCast(k*sizeof(PetscScalar)+kr*sizeof(PetscReal),&size));
+  PetscCall(PetscMPIIntCast(m-l,&n));
+  PetscCall(PetscMPIIntCast(ld*(m-l),&ldn));
+  PetscCall(PetscMPIIntCast(3*ld,&ld3));
+  PetscCallMPI(MPI_Comm_rank(PetscObjectComm((PetscObject)ds),&rank));
   if (!rank) {
-    if (ds->compact) {
-      ierr = MPI_Pack(ds->rmat[DS_MAT_T],ld3,MPIU_REAL,ds->work,size,&off,PetscObjectComm((PetscObject)ds));CHKERRMPI(ierr);
-    } else {
-      ierr = MPI_Pack(ds->mat[DS_MAT_A]+l*ld,ldn,MPIU_SCALAR,ds->work,size,&off,PetscObjectComm((PetscObject)ds));CHKERRMPI(ierr);
-    }
+    if (ds->compact) PetscCallMPI(MPI_Pack(ds->rmat[DS_MAT_T],ld3,MPIU_REAL,ds->work,size,&off,PetscObjectComm((PetscObject)ds)));
+    else PetscCallMPI(MPI_Pack(ds->mat[DS_MAT_A]+l*ld,ldn,MPIU_SCALAR,ds->work,size,&off,PetscObjectComm((PetscObject)ds)));
     if (ds->state>DS_STATE_RAW) {
-      ierr = MPI_Pack(ds->mat[DS_MAT_U]+l*ld,ldn,MPIU_SCALAR,ds->work,size,&off,PetscObjectComm((PetscObject)ds));CHKERRMPI(ierr);
-      ierr = MPI_Pack(ds->mat[DS_MAT_V]+l*ld,ldn,MPIU_SCALAR,ds->work,size,&off,PetscObjectComm((PetscObject)ds));CHKERRMPI(ierr);
-      ierr = MPI_Pack(ds->mat[DS_MAT_X]+l*ld,ldn,MPIU_SCALAR,ds->work,size,&off,PetscObjectComm((PetscObject)ds));CHKERRMPI(ierr);
-    }
-    if (eigr) {
-      ierr = MPI_Pack(eigr+l,n,MPIU_SCALAR,ds->work,size,&off,PetscObjectComm((PetscObject)ds));CHKERRMPI(ierr);
+      PetscCallMPI(MPI_Pack(ds->mat[DS_MAT_U]+l*ld,ldn,MPIU_SCALAR,ds->work,size,&off,PetscObjectComm((PetscObject)ds)));
+      PetscCallMPI(MPI_Pack(ds->mat[DS_MAT_V]+l*ld,ldn,MPIU_SCALAR,ds->work,size,&off,PetscObjectComm((PetscObject)ds)));
+      PetscCallMPI(MPI_Pack(ds->mat[DS_MAT_X]+l*ld,ldn,MPIU_SCALAR,ds->work,size,&off,PetscObjectComm((PetscObject)ds)));
     }
+    if (eigr) PetscCallMPI(MPI_Pack(eigr+l,n,MPIU_SCALAR,ds->work,size,&off,PetscObjectComm((PetscObject)ds)));
   }
-  ierr = MPI_Bcast(ds->work,size,MPI_BYTE,0,PetscObjectComm((PetscObject)ds));CHKERRMPI(ierr);
+  PetscCallMPI(MPI_Bcast(ds->work,size,MPI_BYTE,0,PetscObjectComm((PetscObject)ds)));
   if (rank) {
-    if (ds->compact) {
-      ierr = MPI_Unpack(ds->work,size,&off,ds->rmat[DS_MAT_T],ld3,MPIU_REAL,PetscObjectComm((PetscObject)ds));CHKERRMPI(ierr);
-    } else {
-      ierr = MPI_Unpack(ds->work,size,&off,ds->mat[DS_MAT_A]+l*ld,ldn,MPIU_SCALAR,PetscObjectComm((PetscObject)ds));CHKERRMPI(ierr);
-    }
+    if (ds->compact) PetscCallMPI(MPI_Unpack(ds->work,size,&off,ds->rmat[DS_MAT_T],ld3,MPIU_REAL,PetscObjectComm((PetscObject)ds)));
+    else PetscCallMPI(MPI_Unpack(ds->work,size,&off,ds->mat[DS_MAT_A]+l*ld,ldn,MPIU_SCALAR,PetscObjectComm((PetscObject)ds)));
     if (ds->state>DS_STATE_RAW) {
-      ierr = MPI_Unpack(ds->work,size,&off,ds->mat[DS_MAT_U]+l*ld,ldn,MPIU_SCALAR,PetscObjectComm((PetscObject)ds));CHKERRMPI(ierr);
-      ierr = MPI_Unpack(ds->work,size,&off,ds->mat[DS_MAT_V]+l*ld,ldn,MPIU_SCALAR,PetscObjectComm((PetscObject)ds));CHKERRMPI(ierr);
-    }
-    if (eigr) {
-      ierr = MPI_Unpack(ds->work,size,&off,eigr+l,n,MPIU_SCALAR,PetscObjectComm((PetscObject)ds));CHKERRMPI(ierr);
+      PetscCallMPI(MPI_Unpack(ds->work,size,&off,ds->mat[DS_MAT_U]+l*ld,ldn,MPIU_SCALAR,PetscObjectComm((PetscObject)ds)));
+      PetscCallMPI(MPI_Unpack(ds->work,size,&off,ds->mat[DS_MAT_V]+l*ld,ldn,MPIU_SCALAR,PetscObjectComm((PetscObject)ds)));
+      PetscCallMPI(MPI_Unpack(ds->work,size,&off,ds->mat[DS_MAT_X]+l*ld,ldn,MPIU_SCALAR,PetscObjectComm((PetscObject)ds)));
     }
+    if (eigr) PetscCallMPI(MPI_Unpack(ds->work,size,&off,eigr+l,n,MPIU_SCALAR,PetscObjectComm((PetscObject)ds)));
   }
   PetscFunctionReturn(0);
 }
@@ -555,7 +529,7 @@ PetscErrorCode DSMatGetSize_GSVD(DS ds,DSMatType t,PetscInt *rows,PetscInt *cols
   DS_GSVD *ctx = (DS_GSVD*)ds->data;
 
   PetscFunctionBegin;
-  if (!ctx->m) SETERRQ(PetscObjectComm((PetscObject)ds),PETSC_ERR_ORDER,"You should set the other dimensions with DSGSVDSetDimensions()");
+  PetscCheck(ctx->m,PetscObjectComm((PetscObject)ds),PETSC_ERR_ORDER,"You should set the other dimensions with DSGSVDSetDimensions()");
   switch (t) {
     case DS_MAT_A:
       *rows = ds->n;
@@ -592,13 +566,13 @@ static PetscErrorCode DSGSVDSetDimensions_GSVD(DS ds,PetscInt m,PetscInt p)
   if (m==PETSC_DECIDE || m==PETSC_DEFAULT) {
     ctx->m = ds->ld;
   } else {
-    if (m<1 || m>ds->ld) SETERRQ(PetscObjectComm((PetscObject)ds),PETSC_ERR_ARG_OUTOFRANGE,"Illegal value of m. Must be between 1 and ld");
+    PetscCheck(m>0 && m<=ds->ld,PetscObjectComm((PetscObject)ds),PETSC_ERR_ARG_OUTOFRANGE,"Illegal value of m. Must be between 1 and ld");
     ctx->m = m;
   }
   if (p==PETSC_DECIDE || p==PETSC_DEFAULT) {
     ctx->p = ds->n;
   } else {
-    if (p<1 || p>ds->ld) SETERRQ(PetscObjectComm((PetscObject)ds),PETSC_ERR_ARG_OUTOFRANGE,"Illegal value of p. Must be between 1 and ld");
+    PetscCheck(p>0 && p<=ds->ld,PetscObjectComm((PetscObject)ds),PETSC_ERR_ARG_OUTOFRANGE,"Illegal value of p. Must be between 1 and ld");
     ctx->p = p;
   }
   PetscFunctionReturn(0);
@@ -625,13 +599,11 @@ static PetscErrorCode DSGSVDSetDimensions_GSVD(DS ds,PetscInt m,PetscInt p)
 @*/
 PetscErrorCode DSGSVDSetDimensions(DS ds,PetscInt m,PetscInt p)
 {
-  PetscErrorCode ierr;
-
   PetscFunctionBegin;
   PetscValidHeaderSpecific(ds,DS_CLASSID,1);
   PetscValidLogicalCollectiveInt(ds,m,2);
   PetscValidLogicalCollectiveInt(ds,p,3);
-  ierr = PetscTryMethod(ds,"DSGSVDSetDimensions_C",(DS,PetscInt,PetscInt),(ds,m,p));CHKERRQ(ierr);
+  PetscTryMethod(ds,"DSGSVDSetDimensions_C",(DS,PetscInt,PetscInt),(ds,m,p));
   PetscFunctionReturn(0);
 }
 
@@ -663,22 +635,18 @@ static PetscErrorCode DSGSVDGetDimensions_GSVD(DS ds,PetscInt *m,PetscInt *p)
 @*/
 PetscErrorCode DSGSVDGetDimensions(DS ds,PetscInt *m,PetscInt *p)
 {
-  PetscErrorCode ierr;
-
   PetscFunctionBegin;
   PetscValidHeaderSpecific(ds,DS_CLASSID,1);
-  ierr = PetscUseMethod(ds,"DSGSVDGetDimensions_C",(DS,PetscInt*,PetscInt*),(ds,m,p));CHKERRQ(ierr);
+  PetscUseMethod(ds,"DSGSVDGetDimensions_C",(DS,PetscInt*,PetscInt*),(ds,m,p));
   PetscFunctionReturn(0);
 }
 
 PetscErrorCode DSDestroy_GSVD(DS ds)
 {
-  PetscErrorCode ierr;
-
   PetscFunctionBegin;
-  ierr = PetscFree(ds->data);CHKERRQ(ierr);
-  ierr = PetscObjectComposeFunction((PetscObject)ds,"DSGSVDSetDimensions_C",NULL);CHKERRQ(ierr);
-  ierr = PetscObjectComposeFunction((PetscObject)ds,"DSGSVDGetDimensions_C",NULL);CHKERRQ(ierr);
+  PetscCall(PetscFree(ds->data));
+  PetscCall(PetscObjectComposeFunction((PetscObject)ds,"DSGSVDSetDimensions_C",NULL));
+  PetscCall(PetscObjectComposeFunction((PetscObject)ds,"DSGSVDGetDimensions_C",NULL));
   PetscFunctionReturn(0);
 }
 
@@ -728,10 +696,9 @@ M*/
 SLEPC_EXTERN PetscErrorCode DSCreate_GSVD(DS ds)
 {
   DS_GSVD        *ctx;
-  PetscErrorCode ierr;
 
   PetscFunctionBegin;
-  ierr = PetscNewLog(ds,&ctx);CHKERRQ(ierr);
+  PetscCall(PetscNewLog(ds,&ctx));
   ds->data = (void*)ctx;
 
   ds->ops->allocate      = DSAllocate_GSVD;
@@ -744,8 +711,7 @@ SLEPC_EXTERN PetscErrorCode DSCreate_GSVD(DS ds)
   ds->ops->update        = DSUpdateExtraRow_GSVD;
   ds->ops->matgetsize    = DSMatGetSize_GSVD;
   ds->ops->destroy       = DSDestroy_GSVD;
-  ierr = PetscObjectComposeFunction((PetscObject)ds,"DSGSVDSetDimensions_C",DSGSVDSetDimensions_GSVD);CHKERRQ(ierr);
-  ierr = PetscObjectComposeFunction((PetscObject)ds,"DSGSVDGetDimensions_C",DSGSVDGetDimensions_GSVD);CHKERRQ(ierr);
+  PetscCall(PetscObjectComposeFunction((PetscObject)ds,"DSGSVDSetDimensions_C",DSGSVDSetDimensions_GSVD));
+  PetscCall(PetscObjectComposeFunction((PetscObject)ds,"DSGSVDGetDimensions_C",DSGSVDGetDimensions_GSVD));
   PetscFunctionReturn(0);
 }
-
