@@ -1,7 +1,7 @@
 /*
    - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
    SLEPc - Scalable Library for Eigenvalue Problem Computations
-   Copyright (c) 2002-2021, Universitat Politecnica de Valencia, Spain
+   Copyright (c) 2002-, Universitat Politecnica de Valencia, Spain
 
    This file is part of SLEPc.
    SLEPc is distributed under a 2-clause BSD license (see LICENSE).
@@ -262,7 +262,6 @@ PetscErrorCode BDC_dsbtdc_(const char *jobz,const char *jobacc,PetscBLASInt n,
   PetscBLASInt   ldvt, ksum=0, kskp1, spneed, nrblks, liwmin, isvals;
   PetscReal      p, d2, eps, dmax, emax, done = 1.0;
   PetscReal      dnrm, tiny, anorm, exdnrm=0, dropsv, absdiff;
-  PetscErrorCode ierr;
 
   PetscFunctionBegin;
   /* Determine machine epsilon. */
@@ -297,7 +296,7 @@ PetscErrorCode BDC_dsbtdc_(const char *jobz,const char *jobacc,PetscBLASInt n,
     else if (liwork < liwmin) *info = -21;
   }
 
-  if (*info) SETERRQ1(PETSC_COMM_SELF,PETSC_ERR_ARG_WRONG,"Wrong argument %d in DSBTDC",-(*info));
+  PetscCheck(!*info,PETSC_COMM_SELF,PETSC_ERR_ARG_WRONG,"Wrong argument %" PetscBLASInt_FMT " in DSBTDC",-(*info));
 
   /* Quick return if possible */
 
@@ -549,7 +548,7 @@ L20:
       /* check whether there is enough workspace */
 
       spneed = 2*nk*nk + nk * 6 + 1;
-      if (spneed > lwork) SETERRQ1(PETSC_COMM_SELF,1,"dsbtdc: not enough workspace for DSYEVD, info = %d",lwork - 200 - spneed);
+      PetscCheck(spneed<=lwork,PETSC_COMM_SELF,PETSC_ERR_MEM,"dsbtdc: not enough workspace for DSYEVD, info = %" PetscBLASInt_FMT,lwork - 200 - spneed);
 
       PetscStackCallBLAS("LAPACKsyevd",LAPACKsyevd_("V", "L", &nk,
                     &z[np + np*ldz], &ldz, &ev[np],
@@ -609,11 +608,10 @@ L20:
     /* call the block-tridiagonal divide-and-conquer on the */
     /* irreducible subproblem which has been identified */
 
-    ierr = BDC_dibtdc_(jobz, nk, nrblks, &ksizes[start], &d[start*l1d*l2d], l1d, l2d,
+    PetscCall(BDC_dibtdc_(jobz, nk, nrblks, &ksizes[start], &d[start*l1d*l2d], l1d, l2d,
                 &e[start*l2e*l1e], &iwork[start], l1e, l2e, tau2, &ev[np],
-                &z[np + np*ldz], ldz, work, lwork, &iwork[nblks-1], liwork, info, 1);
-                CHKERRQ(ierr);
-    if (*info) SETERRQ1(PETSC_COMM_SELF,1,"dsbtdc: Error in DIBTDC, info = %d",*info);
+                &z[np + np*ldz], ldz, work, lwork, &iwork[nblks-1], liwork, info, 1));
+    PetscCheck(!*info,PETSC_COMM_SELF,PETSC_ERR_LIB,"dsbtdc: Error in DIBTDC, info = %" PetscBLASInt_FMT,*info);
 
 /* ************************************************************************** */
 
@@ -661,12 +659,12 @@ L20:
   /*    approximations).............................................. */
 
   *mingap = ev[1] - ev[0];
-  if (*mingap < 0.) SETERRQ2(PETSC_COMM_SELF,1,"dsbtdc: Eigenvalue approximations are not ordered properly. Approximation %d is larger than approximation %d.",1,2);
+  PetscCheck(*mingap>=0.,PETSC_COMM_SELF,PETSC_ERR_LIB,"dsbtdc: Eigenvalue approximations are not ordered properly. Approximation 1 is larger than approximation 2.");
   *mingapi = 1;
   for (i = 2; i < n; ++i) {
     absdiff = ev[i] - ev[i-1];
-    if (absdiff < 0.) SETERRQ2(PETSC_COMM_SELF,1,"dsbtdc: Eigenvalue approximations are not ordered properly. Approximation %d is larger than approximation %d.",i,i+1);
-    else if (absdiff < *mingap) {
+    PetscCheck(absdiff>=0.,PETSC_COMM_SELF,PETSC_ERR_LIB,"dsbtdc: Eigenvalue approximations are not ordered properly. Approximation %" PetscBLASInt_FMT " is larger than approximation %" PetscBLASInt_FMT ".",i,i+1);
+    if (absdiff < *mingap) {
       *mingap = absdiff;
       *mingapi = i;
     }
@@ -678,4 +676,3 @@ L20:
   if (*mingap <= tol / 10) *info = -103;
   PetscFunctionReturn(0);
 }
-
