@@ -1,7 +1,7 @@
 /*
    - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
    SLEPc - Scalable Library for Eigenvalue Problem Computations
-   Copyright (c) 2002-2021, Universitat Politecnica de Valencia, Spain
+   Copyright (c) 2002-, Universitat Politecnica de Valencia, Spain
 
    This file is part of SLEPc.
    SLEPc is distributed under a 2-clause BSD license (see LICENSE).
@@ -19,17 +19,12 @@ PetscErrorCode DSAllocateMatrix_Private(DS ds,DSMatType m,PetscBool isreal)
   size_t         sz;
   PetscInt       n,d,nelem;
   PetscBool      ispep,isnep;
-  PetscErrorCode ierr;
 
   PetscFunctionBegin;
-  ierr = PetscObjectTypeCompare((PetscObject)ds,DSPEP,&ispep);CHKERRQ(ierr);
-  ierr = PetscObjectTypeCompare((PetscObject)ds,DSNEP,&isnep);CHKERRQ(ierr);
-  if (ispep) {
-    ierr = DSPEPGetDegree(ds,&d);CHKERRQ(ierr);
-  }
-  if (isnep) {
-    ierr = DSNEPGetMinimality(ds,&d);CHKERRQ(ierr);
-  }
+  PetscCall(PetscObjectTypeCompare((PetscObject)ds,DSPEP,&ispep));
+  PetscCall(PetscObjectTypeCompare((PetscObject)ds,DSNEP,&isnep));
+  if (ispep) PetscCall(DSPEPGetDegree(ds,&d));
+  if (isnep) PetscCall(DSNEPGetMinimality(ds,&d));
   if ((ispep || isnep) && (m==DS_MAT_A || m==DS_MAT_B || m==DS_MAT_W || m==DS_MAT_U || m==DS_MAT_X || m==DS_MAT_Y)) n = d*ds->ld;
   else n = ds->ld;
 
@@ -51,45 +46,37 @@ PetscErrorCode DSAllocateMatrix_Private(DS ds,DSMatType m,PetscBool isreal)
   }
   if (isreal) {
     sz = nelem*sizeof(PetscReal);
-    if (ds->rmat[m]) {
-      ierr = PetscFree(ds->rmat[m]);CHKERRQ(ierr);
-    } else {
-      ierr = PetscLogObjectMemory((PetscObject)ds,sz);CHKERRQ(ierr);
-    }
-    ierr = PetscCalloc1(nelem,&ds->rmat[m]);CHKERRQ(ierr);
+    if (ds->rmat[m]) PetscCall(PetscFree(ds->rmat[m]));
+    else PetscCall(PetscLogObjectMemory((PetscObject)ds,sz));
+    PetscCall(PetscCalloc1(nelem,&ds->rmat[m]));
   } else {
     sz = nelem*sizeof(PetscScalar);
-    if (ds->mat[m]) {
-      ierr = PetscFree(ds->mat[m]);CHKERRQ(ierr);
-    } else {
-      ierr = PetscLogObjectMemory((PetscObject)ds,sz);CHKERRQ(ierr);
-    }
-    ierr = PetscCalloc1(nelem,&ds->mat[m]);CHKERRQ(ierr);
+    if (ds->mat[m]) PetscCall(PetscFree(ds->mat[m]));
+    else PetscCall(PetscLogObjectMemory((PetscObject)ds,sz));
+    PetscCall(PetscCalloc1(nelem,&ds->mat[m]));
   }
   PetscFunctionReturn(0);
 }
 
 PetscErrorCode DSAllocateWork_Private(DS ds,PetscInt s,PetscInt r,PetscInt i)
 {
-  PetscErrorCode ierr;
-
   PetscFunctionBegin;
   if (s>ds->lwork) {
-    ierr = PetscFree(ds->work);CHKERRQ(ierr);
-    ierr = PetscMalloc1(s,&ds->work);CHKERRQ(ierr);
-    ierr = PetscLogObjectMemory((PetscObject)ds,(s-ds->lwork)*sizeof(PetscScalar));CHKERRQ(ierr);
+    PetscCall(PetscFree(ds->work));
+    PetscCall(PetscMalloc1(s,&ds->work));
+    PetscCall(PetscLogObjectMemory((PetscObject)ds,(s-ds->lwork)*sizeof(PetscScalar)));
     ds->lwork = s;
   }
   if (r>ds->lrwork) {
-    ierr = PetscFree(ds->rwork);CHKERRQ(ierr);
-    ierr = PetscMalloc1(r,&ds->rwork);CHKERRQ(ierr);
-    ierr = PetscLogObjectMemory((PetscObject)ds,(r-ds->lrwork)*sizeof(PetscReal));CHKERRQ(ierr);
+    PetscCall(PetscFree(ds->rwork));
+    PetscCall(PetscMalloc1(r,&ds->rwork));
+    PetscCall(PetscLogObjectMemory((PetscObject)ds,(r-ds->lrwork)*sizeof(PetscReal)));
     ds->lrwork = r;
   }
   if (i>ds->liwork) {
-    ierr = PetscFree(ds->iwork);CHKERRQ(ierr);
-    ierr = PetscMalloc1(i,&ds->iwork);CHKERRQ(ierr);
-    ierr = PetscLogObjectMemory((PetscObject)ds,(i-ds->liwork)*sizeof(PetscBLASInt));CHKERRQ(ierr);
+    PetscCall(PetscFree(ds->iwork));
+    PetscCall(PetscMalloc1(i,&ds->iwork));
+    PetscCall(PetscLogObjectMemory((PetscObject)ds,(i-ds->liwork)*sizeof(PetscBLASInt)));
     ds->liwork = i;
   }
   PetscFunctionReturn(0);
@@ -115,7 +102,6 @@ PetscErrorCode DSAllocateWork_Private(DS ds,PetscInt s,PetscInt r,PetscInt i)
 @*/
 PetscErrorCode DSViewMat(DS ds,PetscViewer viewer,DSMatType m)
 {
-  PetscErrorCode    ierr;
   PetscInt          i,j,rows,cols;
   PetscScalar       *v;
   PetscViewerFormat format;
@@ -127,15 +113,13 @@ PetscErrorCode DSViewMat(DS ds,PetscViewer viewer,DSMatType m)
   PetscValidHeaderSpecific(ds,DS_CLASSID,1);
   PetscValidLogicalCollectiveEnum(ds,m,3);
   DSCheckValidMat(ds,m,3);
-  if (!viewer) {
-    ierr = PetscViewerASCIIGetStdout(PetscObjectComm((PetscObject)ds),&viewer);CHKERRQ(ierr);
-  }
+  if (!viewer) PetscCall(PetscViewerASCIIGetStdout(PetscObjectComm((PetscObject)ds),&viewer));
   PetscValidHeaderSpecific(viewer,PETSC_VIEWER_CLASSID,2);
   PetscCheckSameComm(ds,1,viewer,2);
-  ierr = PetscViewerGetFormat(viewer,&format);CHKERRQ(ierr);
+  PetscCall(PetscViewerGetFormat(viewer,&format));
   if (format == PETSC_VIEWER_ASCII_INFO || format == PETSC_VIEWER_ASCII_INFO_DETAIL) PetscFunctionReturn(0);
-  ierr = PetscViewerASCIIUseTabs(viewer,PETSC_FALSE);CHKERRQ(ierr);
-  ierr = DSMatGetSize(ds,m,&rows,&cols);CHKERRQ(ierr);
+  PetscCall(PetscViewerASCIIUseTabs(viewer,PETSC_FALSE));
+  PetscCall(DSMatGetSize(ds,m,&rows,&cols));
 #if defined(PETSC_USE_COMPLEX)
   /* determine if matrix has all real values */
   v = ds->mat[m];
@@ -144,40 +128,32 @@ PetscErrorCode DSViewMat(DS ds,PetscViewer viewer,DSMatType m)
       if (PetscImaginaryPart(v[i+j*ds->ld])) { allreal = PETSC_FALSE; break; }
 #endif
   if (format == PETSC_VIEWER_ASCII_MATLAB) {
-    ierr = PetscViewerASCIIPrintf(viewer,"%% Size = %D %D\n",rows,cols);CHKERRQ(ierr);
-    ierr = PetscViewerASCIIPrintf(viewer,"%s = [\n",DSMatName[m]);CHKERRQ(ierr);
-  } else {
-    ierr = PetscViewerASCIIPrintf(viewer,"Matrix %s =\n",DSMatName[m]);CHKERRQ(ierr);
-  }
+    PetscCall(PetscViewerASCIIPrintf(viewer,"%% Size = %" PetscInt_FMT " %" PetscInt_FMT "\n",rows,cols));
+    PetscCall(PetscViewerASCIIPrintf(viewer,"%s = [\n",DSMatName[m]));
+  } else PetscCall(PetscViewerASCIIPrintf(viewer,"Matrix %s =\n",DSMatName[m]));
 
   for (i=0;i<rows;i++) {
     v = ds->mat[m]+i;
     for (j=0;j<cols;j++) {
 #if defined(PETSC_USE_COMPLEX)
-      if (allreal) {
-        ierr = PetscViewerASCIIPrintf(viewer,"%18.16e ",(double)PetscRealPart(*v));CHKERRQ(ierr);
-      } else {
-        ierr = PetscViewerASCIIPrintf(viewer,"%18.16e%+18.16ei ",(double)PetscRealPart(*v),(double)PetscImaginaryPart(*v));CHKERRQ(ierr);
-      }
+      if (allreal) PetscCall(PetscViewerASCIIPrintf(viewer,"%18.16e ",(double)PetscRealPart(*v)));
+      else PetscCall(PetscViewerASCIIPrintf(viewer,"%18.16e%+18.16ei ",(double)PetscRealPart(*v),(double)PetscImaginaryPart(*v)));
 #else
-      ierr = PetscViewerASCIIPrintf(viewer,"%18.16e ",(double)*v);CHKERRQ(ierr);
+      PetscCall(PetscViewerASCIIPrintf(viewer,"%18.16e ",(double)*v));
 #endif
       v += ds->ld;
     }
-    ierr = PetscViewerASCIIPrintf(viewer,"\n");CHKERRQ(ierr);
+    PetscCall(PetscViewerASCIIPrintf(viewer,"\n"));
   }
 
-  if (format == PETSC_VIEWER_ASCII_MATLAB) {
-    ierr = PetscViewerASCIIPrintf(viewer,"];\n");CHKERRQ(ierr);
-  }
-  ierr = PetscViewerASCIIUseTabs(viewer,PETSC_TRUE);CHKERRQ(ierr);
-  ierr = PetscViewerFlush(viewer);CHKERRQ(ierr);
+  if (format == PETSC_VIEWER_ASCII_MATLAB) PetscCall(PetscViewerASCIIPrintf(viewer,"];\n"));
+  PetscCall(PetscViewerASCIIUseTabs(viewer,PETSC_TRUE));
+  PetscCall(PetscViewerFlush(viewer));
   PetscFunctionReturn(0);
 }
 
 PetscErrorCode DSSortEigenvalues_Private(DS ds,PetscScalar *wr,PetscScalar *wi,PetscInt *perm,PetscBool isghiep)
 {
-  PetscErrorCode ierr;
   PetscScalar    re,im,wi0;
   PetscInt       n,i,j,result,tmp1,tmp2=0,d=1;
 
@@ -205,7 +181,7 @@ PetscErrorCode DSSortEigenvalues_Private(DS ds,PetscScalar *wr,PetscScalar *wi,P
     j = i-1;
     if (wi) wi0 = wi[perm[j]];
     else wi0 = 0.0;
-    ierr = SlepcSCCompare(ds->sc,re,im,wr[perm[j]],wi0,&result);CHKERRQ(ierr);
+    PetscCall(SlepcSCCompare(ds->sc,re,im,wr[perm[j]],wi0,&result));
     while (result<0 && j>=ds->l) {
       perm[j+d] = perm[j];
       j--;
@@ -219,7 +195,7 @@ PetscErrorCode DSSortEigenvalues_Private(DS ds,PetscScalar *wr,PetscScalar *wi,P
       if (j>=ds->l) {
         if (wi) wi0 = wi[perm[j]];
         else wi0 = 0.0;
-        ierr = SlepcSCCompare(ds->sc,re,im,wr[perm[j]],wi0,&result);CHKERRQ(ierr);
+        PetscCall(SlepcSCCompare(ds->sc,re,im,wr[perm[j]],wi0,&result));
       }
     }
     perm[j+1] = tmp1;
@@ -230,7 +206,6 @@ PetscErrorCode DSSortEigenvalues_Private(DS ds,PetscScalar *wr,PetscScalar *wi,P
 
 PetscErrorCode DSSortEigenvaluesReal_Private(DS ds,PetscReal *eig,PetscInt *perm)
 {
-  PetscErrorCode ierr;
   PetscScalar    re;
   PetscInt       i,j,result,tmp,l,n;
 
@@ -241,12 +216,10 @@ PetscErrorCode DSSortEigenvaluesReal_Private(DS ds,PetscReal *eig,PetscInt *perm
   for (i=l+1;i<n;i++) {
     re = eig[perm[i]];
     j = i-1;
-    ierr = SlepcSCCompare(ds->sc,re,0.0,eig[perm[j]],0.0,&result);CHKERRQ(ierr);
+    PetscCall(SlepcSCCompare(ds->sc,re,0.0,eig[perm[j]],0.0,&result));
     while (result<0 && j>=l) {
       tmp = perm[j]; perm[j] = perm[j+1]; perm[j+1] = tmp; j--;
-      if (j>=l) {
-        ierr = SlepcSCCompare(ds->sc,re,0.0,eig[perm[j]],0.0,&result);CHKERRQ(ierr);
-      }
+      if (j>=l) PetscCall(SlepcSCCompare(ds->sc,re,0.0,eig[perm[j]],0.0,&result));
     }
   }
   PetscFunctionReturn(0);
@@ -258,7 +231,6 @@ PetscErrorCode DSSortEigenvaluesReal_Private(DS ds,PetscReal *eig,PetscInt *perm
 */
 PetscErrorCode DSCopyMatrix_Private(DS ds,DSMatType dst,DSMatType src)
 {
-  PetscErrorCode ierr;
   PetscInt    j,m,off,ld;
   PetscScalar *S,*D;
 
@@ -268,9 +240,7 @@ PetscErrorCode DSCopyMatrix_Private(DS ds,DSMatType dst,DSMatType src)
   off = ds->l+ds->l*ld;
   S   = ds->mat[src];
   D   = ds->mat[dst];
-  for (j=0;j<m;j++) {
-    ierr = PetscArraycpy(D+off+j*ld,S+off+j*ld,m);CHKERRQ(ierr);
-  }
+  for (j=0;j<m;j++) PetscCall(PetscArraycpy(D+off+j*ld,S+off+j*ld,m));
   PetscFunctionReturn(0);
 }
 
@@ -397,10 +367,11 @@ PetscErrorCode DSPermuteBoth_Private(DS ds,PetscInt istart,PetscInt iend,PetscIn
 -  mat - the matrix to modify
 
    Level: intermediate
+
+.seealso: DSGetMat()
 @*/
 PetscErrorCode DSSetIdentity(DS ds,DSMatType mat)
 {
-  PetscErrorCode ierr;
   PetscScalar    *x;
   PetscInt       i,ld,n,l;
 
@@ -409,14 +380,14 @@ PetscErrorCode DSSetIdentity(DS ds,DSMatType mat)
   PetscValidLogicalCollectiveEnum(ds,mat,2);
   DSCheckValidMat(ds,mat,2);
 
-  ierr = DSGetDimensions(ds,&n,&l,NULL,NULL);CHKERRQ(ierr);
-  ierr = DSGetLeadingDimension(ds,&ld);CHKERRQ(ierr);
-  ierr = PetscLogEventBegin(DS_Other,ds,0,0,0);CHKERRQ(ierr);
-  ierr = DSGetArray(ds,mat,&x);CHKERRQ(ierr);
-  ierr = PetscArrayzero(&x[ld*l],ld*(n-l));CHKERRQ(ierr);
+  PetscCall(DSGetDimensions(ds,&n,&l,NULL,NULL));
+  PetscCall(DSGetLeadingDimension(ds,&ld));
+  PetscCall(PetscLogEventBegin(DS_Other,ds,0,0,0));
+  PetscCall(DSGetArray(ds,mat,&x));
+  PetscCall(PetscArrayzero(&x[ld*l],ld*(n-l)));
   for (i=l;i<n;i++) x[i+i*ld] = 1.0;
-  ierr = DSRestoreArray(ds,mat,&x);CHKERRQ(ierr);
-  ierr = PetscLogEventEnd(DS_Other,ds,0,0,0);CHKERRQ(ierr);
+  PetscCall(DSRestoreArray(ds,mat,&x));
+  PetscCall(PetscLogEventEnd(DS_Other,ds,0,0,0));
   PetscFunctionReturn(0);
 }
 
@@ -439,7 +410,6 @@ PetscErrorCode DSSetIdentity(DS ds,DSMatType mat)
 @*/
 PetscErrorCode DSOrthogonalize(DS ds,DSMatType mat,PetscInt cols,PetscInt *lindcols)
 {
-  PetscErrorCode ierr;
   PetscInt       n,l,ld;
   PetscBLASInt   ld_,rA,cA,info,ltau,lw;
   PetscScalar    *A,*tau,*w,saux,dummy;
@@ -451,24 +421,24 @@ PetscErrorCode DSOrthogonalize(DS ds,DSMatType mat,PetscInt cols,PetscInt *lindc
   DSCheckValidMat(ds,mat,2);
   PetscValidLogicalCollectiveInt(ds,cols,3);
 
-  ierr = DSGetDimensions(ds,&n,&l,NULL,NULL);CHKERRQ(ierr);
-  ierr = DSGetLeadingDimension(ds,&ld);CHKERRQ(ierr);
+  PetscCall(DSGetDimensions(ds,&n,&l,NULL,NULL));
+  PetscCall(DSGetLeadingDimension(ds,&ld));
   n = n - l;
-  if (cols > n) SETERRQ(PetscObjectComm((PetscObject)ds),PETSC_ERR_ARG_WRONG,"Invalid number of columns");
+  PetscCheck(cols<=n,PetscObjectComm((PetscObject)ds),PETSC_ERR_ARG_WRONG,"Invalid number of columns");
   if (n == 0 || cols == 0) PetscFunctionReturn(0);
 
-  ierr = PetscLogEventBegin(DS_Other,ds,0,0,0);CHKERRQ(ierr);
-  ierr = PetscFPTrapPush(PETSC_FP_TRAP_OFF);CHKERRQ(ierr);
-  ierr = DSGetArray(ds,mat,&A);CHKERRQ(ierr);
-  ierr = PetscBLASIntCast(PetscMin(cols,n),&ltau);CHKERRQ(ierr);
-  ierr = PetscBLASIntCast(ld,&ld_);CHKERRQ(ierr);
-  ierr = PetscBLASIntCast(n,&rA);CHKERRQ(ierr);
-  ierr = PetscBLASIntCast(cols,&cA);CHKERRQ(ierr);
+  PetscCall(PetscLogEventBegin(DS_Other,ds,0,0,0));
+  PetscCall(PetscFPTrapPush(PETSC_FP_TRAP_OFF));
+  PetscCall(DSGetArray(ds,mat,&A));
+  PetscCall(PetscBLASIntCast(PetscMin(cols,n),&ltau));
+  PetscCall(PetscBLASIntCast(ld,&ld_));
+  PetscCall(PetscBLASIntCast(n,&rA));
+  PetscCall(PetscBLASIntCast(cols,&cA));
   lw = -1;
   PetscStackCallBLAS("LAPACKgeqrf",LAPACKgeqrf_(&rA,&cA,A,&ld_,&dummy,&saux,&lw,&info));
   SlepcCheckLapackInfo("geqrf",info);
   lw = (PetscBLASInt)PetscRealPart(saux);
-  ierr = DSAllocateWork_Private(ds,lw+ltau,0,0);CHKERRQ(ierr);
+  PetscCall(DSAllocateWork_Private(ds,lw+ltau,0,0));
   tau = ds->work;
   w = &tau[ltau];
   PetscStackCallBLAS("LAPACKgeqrf",LAPACKgeqrf_(&rA,&cA,&A[ld*l+l],&ld_,tau,w,&lw,&info));
@@ -477,10 +447,10 @@ PetscErrorCode DSOrthogonalize(DS ds,DSMatType mat,PetscInt cols,PetscInt *lindc
   SlepcCheckLapackInfo("orgqr",info);
   if (lindcols) *lindcols = ltau;
 
-  ierr = PetscFPTrapPop();CHKERRQ(ierr);
-  ierr = PetscLogEventEnd(DS_Other,ds,0,0,0);CHKERRQ(ierr);
-  ierr = DSRestoreArray(ds,mat,&A);CHKERRQ(ierr);
-  ierr = PetscObjectStateIncrease((PetscObject)ds);CHKERRQ(ierr);
+  PetscCall(PetscFPTrapPop());
+  PetscCall(PetscLogEventEnd(DS_Other,ds,0,0,0));
+  PetscCall(DSRestoreArray(ds,mat,&A));
+  PetscCall(PetscObjectStateIncrease((PetscObject)ds));
   PetscFunctionReturn(0);
 }
 
@@ -496,7 +466,6 @@ PetscErrorCode DSOrthogonalize(DS ds,DSMatType mat,PetscInt cols,PetscInt *lindc
 */
 static PetscErrorCode SlepcMatDenseMult(PetscScalar *C,PetscInt _ldC,PetscScalar b,PetscScalar a,const PetscScalar *A,PetscInt _ldA,PetscInt rA,PetscInt cA,PetscBool At,const PetscScalar *B,PetscInt _ldB,PetscInt rB,PetscInt cB,PetscBool Bt)
 {
-  PetscErrorCode ierr;
   PetscInt       tmp;
   PetscBLASInt   m, n, k, ldA = _ldA, ldB = _ldB, ldC = _ldC;
   const char     *N = "N", *T = "C", *qA = N, *qB = N;
@@ -512,7 +481,7 @@ static PetscErrorCode SlepcMatDenseMult(PetscScalar *C,PetscInt _ldC,PetscScalar
   if (Bt) tmp = rB, rB = cB, cB = tmp, qB = T;
 
   /* Check size */
-  if (cA != rB) SETERRQ(PETSC_COMM_SELF,PETSC_ERR_PLIB,"Matrix dimensions do not match");
+  PetscCheck(cA==rB,PETSC_COMM_SELF,PETSC_ERR_PLIB,"Matrix dimensions do not match");
 
   /* Do stub */
   if ((rA == 1) && (cA == 1) && (cB == 1)) {
@@ -526,7 +495,7 @@ static PetscErrorCode SlepcMatDenseMult(PetscScalar *C,PetscInt _ldC,PetscScalar
     PetscStackCallBLAS("BLASgemm",BLASgemm_(qA,qB,&m,&n,&k,&a,(PetscScalar*)A,&ldA,(PetscScalar*)B,&ldB,&b,C,&ldC));
   }
 
-  ierr = PetscLogFlops(2.0*m*n*k);CHKERRQ(ierr);
+  PetscCall(PetscLogFlops(2.0*m*n*k));
   PetscFunctionReturn(0);
 }
 
@@ -555,7 +524,6 @@ static PetscErrorCode SlepcMatDenseMult(PetscScalar *C,PetscInt _ldC,PetscScalar
 @*/
 PetscErrorCode DSPseudoOrthogonalize(DS ds,DSMatType mat,PetscInt cols,PetscReal *s,PetscInt *lindcols,PetscReal *ns)
 {
-  PetscErrorCode ierr;
   PetscInt       i,j,k,l,n,ld;
   PetscBLASInt   info,one=1,zero=0,rA_,ld_;
   PetscScalar    *A,*A_,*m,*h,nr0;
@@ -568,39 +536,39 @@ PetscErrorCode DSPseudoOrthogonalize(DS ds,DSMatType mat,PetscInt cols,PetscReal
   DSCheckValidMat(ds,mat,2);
   PetscValidLogicalCollectiveInt(ds,cols,3);
   PetscValidRealPointer(s,4);
-  ierr = DSGetDimensions(ds,&n,&l,NULL,NULL);CHKERRQ(ierr);
-  ierr = DSGetLeadingDimension(ds,&ld);CHKERRQ(ierr);
+  PetscCall(DSGetDimensions(ds,&n,&l,NULL,NULL));
+  PetscCall(DSGetLeadingDimension(ds,&ld));
   n = n - l;
-  if (cols > n) SETERRQ(PetscObjectComm((PetscObject)ds),PETSC_ERR_ARG_WRONG,"Invalid number of columns");
+  PetscCheck(cols<=n,PetscObjectComm((PetscObject)ds),PETSC_ERR_ARG_WRONG,"Invalid number of columns");
   if (n == 0 || cols == 0) PetscFunctionReturn(0);
-  ierr = PetscBLASIntCast(n,&rA_);CHKERRQ(ierr);
-  ierr = PetscBLASIntCast(ld,&ld_);CHKERRQ(ierr);
-  ierr = DSGetArray(ds,mat,&A_);CHKERRQ(ierr);
+  PetscCall(PetscBLASIntCast(n,&rA_));
+  PetscCall(PetscBLASIntCast(ld,&ld_));
+  PetscCall(DSGetArray(ds,mat,&A_));
   A = &A_[ld*l+l];
-  ierr = DSAllocateWork_Private(ds,n+cols,ns?0:cols,0);CHKERRQ(ierr);
+  PetscCall(DSAllocateWork_Private(ds,n+cols,ns?0:cols,0));
   m = ds->work;
   h = &m[n];
   ns_ = ns ? ns : ds->rwork;
-  ierr = PetscLogEventBegin(DS_Other,ds,0,0,0);CHKERRQ(ierr);
+  PetscCall(PetscLogEventBegin(DS_Other,ds,0,0,0));
   for (i=0; i<cols; i++) {
     /* m <- diag(s)*A[i] */
     for (k=0; k<n; k++) m[k] = s[k]*A[k+i*ld];
     /* nr_o <- mynorm(A[i]'*m), mynorm(x) = sign(x)*sqrt(|x|) */
-    ierr = SlepcMatDenseMult(&nr0,1,0.0,1.0,&A[ld*i],ld,n,1,PETSC_TRUE,m,n,n,1,PETSC_FALSE);CHKERRQ(ierr);
+    PetscCall(SlepcMatDenseMult(&nr0,1,0.0,1.0,&A[ld*i],ld,n,1,PETSC_TRUE,m,n,n,1,PETSC_FALSE));
     nr = nr_o = PetscSign(PetscRealPart(nr0))*PetscSqrtReal(PetscAbsScalar(nr0));
     for (j=0; j<3 && i>0; j++) {
       /* h <- A[0:i-1]'*m */
-      ierr = SlepcMatDenseMult(h,i,0.0,1.0,A,ld,n,i,PETSC_TRUE,m,n,n,1,PETSC_FALSE);CHKERRQ(ierr);
+      PetscCall(SlepcMatDenseMult(h,i,0.0,1.0,A,ld,n,i,PETSC_TRUE,m,n,n,1,PETSC_FALSE));
       /* h <- diag(ns)*h */
       for (k=0; k<i; k++) h[k] *= ns_[k];
       /* A[i] <- A[i] - A[0:i-1]*h */
-      ierr = SlepcMatDenseMult(&A[ld*i],ld,1.0,-1.0,A,ld,n,i,PETSC_FALSE,h,i,i,1,PETSC_FALSE);CHKERRQ(ierr);
+      PetscCall(SlepcMatDenseMult(&A[ld*i],ld,1.0,-1.0,A,ld,n,i,PETSC_FALSE,h,i,i,1,PETSC_FALSE));
       /* m <- diag(s)*A[i] */
       for (k=0; k<n; k++) m[k] = s[k]*A[k+i*ld];
       /* nr_o <- mynorm(A[i]'*m) */
-      ierr = SlepcMatDenseMult(&nr0,1,0.0,1.0,&A[ld*i],ld,n,1,PETSC_TRUE,m,n,n,1,PETSC_FALSE);CHKERRQ(ierr);
+      PetscCall(SlepcMatDenseMult(&nr0,1,0.0,1.0,&A[ld*i],ld,n,1,PETSC_TRUE,m,n,n,1,PETSC_FALSE));
       nr = PetscSign(PetscRealPart(nr0))*PetscSqrtReal(PetscAbsScalar(nr0));
-      if (PetscAbs(nr) < PETSC_MACHINE_EPSILON) SETERRQ(PETSC_COMM_SELF,PETSC_ERR_CONV_FAILED,"Linear dependency detected");
+      PetscCheck(PetscAbs(nr)>PETSC_MACHINE_EPSILON,PETSC_COMM_SELF,PETSC_ERR_CONV_FAILED,"Linear dependency detected");
       if (PetscAbs(nr) > 0.7*PetscAbs(nr_o)) break;
       nr_o = nr;
     }
@@ -610,9 +578,9 @@ PetscErrorCode DSPseudoOrthogonalize(DS ds,DSMatType mat,PetscInt cols,PetscReal
     PetscStackCallBLAS("LAPACKlascl",LAPACKlascl_("G",&zero,&zero,&nr_abs,&done,&rA_,&one,A+i*ld,&ld_,&info));
     SlepcCheckLapackInfo("lascl",info);
   }
-  ierr = PetscLogEventEnd(DS_Other,ds,0,0,0);CHKERRQ(ierr);
-  ierr = DSRestoreArray(ds,mat,&A_);CHKERRQ(ierr);
-  ierr = PetscObjectStateIncrease((PetscObject)ds);CHKERRQ(ierr);
+  PetscCall(PetscLogEventEnd(DS_Other,ds,0,0,0));
+  PetscCall(DSRestoreArray(ds,mat,&A_));
+  PetscCall(PetscObjectStateIncrease((PetscObject)ds));
   if (lindcols) *lindcols = cols;
   PetscFunctionReturn(0);
 }
