@@ -1,7 +1,7 @@
 /*
    - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
    SLEPc - Scalable Library for Eigenvalue Problem Computations
-   Copyright (c) 2002-2021, Universitat Politecnica de Valencia, Spain
+   Copyright (c) 2002-, Universitat Politecnica de Valencia, Spain
 
    This file is part of SLEPc.
    SLEPc is distributed under a 2-clause BSD license (see LICENSE).
@@ -29,10 +29,10 @@ static PetscErrorCode RGEllipseSetParameters_Ellipse(RG rg,PetscScalar center,Pe
   if (radius == PETSC_DEFAULT) {
     ctx->radius = 1.0;
   } else {
-    if (radius<=0.0) SETERRQ(PetscObjectComm((PetscObject)rg),PETSC_ERR_ARG_OUTOFRANGE,"The radius argument must be > 0.0");
+    PetscCheck(radius>0.0,PetscObjectComm((PetscObject)rg),PETSC_ERR_ARG_OUTOFRANGE,"The radius argument must be > 0.0");
     ctx->radius = radius;
   }
-  if (vscale<=0.0) SETERRQ(PetscObjectComm((PetscObject)rg),PETSC_ERR_ARG_OUTOFRANGE,"The vscale argument must be > 0.0");
+  PetscCheck(vscale>0.0,PetscObjectComm((PetscObject)rg),PETSC_ERR_ARG_OUTOFRANGE,"The vscale argument must be > 0.0");
   ctx->vscale = vscale;
   PetscFunctionReturn(0);
 }
@@ -66,14 +66,12 @@ static PetscErrorCode RGEllipseSetParameters_Ellipse(RG rg,PetscScalar center,Pe
 @*/
 PetscErrorCode RGEllipseSetParameters(RG rg,PetscScalar center,PetscReal radius,PetscReal vscale)
 {
-  PetscErrorCode ierr;
-
   PetscFunctionBegin;
   PetscValidHeaderSpecific(rg,RG_CLASSID,1);
   PetscValidLogicalCollectiveScalar(rg,center,2);
   PetscValidLogicalCollectiveReal(rg,radius,3);
   PetscValidLogicalCollectiveReal(rg,vscale,4);
-  ierr = PetscTryMethod(rg,"RGEllipseSetParameters_C",(RG,PetscScalar,PetscReal,PetscReal),(rg,center,radius,vscale));CHKERRQ(ierr);
+  PetscTryMethod(rg,"RGEllipseSetParameters_C",(RG,PetscScalar,PetscReal,PetscReal),(rg,center,radius,vscale));
   PetscFunctionReturn(0);
 }
 
@@ -107,17 +105,14 @@ static PetscErrorCode RGEllipseGetParameters_Ellipse(RG rg,PetscScalar *center,P
 @*/
 PetscErrorCode RGEllipseGetParameters(RG rg,PetscScalar *center,PetscReal *radius,PetscReal *vscale)
 {
-  PetscErrorCode ierr;
-
   PetscFunctionBegin;
   PetscValidHeaderSpecific(rg,RG_CLASSID,1);
-  ierr = PetscUseMethod(rg,"RGEllipseGetParameters_C",(RG,PetscScalar*,PetscReal*,PetscReal*),(rg,center,radius,vscale));CHKERRQ(ierr);
+  PetscUseMethod(rg,"RGEllipseGetParameters_C",(RG,PetscScalar*,PetscReal*,PetscReal*),(rg,center,radius,vscale));
   PetscFunctionReturn(0);
 }
 
 PetscErrorCode RGView_Ellipse(RG rg,PetscViewer viewer)
 {
-  PetscErrorCode ierr;
   RG_ELLIPSE     *ctx = (RG_ELLIPSE*)rg->data;
   PetscBool      isdraw,isascii;
   int            winw,winh;
@@ -127,19 +122,19 @@ PetscErrorCode RGView_Ellipse(RG rg,PetscViewer viewer)
   char           str[50];
 
   PetscFunctionBegin;
-  ierr = PetscObjectTypeCompare((PetscObject)viewer,PETSCVIEWERDRAW,&isdraw);CHKERRQ(ierr);
-  ierr = PetscObjectTypeCompare((PetscObject)viewer,PETSCVIEWERASCII,&isascii);CHKERRQ(ierr);
+  PetscCall(PetscObjectTypeCompare((PetscObject)viewer,PETSCVIEWERDRAW,&isdraw));
+  PetscCall(PetscObjectTypeCompare((PetscObject)viewer,PETSCVIEWERASCII,&isascii));
   if (isascii) {
-    ierr = SlepcSNPrintfScalar(str,sizeof(str),ctx->center,PETSC_FALSE);CHKERRQ(ierr);
-    ierr = PetscViewerASCIIPrintf(viewer,"  center: %s, radius: %g, vscale: %g\n",str,RGShowReal(ctx->radius),RGShowReal(ctx->vscale));CHKERRQ(ierr);
+    PetscCall(SlepcSNPrintfScalar(str,sizeof(str),ctx->center,PETSC_FALSE));
+    PetscCall(PetscViewerASCIIPrintf(viewer,"  center: %s, radius: %g, vscale: %g\n",str,RGShowReal(ctx->radius),RGShowReal(ctx->vscale)));
   } else if (isdraw) {
-    ierr = PetscViewerDrawGetDraw(viewer,0,&draw);CHKERRQ(ierr);
-    ierr = PetscDrawCheckResizedWindow(draw);CHKERRQ(ierr);
-    ierr = PetscDrawGetWindowSize(draw,&winw,&winh);CHKERRQ(ierr);
+    PetscCall(PetscViewerDrawGetDraw(viewer,0,&draw));
+    PetscCall(PetscDrawCheckResizedWindow(draw));
+    PetscCall(PetscDrawGetWindowSize(draw,&winw,&winh));
     winw = PetscMax(winw,1); winh = PetscMax(winh,1);
-    ierr = PetscDrawClear(draw);CHKERRQ(ierr);
-    ierr = PetscDrawSetTitle(draw,"Ellipse region");CHKERRQ(ierr);
-    ierr = PetscDrawAxisCreate(draw,&axis);CHKERRQ(ierr);
+    PetscCall(PetscDrawClear(draw));
+    PetscCall(PetscDrawSetTitle(draw,"Ellipse region"));
+    PetscCall(PetscDrawAxisCreate(draw,&axis));
     cx = PetscRealPart(ctx->center)*rg->sfactor;
     cy = PetscImaginaryPart(ctx->center)*rg->sfactor;
     r  = ctx->radius*rg->sfactor;
@@ -148,13 +143,13 @@ PetscErrorCode RGView_Ellipse(RG rg,PetscViewer viewer)
     ab = cx;
     cd = cy;
     w  = scale*PetscMax(lx/winw,ly/winh)/2;
-    ierr = PetscDrawAxisSetLimits(axis,ab-w*winw,ab+w*winw,cd-w*winh,cd+w*winh);CHKERRQ(ierr);
-    ierr = PetscDrawAxisDraw(axis);CHKERRQ(ierr);
-    ierr = PetscDrawAxisDestroy(&axis);CHKERRQ(ierr);
-    ierr = PetscDrawEllipse(draw,cx,cy,2*r,2*r*ctx->vscale,PETSC_DRAW_RED);CHKERRQ(ierr);
-    ierr = PetscDrawFlush(draw);CHKERRQ(ierr);
-    ierr = PetscDrawSave(draw);CHKERRQ(ierr);
-    ierr = PetscDrawPause(draw);CHKERRQ(ierr);
+    PetscCall(PetscDrawAxisSetLimits(axis,ab-w*winw,ab+w*winw,cd-w*winh,cd+w*winh));
+    PetscCall(PetscDrawAxisDraw(axis));
+    PetscCall(PetscDrawAxisDestroy(&axis));
+    PetscCall(PetscDrawEllipse(draw,cx,cy,2*r,2*r*ctx->vscale,PETSC_DRAW_RED));
+    PetscCall(PetscDrawFlush(draw));
+    PetscCall(PetscDrawSave(draw));
+    PetscCall(PetscDrawPause(draw));
   }
   PetscFunctionReturn(0);
 }
@@ -181,8 +176,8 @@ PetscErrorCode RGComputeContour_Ellipse(RG rg,PetscInt n,PetscScalar *cr,PetscSc
 #if defined(PETSC_USE_COMPLEX)
     cr[i] = ctx->center + ctx->radius*PetscCMPLX(PetscCosReal(theta),ctx->vscale*PetscSinReal(theta));
 #else
-    cr[i] = ctx->center + ctx->radius*PetscCosReal(theta);
-    ci[i] = ctx->radius*ctx->vscale*PetscSinReal(theta);
+    if (cr) cr[i] = ctx->center + ctx->radius*PetscCosReal(theta);
+    if (ci) ci[i] = ctx->radius*ctx->vscale*PetscSinReal(theta);
 #endif
   }
   PetscFunctionReturn(0);
@@ -200,6 +195,28 @@ PetscErrorCode RGComputeBoundingBox_Ellipse(RG rg,PetscReal *a,PetscReal *b,Pets
   PetscFunctionReturn(0);
 }
 
+PetscErrorCode RGComputeQuadrature_Ellipse(RG rg,RGQuadRule quad,PetscInt n,PetscScalar *z,PetscScalar *zn,PetscScalar *w)
+{
+  RG_ELLIPSE *ctx = (RG_ELLIPSE*)rg->data;
+  PetscReal  theta;
+  PetscInt   i;
+
+  PetscFunctionBegin;
+  for (i=0;i<n;i++) {
+#if defined(PETSC_USE_COMPLEX)
+    theta = 2.0*PETSC_PI*(i+0.5)/n;
+    zn[i] = PetscCMPLX(PetscCosReal(theta),ctx->vscale*PetscSinReal(theta));
+    w[i]  = rg->sfactor*ctx->radius*(PetscCMPLX(ctx->vscale*PetscCosReal(theta),PetscSinReal(theta)))/n;
+#else
+    theta = PETSC_PI*(i+0.5)/n;
+    zn[i] = PetscCosReal(theta);
+    w[i]  = PetscCosReal((n-1)*theta)/n;
+    z[i]  = rg->sfactor*(ctx->center + ctx->radius*zn[i]);
+#endif
+  }
+  PetscFunctionReturn(0);
+}
+
 PetscErrorCode RGCheckInside_Ellipse(RG rg,PetscReal px,PetscReal py,PetscInt *inside)
 {
   RG_ELLIPSE *ctx = (RG_ELLIPSE*)rg->data;
@@ -218,58 +235,65 @@ PetscErrorCode RGCheckInside_Ellipse(RG rg,PetscReal px,PetscReal py,PetscInt *i
   PetscFunctionReturn(0);
 }
 
+PetscErrorCode RGIsAxisymmetric_Ellipse(RG rg,PetscBool vertical,PetscBool *symm)
+{
+  RG_ELLIPSE *ctx = (RG_ELLIPSE*)rg->data;
+
+  PetscFunctionBegin;
+  if (vertical) *symm = (PetscRealPart(ctx->center) == 0.0)? PETSC_TRUE: PETSC_FALSE;
+  else *symm = (PetscImaginaryPart(ctx->center) == 0.0)? PETSC_TRUE: PETSC_FALSE;
+  PetscFunctionReturn(0);
+}
+
 PetscErrorCode RGSetFromOptions_Ellipse(PetscOptionItems *PetscOptionsObject,RG rg)
 {
-  PetscErrorCode ierr;
   PetscScalar    s;
   PetscReal      r1,r2;
   PetscBool      flg1,flg2,flg3;
 
   PetscFunctionBegin;
-  ierr = PetscOptionsHead(PetscOptionsObject,"RG Ellipse Options");CHKERRQ(ierr);
+  PetscCall(PetscOptionsHead(PetscOptionsObject,"RG Ellipse Options"));
 
-    ierr = RGEllipseGetParameters(rg,&s,&r1,&r2);CHKERRQ(ierr);
-    ierr = PetscOptionsScalar("-rg_ellipse_center","Center of ellipse","RGEllipseSetParameters",s,&s,&flg1);CHKERRQ(ierr);
-    ierr = PetscOptionsReal("-rg_ellipse_radius","Radius of ellipse","RGEllipseSetParameters",r1,&r1,&flg2);CHKERRQ(ierr);
-    ierr = PetscOptionsReal("-rg_ellipse_vscale","Vertical scale of ellipse","RGEllipseSetParameters",r2,&r2,&flg3);CHKERRQ(ierr);
-    if (flg1 || flg2 || flg3) { ierr = RGEllipseSetParameters(rg,s,r1,r2);CHKERRQ(ierr); }
+    PetscCall(RGEllipseGetParameters(rg,&s,&r1,&r2));
+    PetscCall(PetscOptionsScalar("-rg_ellipse_center","Center of ellipse","RGEllipseSetParameters",s,&s,&flg1));
+    PetscCall(PetscOptionsReal("-rg_ellipse_radius","Radius of ellipse","RGEllipseSetParameters",r1,&r1,&flg2));
+    PetscCall(PetscOptionsReal("-rg_ellipse_vscale","Vertical scale of ellipse","RGEllipseSetParameters",r2,&r2,&flg3));
+    if (flg1 || flg2 || flg3) PetscCall(RGEllipseSetParameters(rg,s,r1,r2));
 
-  ierr = PetscOptionsTail();CHKERRQ(ierr);
+  PetscCall(PetscOptionsTail());
   PetscFunctionReturn(0);
 }
 
 PetscErrorCode RGDestroy_Ellipse(RG rg)
 {
-  PetscErrorCode ierr;
-
   PetscFunctionBegin;
-  ierr = PetscFree(rg->data);CHKERRQ(ierr);
-  ierr = PetscObjectComposeFunction((PetscObject)rg,"RGEllipseSetParameters_C",NULL);CHKERRQ(ierr);
-  ierr = PetscObjectComposeFunction((PetscObject)rg,"RGEllipseGetParameters_C",NULL);CHKERRQ(ierr);
+  PetscCall(PetscFree(rg->data));
+  PetscCall(PetscObjectComposeFunction((PetscObject)rg,"RGEllipseSetParameters_C",NULL));
+  PetscCall(PetscObjectComposeFunction((PetscObject)rg,"RGEllipseGetParameters_C",NULL));
   PetscFunctionReturn(0);
 }
 
 SLEPC_EXTERN PetscErrorCode RGCreate_Ellipse(RG rg)
 {
   RG_ELLIPSE     *ellipse;
-  PetscErrorCode ierr;
 
   PetscFunctionBegin;
-  ierr = PetscNewLog(rg,&ellipse);CHKERRQ(ierr);
+  PetscCall(PetscNewLog(rg,&ellipse));
   ellipse->center = 0.0;
   ellipse->radius = PETSC_MAX_REAL;
   ellipse->vscale = 1.0;
   rg->data = (void*)ellipse;
 
-  rg->ops->istrivial      = RGIsTrivial_Ellipse;
-  rg->ops->computecontour = RGComputeContour_Ellipse;
-  rg->ops->computebbox    = RGComputeBoundingBox_Ellipse;
-  rg->ops->checkinside    = RGCheckInside_Ellipse;
-  rg->ops->setfromoptions = RGSetFromOptions_Ellipse;
-  rg->ops->view           = RGView_Ellipse;
-  rg->ops->destroy        = RGDestroy_Ellipse;
-  ierr = PetscObjectComposeFunction((PetscObject)rg,"RGEllipseSetParameters_C",RGEllipseSetParameters_Ellipse);CHKERRQ(ierr);
-  ierr = PetscObjectComposeFunction((PetscObject)rg,"RGEllipseGetParameters_C",RGEllipseGetParameters_Ellipse);CHKERRQ(ierr);
+  rg->ops->istrivial         = RGIsTrivial_Ellipse;
+  rg->ops->computecontour    = RGComputeContour_Ellipse;
+  rg->ops->computebbox       = RGComputeBoundingBox_Ellipse;
+  rg->ops->computequadrature = RGComputeQuadrature_Ellipse;
+  rg->ops->checkinside       = RGCheckInside_Ellipse;
+  rg->ops->isaxisymmetric    = RGIsAxisymmetric_Ellipse;
+  rg->ops->setfromoptions    = RGSetFromOptions_Ellipse;
+  rg->ops->view              = RGView_Ellipse;
+  rg->ops->destroy           = RGDestroy_Ellipse;
+  PetscCall(PetscObjectComposeFunction((PetscObject)rg,"RGEllipseSetParameters_C",RGEllipseSetParameters_Ellipse));
+  PetscCall(PetscObjectComposeFunction((PetscObject)rg,"RGEllipseGetParameters_C",RGEllipseGetParameters_Ellipse));
   PetscFunctionReturn(0);
 }
-
