@@ -1,7 +1,7 @@
 /*
    - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
    SLEPc - Scalable Library for Eigenvalue Problem Computations
-   Copyright (c) 2002-2021, Universitat Politecnica de Valencia, Spain
+   Copyright (c) 2002-, Universitat Politecnica de Valencia, Spain
 
    This file is part of SLEPc.
    SLEPc is distributed under a 2-clause BSD license (see LICENSE).
@@ -21,60 +21,56 @@
 */
 PetscErrorCode STComputeOperator_Filter(ST st)
 {
-  PetscErrorCode ierr;
   ST_FILTER      *ctx = (ST_FILTER*)st->data;
 
   PetscFunctionBegin;
-  if (st->nmat>1) SETERRQ(PetscObjectComm((PetscObject)st),1,"Only implemented for standard eigenvalue problem");
-  if (ctx->intb >= PETSC_MAX_REAL && ctx->inta <= PETSC_MIN_REAL) SETERRQ(PetscObjectComm((PetscObject)st),1,"Must pass an interval with STFilterSetInterval()");
-  if (ctx->right == 0.0 && ctx->left == 0.0) SETERRQ(PetscObjectComm((PetscObject)st),1,"Must pass an approximate numerical range with STFilterSetRange()");
-  if (ctx->left > ctx->inta || ctx->right < ctx->intb) SETERRQ4(PetscObjectComm((PetscObject)st),1,"The requested interval [%g,%g] must be contained in the numerical range [%g,%g]",(double)ctx->inta,(double)ctx->intb,(double)ctx->left,(double)ctx->right);
+  PetscCheck(st->nmat==1,PetscObjectComm((PetscObject)st),PETSC_ERR_SUP,"Only implemented for standard eigenvalue problem");
+  PetscCheck(ctx->intb<PETSC_MAX_REAL || ctx->inta>PETSC_MIN_REAL,PetscObjectComm((PetscObject)st),PETSC_ERR_ORDER,"Must pass an interval with STFilterSetInterval()");
+  PetscCheck(ctx->right!=0.0 || ctx->left!=0.0,PetscObjectComm((PetscObject)st),PETSC_ERR_ORDER,"Must pass an approximate numerical range with STFilterSetRange()");
+  PetscCheck(ctx->left<=ctx->inta && ctx->right>=ctx->intb,PetscObjectComm((PetscObject)st),PETSC_ERR_USER_INPUT,"The requested interval [%g,%g] must be contained in the numerical range [%g,%g]",(double)ctx->inta,(double)ctx->intb,(double)ctx->left,(double)ctx->right);
   if (!ctx->polyDegree) ctx->polyDegree = 100;
   ctx->frame[0] = ctx->left;
   ctx->frame[1] = ctx->inta;
   ctx->frame[2] = ctx->intb;
   ctx->frame[3] = ctx->right;
-  ierr = STFilter_FILTLAN_setFilter(st,&st->T[0]);CHKERRQ(ierr);
+  PetscCall(STFilter_FILTLAN_setFilter(st,&st->T[0]));
   st->M = st->T[0];
-  ierr = MatDestroy(&st->P);CHKERRQ(ierr);
+  PetscCall(MatDestroy(&st->P));
   PetscFunctionReturn(0);
 }
 
 PetscErrorCode STSetUp_Filter(ST st)
 {
-  PetscErrorCode ierr;
-
   PetscFunctionBegin;
-  ierr = STSetWorkVecs(st,4);CHKERRQ(ierr);
+  PetscCall(STSetWorkVecs(st,4));
   PetscFunctionReturn(0);
 }
 
 PetscErrorCode STSetFromOptions_Filter(PetscOptionItems *PetscOptionsObject,ST st)
 {
-  PetscErrorCode ierr;
   PetscReal      array[2]={0,0};
   PetscInt       k;
   PetscBool      flg;
 
   PetscFunctionBegin;
-  ierr = PetscOptionsHead(PetscOptionsObject,"ST Filter Options");CHKERRQ(ierr);
+  PetscCall(PetscOptionsHead(PetscOptionsObject,"ST Filter Options"));
 
     k = 2;
-    ierr = PetscOptionsRealArray("-st_filter_interval","Interval containing the desired eigenvalues (two real values separated with a comma without spaces)","STFilterSetInterval",array,&k,&flg);CHKERRQ(ierr);
+    PetscCall(PetscOptionsRealArray("-st_filter_interval","Interval containing the desired eigenvalues (two real values separated with a comma without spaces)","STFilterSetInterval",array,&k,&flg));
     if (flg) {
-      if (k<2) SETERRQ(PetscObjectComm((PetscObject)st),PETSC_ERR_ARG_SIZ,"Must pass two values in -st_filter_interval (comma-separated without spaces)");
-      ierr = STFilterSetInterval(st,array[0],array[1]);CHKERRQ(ierr);
+      PetscCheck(k>1,PetscObjectComm((PetscObject)st),PETSC_ERR_ARG_SIZ,"Must pass two values in -st_filter_interval (comma-separated without spaces)");
+      PetscCall(STFilterSetInterval(st,array[0],array[1]));
     }
     k = 2;
-    ierr = PetscOptionsRealArray("-st_filter_range","Interval containing all eigenvalues (two real values separated with a comma without spaces)","STFilterSetRange",array,&k,&flg);CHKERRQ(ierr);
+    PetscCall(PetscOptionsRealArray("-st_filter_range","Interval containing all eigenvalues (two real values separated with a comma without spaces)","STFilterSetRange",array,&k,&flg));
     if (flg) {
-      if (k<2) SETERRQ(PetscObjectComm((PetscObject)st),PETSC_ERR_ARG_SIZ,"Must pass two values in -st_filter_range (comma-separated without spaces)");
-      ierr = STFilterSetRange(st,array[0],array[1]);CHKERRQ(ierr);
+      PetscCheck(k>1,PetscObjectComm((PetscObject)st),PETSC_ERR_ARG_SIZ,"Must pass two values in -st_filter_range (comma-separated without spaces)");
+      PetscCall(STFilterSetRange(st,array[0],array[1]));
     }
-    ierr = PetscOptionsInt("-st_filter_degree","Degree of filter polynomial","STFilterSetDegree",100,&k,&flg);CHKERRQ(ierr);
-    if (flg) { ierr = STFilterSetDegree(st,k);CHKERRQ(ierr); }
+    PetscCall(PetscOptionsInt("-st_filter_degree","Degree of filter polynomial","STFilterSetDegree",100,&k,&flg));
+    if (flg) PetscCall(STFilterSetDegree(st,k));
 
-  ierr = PetscOptionsTail();CHKERRQ(ierr);
+  PetscCall(PetscOptionsTail());
   PetscFunctionReturn(0);
 }
 
@@ -83,7 +79,7 @@ static PetscErrorCode STFilterSetInterval_Filter(ST st,PetscReal inta,PetscReal
   ST_FILTER *ctx = (ST_FILTER*)st->data;
 
   PetscFunctionBegin;
-  if (inta>intb) SETERRQ(PetscObjectComm((PetscObject)st),PETSC_ERR_ARG_WRONG,"Badly defined interval, must be inta<intb");
+  PetscCheck(inta<intb,PetscObjectComm((PetscObject)st),PETSC_ERR_ARG_WRONG,"Badly defined interval, must be inta<intb");
   if (ctx->inta != inta || ctx->intb != intb) {
     ctx->inta   = inta;
     ctx->intb   = intb;
@@ -123,13 +119,11 @@ static PetscErrorCode STFilterSetInterval_Filter(ST st,PetscReal inta,PetscReal
 @*/
 PetscErrorCode STFilterSetInterval(ST st,PetscReal inta,PetscReal intb)
 {
-  PetscErrorCode ierr;
-
   PetscFunctionBegin;
   PetscValidHeaderSpecific(st,ST_CLASSID,1);
   PetscValidLogicalCollectiveReal(st,inta,2);
   PetscValidLogicalCollectiveReal(st,intb,3);
-  ierr = PetscTryMethod(st,"STFilterSetInterval_C",(ST,PetscReal,PetscReal),(st,inta,intb));CHKERRQ(ierr);
+  PetscTryMethod(st,"STFilterSetInterval_C",(ST,PetscReal,PetscReal),(st,inta,intb));
   PetscFunctionReturn(0);
 }
 
@@ -151,7 +145,7 @@ static PetscErrorCode STFilterGetInterval_Filter(ST st,PetscReal *inta,PetscReal
    Input Parameter:
 .  st  - the spectral transformation context
 
-   Output Parameter:
+   Output Parameters:
 +  inta - left end of the interval
 -  intb - right end of the interval
 
@@ -161,11 +155,9 @@ static PetscErrorCode STFilterGetInterval_Filter(ST st,PetscReal *inta,PetscReal
 @*/
 PetscErrorCode STFilterGetInterval(ST st,PetscReal *inta,PetscReal *intb)
 {
-  PetscErrorCode ierr;
-
   PetscFunctionBegin;
   PetscValidHeaderSpecific(st,ST_CLASSID,1);
-  ierr = PetscUseMethod(st,"STFilterGetInterval_C",(ST,PetscReal*,PetscReal*),(st,inta,intb));CHKERRQ(ierr);
+  PetscUseMethod(st,"STFilterGetInterval_C",(ST,PetscReal*,PetscReal*),(st,inta,intb));
   PetscFunctionReturn(0);
 }
 
@@ -174,7 +166,7 @@ static PetscErrorCode STFilterSetRange_Filter(ST st,PetscReal left,PetscReal rig
   ST_FILTER *ctx = (ST_FILTER*)st->data;
 
   PetscFunctionBegin;
-  if (left>right) SETERRQ(PetscObjectComm((PetscObject)st),PETSC_ERR_ARG_WRONG,"Badly defined interval, must be left<right");
+  PetscCheck(left<right,PetscObjectComm((PetscObject)st),PETSC_ERR_ARG_WRONG,"Badly defined interval, must be left<right");
   if (ctx->left != left || ctx->right != right) {
     ctx->left   = left;
     ctx->right  = right;
@@ -209,13 +201,11 @@ static PetscErrorCode STFilterSetRange_Filter(ST st,PetscReal left,PetscReal rig
 @*/
 PetscErrorCode STFilterSetRange(ST st,PetscReal left,PetscReal right)
 {
-  PetscErrorCode ierr;
-
   PetscFunctionBegin;
   PetscValidHeaderSpecific(st,ST_CLASSID,1);
   PetscValidLogicalCollectiveReal(st,left,2);
   PetscValidLogicalCollectiveReal(st,right,3);
-  ierr = PetscTryMethod(st,"STFilterSetRange_C",(ST,PetscReal,PetscReal),(st,left,right));CHKERRQ(ierr);
+  PetscTryMethod(st,"STFilterSetRange_C",(ST,PetscReal,PetscReal),(st,left,right));
   PetscFunctionReturn(0);
 }
 
@@ -237,7 +227,7 @@ static PetscErrorCode STFilterGetRange_Filter(ST st,PetscReal *left,PetscReal *r
    Input Parameter:
 .  st  - the spectral transformation context
 
-   Output Parameter:
+   Output Parameters:
 +  left  - left end of the interval
 -  right - right end of the interval
 
@@ -247,11 +237,9 @@ static PetscErrorCode STFilterGetRange_Filter(ST st,PetscReal *left,PetscReal *r
 @*/
 PetscErrorCode STFilterGetRange(ST st,PetscReal *left,PetscReal *right)
 {
-  PetscErrorCode ierr;
-
   PetscFunctionBegin;
   PetscValidHeaderSpecific(st,ST_CLASSID,1);
-  ierr = PetscUseMethod(st,"STFilterGetRange_C",(ST,PetscReal*,PetscReal*),(st,left,right));CHKERRQ(ierr);
+  PetscUseMethod(st,"STFilterGetRange_C",(ST,PetscReal*,PetscReal*),(st,left,right));
   PetscFunctionReturn(0);
 }
 
@@ -266,7 +254,7 @@ static PetscErrorCode STFilterSetDegree_Filter(ST st,PetscInt deg)
     st->opready     = PETSC_FALSE;
     ctx->filtch     = PETSC_TRUE;
   } else {
-    if (deg<=0) SETERRQ(PetscObjectComm((PetscObject)st),PETSC_ERR_ARG_OUTOFRANGE,"Illegal value of degree. Must be > 0");
+    PetscCheck(deg>0,PetscObjectComm((PetscObject)st),PETSC_ERR_ARG_OUTOFRANGE,"Illegal value of degree. Must be > 0");
     if (ctx->polyDegree != deg) {
       ctx->polyDegree = deg;
       st->state       = ST_STATE_INITIAL;
@@ -295,12 +283,10 @@ static PetscErrorCode STFilterSetDegree_Filter(ST st,PetscInt deg)
 @*/
 PetscErrorCode STFilterSetDegree(ST st,PetscInt deg)
 {
-  PetscErrorCode ierr;
-
   PetscFunctionBegin;
   PetscValidHeaderSpecific(st,ST_CLASSID,1);
   PetscValidLogicalCollectiveInt(st,deg,2);
-  ierr = PetscTryMethod(st,"STFilterSetDegree_C",(ST,PetscInt),(st,deg));CHKERRQ(ierr);
+  PetscTryMethod(st,"STFilterSetDegree_C",(ST,PetscInt),(st,deg));
   PetscFunctionReturn(0);
 }
 
@@ -330,12 +316,10 @@ static PetscErrorCode STFilterGetDegree_Filter(ST st,PetscInt *deg)
 @*/
 PetscErrorCode STFilterGetDegree(ST st,PetscInt *deg)
 {
-  PetscErrorCode ierr;
-
   PetscFunctionBegin;
   PetscValidHeaderSpecific(st,ST_CLASSID,1);
   PetscValidIntPointer(deg,2);
-  ierr = PetscUseMethod(st,"STFilterGetDegree_C",(ST,PetscInt*),(st,deg));CHKERRQ(ierr);
+  PetscUseMethod(st,"STFilterGetDegree_C",(ST,PetscInt*),(st,deg));
   PetscFunctionReturn(0);
 }
 
@@ -361,77 +345,73 @@ static PetscErrorCode STFilterGetThreshold_Filter(ST st,PetscReal *gamma)
 .  gamma - the threshold value
 
    Level: developer
+
+.seealso: STFilterGetRange()
 @*/
 PetscErrorCode STFilterGetThreshold(ST st,PetscReal *gamma)
 {
-  PetscErrorCode ierr;
-
   PetscFunctionBegin;
   PetscValidHeaderSpecific(st,ST_CLASSID,1);
   PetscValidRealPointer(gamma,2);
-  ierr = PetscUseMethod(st,"STFilterGetThreshold_C",(ST,PetscReal*),(st,gamma));CHKERRQ(ierr);
+  PetscUseMethod(st,"STFilterGetThreshold_C",(ST,PetscReal*),(st,gamma));
   PetscFunctionReturn(0);
 }
 
 PetscErrorCode STReset_Filter(ST st)
 {
-  PetscErrorCode ierr;
   ST_FILTER      *ctx = (ST_FILTER*)st->data;
 
   PetscFunctionBegin;
   ctx->left  = 0.0;
   ctx->right = 0.0;
-  ierr = MatDestroy(&ctx->T);CHKERRQ(ierr);
+  PetscCall(MatDestroy(&ctx->T));
+  PetscCall(MatDestroyMatrices(ctx->nW,&ctx->W));
+  ctx->nW = 0;
   PetscFunctionReturn(0);
 }
 
 PetscErrorCode STView_Filter(ST st,PetscViewer viewer)
 {
-  PetscErrorCode ierr;
   ST_FILTER      *ctx = (ST_FILTER*)st->data;
   PetscBool      isascii;
 
   PetscFunctionBegin;
-  ierr = PetscObjectTypeCompare((PetscObject)viewer,PETSCVIEWERASCII,&isascii);CHKERRQ(ierr);
+  PetscCall(PetscObjectTypeCompare((PetscObject)viewer,PETSCVIEWERASCII,&isascii));
   if (isascii) {
-    ierr = PetscViewerASCIIPrintf(viewer,"  Filter: interval of desired eigenvalues is [%g,%g]\n",(double)ctx->inta,(double)ctx->intb);CHKERRQ(ierr);
-    ierr = PetscViewerASCIIPrintf(viewer,"  Filter: numerical range is [%g,%g]\n",(double)ctx->left,(double)ctx->right);CHKERRQ(ierr);
-    ierr = PetscViewerASCIIPrintf(viewer,"  Filter: degree of filter polynomial is %D\n",ctx->polyDegree);CHKERRQ(ierr);
-    if (st->state>=ST_STATE_SETUP) {
-      ierr = PetscViewerASCIIPrintf(viewer,"  Filter: limit to accept eigenvalues: theta=%g\n",ctx->filterInfo->yLimit);CHKERRQ(ierr);
-    }
+    PetscCall(PetscViewerASCIIPrintf(viewer,"  Filter: interval of desired eigenvalues is [%g,%g]\n",(double)ctx->inta,(double)ctx->intb));
+    PetscCall(PetscViewerASCIIPrintf(viewer,"  Filter: numerical range is [%g,%g]\n",(double)ctx->left,(double)ctx->right));
+    PetscCall(PetscViewerASCIIPrintf(viewer,"  Filter: degree of filter polynomial is %" PetscInt_FMT "\n",ctx->polyDegree));
+    if (st->state>=ST_STATE_SETUP) PetscCall(PetscViewerASCIIPrintf(viewer,"  Filter: limit to accept eigenvalues: theta=%g\n",(double)ctx->filterInfo->yLimit));
   }
   PetscFunctionReturn(0);
 }
 
 PetscErrorCode STDestroy_Filter(ST st)
 {
-  PetscErrorCode ierr;
   ST_FILTER      *ctx = (ST_FILTER*)st->data;
 
   PetscFunctionBegin;
-  ierr = PetscFree(ctx->opts);CHKERRQ(ierr);
-  ierr = PetscFree(ctx->filterInfo);CHKERRQ(ierr);
-  ierr = PetscFree(ctx->baseFilter);CHKERRQ(ierr);
-  ierr = PetscFree(st->data);CHKERRQ(ierr);
-  ierr = PetscObjectComposeFunction((PetscObject)st,"STFilterSetInterval_C",NULL);CHKERRQ(ierr);
-  ierr = PetscObjectComposeFunction((PetscObject)st,"STFilterGetInterval_C",NULL);CHKERRQ(ierr);
-  ierr = PetscObjectComposeFunction((PetscObject)st,"STFilterSetRange_C",NULL);CHKERRQ(ierr);
-  ierr = PetscObjectComposeFunction((PetscObject)st,"STFilterGetRange_C",NULL);CHKERRQ(ierr);
-  ierr = PetscObjectComposeFunction((PetscObject)st,"STFilterSetDegree_C",NULL);CHKERRQ(ierr);
-  ierr = PetscObjectComposeFunction((PetscObject)st,"STFilterGetDegree_C",NULL);CHKERRQ(ierr);
-  ierr = PetscObjectComposeFunction((PetscObject)st,"STFilterGetThreshold_C",NULL);CHKERRQ(ierr);
+  PetscCall(PetscFree(ctx->opts));
+  PetscCall(PetscFree(ctx->filterInfo));
+  PetscCall(PetscFree(ctx->baseFilter));
+  PetscCall(PetscFree(st->data));
+  PetscCall(PetscObjectComposeFunction((PetscObject)st,"STFilterSetInterval_C",NULL));
+  PetscCall(PetscObjectComposeFunction((PetscObject)st,"STFilterGetInterval_C",NULL));
+  PetscCall(PetscObjectComposeFunction((PetscObject)st,"STFilterSetRange_C",NULL));
+  PetscCall(PetscObjectComposeFunction((PetscObject)st,"STFilterGetRange_C",NULL));
+  PetscCall(PetscObjectComposeFunction((PetscObject)st,"STFilterSetDegree_C",NULL));
+  PetscCall(PetscObjectComposeFunction((PetscObject)st,"STFilterGetDegree_C",NULL));
+  PetscCall(PetscObjectComposeFunction((PetscObject)st,"STFilterGetThreshold_C",NULL));
   PetscFunctionReturn(0);
 }
 
 SLEPC_EXTERN PetscErrorCode STCreate_Filter(ST st)
 {
-  PetscErrorCode ierr;
   ST_FILTER      *ctx;
   FILTLAN_IOP    iop;
   FILTLAN_PFI    pfi;
   PetscFunctionBegin;
-  ierr = PetscNewLog(st,&ctx);CHKERRQ(ierr);
+  PetscCall(PetscNewLog(st,&ctx));
   st->data = (void*)ctx;
 
   st->usesksp = PETSC_FALSE;
@@ -443,7 +423,7 @@ SLEPC_EXTERN PetscErrorCode STCreate_Filter(ST st)
   ctx->polyDegree         = 0;
   ctx->baseDegree         = 10;
 
-  ierr = PetscNewLog(st,&iop);CHKERRQ(ierr);
+  PetscCall(PetscNewLog(st,&iop));
   ctx->opts               = iop;
   iop->intervalWeights[0] = 100.0;
   iop->intervalWeights[1] = 1.0;
@@ -463,7 +443,7 @@ SLEPC_EXTERN PetscErrorCode STCreate_Filter(ST st)
   iop->yBottomLine        = 0.001;
   iop->yRippleLimit       = 0.8;
 
-  ierr = PetscNewLog(st,&pfi);CHKERRQ(ierr);
+  PetscCall(PetscNewLog(st,&pfi));
   ctx->filterInfo         = pfi;
 
   st->ops->apply           = STApply_Generic;
@@ -474,13 +454,12 @@ SLEPC_EXTERN PetscErrorCode STCreate_Filter(ST st)
   st->ops->reset           = STReset_Filter;
   st->ops->view            = STView_Filter;
 
-  ierr = PetscObjectComposeFunction((PetscObject)st,"STFilterSetInterval_C",STFilterSetInterval_Filter);CHKERRQ(ierr);
-  ierr = PetscObjectComposeFunction((PetscObject)st,"STFilterGetInterval_C",STFilterGetInterval_Filter);CHKERRQ(ierr);
-  ierr = PetscObjectComposeFunction((PetscObject)st,"STFilterSetRange_C",STFilterSetRange_Filter);CHKERRQ(ierr);
-  ierr = PetscObjectComposeFunction((PetscObject)st,"STFilterGetRange_C",STFilterGetRange_Filter);CHKERRQ(ierr);
-  ierr = PetscObjectComposeFunction((PetscObject)st,"STFilterSetDegree_C",STFilterSetDegree_Filter);CHKERRQ(ierr);
-  ierr = PetscObjectComposeFunction((PetscObject)st,"STFilterGetDegree_C",STFilterGetDegree_Filter);CHKERRQ(ierr);
-  ierr = PetscObjectComposeFunction((PetscObject)st,"STFilterGetThreshold_C",STFilterGetThreshold_Filter);CHKERRQ(ierr);
+  PetscCall(PetscObjectComposeFunction((PetscObject)st,"STFilterSetInterval_C",STFilterSetInterval_Filter));
+  PetscCall(PetscObjectComposeFunction((PetscObject)st,"STFilterGetInterval_C",STFilterGetInterval_Filter));
+  PetscCall(PetscObjectComposeFunction((PetscObject)st,"STFilterSetRange_C",STFilterSetRange_Filter));
+  PetscCall(PetscObjectComposeFunction((PetscObject)st,"STFilterGetRange_C",STFilterGetRange_Filter));
+  PetscCall(PetscObjectComposeFunction((PetscObject)st,"STFilterSetDegree_C",STFilterSetDegree_Filter));
+  PetscCall(PetscObjectComposeFunction((PetscObject)st,"STFilterGetDegree_C",STFilterGetDegree_Filter));
+  PetscCall(PetscObjectComposeFunction((PetscObject)st,"STFilterGetThreshold_C",STFilterGetThreshold_Filter));
   PetscFunctionReturn(0);
 }
-
