@@ -1,7 +1,7 @@
 /*
    - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
    SLEPc - Scalable Library for Eigenvalue Problem Computations
-   Copyright (c) 2002-2021, Universitat Politecnica de Valencia, Spain
+   Copyright (c) 2002-, Universitat Politecnica de Valencia, Spain
 
    This file is part of SLEPc.
    SLEPc is distributed under a 2-clause BSD license (see LICENSE).
@@ -19,40 +19,32 @@ typedef struct {
 
 static PetscErrorCode STSetDefaultKSP_Precond(ST st)
 {
-  PetscErrorCode ierr;
   PC             pc;
   PCType         pctype;
   PetscBool      t0,t1;
 
   PetscFunctionBegin;
-  ierr = KSPGetPC(st->ksp,&pc);CHKERRQ(ierr);
-  ierr = PCGetType(pc,&pctype);CHKERRQ(ierr);
+  PetscCall(KSPGetPC(st->ksp,&pc));
+  PetscCall(PCGetType(pc,&pctype));
   if (!pctype && st->A && st->A[0]) {
-    if (st->matmode == ST_MATMODE_SHELL) {
-      ierr = PCSetType(pc,PCJACOBI);CHKERRQ(ierr);
-    } else {
-      ierr = MatHasOperation(st->A[0],MATOP_DUPLICATE,&t0);CHKERRQ(ierr);
-      if (st->nmat>1) {
-        ierr = MatHasOperation(st->A[0],MATOP_AXPY,&t1);CHKERRQ(ierr);
-      } else t1 = PETSC_TRUE;
-      ierr = PCSetType(pc,(t0 && t1)?PCBJACOBI:PCNONE);CHKERRQ(ierr);
+    if (st->matmode == ST_MATMODE_SHELL) PetscCall(PCSetType(pc,PCJACOBI));
+    else {
+      PetscCall(MatHasOperation(st->A[0],MATOP_DUPLICATE,&t0));
+      if (st->nmat>1) PetscCall(MatHasOperation(st->A[0],MATOP_AXPY,&t1));
+      else t1 = PETSC_TRUE;
+      PetscCall(PCSetType(pc,(t0 && t1)?PCBJACOBI:PCNONE));
     }
   }
-  ierr = KSPSetErrorIfNotConverged(st->ksp,PETSC_FALSE);CHKERRQ(ierr);
+  PetscCall(KSPSetErrorIfNotConverged(st->ksp,PETSC_FALSE));
   PetscFunctionReturn(0);
 }
 
 PetscErrorCode STPostSolve_Precond(ST st)
 {
-  PetscErrorCode ierr;
-
   PetscFunctionBegin;
   if (st->matmode == ST_MATMODE_INPLACE && !(st->Pmat || (PetscAbsScalar(st->sigma)>=PETSC_MAX_REAL && st->nmat>1))) {
-    if (st->nmat>1) {
-      ierr = MatAXPY(st->A[0],st->sigma,st->A[1],st->str);CHKERRQ(ierr);
-    } else {
-      ierr = MatShift(st->A[0],st->sigma);CHKERRQ(ierr);
-    }
+    if (st->nmat>1) PetscCall(MatAXPY(st->A[0],st->sigma,st->A[1],st->str));
+    else PetscCall(MatShift(st->A[0],st->sigma));
     st->Astate[0] = ((PetscObject)st->A[0])->state;
     st->state   = ST_STATE_INITIAL;
     st->opready = PETSC_FALSE;
@@ -68,30 +60,37 @@ PetscErrorCode STPostSolve_Precond(ST st)
 */
 PetscErrorCode STComputeOperator_Precond(ST st)
 {
-  PetscErrorCode ierr;
-
   PetscFunctionBegin;
   /* if the user did not set the shift, use the target value */
   if (!st->sigma_set) st->sigma = st->defsigma;
   st->M = NULL;
 
+  /* build custom preconditioner from the split matrices */
+  if (st->Psplit) {
+    if (!(PetscAbsScalar(st->sigma) < PETSC_MAX_REAL) && st->nmat>1) {
+      PetscCall(PetscObjectReference((PetscObject)st->Psplit[0]));
+      PetscCall(MatDestroy(&st->Pmat));
+      st->Pmat = st->Psplit[0];
+    } else if (PetscAbsScalar(st->sigma)<PETSC_MAX_REAL) PetscCall(STMatMAXPY_Private(st,-st->sigma,0.0,0,NULL,PETSC_TRUE,PETSC_TRUE,&st->Pmat));
+  }
+
   /* P = A-sigma*B */
   if (st->Pmat) {
-    ierr = PetscObjectReference((PetscObject)st->Pmat);CHKERRQ(ierr);
-    ierr = MatDestroy(&st->P);CHKERRQ(ierr);
+    PetscCall(PetscObjectReference((PetscObject)st->Pmat));
+    PetscCall(MatDestroy(&st->P));
     st->P = st->Pmat;
   } else {
-    ierr = PetscObjectReference((PetscObject)st->A[1]);CHKERRQ(ierr);
-    ierr = MatDestroy(&st->T[0]);CHKERRQ(ierr);
+    PetscCall(PetscObjectReference((PetscObject)st->A[1]));
+    PetscCall(MatDestroy(&st->T[0]));
     st->T[0] = st->A[1];
     if (!(PetscAbsScalar(st->sigma) < PETSC_MAX_REAL) && st->nmat>1) {
-      ierr = PetscObjectReference((PetscObject)st->T[0]);CHKERRQ(ierr);
-      ierr = MatDestroy(&st->P);CHKERRQ(ierr);
+      PetscCall(PetscObjectReference((PetscObject)st->T[0]));
+      PetscCall(MatDestroy(&st->P));
       st->P = st->T[0];
     } else if (PetscAbsScalar(st->sigma)<PETSC_MAX_REAL) {
-      ierr = STMatMAXPY_Private(st,-st->sigma,0.0,0,NULL,PetscNot(st->state==ST_STATE_UPDATED),&st->T[1]);CHKERRQ(ierr);
-      ierr = PetscObjectReference((PetscObject)st->T[1]);CHKERRQ(ierr);
-      ierr = MatDestroy(&st->P);CHKERRQ(ierr);
+      PetscCall(STMatMAXPY_Private(st,-st->sigma,0.0,0,NULL,PetscNot(st->state==ST_STATE_UPDATED),PETSC_FALSE,&st->T[1]));
+      PetscCall(PetscObjectReference((PetscObject)st->T[1]));
+      PetscCall(MatDestroy(&st->P));
       st->P = st->T[1];
     }
   }
@@ -100,12 +99,11 @@ PetscErrorCode STComputeOperator_Precond(ST st)
 
 PetscErrorCode STSetUp_Precond(ST st)
 {
-  PetscErrorCode ierr;
   ST_PRECOND     *ctx = (ST_PRECOND*)st->data;
 
   PetscFunctionBegin;
   if (st->P) {
-    ierr = STKSPSetOperators(st,ctx->ksphasmat?st->P:NULL,st->P);CHKERRQ(ierr);
+    PetscCall(ST_KSPSetOperators(st,ctx->ksphasmat?st->P:NULL,st->P));
     /* NOTE: we do not call KSPSetUp() here because some eigensolvers such as JD require a lazy setup */
   }
   PetscFunctionReturn(0);
@@ -113,21 +111,21 @@ PetscErrorCode STSetUp_Precond(ST st)
 
 PetscErrorCode STSetShift_Precond(ST st,PetscScalar newshift)
 {
-  PetscErrorCode ierr;
   ST_PRECOND     *ctx = (ST_PRECOND*)st->data;
 
   PetscFunctionBegin;
+  if (st->Psplit) { /* update custom preconditioner from the split matrices */
+    if (PetscAbsScalar(st->sigma)<PETSC_MAX_REAL || st->nmat==1) PetscCall(STMatMAXPY_Private(st,-st->sigma,0.0,0,NULL,PETSC_FALSE,PETSC_TRUE,&st->Pmat));
+  }
   if (st->transform && !st->Pmat) {
-    ierr = STMatMAXPY_Private(st,-newshift,-st->sigma,0,NULL,PETSC_FALSE,&st->T[1]);CHKERRQ(ierr);
+    PetscCall(STMatMAXPY_Private(st,-newshift,-st->sigma,0,NULL,PETSC_FALSE,PETSC_FALSE,&st->T[1]));
     if (st->P!=st->T[1]) {
-      ierr = PetscObjectReference((PetscObject)st->T[1]);CHKERRQ(ierr);
-      ierr = MatDestroy(&st->P);CHKERRQ(ierr);
+      PetscCall(PetscObjectReference((PetscObject)st->T[1]));
+      PetscCall(MatDestroy(&st->P));
       st->P = st->T[1];
     }
   }
-  if (st->P) {
-    ierr = STKSPSetOperators(st,ctx->ksphasmat?st->P:NULL,st->P);CHKERRQ(ierr);
-  }
+  if (st->P) PetscCall(ST_KSPSetOperators(st,ctx->ksphasmat?st->P:NULL,st->P));
   PetscFunctionReturn(0);
 }
 
@@ -150,7 +148,7 @@ static PetscErrorCode STPrecondSetKSPHasMat_Precond(ST st,PetscBool ksphasmat)
 
    Collective on st
 
-   Input Parameter:
+   Input Parameters:
 +  st - the spectral transformation context
 -  ksphasmat - the flag
 
@@ -165,12 +163,10 @@ static PetscErrorCode STPrecondSetKSPHasMat_Precond(ST st,PetscBool ksphasmat)
 @*/
 PetscErrorCode STPrecondSetKSPHasMat(ST st,PetscBool ksphasmat)
 {
-  PetscErrorCode ierr;
-
   PetscFunctionBegin;
   PetscValidHeaderSpecific(st,ST_CLASSID,1);
   PetscValidLogicalCollectiveBool(st,ksphasmat,2);
-  ierr = PetscTryMethod(st,"STPrecondSetKSPHasMat_C",(ST,PetscBool),(st,ksphasmat));CHKERRQ(ierr);
+  PetscTryMethod(st,"STPrecondSetKSPHasMat_C",(ST,PetscBool),(st,ksphasmat));
   PetscFunctionReturn(0);
 }
 
@@ -202,33 +198,28 @@ static PetscErrorCode STPrecondGetKSPHasMat_Precond(ST st,PetscBool *ksphasmat)
 @*/
 PetscErrorCode STPrecondGetKSPHasMat(ST st,PetscBool *ksphasmat)
 {
-  PetscErrorCode ierr;
-
   PetscFunctionBegin;
   PetscValidHeaderSpecific(st,ST_CLASSID,1);
   PetscValidBoolPointer(ksphasmat,2);
-  ierr = PetscUseMethod(st,"STPrecondGetKSPHasMat_C",(ST,PetscBool*),(st,ksphasmat));CHKERRQ(ierr);
+  PetscUseMethod(st,"STPrecondGetKSPHasMat_C",(ST,PetscBool*),(st,ksphasmat));
   PetscFunctionReturn(0);
 }
 
 PetscErrorCode STDestroy_Precond(ST st)
 {
-  PetscErrorCode ierr;
-
   PetscFunctionBegin;
-  ierr = PetscFree(st->data);CHKERRQ(ierr);
-  ierr = PetscObjectComposeFunction((PetscObject)st,"STPrecondGetKSPHasMat_C",NULL);CHKERRQ(ierr);
-  ierr = PetscObjectComposeFunction((PetscObject)st,"STPrecondSetKSPHasMat_C",NULL);CHKERRQ(ierr);
+  PetscCall(PetscFree(st->data));
+  PetscCall(PetscObjectComposeFunction((PetscObject)st,"STPrecondGetKSPHasMat_C",NULL));
+  PetscCall(PetscObjectComposeFunction((PetscObject)st,"STPrecondSetKSPHasMat_C",NULL));
   PetscFunctionReturn(0);
 }
 
 SLEPC_EXTERN PetscErrorCode STCreate_Precond(ST st)
 {
-  PetscErrorCode ierr;
   ST_PRECOND     *ctx;
 
   PetscFunctionBegin;
-  ierr = PetscNewLog(st,&ctx);CHKERRQ(ierr);
+  PetscCall(PetscNewLog(st,&ctx));
   st->data = (void*)ctx;
 
   st->usesksp = PETSC_TRUE;
@@ -244,8 +235,7 @@ SLEPC_EXTERN PetscErrorCode STCreate_Precond(ST st)
   st->ops->destroy         = STDestroy_Precond;
   st->ops->setdefaultksp   = STSetDefaultKSP_Precond;
 
-  ierr = PetscObjectComposeFunction((PetscObject)st,"STPrecondGetKSPHasMat_C",STPrecondGetKSPHasMat_Precond);CHKERRQ(ierr);
-  ierr = PetscObjectComposeFunction((PetscObject)st,"STPrecondSetKSPHasMat_C",STPrecondSetKSPHasMat_Precond);CHKERRQ(ierr);
+  PetscCall(PetscObjectComposeFunction((PetscObject)st,"STPrecondGetKSPHasMat_C",STPrecondGetKSPHasMat_Precond));
+  PetscCall(PetscObjectComposeFunction((PetscObject)st,"STPrecondSetKSPHasMat_C",STPrecondSetKSPHasMat_Precond));
   PetscFunctionReturn(0);
 }
-
