@@ -1,7 +1,7 @@
 /*
    - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
    SLEPc - Scalable Library for Eigenvalue Problem Computations
-   Copyright (c) 2002-2021, Universitat Politecnica de Valencia, Spain
+   Copyright (c) 2002-, Universitat Politecnica de Valencia, Spain
 
    This file is part of SLEPc.
    SLEPc is distributed under a 2-clause BSD license (see LICENSE).
@@ -29,10 +29,8 @@ const char *STMatModes[] = {"COPY","INPLACE","SHELL","STMatMode","ST_MATMODE_",0
 @*/
 PetscErrorCode STFinalizePackage(void)
 {
-  PetscErrorCode ierr;
-
   PetscFunctionBegin;
-  ierr = PetscFunctionListDestroy(&STList);CHKERRQ(ierr);
+  PetscCall(PetscFunctionListDestroy(&STList));
   STPackageInitialized = PETSC_FALSE;
   STRegisterAllCalled  = PETSC_FALSE;
   PetscFunctionReturn(0);
@@ -52,36 +50,35 @@ PetscErrorCode STInitializePackage(void)
   char           logList[256];
   PetscBool      opt,pkg;
   PetscClassId   classids[1];
-  PetscErrorCode ierr;
 
   PetscFunctionBegin;
   if (STPackageInitialized) PetscFunctionReturn(0);
   STPackageInitialized = PETSC_TRUE;
   /* Register Classes */
-  ierr = PetscClassIdRegister("Spectral Transform",&ST_CLASSID);CHKERRQ(ierr);
+  PetscCall(PetscClassIdRegister("Spectral Transform",&ST_CLASSID));
   /* Register Constructors */
-  ierr = STRegisterAll();CHKERRQ(ierr);
+  PetscCall(STRegisterAll());
   /* Register Events */
-  ierr = PetscLogEventRegister("STSetUp",ST_CLASSID,&ST_SetUp);CHKERRQ(ierr);
-  ierr = PetscLogEventRegister("STComputeOperatr",ST_CLASSID,&ST_ComputeOperator);CHKERRQ(ierr);
-  ierr = PetscLogEventRegister("STApply",ST_CLASSID,&ST_Apply);CHKERRQ(ierr);
-  ierr = PetscLogEventRegister("STApplyTranspose",ST_CLASSID,&ST_ApplyTranspose);CHKERRQ(ierr);
-  ierr = PetscLogEventRegister("STMatSetUp",ST_CLASSID,&ST_MatSetUp);CHKERRQ(ierr);
-  ierr = PetscLogEventRegister("STMatMult",ST_CLASSID,&ST_MatMult);CHKERRQ(ierr);
-  ierr = PetscLogEventRegister("STMatMultTranspose",ST_CLASSID,&ST_MatMultTranspose);CHKERRQ(ierr);
-  ierr = PetscLogEventRegister("STMatSolve",ST_CLASSID,&ST_MatSolve);CHKERRQ(ierr);
-  ierr = PetscLogEventRegister("STMatSolveTranspose",ST_CLASSID,&ST_MatSolveTranspose);CHKERRQ(ierr);
+  PetscCall(PetscLogEventRegister("STSetUp",ST_CLASSID,&ST_SetUp));
+  PetscCall(PetscLogEventRegister("STComputeOperatr",ST_CLASSID,&ST_ComputeOperator));
+  PetscCall(PetscLogEventRegister("STApply",ST_CLASSID,&ST_Apply));
+  PetscCall(PetscLogEventRegister("STApplyTranspose",ST_CLASSID,&ST_ApplyTranspose));
+  PetscCall(PetscLogEventRegister("STMatSetUp",ST_CLASSID,&ST_MatSetUp));
+  PetscCall(PetscLogEventRegister("STMatMult",ST_CLASSID,&ST_MatMult));
+  PetscCall(PetscLogEventRegister("STMatMultTranspose",ST_CLASSID,&ST_MatMultTranspose));
+  PetscCall(PetscLogEventRegister("STMatSolve",ST_CLASSID,&ST_MatSolve));
+  PetscCall(PetscLogEventRegister("STMatSolveTranspose",ST_CLASSID,&ST_MatSolveTranspose));
   /* Process Info */
   classids[0] = ST_CLASSID;
-  ierr = PetscInfoProcessClass("st",1,&classids[0]);CHKERRQ(ierr);
+  PetscCall(PetscInfoProcessClass("st",1,&classids[0]));
   /* Process summary exclusions */
-  ierr = PetscOptionsGetString(NULL,NULL,"-log_exclude",logList,sizeof(logList),&opt);CHKERRQ(ierr);
+  PetscCall(PetscOptionsGetString(NULL,NULL,"-log_exclude",logList,sizeof(logList),&opt));
   if (opt) {
-    ierr = PetscStrInList("st",logList,',',&pkg);CHKERRQ(ierr);
-    if (pkg) { ierr = PetscLogEventDeactivateClass(ST_CLASSID);CHKERRQ(ierr); }
+    PetscCall(PetscStrInList("st",logList,',',&pkg));
+    if (pkg) PetscCall(PetscLogEventDeactivateClass(ST_CLASSID));
   }
   /* Register package finalizer */
-  ierr = PetscRegisterFinalize(STFinalizePackage);CHKERRQ(ierr);
+  PetscCall(PetscRegisterFinalize(STFinalizePackage));
   PetscFunctionReturn(0);
 }
 
@@ -100,26 +97,26 @@ PetscErrorCode STInitializePackage(void)
 @*/
 PetscErrorCode STReset(ST st)
 {
-  PetscErrorCode ierr;
-
   PetscFunctionBegin;
   if (st) PetscValidHeaderSpecific(st,ST_CLASSID,1);
   if (!st) PetscFunctionReturn(0);
   STCheckNotSeized(st,1);
-  if (st->ops->reset) { ierr = (*st->ops->reset)(st);CHKERRQ(ierr); }
-  if (st->ksp) { ierr = KSPReset(st->ksp);CHKERRQ(ierr); }
-  ierr = MatDestroyMatrices(PetscMax(2,st->nmat),&st->T);CHKERRQ(ierr);
-  ierr = MatDestroyMatrices(PetscMax(2,st->nmat),&st->A);CHKERRQ(ierr);
+  if (st->ops->reset) PetscCall((*st->ops->reset)(st));
+  if (st->ksp) PetscCall(KSPReset(st->ksp));
+  PetscCall(MatDestroyMatrices(PetscMax(2,st->nmat),&st->T));
+  PetscCall(MatDestroyMatrices(PetscMax(2,st->nmat),&st->A));
   st->nmat = 0;
-  ierr = PetscFree(st->Astate);CHKERRQ(ierr);
-  ierr = MatDestroy(&st->Op);CHKERRQ(ierr);
-  ierr = MatDestroy(&st->P);CHKERRQ(ierr);
-  ierr = MatDestroy(&st->Pmat);CHKERRQ(ierr);
-  ierr = VecDestroyVecs(st->nwork,&st->work);CHKERRQ(ierr);
+  PetscCall(PetscFree(st->Astate));
+  PetscCall(MatDestroy(&st->Op));
+  PetscCall(MatDestroy(&st->P));
+  PetscCall(MatDestroy(&st->Pmat));
+  PetscCall(MatDestroyMatrices(st->nsplit,&st->Psplit));
+  st->nsplit = 0;
+  PetscCall(VecDestroyVecs(st->nwork,&st->work));
   st->nwork = 0;
-  ierr = VecDestroy(&st->wb);CHKERRQ(ierr);
-  ierr = VecDestroy(&st->wht);CHKERRQ(ierr);
-  ierr = VecDestroy(&st->D);CHKERRQ(ierr);
+  PetscCall(VecDestroy(&st->wb));
+  PetscCall(VecDestroy(&st->wht));
+  PetscCall(VecDestroy(&st->D));
   st->state   = ST_STATE_INITIAL;
   st->opready = PETSC_FALSE;
   PetscFunctionReturn(0);
@@ -139,16 +136,14 @@ PetscErrorCode STReset(ST st)
 @*/
 PetscErrorCode STDestroy(ST *st)
 {
-  PetscErrorCode ierr;
-
   PetscFunctionBegin;
   if (!*st) PetscFunctionReturn(0);
   PetscValidHeaderSpecific(*st,ST_CLASSID,1);
   if (--((PetscObject)(*st))->refct > 0) { *st = 0; PetscFunctionReturn(0); }
-  ierr = STReset(*st);CHKERRQ(ierr);
-  if ((*st)->ops->destroy) { ierr = (*(*st)->ops->destroy)(*st);CHKERRQ(ierr); }
-  ierr = KSPDestroy(&(*st)->ksp);CHKERRQ(ierr);
-  ierr = PetscHeaderDestroy(st);CHKERRQ(ierr);
+  PetscCall(STReset(*st));
+  if ((*st)->ops->destroy) PetscCall((*(*st)->ops->destroy)(*st));
+  PetscCall(KSPDestroy(&(*st)->ksp));
+  PetscCall(PetscHeaderDestroy(st));
   PetscFunctionReturn(0);
 }
 
@@ -161,7 +156,7 @@ PetscErrorCode STDestroy(ST *st)
 .  comm - MPI communicator
 
    Output Parameter:
-.  st - location to put the spectral transformation context
+.  newst - location to put the spectral transformation context
 
    Level: beginner
 
@@ -169,14 +164,13 @@ PetscErrorCode STDestroy(ST *st)
 @*/
 PetscErrorCode STCreate(MPI_Comm comm,ST *newst)
 {
-  PetscErrorCode ierr;
   ST             st;
 
   PetscFunctionBegin;
   PetscValidPointer(newst,2);
   *newst = 0;
-  ierr = STInitializePackage();CHKERRQ(ierr);
-  ierr = SlepcHeaderCreate(st,ST_CLASSID,"ST","Spectral Transformation","ST",comm,STDestroy,STView);CHKERRQ(ierr);
+  PetscCall(STInitializePackage());
+  PetscCall(SlepcHeaderCreate(st,ST_CLASSID,"ST","Spectral Transformation","ST",comm,STDestroy,STView));
 
   st->A            = NULL;
   st->nmat         = 0;
@@ -187,6 +181,10 @@ PetscErrorCode STCreate(MPI_Comm comm,ST *newst)
   st->transform    = PETSC_FALSE;
   st->D            = NULL;
   st->Pmat         = NULL;
+  st->Pmat_set     = PETSC_FALSE;
+  st->Psplit       = NULL;
+  st->nsplit       = 0;
+  st->strp         = UNKNOWN_NONZERO_PATTERN;
 
   st->ksp          = NULL;
   st->usesksp      = PETSC_FALSE;
@@ -214,22 +212,21 @@ PetscErrorCode STCreate(MPI_Comm comm,ST *newst)
 /*
    Checks whether the ST matrices are all symmetric or hermitian.
 */
-PETSC_STATIC_INLINE PetscErrorCode STMatIsSymmetricKnown(ST st,PetscBool *symm,PetscBool *herm)
+static inline PetscErrorCode STMatIsSymmetricKnown(ST st,PetscBool *symm,PetscBool *herm)
 {
-  PetscErrorCode ierr;
   PetscInt       i;
   PetscBool      sbaij=PETSC_FALSE,set,flg=PETSC_FALSE;
 
   PetscFunctionBegin;
   /* check if problem matrices are all sbaij */
   for (i=0;i<st->nmat;i++) {
-    ierr = PetscObjectTypeCompareAny((PetscObject)st->A[i],&sbaij,MATSEQSBAIJ,MATMPISBAIJ,"");CHKERRQ(ierr);
+    PetscCall(PetscObjectTypeCompareAny((PetscObject)st->A[i],&sbaij,MATSEQSBAIJ,MATMPISBAIJ,""));
     if (!sbaij) break;
   }
   /* check if user has set the symmetric flag */
   *symm = PETSC_TRUE;
   for (i=0;i<st->nmat;i++) {
-    ierr = MatIsSymmetricKnown(st->A[i],&set,&flg);CHKERRQ(ierr);
+    PetscCall(MatIsSymmetricKnown(st->A[i],&set,&flg));
     if (!set || !flg) { *symm = PETSC_FALSE; break; }
   }
   if (sbaij) *symm = PETSC_TRUE;
@@ -237,7 +234,7 @@ PETSC_STATIC_INLINE PetscErrorCode STMatIsSymmetricKnown(ST st,PetscBool *symm,P
   /* check if user has set the hermitian flag */
   *herm = PETSC_TRUE;
   for (i=0;i<st->nmat;i++) {
-    ierr = MatIsHermitianKnown(st->A[i],&set,&flg);CHKERRQ(ierr);
+    PetscCall(MatIsHermitianKnown(st->A[i],&set,&flg));
     if (!set || !flg) { *herm = PETSC_FALSE; break; }
   }
 #else
@@ -267,36 +264,36 @@ PETSC_STATIC_INLINE PetscErrorCode STMatIsSymmetricKnown(ST st,PetscBool *symm,P
 PetscErrorCode STSetMatrices(ST st,PetscInt n,Mat A[])
 {
   PetscInt       i;
-  PetscErrorCode ierr;
   PetscBool      same=PETSC_TRUE;
 
   PetscFunctionBegin;
   PetscValidHeaderSpecific(st,ST_CLASSID,1);
   PetscValidLogicalCollectiveInt(st,n,2);
-  if (n <= 0) SETERRQ1(PetscObjectComm((PetscObject)st),PETSC_ERR_ARG_OUTOFRANGE,"Must have one or more matrices, you have %D",n);
+  PetscCheck(n>0,PetscObjectComm((PetscObject)st),PETSC_ERR_ARG_OUTOFRANGE,"Must have one or more matrices, you have %" PetscInt_FMT,n);
   PetscValidPointer(A,3);
   PetscCheckSameComm(st,1,*A,3);
   STCheckNotSeized(st,1);
+  PetscCheck(!st->nsplit || st->nsplit==n,PetscObjectComm((PetscObject)st),PETSC_ERR_SUP,"The number of matrices must be the same as in STSetSplitPreconditioner()");
 
   if (st->state) {
     if (n!=st->nmat) same = PETSC_FALSE;
     for (i=0;same&&i<n;i++) {
       if (A[i]!=st->A[i]) same = PETSC_FALSE;
     }
-    if (!same) { ierr = STReset(st);CHKERRQ(ierr); }
+    if (!same) PetscCall(STReset(st));
   } else same = PETSC_FALSE;
   if (!same) {
-    ierr = MatDestroyMatrices(PetscMax(2,st->nmat),&st->A);CHKERRQ(ierr);
-    ierr = PetscCalloc1(PetscMax(2,n),&st->A);CHKERRQ(ierr);
-    ierr = PetscLogObjectMemory((PetscObject)st,PetscMax(2,n)*sizeof(Mat));CHKERRQ(ierr);
-    ierr = PetscFree(st->Astate);CHKERRQ(ierr);
-    ierr = PetscMalloc1(PetscMax(2,n),&st->Astate);CHKERRQ(ierr);
-    ierr = PetscLogObjectMemory((PetscObject)st,PetscMax(2,n)*sizeof(PetscInt));CHKERRQ(ierr);
+    PetscCall(MatDestroyMatrices(PetscMax(2,st->nmat),&st->A));
+    PetscCall(PetscCalloc1(PetscMax(2,n),&st->A));
+    PetscCall(PetscLogObjectMemory((PetscObject)st,PetscMax(2,n)*sizeof(Mat)));
+    PetscCall(PetscFree(st->Astate));
+    PetscCall(PetscMalloc1(PetscMax(2,n),&st->Astate));
+    PetscCall(PetscLogObjectMemory((PetscObject)st,PetscMax(2,n)*sizeof(PetscInt)));
   }
   for (i=0;i<n;i++) {
     PetscValidHeaderSpecific(A[i],MAT_CLASSID,3);
-    ierr = PetscObjectReference((PetscObject)A[i]);CHKERRQ(ierr);
-    ierr = MatDestroy(&st->A[i]);CHKERRQ(ierr);
+    PetscCall(PetscObjectReference((PetscObject)A[i]));
+    PetscCall(MatDestroy(&st->A[i]));
     st->A[i] = A[i];
     st->Astate[i] = ((PetscObject)A[i])->state;
   }
@@ -307,10 +304,9 @@ PetscErrorCode STSetMatrices(ST st,PetscInt n,Mat A[])
   st->nmat = n;
   if (same) st->state = ST_STATE_UPDATED;
   else st->state = ST_STATE_INITIAL;
+  PetscCheck(!same || !st->Psplit,PetscObjectComm((PetscObject)st),PETSC_ERR_SUP,"Support for changing the matrices while using a split preconditioner is not implemented yet");
   st->opready = PETSC_FALSE;
-  if (!same) {
-    ierr = STMatIsSymmetricKnown(st,&st->asymm,&st->aherm);CHKERRQ(ierr);
-  }
+  if (!same) PetscCall(STMatIsSymmetricKnown(st,&st->asymm,&st->aherm));
   PetscFunctionReturn(0);
 }
 
@@ -319,7 +315,7 @@ PetscErrorCode STSetMatrices(ST st,PetscInt n,Mat A[])
 
    Not collective, though parallel Mats are returned if the ST is parallel
 
-   Input Parameter:
+   Input Parameters:
 +  st - the spectral transformation context
 -  k  - the index of the requested matrix (starting in 0)
 
@@ -337,8 +333,8 @@ PetscErrorCode STGetMatrix(ST st,PetscInt k,Mat *A)
   PetscValidLogicalCollectiveInt(st,k,2);
   PetscValidPointer(A,3);
   STCheckMatrices(st,1);
-  if (k<0 || k>=st->nmat) SETERRQ1(PetscObjectComm((PetscObject)st),PETSC_ERR_ARG_OUTOFRANGE,"k must be between 0 and %D",st->nmat-1);
-  if (((PetscObject)st->A[k])->state!=st->Astate[k]) SETERRQ(PetscObjectComm((PetscObject)st),PETSC_ERR_SUP,"Cannot retrieve original matrices (have been modified)");
+  PetscCheck(k>=0 && k<st->nmat,PetscObjectComm((PetscObject)st),PETSC_ERR_ARG_OUTOFRANGE,"k must be between 0 and %" PetscInt_FMT,st->nmat-1);
+  PetscCheck(((PetscObject)st->A[k])->state==st->Astate[k],PetscObjectComm((PetscObject)st),PETSC_ERR_SUP,"Cannot retrieve original matrices (have been modified)");
   *A = st->A[k];
   PetscFunctionReturn(0);
 }
@@ -348,7 +344,7 @@ PetscErrorCode STGetMatrix(ST st,PetscInt k,Mat *A)
 
    Not collective, though parallel Mats are returned if the ST is parallel
 
-   Input Parameter:
+   Input Parameters:
 +  st - the spectral transformation context
 -  k  - the index of the requested matrix (starting in 0)
 
@@ -366,8 +362,8 @@ PetscErrorCode STGetMatrixTransformed(ST st,PetscInt k,Mat *T)
   PetscValidLogicalCollectiveInt(st,k,2);
   PetscValidPointer(T,3);
   STCheckMatrices(st,1);
-  if (k<0 || k>=st->nmat) SETERRQ1(PetscObjectComm((PetscObject)st),PETSC_ERR_ARG_OUTOFRANGE,"k must be between 0 and %D",st->nmat-1);
-  if (!st->T) SETERRQ(PetscObjectComm((PetscObject)st),PETSC_ERR_POINTER,"There are no transformed matrices");
+  PetscCheck(k>=0 && k<st->nmat,PetscObjectComm((PetscObject)st),PETSC_ERR_ARG_OUTOFRANGE,"k must be between 0 and %" PetscInt_FMT,st->nmat-1);
+  PetscCheck(st->T,PetscObjectComm((PetscObject)st),PETSC_ERR_POINTER,"There are no transformed matrices");
   *T = st->T[k];
   PetscFunctionReturn(0);
 }
@@ -429,7 +425,7 @@ PetscErrorCode STResetMatrixState(ST st)
 
    Collective on st
 
-   Input Parameter:
+   Input Parameters:
 +  st  - the spectral transformation context
 -  mat - the matrix that will be used in constructing the preconditioner
 
@@ -449,22 +445,30 @@ PetscErrorCode STResetMatrixState(ST st)
    If a preconditioner matrix is set, the default is to use an iterative KSP
    rather than a direct method.
 
+   An alternative to pass an approximation of A-sigma*B with this function is
+   to provide approximations of A and B via STSetSplitPreconditioner(). The
+   difference is that when sigma changes the preconditioner is recomputed.
+
+   Use NULL to remove a previously set matrix.
+
    Level: advanced
 
-.seealso: STGetPreconditionerMat(), STSetShift(), STGetOperator()
+.seealso: STGetPreconditionerMat(), STSetShift(), STGetOperator(), STSetSplitPreconditioner()
 @*/
 PetscErrorCode STSetPreconditionerMat(ST st,Mat mat)
 {
-  PetscErrorCode ierr;
-
   PetscFunctionBegin;
   PetscValidHeaderSpecific(st,ST_CLASSID,1);
-  PetscValidHeaderSpecific(mat,MAT_CLASSID,2);
-  PetscCheckSameComm(st,1,mat,2);
+  if (mat) {
+    PetscValidHeaderSpecific(mat,MAT_CLASSID,2);
+    PetscCheckSameComm(st,1,mat,2);
+  }
   STCheckNotSeized(st,1);
-  ierr = PetscObjectReference((PetscObject)mat);CHKERRQ(ierr);
-  ierr = MatDestroy(&st->Pmat);CHKERRQ(ierr);
+  PetscCheck(!mat || !st->Psplit,PetscObjectComm((PetscObject)st),PETSC_ERR_SUP,"Cannot call both STSetPreconditionerMat and STSetSplitPreconditioner");
+  if (mat) PetscCall(PetscObjectReference((PetscObject)mat));
+  PetscCall(MatDestroy(&st->Pmat));
   st->Pmat     = mat;
+  st->Pmat_set = mat? PETSC_TRUE: PETSC_FALSE;
   st->state    = ST_STATE_INITIAL;
   st->opready  = PETSC_FALSE;
   PetscFunctionReturn(0);
@@ -473,7 +477,7 @@ PetscErrorCode STSetPreconditionerMat(ST st,Mat mat)
 /*@
    STGetPreconditionerMat - Returns the matrix previously set by STSetPreconditionerMat().
 
-   Collective on st
+   Not Collective
 
    Input Parameter:
 .  st - the spectral transformation context
@@ -491,7 +495,138 @@ PetscErrorCode STGetPreconditionerMat(ST st,Mat *mat)
   PetscFunctionBegin;
   PetscValidHeaderSpecific(st,ST_CLASSID,1);
   PetscValidPointer(mat,2);
-  *mat = st->Pmat;
+  *mat = st->Pmat_set? st->Pmat: NULL;
+  PetscFunctionReturn(0);
+}
+
+/*@
+   STSetSplitPreconditioner - Sets the matrices from which to build the preconditioner
+   in split form.
+
+   Collective on st
+
+   Input Parameters:
++  st     - the spectral transformation context
+.  n      - number of matrices
+.  Psplit - array of matrices
+-  strp   - structure flag for Psplit matrices
+
+   Notes:
+   The number of matrices passed here must be the same as in STSetMatrices().
+
+   For linear eigenproblems, the preconditioner matrix is computed as
+   Pmat(sigma) = A0-sigma*B0, where A0 and B0 are approximations of A and B
+   (the eigenproblem matrices) provided via the Psplit array in this function.
+   Compared to STSetPreconditionerMat(), this function allows setting a preconditioner
+   in a way that is independent of the shift sigma. Whenever the value of sigma
+   changes the preconditioner is recomputed.
+
+   Similarly, for polynomial eigenproblems the matrix for the preconditioner
+   is expressed as Pmat(sigma) = sum_i Psplit_i*phi_i(sigma), for i=1,...,n, where
+   the phi_i's are the polynomial basis functions.
+
+   The structure flag provides information about the relative nonzero pattern of the
+   Psplit_i matrices, in the same way as in STSetMatStructure().
+
+   Use n=0 to reset a previously set split preconditioner.
+
+   Level: advanced
+
+.seealso: STGetSplitPreconditionerTerm(), STGetSplitPreconditionerInfo(), STSetPreconditionerMat(), STSetMatrices(), STSetMatStructure()
+ @*/
+PetscErrorCode STSetSplitPreconditioner(ST st,PetscInt n,Mat Psplit[],MatStructure strp)
+{
+  PetscInt       i,N=0,M,M0=0,mloc,nloc,mloc0=0;
+
+  PetscFunctionBegin;
+  PetscValidHeaderSpecific(st,ST_CLASSID,1);
+  PetscValidLogicalCollectiveInt(st,n,2);
+  PetscCheck(n>=0,PetscObjectComm((PetscObject)st),PETSC_ERR_ARG_OUTOFRANGE,"Negative value of n = %" PetscInt_FMT,n);
+  PetscCheck(!n || !st->Pmat_set,PetscObjectComm((PetscObject)st),PETSC_ERR_SUP,"Cannot call both STSetPreconditionerMat and STSetSplitPreconditioner");
+  PetscCheck(!n || !st->nmat || st->nmat==n,PetscObjectComm((PetscObject)st),PETSC_ERR_SUP,"The number of matrices must be the same as in STSetMatrices()");
+  if (n) PetscValidPointer(Psplit,3);
+  PetscValidLogicalCollectiveEnum(st,strp,4);
+  STCheckNotSeized(st,1);
+
+  for (i=0;i<n;i++) {
+    PetscValidHeaderSpecific(Psplit[i],MAT_CLASSID,3);
+    PetscCheckSameComm(st,1,Psplit[i],3);
+    PetscCall(MatGetSize(Psplit[i],&M,&N));
+    PetscCall(MatGetLocalSize(Psplit[i],&mloc,&nloc));
+    PetscCheck(M==N,PetscObjectComm((PetscObject)st),PETSC_ERR_ARG_WRONG,"Psplit[%" PetscInt_FMT "] is a non-square matrix (%" PetscInt_FMT " rows, %" PetscInt_FMT " cols)",i,M,N);
+    PetscCheck(mloc==nloc,PetscObjectComm((PetscObject)st),PETSC_ERR_ARG_WRONG,"Psplit[%" PetscInt_FMT "] does not have equal row and column local sizes (%" PetscInt_FMT ", %" PetscInt_FMT ")",i,mloc,nloc);
+    if (!i) { M0 = M; mloc0 = mloc; }
+    PetscCheck(M==M0,PetscObjectComm((PetscObject)st),PETSC_ERR_ARG_INCOMP,"Dimensions of Psplit[%" PetscInt_FMT "] do not match with previous matrices (%" PetscInt_FMT ", %" PetscInt_FMT ")",i,M,M0);
+    PetscCheck(mloc==mloc0,PetscObjectComm((PetscObject)st),PETSC_ERR_ARG_INCOMP,"Local dimensions of Psplit[%" PetscInt_FMT "] do not match with previous matrices (%" PetscInt_FMT ", %" PetscInt_FMT ")",i,mloc,mloc0);
+    PetscCall(PetscObjectReference((PetscObject)Psplit[i]));
+  }
+
+  if (st->Psplit) PetscCall(MatDestroyMatrices(st->nsplit,&st->Psplit));
+
+  /* allocate space and copy matrices */
+  if (n) {
+    PetscCall(PetscMalloc1(n,&st->Psplit));
+    PetscCall(PetscLogObjectMemory((PetscObject)st,n*sizeof(Mat)));
+    for (i=0;i<n;i++) st->Psplit[i] = Psplit[i];
+  }
+  st->nsplit = n;
+  st->strp   = strp;
+  st->state  = ST_STATE_INITIAL;
+  PetscFunctionReturn(0);
+}
+
+/*@
+   STGetSplitPreconditionerTerm - Gets the matrices associated with
+   the split preconditioner.
+
+   Not collective, though parallel Mats are returned if the ST is parallel
+
+   Input Parameters:
++  st - the spectral transformation context
+-  k  - the index of the requested matrix (starting in 0)
+
+   Output Parameter:
+.  Psplit - the returned matrix
+
+   Level: advanced
+
+.seealso: STSetSplitPreconditioner(), STGetSplitPreconditionerInfo()
+@*/
+PetscErrorCode STGetSplitPreconditionerTerm(ST st,PetscInt k,Mat *Psplit)
+{
+  PetscFunctionBegin;
+  PetscValidHeaderSpecific(st,ST_CLASSID,1);
+  PetscValidLogicalCollectiveInt(st,k,2);
+  PetscValidPointer(Psplit,3);
+  PetscCheck(k>=0 && k<st->nsplit,PetscObjectComm((PetscObject)st),PETSC_ERR_ARG_OUTOFRANGE,"k must be between 0 and %" PetscInt_FMT,st->nsplit-1);
+  PetscCheck(st->Psplit,PetscObjectComm((PetscObject)st),PETSC_ERR_ORDER,"You have not called STSetSplitPreconditioner()");
+  *Psplit = st->Psplit[k];
+  PetscFunctionReturn(0);
+}
+
+/*@
+   STGetSplitPreconditionerInfo - Returns the number of matrices of the split
+   preconditioner, as well as the structure flag.
+
+   Not collective
+
+   Input Parameter:
+.  st - the spectral transformation context
+
+   Output Parameters:
++  n    - the number of matrices passed in STSetSplitPreconditioner()
+-  strp - the matrix structure flag passed in STSetSplitPreconditioner()
+
+   Level: advanced
+
+.seealso: STSetSplitPreconditioner(), STGetSplitPreconditionerTerm()
+@*/
+PetscErrorCode STGetSplitPreconditionerInfo(ST st,PetscInt *n,MatStructure *strp)
+{
+  PetscFunctionBegin;
+  PetscValidHeaderSpecific(st,ST_CLASSID,1);
+  if (n)    *n    = st->nsplit;
+  if (strp) *strp = st->strp;
   PetscFunctionReturn(0);
 }
 
@@ -517,17 +652,13 @@ PetscErrorCode STGetPreconditionerMat(ST st,Mat *mat)
 @*/
 PetscErrorCode STSetShift(ST st,PetscScalar shift)
 {
-  PetscErrorCode ierr;
-
   PetscFunctionBegin;
   PetscValidHeaderSpecific(st,ST_CLASSID,1);
   PetscValidType(st,1);
   PetscValidLogicalCollectiveScalar(st,shift,2);
   if (st->sigma != shift) {
     STCheckNotSeized(st,1);
-    if (st->state==ST_STATE_SETUP && st->ops->setshift) {
-      ierr = (*st->ops->setshift)(st,shift);CHKERRQ(ierr);
-    }
+    if (st->state==ST_STATE_SETUP && st->ops->setshift) PetscCall((*st->ops->setshift)(st,shift));
     st->sigma = shift;
   }
   st->sigma_set = PETSC_TRUE;
@@ -633,8 +764,6 @@ PetscErrorCode STScaleShift(ST st,PetscScalar factor)
 @*/
 PetscErrorCode STSetBalanceMatrix(ST st,Vec D)
 {
-  PetscErrorCode ierr;
-
   PetscFunctionBegin;
   PetscValidHeaderSpecific(st,ST_CLASSID,1);
   if (st->D == D) PetscFunctionReturn(0);
@@ -642,9 +771,9 @@ PetscErrorCode STSetBalanceMatrix(ST st,Vec D)
   if (D) {
     PetscValidHeaderSpecific(D,VEC_CLASSID,2);
     PetscCheckSameComm(st,1,D,2);
-    ierr = PetscObjectReference((PetscObject)D);CHKERRQ(ierr);
+    PetscCall(PetscObjectReference((PetscObject)D));
   }
-  ierr = VecDestroy(&st->D);CHKERRQ(ierr);
+  PetscCall(VecDestroy(&st->D));
   st->D = D;
   st->state   = ST_STATE_INITIAL;
   st->opready = PETSC_FALSE;
@@ -691,14 +820,14 @@ PetscErrorCode STGetBalanceMatrix(ST st,Vec *D)
 -  left  - (optional) vector that the matrix vector product can be stored in
 
    Level: developer
+
+.seealso: STMatCreateVecsEmpty()
 @*/
 PetscErrorCode STMatCreateVecs(ST st,Vec *right,Vec *left)
 {
-  PetscErrorCode ierr;
-
   PetscFunctionBegin;
   STCheckMatrices(st,1);
-  ierr = MatCreateVecs(st->A[0],right,left);CHKERRQ(ierr);
+  PetscCall(MatCreateVecs(st->A[0],right,left));
   PetscFunctionReturn(0);
 }
 
@@ -717,15 +846,13 @@ PetscErrorCode STMatCreateVecs(ST st,Vec *right,Vec *left)
 
    Level: developer
 
-.seealso: MatCreateVecsEmpty()
+.seealso: STMatCreateVecs(), MatCreateVecsEmpty()
 @*/
 PetscErrorCode STMatCreateVecsEmpty(ST st,Vec *right,Vec *left)
 {
-  PetscErrorCode ierr;
-
   PetscFunctionBegin;
   STCheckMatrices(st,1);
-  ierr = MatCreateVecsEmpty(st->A[0],right,left);CHKERRQ(ierr);
+  PetscCall(MatCreateVecsEmpty(st->A[0],right,left));
   PetscFunctionReturn(0);
 }
 
@@ -742,14 +869,14 @@ PetscErrorCode STMatCreateVecsEmpty(ST st,Vec *right,Vec *left)
 -  n - the number of global columns
 
    Level: developer
+
+.seealso: STMatGetLocalSize()
 @*/
 PetscErrorCode STMatGetSize(ST st,PetscInt *m,PetscInt *n)
 {
-  PetscErrorCode ierr;
-
   PetscFunctionBegin;
   STCheckMatrices(st,1);
-  ierr = MatGetSize(st->A[0],m,n);CHKERRQ(ierr);
+  PetscCall(MatGetSize(st->A[0],m,n));
   PetscFunctionReturn(0);
 }
 
@@ -766,14 +893,14 @@ PetscErrorCode STMatGetSize(ST st,PetscInt *m,PetscInt *n)
 -  n - the number of local columns
 
    Level: developer
+
+.seealso: STMatGetSize()
 @*/
 PetscErrorCode STMatGetLocalSize(ST st,PetscInt *m,PetscInt *n)
 {
-  PetscErrorCode ierr;
-
   PetscFunctionBegin;
   STCheckMatrices(st,1);
-  ierr = MatGetLocalSize(st->A[0],m,n);CHKERRQ(ierr);
+  PetscCall(MatGetLocalSize(st->A[0],m,n));
   PetscFunctionReturn(0);
 }
 
@@ -798,14 +925,12 @@ PetscErrorCode STMatGetLocalSize(ST st,PetscInt *m,PetscInt *n)
 @*/
 PetscErrorCode STSetOptionsPrefix(ST st,const char *prefix)
 {
-  PetscErrorCode ierr;
-
   PetscFunctionBegin;
   PetscValidHeaderSpecific(st,ST_CLASSID,1);
-  if (!st->ksp) { ierr = STGetKSP(st,&st->ksp);CHKERRQ(ierr); }
-  ierr = KSPSetOptionsPrefix(st->ksp,prefix);CHKERRQ(ierr);
-  ierr = KSPAppendOptionsPrefix(st->ksp,"st_");CHKERRQ(ierr);
-  ierr = PetscObjectSetOptionsPrefix((PetscObject)st,prefix);CHKERRQ(ierr);
+  if (!st->ksp) PetscCall(STGetKSP(st,&st->ksp));
+  PetscCall(KSPSetOptionsPrefix(st->ksp,prefix));
+  PetscCall(KSPAppendOptionsPrefix(st->ksp,"st_"));
+  PetscCall(PetscObjectSetOptionsPrefix((PetscObject)st,prefix));
   PetscFunctionReturn(0);
 }
 
@@ -830,14 +955,12 @@ PetscErrorCode STSetOptionsPrefix(ST st,const char *prefix)
 @*/
 PetscErrorCode STAppendOptionsPrefix(ST st,const char *prefix)
 {
-  PetscErrorCode ierr;
-
   PetscFunctionBegin;
   PetscValidHeaderSpecific(st,ST_CLASSID,1);
-  ierr = PetscObjectAppendOptionsPrefix((PetscObject)st,prefix);CHKERRQ(ierr);
-  if (!st->ksp) { ierr = STGetKSP(st,&st->ksp);CHKERRQ(ierr); }
-  ierr = KSPSetOptionsPrefix(st->ksp,((PetscObject)st)->prefix);CHKERRQ(ierr);
-  ierr = KSPAppendOptionsPrefix(st->ksp,"st_");CHKERRQ(ierr);
+  PetscCall(PetscObjectAppendOptionsPrefix((PetscObject)st,prefix));
+  if (!st->ksp) PetscCall(STGetKSP(st,&st->ksp));
+  PetscCall(KSPSetOptionsPrefix(st->ksp,((PetscObject)st)->prefix));
+  PetscCall(KSPAppendOptionsPrefix(st->ksp,"st_"));
   PetscFunctionReturn(0);
 }
 
@@ -863,12 +986,10 @@ PetscErrorCode STAppendOptionsPrefix(ST st,const char *prefix)
 @*/
 PetscErrorCode STGetOptionsPrefix(ST st,const char *prefix[])
 {
-  PetscErrorCode ierr;
-
   PetscFunctionBegin;
   PetscValidHeaderSpecific(st,ST_CLASSID,1);
   PetscValidPointer(prefix,2);
-  ierr = PetscObjectGetOptionsPrefix((PetscObject)st,prefix);CHKERRQ(ierr);
+  PetscCall(PetscObjectGetOptionsPrefix((PetscObject)st,prefix));
   PetscFunctionReturn(0);
 }
 
@@ -898,57 +1019,51 @@ PetscErrorCode STGetOptionsPrefix(ST st,const char *prefix[])
 @*/
 PetscErrorCode STView(ST st,PetscViewer viewer)
 {
-  PetscErrorCode ierr;
   STType         cstr;
   char           str[50];
   PetscBool      isascii,isstring;
 
   PetscFunctionBegin;
   PetscValidHeaderSpecific(st,ST_CLASSID,1);
-  if (!viewer) {
-    ierr = PetscViewerASCIIGetStdout(PetscObjectComm((PetscObject)st),&viewer);CHKERRQ(ierr);
-  }
+  if (!viewer) PetscCall(PetscViewerASCIIGetStdout(PetscObjectComm((PetscObject)st),&viewer));
   PetscValidHeaderSpecific(viewer,PETSC_VIEWER_CLASSID,2);
   PetscCheckSameComm(st,1,viewer,2);
 
-  ierr = PetscObjectTypeCompare((PetscObject)viewer,PETSCVIEWERASCII,&isascii);CHKERRQ(ierr);
-  ierr = PetscObjectTypeCompare((PetscObject)viewer,PETSCVIEWERSTRING,&isstring);CHKERRQ(ierr);
+  PetscCall(PetscObjectTypeCompare((PetscObject)viewer,PETSCVIEWERASCII,&isascii));
+  PetscCall(PetscObjectTypeCompare((PetscObject)viewer,PETSCVIEWERSTRING,&isstring));
   if (isascii) {
-    ierr = PetscObjectPrintClassNamePrefixType((PetscObject)st,viewer);CHKERRQ(ierr);
+    PetscCall(PetscObjectPrintClassNamePrefixType((PetscObject)st,viewer));
     if (st->ops->view) {
-      ierr = PetscViewerASCIIPushTab(viewer);CHKERRQ(ierr);
-      ierr = (*st->ops->view)(st,viewer);CHKERRQ(ierr);
-      ierr = PetscViewerASCIIPopTab(viewer);CHKERRQ(ierr);
+      PetscCall(PetscViewerASCIIPushTab(viewer));
+      PetscCall((*st->ops->view)(st,viewer));
+      PetscCall(PetscViewerASCIIPopTab(viewer));
     }
-    ierr = SlepcSNPrintfScalar(str,sizeof(str),st->sigma,PETSC_FALSE);CHKERRQ(ierr);
-    ierr = PetscViewerASCIIPrintf(viewer,"  shift: %s\n",str);CHKERRQ(ierr);
-    ierr = PetscViewerASCIIPrintf(viewer,"  number of matrices: %D\n",st->nmat);CHKERRQ(ierr);
+    PetscCall(SlepcSNPrintfScalar(str,sizeof(str),st->sigma,PETSC_FALSE));
+    PetscCall(PetscViewerASCIIPrintf(viewer,"  shift: %s\n",str));
+    PetscCall(PetscViewerASCIIPrintf(viewer,"  number of matrices: %" PetscInt_FMT "\n",st->nmat));
     switch (st->matmode) {
     case ST_MATMODE_COPY:
       break;
     case ST_MATMODE_INPLACE:
-      ierr = PetscViewerASCIIPrintf(viewer,"  shifting the matrix and unshifting at exit\n");CHKERRQ(ierr);
+      PetscCall(PetscViewerASCIIPrintf(viewer,"  shifting the matrix and unshifting at exit\n"));
       break;
     case ST_MATMODE_SHELL:
-      ierr = PetscViewerASCIIPrintf(viewer,"  using a shell matrix\n");CHKERRQ(ierr);
+      PetscCall(PetscViewerASCIIPrintf(viewer,"  using a shell matrix\n"));
       break;
     }
-    if (st->nmat>1 && st->matmode != ST_MATMODE_SHELL) {
-      ierr = PetscViewerASCIIPrintf(viewer,"  all matrices have %s\n",MatStructures[st->str]);CHKERRQ(ierr);
-    }
-    if (st->transform && st->nmat>2) {
-      ierr = PetscViewerASCIIPrintf(viewer,"  computing transformed matrices\n");CHKERRQ(ierr);
-    }
+    if (st->nmat>1 && st->matmode != ST_MATMODE_SHELL) PetscCall(PetscViewerASCIIPrintf(viewer,"  nonzero pattern of the matrices: %s\n",MatStructures[st->str]));
+    if (st->Psplit) PetscCall(PetscViewerASCIIPrintf(viewer,"  using split preconditioner matrices with %s\n",MatStructures[st->strp]));
+    if (st->transform && st->nmat>2) PetscCall(PetscViewerASCIIPrintf(viewer,"  computing transformed matrices\n"));
   } else if (isstring) {
-    ierr = STGetType(st,&cstr);CHKERRQ(ierr);
-    ierr = PetscViewerStringSPrintf(viewer," %-7.7s",cstr);CHKERRQ(ierr);
-    if (st->ops->view) { ierr = (*st->ops->view)(st,viewer);CHKERRQ(ierr); }
+    PetscCall(STGetType(st,&cstr));
+    PetscCall(PetscViewerStringSPrintf(viewer," %-7.7s",cstr));
+    if (st->ops->view) PetscCall((*st->ops->view)(st,viewer));
   }
   if (st->usesksp) {
-    if (!st->ksp) { ierr = STGetKSP(st,&st->ksp);CHKERRQ(ierr); }
-    ierr = PetscViewerASCIIPushTab(viewer);CHKERRQ(ierr);
-    ierr = KSPView(st->ksp,viewer);CHKERRQ(ierr);
-    ierr = PetscViewerASCIIPopTab(viewer);CHKERRQ(ierr);
+    if (!st->ksp) PetscCall(STGetKSP(st,&st->ksp));
+    PetscCall(PetscViewerASCIIPushTab(viewer));
+    PetscCall(KSPView(st->ksp,viewer));
+    PetscCall(PetscViewerASCIIPopTab(viewer));
   }
   PetscFunctionReturn(0);
 }
@@ -969,11 +1084,9 @@ PetscErrorCode STView(ST st,PetscViewer viewer)
 @*/
 PetscErrorCode STViewFromOptions(ST st,PetscObject obj,const char name[])
 {
-  PetscErrorCode ierr;
-
   PetscFunctionBegin;
   PetscValidHeaderSpecific(st,ST_CLASSID,1);
-  ierr = PetscObjectViewFromOptions((PetscObject)st,obj,name);CHKERRQ(ierr);
+  PetscCall(PetscObjectViewFromOptions((PetscObject)st,obj,name));
   PetscFunctionReturn(0);
 }
 
@@ -1006,11 +1119,8 @@ $     -st_type my_transform
 @*/
 PetscErrorCode STRegister(const char *name,PetscErrorCode (*function)(ST))
 {
-  PetscErrorCode ierr;
-
   PetscFunctionBegin;
-  ierr = STInitializePackage();CHKERRQ(ierr);
-  ierr = PetscFunctionListAdd(&STList,name,function);CHKERRQ(ierr);
+  PetscCall(STInitializePackage());
+  PetscCall(PetscFunctionListAdd(&STList,name,function));
   PetscFunctionReturn(0);
 }
-
