@@ -1,7 +1,7 @@
 /*
    - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
    SLEPc - Scalable Library for Eigenvalue Problem Computations
-   Copyright (c) 2002-2021, Universitat Politecnica de Valencia, Spain
+   Copyright (c) 2002-, Universitat Politecnica de Valencia, Spain
 
    This file is part of SLEPc.
    SLEPc is distributed under a 2-clause BSD license (see LICENSE).
@@ -45,27 +45,27 @@ PetscFunctionList STList = 0;
 @*/
 PetscErrorCode STSetType(ST st,STType type)
 {
-  PetscErrorCode ierr,(*r)(ST);
+  PetscErrorCode (*r)(ST);
   PetscBool      match;
 
   PetscFunctionBegin;
   PetscValidHeaderSpecific(st,ST_CLASSID,1);
   PetscValidCharPointer(type,2);
 
-  ierr = PetscObjectTypeCompare((PetscObject)st,type,&match);CHKERRQ(ierr);
+  PetscCall(PetscObjectTypeCompare((PetscObject)st,type,&match));
   if (match) PetscFunctionReturn(0);
   STCheckNotSeized(st,1);
 
-  ierr =  PetscFunctionListFind(STList,type,&r);CHKERRQ(ierr);
-  if (!r) SETERRQ1(PetscObjectComm((PetscObject)st),PETSC_ERR_ARG_UNKNOWN_TYPE,"Unable to find requested ST type %s",type);
+  PetscCall(PetscFunctionListFind(STList,type,&r));
+  PetscCheck(r,PetscObjectComm((PetscObject)st),PETSC_ERR_ARG_UNKNOWN_TYPE,"Unable to find requested ST type %s",type);
 
-  if (st->ops->destroy) { ierr = (*st->ops->destroy)(st);CHKERRQ(ierr); }
-  ierr = PetscMemzero(st->ops,sizeof(struct _STOps));CHKERRQ(ierr);
+  if (st->ops->destroy) PetscCall((*st->ops->destroy)(st));
+  PetscCall(PetscMemzero(st->ops,sizeof(struct _STOps)));
 
   st->state   = ST_STATE_INITIAL;
   st->opready = PETSC_FALSE;
-  ierr = PetscObjectChangeTypeName((PetscObject)st,type);CHKERRQ(ierr);
-  ierr = (*r)(st);CHKERRQ(ierr);
+  PetscCall(PetscObjectChangeTypeName((PetscObject)st,type));
+  PetscCall((*r)(st));
   PetscFunctionReturn(0);
 }
 
@@ -78,7 +78,7 @@ PetscErrorCode STSetType(ST st,STType type)
 .  st - the spectral transformation context
 
    Output Parameter:
-.  name - name of the spectral transformation
+.  type - name of the spectral transformation
 
    Level: intermediate
 
@@ -105,6 +105,8 @@ PetscErrorCode STGetType(ST st,STType *type)
 .  st - the spectral transformation context
 
    Level: beginner
+
+.seealso: STSetOptionsPrefix()
 @*/
 PetscErrorCode STSetFromOptions(ST st)
 {
@@ -112,42 +114,36 @@ PetscErrorCode STSetFromOptions(ST st)
   PetscScalar    s;
   char           type[256];
   PetscBool      flg,bval;
-  const char     *structure_list[4] = {"different","subset","same","unknown"};
   STMatMode      mode;
   MatStructure   mstr;
 
   PetscFunctionBegin;
   PetscValidHeaderSpecific(st,ST_CLASSID,1);
-  ierr = STRegisterAll();CHKERRQ(ierr);
-  ierr = PetscObjectOptionsBegin((PetscObject)st);CHKERRQ(ierr);
-    ierr = PetscOptionsFList("-st_type","Spectral transformation","STSetType",STList,(char*)(((PetscObject)st)->type_name?((PetscObject)st)->type_name:STSHIFT),type,sizeof(type),&flg);CHKERRQ(ierr);
-    if (flg) {
-      ierr = STSetType(st,type);CHKERRQ(ierr);
-    } else if (!((PetscObject)st)->type_name) {
-      ierr = STSetType(st,STSHIFT);CHKERRQ(ierr);
-    }
+  PetscCall(STRegisterAll());
+  ierr = PetscObjectOptionsBegin((PetscObject)st);PetscCall(ierr);
+    PetscCall(PetscOptionsFList("-st_type","Spectral transformation","STSetType",STList,(char*)(((PetscObject)st)->type_name?((PetscObject)st)->type_name:STSHIFT),type,sizeof(type),&flg));
+    if (flg) PetscCall(STSetType(st,type));
+    else if (!((PetscObject)st)->type_name) PetscCall(STSetType(st,STSHIFT));
 
-    ierr = PetscOptionsScalar("-st_shift","Value of the shift","STSetShift",st->sigma,&s,&flg);CHKERRQ(ierr);
-    if (flg) { ierr = STSetShift(st,s);CHKERRQ(ierr); }
+    PetscCall(PetscOptionsScalar("-st_shift","Value of the shift","STSetShift",st->sigma,&s,&flg));
+    if (flg) PetscCall(STSetShift(st,s));
 
-    ierr = PetscOptionsEnum("-st_matmode","Matrix mode for transformed matrices","STSetMatMode",STMatModes,(PetscEnum)st->matmode,(PetscEnum*)&mode,&flg);CHKERRQ(ierr);
-    if (flg) { ierr = STSetMatMode(st,mode);CHKERRQ(ierr); }
+    PetscCall(PetscOptionsEnum("-st_matmode","Matrix mode for transformed matrices","STSetMatMode",STMatModes,(PetscEnum)st->matmode,(PetscEnum*)&mode,&flg));
+    if (flg) PetscCall(STSetMatMode(st,mode));
 
-    ierr = PetscOptionsEList("-st_matstructure","Relation of the sparsity pattern of the matrices","STSetMatStructure",structure_list,4,structure_list[st->str],(PetscInt*)&mstr,&flg);CHKERRQ(ierr);
-    if (flg) { ierr = STSetMatStructure(st,mstr);CHKERRQ(ierr); }
+    PetscCall(PetscOptionsEnum("-st_matstructure","Relation of the sparsity pattern of the matrices","STSetMatStructure",MatStructures,(PetscEnum)st->str,(PetscEnum*)&mstr,&flg));
+    if (flg) PetscCall(STSetMatStructure(st,mstr));
 
-    ierr = PetscOptionsBool("-st_transform","Whether transformed matrices are computed or not","STSetTransform",st->transform,&bval,&flg);CHKERRQ(ierr);
-    if (flg) { ierr = STSetTransform(st,bval);CHKERRQ(ierr); }
+    PetscCall(PetscOptionsBool("-st_transform","Whether transformed matrices are computed or not","STSetTransform",st->transform,&bval,&flg));
+    if (flg) PetscCall(STSetTransform(st,bval));
 
-    if (st->ops->setfromoptions) {
-      ierr = (*st->ops->setfromoptions)(PetscOptionsObject,st);CHKERRQ(ierr);
-    }
-    ierr = PetscObjectProcessOptionsHandlers(PetscOptionsObject,(PetscObject)st);CHKERRQ(ierr);
-  ierr = PetscOptionsEnd();CHKERRQ(ierr);
+    if (st->ops->setfromoptions) PetscCall((*st->ops->setfromoptions)(PetscOptionsObject,st));
+    PetscCall(PetscObjectProcessOptionsHandlers(PetscOptionsObject,(PetscObject)st));
+  ierr = PetscOptionsEnd();PetscCall(ierr);
 
   if (st->usesksp) {
-    ierr = STSetDefaultKSP(st);CHKERRQ(ierr);
-    ierr = KSPSetFromOptions(st->ksp);CHKERRQ(ierr);
+    PetscCall(STSetDefaultKSP(st));
+    PetscCall(KSPSetFromOptions(st->ksp));
   }
   PetscFunctionReturn(0);
 }
@@ -366,4 +362,3 @@ PetscErrorCode STGetTransform(ST st,PetscBool *flg)
   *flg = st->transform;
   PetscFunctionReturn(0);
 }
-
