@@ -1,7 +1,7 @@
 /*
    - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
    SLEPc - Scalable Library for Eigenvalue Problem Computations
-   Copyright (c) 2002-2021, Universitat Politecnica de Valencia, Spain
+   Copyright (c) 2002-, Universitat Politecnica de Valencia, Spain
 
    This file is part of SLEPc.
    SLEPc is distributed under a 2-clause BSD license (see LICENSE).
@@ -15,17 +15,12 @@
 
 PetscErrorCode STApply_Generic(ST st,Vec x,Vec y)
 {
-  PetscErrorCode ierr;
-
   PetscFunctionBegin;
   if (st->M && st->P) {
-    ierr = MatMult(st->M,x,st->work[0]);CHKERRQ(ierr);
-    ierr = STMatSolve(st,st->work[0],y);CHKERRQ(ierr);
-  } else if (st->M) {
-    ierr = MatMult(st->M,x,y);CHKERRQ(ierr);
-  } else {
-    ierr = STMatSolve(st,x,y);CHKERRQ(ierr);
-  }
+    PetscCall(MatMult(st->M,x,st->work[0]));
+    PetscCall(STMatSolve(st,st->work[0],y));
+  } else if (st->M) PetscCall(MatMult(st->M,x,y));
+  else PetscCall(STMatSolve(st,x,y));
   PetscFunctionReturn(0);
 }
 
@@ -49,7 +44,6 @@ PetscErrorCode STApply_Generic(ST st,Vec x,Vec y)
 @*/
 PetscErrorCode STApply(ST st,Vec x,Vec y)
 {
-  PetscErrorCode ierr;
   Mat            Op;
 
   PetscFunctionBegin;
@@ -58,29 +52,25 @@ PetscErrorCode STApply(ST st,Vec x,Vec y)
   PetscValidHeaderSpecific(y,VEC_CLASSID,3);
   PetscValidType(st,1);
   STCheckMatrices(st,1);
-  if (x == y) SETERRQ(PetscObjectComm((PetscObject)st),PETSC_ERR_ARG_IDN,"x and y must be different vectors");
-  ierr = VecSetErrorIfLocked(y,3);CHKERRQ(ierr);
-  if (!st->ops->apply) SETERRQ(PetscObjectComm((PetscObject)st),PETSC_ERR_SUP,"ST does not have apply");
-  ierr = STGetOperator_Private(st,&Op);CHKERRQ(ierr);
-  ierr = MatMult(Op,x,y);CHKERRQ(ierr);
+  PetscCheck(x!=y,PetscObjectComm((PetscObject)st),PETSC_ERR_ARG_IDN,"x and y must be different vectors");
+  PetscCall(VecSetErrorIfLocked(y,3));
+  PetscCheck(st->ops->apply,PetscObjectComm((PetscObject)st),PETSC_ERR_SUP,"ST does not have apply");
+  PetscCall(STGetOperator_Private(st,&Op));
+  PetscCall(MatMult(Op,x,y));
   PetscFunctionReturn(0);
 }
 
 PetscErrorCode STApplyMat_Generic(ST st,Mat B,Mat C)
 {
-  PetscErrorCode ierr;
   Mat            work;
 
   PetscFunctionBegin;
   if (st->M && st->P) {
-    ierr = MatMatMult(st->M,B,MAT_INITIAL_MATRIX,PETSC_DEFAULT,&work);CHKERRQ(ierr);
-    ierr = STMatMatSolve(st,work,C);CHKERRQ(ierr);
-    ierr = MatDestroy(&work);CHKERRQ(ierr);
-  } else if (st->M) {
-    ierr = MatMatMult(st->M,B,MAT_REUSE_MATRIX,PETSC_DEFAULT,&C);CHKERRQ(ierr);
-  } else {
-    ierr = STMatMatSolve(st,B,C);CHKERRQ(ierr);
-  }
+    PetscCall(MatMatMult(st->M,B,MAT_INITIAL_MATRIX,PETSC_DEFAULT,&work));
+    PetscCall(STMatMatSolve(st,work,C));
+    PetscCall(MatDestroy(&work));
+  } else if (st->M) PetscCall(MatMatMult(st->M,B,MAT_REUSE_MATRIX,PETSC_DEFAULT,&C));
+  else PetscCall(STMatMatSolve(st,B,C));
   PetscFunctionReturn(0);
 }
 
@@ -96,7 +86,7 @@ PetscErrorCode STApplyMat_Generic(ST st,Mat B,Mat C)
 -  X  - input matrix
 
    Output Parameter:
-.  y - output matrix
+.  Y - output matrix
 
    Level: developer
 
@@ -104,33 +94,26 @@ PetscErrorCode STApplyMat_Generic(ST st,Mat B,Mat C)
 @*/
 PetscErrorCode STApplyMat(ST st,Mat X,Mat Y)
 {
-  PetscErrorCode ierr;
-
   PetscFunctionBegin;
   PetscValidHeaderSpecific(st,ST_CLASSID,1);
   PetscValidHeaderSpecific(X,MAT_CLASSID,2);
   PetscValidHeaderSpecific(Y,MAT_CLASSID,3);
   PetscValidType(st,1);
   STCheckMatrices(st,1);
-  if (X == Y) SETERRQ(PetscObjectComm((PetscObject)st),PETSC_ERR_ARG_IDN,"X and Y must be different matrices");
-  if (!st->ops->applymat) SETERRQ(PetscObjectComm((PetscObject)st),PETSC_ERR_SUP,"ST does not have applymat");
-  ierr = (*st->ops->applymat)(st,X,Y);CHKERRQ(ierr);
+  PetscCheck(X!=Y,PetscObjectComm((PetscObject)st),PETSC_ERR_ARG_IDN,"X and Y must be different matrices");
+  PetscCheck(st->ops->applymat,PetscObjectComm((PetscObject)st),PETSC_ERR_SUP,"ST does not have applymat");
+  PetscCall((*st->ops->applymat)(st,X,Y));
   PetscFunctionReturn(0);
 }
 
 PetscErrorCode STApplyTranspose_Generic(ST st,Vec x,Vec y)
 {
-  PetscErrorCode ierr;
-
   PetscFunctionBegin;
   if (st->M && st->P) {
-    ierr = STMatSolveTranspose(st,x,st->work[0]);CHKERRQ(ierr);
-    ierr = MatMultTranspose(st->M,st->work[0],y);CHKERRQ(ierr);
-  } else if (st->M) {
-    ierr = MatMultTranspose(st->M,x,y);CHKERRQ(ierr);
-  } else {
-    ierr = STMatSolveTranspose(st,x,y);CHKERRQ(ierr);
-  }
+    PetscCall(STMatSolveTranspose(st,x,st->work[0]));
+    PetscCall(MatMultTranspose(st->M,st->work[0],y));
+  } else if (st->M) PetscCall(MatMultTranspose(st->M,x,y));
+  else PetscCall(STMatSolveTranspose(st,x,y));
   PetscFunctionReturn(0);
 }
 
@@ -154,7 +137,6 @@ PetscErrorCode STApplyTranspose_Generic(ST st,Vec x,Vec y)
 @*/
 PetscErrorCode STApplyTranspose(ST st,Vec x,Vec y)
 {
-  PetscErrorCode ierr;
   Mat            Op;
 
   PetscFunctionBegin;
@@ -163,11 +145,11 @@ PetscErrorCode STApplyTranspose(ST st,Vec x,Vec y)
   PetscValidHeaderSpecific(y,VEC_CLASSID,3);
   PetscValidType(st,1);
   STCheckMatrices(st,1);
-  if (x == y) SETERRQ(PetscObjectComm((PetscObject)st),PETSC_ERR_ARG_IDN,"x and y must be different vectors");
-  ierr = VecSetErrorIfLocked(y,3);CHKERRQ(ierr);
-  if (!st->ops->applytrans) SETERRQ(PetscObjectComm((PetscObject)st),PETSC_ERR_SUP,"ST does not have applytrans");
-  ierr = STGetOperator_Private(st,&Op);CHKERRQ(ierr);
-  ierr = MatMultTranspose(Op,x,y);CHKERRQ(ierr);
+  PetscCheck(x!=y,PetscObjectComm((PetscObject)st),PETSC_ERR_ARG_IDN,"x and y must be different vectors");
+  PetscCall(VecSetErrorIfLocked(y,3));
+  PetscCheck(st->ops->applytrans,PetscObjectComm((PetscObject)st),PETSC_ERR_SUP,"ST does not have applytrans");
+  PetscCall(STGetOperator_Private(st,&Op));
+  PetscCall(MatMultTranspose(Op,x,y));
   PetscFunctionReturn(0);
 }
 
@@ -194,7 +176,6 @@ PetscErrorCode STApplyTranspose(ST st,Vec x,Vec y)
 @*/
 PetscErrorCode STApplyHermitianTranspose(ST st,Vec x,Vec y)
 {
-  PetscErrorCode ierr;
   Mat            Op;
 
   PetscFunctionBegin;
@@ -203,11 +184,11 @@ PetscErrorCode STApplyHermitianTranspose(ST st,Vec x,Vec y)
   PetscValidHeaderSpecific(y,VEC_CLASSID,3);
   PetscValidType(st,1);
   STCheckMatrices(st,1);
-  if (x == y) SETERRQ(PetscObjectComm((PetscObject)st),PETSC_ERR_ARG_IDN,"x and y must be different vectors");
-  ierr = VecSetErrorIfLocked(y,3);CHKERRQ(ierr);
-  if (!st->ops->applytrans) SETERRQ(PetscObjectComm((PetscObject)st),PETSC_ERR_SUP,"ST does not have applytrans");
-  ierr = STGetOperator_Private(st,&Op);CHKERRQ(ierr);
-  ierr = MatMultHermitianTranspose(Op,x,y);CHKERRQ(ierr);
+  PetscCheck(x!=y,PetscObjectComm((PetscObject)st),PETSC_ERR_ARG_IDN,"x and y must be different vectors");
+  PetscCall(VecSetErrorIfLocked(y,3));
+  PetscCheck(st->ops->applytrans,PetscObjectComm((PetscObject)st),PETSC_ERR_SUP,"ST does not have applytrans");
+  PetscCall(STGetOperator_Private(st,&Op));
+  PetscCall(MatMultHermitianTranspose(Op,x,y));
   PetscFunctionReturn(0);
 }
 
@@ -228,119 +209,106 @@ PetscErrorCode STApplyHermitianTranspose(ST st,Vec x,Vec y)
    case of standard eigenproblems.
 
    Level: developer
+
+.seealso: BVSetMatrix()
 @*/
 PetscErrorCode STGetBilinearForm(ST st,Mat *B)
 {
-  PetscErrorCode ierr;
-
   PetscFunctionBegin;
   PetscValidHeaderSpecific(st,ST_CLASSID,1);
   PetscValidType(st,1);
   PetscValidPointer(B,2);
   STCheckMatrices(st,1);
-  ierr = (*st->ops->getbilinearform)(st,B);CHKERRQ(ierr);
+  PetscCall((*st->ops->getbilinearform)(st,B));
   PetscFunctionReturn(0);
 }
 
 PetscErrorCode STGetBilinearForm_Default(ST st,Mat *B)
 {
-  PetscErrorCode ierr;
-
   PetscFunctionBegin;
   if (st->nmat==1) *B = NULL;
   else {
     *B = st->A[1];
-    ierr = PetscObjectReference((PetscObject)*B);CHKERRQ(ierr);
+    PetscCall(PetscObjectReference((PetscObject)*B));
   }
   PetscFunctionReturn(0);
 }
 
 static PetscErrorCode MatMult_STOperator(Mat Op,Vec x,Vec y)
 {
-  PetscErrorCode ierr;
   ST             st;
 
   PetscFunctionBegin;
-  ierr = MatShellGetContext(Op,&st);CHKERRQ(ierr);
-  ierr = STSetUp(st);CHKERRQ(ierr);
-  ierr = PetscLogEventBegin(ST_Apply,st,x,y,0);CHKERRQ(ierr);
+  PetscCall(MatShellGetContext(Op,&st));
+  PetscCall(STSetUp(st));
+  PetscCall(PetscLogEventBegin(ST_Apply,st,x,y,0));
   if (st->D) { /* with balancing */
-    ierr = VecPointwiseDivide(st->wb,x,st->D);CHKERRQ(ierr);
-    ierr = (*st->ops->apply)(st,st->wb,y);CHKERRQ(ierr);
-    ierr = VecPointwiseMult(y,y,st->D);CHKERRQ(ierr);
-  } else {
-    ierr = (*st->ops->apply)(st,x,y);CHKERRQ(ierr);
-  }
-  ierr = PetscLogEventEnd(ST_Apply,st,x,y,0);CHKERRQ(ierr);
+    PetscCall(VecPointwiseDivide(st->wb,x,st->D));
+    PetscCall((*st->ops->apply)(st,st->wb,y));
+    PetscCall(VecPointwiseMult(y,y,st->D));
+  } else PetscCall((*st->ops->apply)(st,x,y));
+  PetscCall(PetscLogEventEnd(ST_Apply,st,x,y,0));
   PetscFunctionReturn(0);
 }
 
 static PetscErrorCode MatMultTranspose_STOperator(Mat Op,Vec x,Vec y)
 {
-  PetscErrorCode ierr;
   ST             st;
 
   PetscFunctionBegin;
-  ierr = MatShellGetContext(Op,&st);CHKERRQ(ierr);
-  ierr = STSetUp(st);CHKERRQ(ierr);
-  ierr = PetscLogEventBegin(ST_ApplyTranspose,st,x,y,0);CHKERRQ(ierr);
+  PetscCall(MatShellGetContext(Op,&st));
+  PetscCall(STSetUp(st));
+  PetscCall(PetscLogEventBegin(ST_ApplyTranspose,st,x,y,0));
   if (st->D) { /* with balancing */
-    ierr = VecPointwiseMult(st->wb,x,st->D);CHKERRQ(ierr);
-    ierr = (*st->ops->applytrans)(st,st->wb,y);CHKERRQ(ierr);
-    ierr = VecPointwiseDivide(y,y,st->D);CHKERRQ(ierr);
-  } else {
-    ierr = (*st->ops->applytrans)(st,x,y);CHKERRQ(ierr);
-  }
-  ierr = PetscLogEventEnd(ST_ApplyTranspose,st,x,y,0);CHKERRQ(ierr);
+    PetscCall(VecPointwiseMult(st->wb,x,st->D));
+    PetscCall((*st->ops->applytrans)(st,st->wb,y));
+    PetscCall(VecPointwiseDivide(y,y,st->D));
+  } else PetscCall((*st->ops->applytrans)(st,x,y));
+  PetscCall(PetscLogEventEnd(ST_ApplyTranspose,st,x,y,0));
   PetscFunctionReturn(0);
 }
 
 #if defined(PETSC_USE_COMPLEX)
 static PetscErrorCode MatMultHermitianTranspose_STOperator(Mat Op,Vec x,Vec y)
 {
-  PetscErrorCode ierr;
   ST             st;
 
   PetscFunctionBegin;
-  ierr = MatShellGetContext(Op,&st);CHKERRQ(ierr);
-  ierr = STSetUp(st);CHKERRQ(ierr);
-  ierr = PetscLogEventBegin(ST_ApplyTranspose,st,x,y,0);CHKERRQ(ierr);
+  PetscCall(MatShellGetContext(Op,&st));
+  PetscCall(STSetUp(st));
+  PetscCall(PetscLogEventBegin(ST_ApplyTranspose,st,x,y,0));
   if (!st->wht) {
-    ierr = MatCreateVecs(st->A[0],&st->wht,NULL);CHKERRQ(ierr);
-    ierr = PetscLogObjectParent((PetscObject)st,(PetscObject)st->wht);CHKERRQ(ierr);
+    PetscCall(MatCreateVecs(st->A[0],&st->wht,NULL));
+    PetscCall(PetscLogObjectParent((PetscObject)st,(PetscObject)st->wht));
   }
-  ierr = VecCopy(x,st->wht);CHKERRQ(ierr);
-  ierr = VecConjugate(st->wht);CHKERRQ(ierr);
+  PetscCall(VecCopy(x,st->wht));
+  PetscCall(VecConjugate(st->wht));
   if (st->D) { /* with balancing */
-    ierr = VecPointwiseMult(st->wb,st->wht,st->D);CHKERRQ(ierr);
-    ierr = (*st->ops->applytrans)(st,st->wb,y);CHKERRQ(ierr);
-    ierr = VecPointwiseDivide(y,y,st->D);CHKERRQ(ierr);
-  } else {
-    ierr = (*st->ops->applytrans)(st,st->wht,y);CHKERRQ(ierr);
-  }
-  ierr = VecConjugate(y);CHKERRQ(ierr);
-  ierr = PetscLogEventEnd(ST_ApplyTranspose,st,x,y,0);CHKERRQ(ierr);
+    PetscCall(VecPointwiseMult(st->wb,st->wht,st->D));
+    PetscCall((*st->ops->applytrans)(st,st->wb,y));
+    PetscCall(VecPointwiseDivide(y,y,st->D));
+  } else PetscCall((*st->ops->applytrans)(st,st->wht,y));
+  PetscCall(VecConjugate(y));
+  PetscCall(PetscLogEventEnd(ST_ApplyTranspose,st,x,y,0));
   PetscFunctionReturn(0);
 }
 #endif
 
 static PetscErrorCode MatMatMult_STOperator(Mat Op,Mat B,Mat C,void *ctx)
 {
-  PetscErrorCode ierr;
   ST             st;
 
   PetscFunctionBegin;
-  ierr = MatShellGetContext(Op,&st);CHKERRQ(ierr);
-  ierr = STSetUp(st);CHKERRQ(ierr);
-  ierr = PetscLogEventBegin(ST_Apply,st,B,C,0);CHKERRQ(ierr);
-  ierr = STApplyMat_Generic(st,B,C);CHKERRQ(ierr);
-  ierr = PetscLogEventEnd(ST_Apply,st,B,C,0);CHKERRQ(ierr);
+  PetscCall(MatShellGetContext(Op,&st));
+  PetscCall(STSetUp(st));
+  PetscCall(PetscLogEventBegin(ST_Apply,st,B,C,0));
+  PetscCall(STApplyMat_Generic(st,B,C));
+  PetscCall(PetscLogEventEnd(ST_Apply,st,B,C,0));
   PetscFunctionReturn(0);
 }
 
 PetscErrorCode STGetOperator_Private(ST st,Mat *Op)
 {
-  PetscErrorCode ierr;
   PetscInt       m,n,M,N;
   Vec            v;
   VecType        vtype;
@@ -349,26 +317,27 @@ PetscErrorCode STGetOperator_Private(ST st,Mat *Op)
   if (!st->Op) {
     if (Op) *Op = NULL;
     /* create the shell matrix */
-    ierr = MatGetLocalSize(st->A[0],&m,&n);CHKERRQ(ierr);
-    ierr = MatGetSize(st->A[0],&M,&N);CHKERRQ(ierr);
-    ierr = MatCreateShell(PetscObjectComm((PetscObject)st),m,n,M,N,st,&st->Op);CHKERRQ(ierr);
-    ierr = MatShellSetOperation(st->Op,MATOP_MULT,(void(*)(void))MatMult_STOperator);CHKERRQ(ierr);
-    ierr = MatShellSetOperation(st->Op,MATOP_MULT_TRANSPOSE,(void(*)(void))MatMultTranspose_STOperator);CHKERRQ(ierr);
+    PetscCall(MatGetLocalSize(st->A[0],&m,&n));
+    PetscCall(MatGetSize(st->A[0],&M,&N));
+    PetscCall(MatCreateShell(PetscObjectComm((PetscObject)st),m,n,M,N,st,&st->Op));
+    PetscCall(MatShellSetOperation(st->Op,MATOP_MULT,(void(*)(void))MatMult_STOperator));
+    PetscCall(MatShellSetOperation(st->Op,MATOP_MULT_TRANSPOSE,(void(*)(void))MatMultTranspose_STOperator));
 #if defined(PETSC_USE_COMPLEX)
-    ierr = MatShellSetOperation(st->Op,MATOP_MULT_HERMITIAN_TRANSPOSE,(void(*)(void))MatMultHermitianTranspose_STOperator);CHKERRQ(ierr);
+    PetscCall(MatShellSetOperation(st->Op,MATOP_MULT_HERMITIAN_TRANSPOSE,(void(*)(void))MatMultHermitianTranspose_STOperator));
 #else
-    ierr = MatShellSetOperation(st->Op,MATOP_MULT_HERMITIAN_TRANSPOSE,(void(*)(void))MatMultTranspose_STOperator);CHKERRQ(ierr);
+    PetscCall(MatShellSetOperation(st->Op,MATOP_MULT_HERMITIAN_TRANSPOSE,(void(*)(void))MatMultTranspose_STOperator));
 #endif
     if (!st->D && st->ops->apply==STApply_Generic) {
-      ierr = MatShellSetMatProductOperation(st->Op,MATPRODUCT_AB,NULL,MatMatMult_STOperator,NULL,MATDENSE,MATDENSE);CHKERRQ(ierr);
+      PetscCall(MatShellSetMatProductOperation(st->Op,MATPRODUCT_AB,NULL,MatMatMult_STOperator,NULL,MATDENSE,MATDENSE));
+      PetscCall(MatShellSetMatProductOperation(st->Op,MATPRODUCT_AB,NULL,MatMatMult_STOperator,NULL,MATDENSECUDA,MATDENSECUDA));
     }
     /* make sure the shell matrix generates a vector of the same type as the problem matrices */
-    ierr = MatCreateVecs(st->A[0],&v,NULL);CHKERRQ(ierr);
-    ierr = VecGetType(v,&vtype);CHKERRQ(ierr);
-    ierr = MatShellSetVecType(st->Op,vtype);CHKERRQ(ierr);
-    ierr = VecDestroy(&v);CHKERRQ(ierr);
+    PetscCall(MatCreateVecs(st->A[0],&v,NULL));
+    PetscCall(VecGetType(v,&vtype));
+    PetscCall(MatShellSetVecType(st->Op,vtype));
+    PetscCall(VecDestroy(&v));
     /* build the operator matrices */
-    ierr = STComputeOperator(st);CHKERRQ(ierr);
+    PetscCall(STComputeOperator(st));
   }
   if (Op) *Op = st->Op;
   PetscFunctionReturn(0);
@@ -393,9 +362,7 @@ PetscErrorCode STGetOperator_Private(ST st,Mat *Op)
    The returned shell matrix is essentially a wrapper to the STApply() and
    STApplyTranspose() operations. The operator can often be expressed as
 
-.vb
-      Op = D*inv(K)*M*inv(D)
-.ve
+$     Op = D*inv(K)*M*inv(D)
 
    where D is the balancing matrix, and M and K are two matrices corresponding
    to the numerator and denominator for spectral transformations that represent
@@ -423,15 +390,13 @@ PetscErrorCode STGetOperator_Private(ST st,Mat *Op)
 @*/
 PetscErrorCode STGetOperator(ST st,Mat *Op)
 {
-  PetscErrorCode ierr;
-
   PetscFunctionBegin;
   PetscValidHeaderSpecific(st,ST_CLASSID,1);
   PetscValidType(st,1);
   STCheckMatrices(st,1);
   STCheckNotSeized(st,1);
-  if (st->nmat>2) SETERRQ(PetscObjectComm((PetscObject)st),PETSC_ERR_ARG_WRONGSTATE,"The operator is not defined in polynomial eigenproblems");
-  ierr = STGetOperator_Private(st,Op);CHKERRQ(ierr);
+  PetscCheck(st->nmat<=2,PetscObjectComm((PetscObject)st),PETSC_ERR_ARG_WRONGSTATE,"The operator is not defined in polynomial eigenproblems");
+  PetscCall(STGetOperator_Private(st,Op));
   if (Op) st->opseized = PETSC_TRUE;
   PetscFunctionReturn(0);
 }
@@ -458,7 +423,7 @@ PetscErrorCode STRestoreOperator(ST st,Mat *Op)
   PetscValidHeaderSpecific(st,ST_CLASSID,1);
   PetscValidPointer(Op,2);
   PetscValidHeaderSpecific(*Op,MAT_CLASSID,2);
-  if (!st->opseized) SETERRQ(PetscObjectComm((PetscObject)st),PETSC_ERR_ARG_WRONGSTATE,"Must be called after STGetOperator()");
+  PetscCheck(st->opseized,PetscObjectComm((PetscObject)st),PETSC_ERR_ARG_WRONGSTATE,"Must be called after STGetOperator()");
   *Op = NULL;
   st->opseized = PETSC_FALSE;
   PetscFunctionReturn(0);
@@ -485,31 +450,30 @@ PetscErrorCode STRestoreOperator(ST st,Mat *Op)
 */
 PetscErrorCode STComputeOperator(ST st)
 {
-  PetscErrorCode ierr;
   PC             pc;
 
   PetscFunctionBegin;
   PetscValidHeaderSpecific(st,ST_CLASSID,1);
   PetscValidType(st,1);
   if (!st->opready && st->ops->computeoperator) {
-    ierr = PetscInfo(st,"Building the operator matrices\n");CHKERRQ(ierr);
+    PetscCall(PetscInfo(st,"Building the operator matrices\n"));
     STCheckMatrices(st,1);
     if (!st->T) {
-      ierr = PetscCalloc1(PetscMax(2,st->nmat),&st->T);CHKERRQ(ierr);
-      ierr = PetscLogObjectMemory((PetscObject)st,PetscMax(2,st->nmat)*sizeof(Mat));CHKERRQ(ierr);
+      PetscCall(PetscCalloc1(PetscMax(2,st->nmat),&st->T));
+      PetscCall(PetscLogObjectMemory((PetscObject)st,PetscMax(2,st->nmat)*sizeof(Mat)));
     }
-    ierr = PetscLogEventBegin(ST_ComputeOperator,st,0,0,0);CHKERRQ(ierr);
-    ierr = (*st->ops->computeoperator)(st);CHKERRQ(ierr);
-    ierr = PetscLogEventEnd(ST_ComputeOperator,st,0,0,0);CHKERRQ(ierr);
+    PetscCall(PetscLogEventBegin(ST_ComputeOperator,st,0,0,0));
+    PetscCall((*st->ops->computeoperator)(st));
+    PetscCall(PetscLogEventEnd(ST_ComputeOperator,st,0,0,0));
     if (st->usesksp) {
-      if (!st->ksp) { ierr = STGetKSP(st,&st->ksp);CHKERRQ(ierr); }
+      if (!st->ksp) PetscCall(STGetKSP(st,&st->ksp));
       if (st->P) {
-        ierr = STSetDefaultKSP(st);CHKERRQ(ierr);
-        ierr = STKSPSetOperators(st,st->P,st->Pmat?st->Pmat:st->P);CHKERRQ(ierr);
+        PetscCall(STSetDefaultKSP(st));
+        PetscCall(ST_KSPSetOperators(st,st->P,st->Pmat?st->Pmat:st->P));
       } else {
         /* STPRECOND defaults to PCNONE if st->P is empty */
-        ierr = KSPGetPC(st->ksp,&pc);CHKERRQ(ierr);
-        ierr = PCSetType(pc,PCNONE);CHKERRQ(ierr);
+        PetscCall(KSPGetPC(st->ksp,&pc));
+        PetscCall(PCSetType(pc,PCNONE));
       }
     }
   }
@@ -532,7 +496,6 @@ PetscErrorCode STComputeOperator(ST st)
 PetscErrorCode STSetUp(ST st)
 {
   PetscInt       i,n,k;
-  PetscErrorCode ierr;
 
   PetscFunctionBegin;
   PetscValidHeaderSpecific(st,ST_CLASSID,1);
@@ -540,48 +503,43 @@ PetscErrorCode STSetUp(ST st)
   STCheckMatrices(st,1);
   switch (st->state) {
     case ST_STATE_INITIAL:
-      ierr = PetscInfo(st,"Setting up new ST\n");CHKERRQ(ierr);
-      if (!((PetscObject)st)->type_name) {
-        ierr = STSetType(st,STSHIFT);CHKERRQ(ierr);
-      }
+      PetscCall(PetscInfo(st,"Setting up new ST\n"));
+      if (!((PetscObject)st)->type_name) PetscCall(STSetType(st,STSHIFT));
       break;
     case ST_STATE_SETUP:
       PetscFunctionReturn(0);
     case ST_STATE_UPDATED:
-      ierr = PetscInfo(st,"Setting up updated ST\n");CHKERRQ(ierr);
+      PetscCall(PetscInfo(st,"Setting up updated ST\n"));
       break;
   }
-  ierr = PetscLogEventBegin(ST_SetUp,st,0,0,0);CHKERRQ(ierr);
+  PetscCall(PetscLogEventBegin(ST_SetUp,st,0,0,0));
   if (st->state!=ST_STATE_UPDATED) {
     if (!(st->nmat<3 && st->opready)) {
       if (st->T) {
-        for (i=0;i<PetscMax(2,st->nmat);i++) {
-          ierr = MatDestroy(&st->T[i]);CHKERRQ(ierr);
-        }
+        for (i=0;i<PetscMax(2,st->nmat);i++) PetscCall(MatDestroy(&st->T[i]));
       }
-      ierr = MatDestroy(&st->P);CHKERRQ(ierr);
+      PetscCall(MatDestroy(&st->P));
     }
   }
   if (st->D) {
-    ierr = MatGetLocalSize(st->A[0],NULL,&n);CHKERRQ(ierr);
-    ierr = VecGetLocalSize(st->D,&k);CHKERRQ(ierr);
-    if (n != k) SETERRQ2(PetscObjectComm((PetscObject)st),PETSC_ERR_ARG_SIZ,"Balance matrix has wrong dimension %D (should be %D)",k,n);
+    PetscCall(MatGetLocalSize(st->A[0],NULL,&n));
+    PetscCall(VecGetLocalSize(st->D,&k));
+    PetscCheck(n==k,PetscObjectComm((PetscObject)st),PETSC_ERR_ARG_SIZ,"Balance matrix has wrong dimension %" PetscInt_FMT " (should be %" PetscInt_FMT ")",k,n);
     if (!st->wb) {
-      ierr = VecDuplicate(st->D,&st->wb);CHKERRQ(ierr);
-      ierr = PetscLogObjectParent((PetscObject)st,(PetscObject)st->wb);CHKERRQ(ierr);
+      PetscCall(VecDuplicate(st->D,&st->wb));
+      PetscCall(PetscLogObjectParent((PetscObject)st,(PetscObject)st->wb));
     }
   }
-  if (st->nmat<3 && st->transform) {
-    ierr = STComputeOperator(st);CHKERRQ(ierr);
-  } else {
+  if (st->nmat<3 && st->transform) PetscCall(STComputeOperator(st));
+  else {
     if (!st->T) {
-      ierr = PetscCalloc1(PetscMax(2,st->nmat),&st->T);CHKERRQ(ierr);
-      ierr = PetscLogObjectMemory((PetscObject)st,PetscMax(2,st->nmat)*sizeof(Mat));CHKERRQ(ierr);
+      PetscCall(PetscCalloc1(PetscMax(2,st->nmat),&st->T));
+      PetscCall(PetscLogObjectMemory((PetscObject)st,PetscMax(2,st->nmat)*sizeof(Mat)));
     }
   }
-  if (st->ops->setup) { ierr = (*st->ops->setup)(st);CHKERRQ(ierr); }
+  if (st->ops->setup) PetscCall((*st->ops->setup)(st));
   st->state = ST_STATE_SETUP;
-  ierr = PetscLogEventEnd(ST_SetUp,st,0,0,0);CHKERRQ(ierr);
+  PetscCall(PetscLogEventEnd(ST_SetUp,st,0,0,0));
   PetscFunctionReturn(0);
 }
 
@@ -593,45 +551,44 @@ PetscErrorCode STSetUp(ST st)
    beta - value of the previous shift (only used in inplace mode)
    k - index of first matrix included in the computation
    coeffs - coefficients of the expansion
-   initial - true if this is the first time (only relevant for shell mode)
+   initial - true if this is the first time
+   precond - whether the preconditioner matrix must be computed
 */
-PetscErrorCode STMatMAXPY_Private(ST st,PetscScalar alpha,PetscScalar beta,PetscInt k,PetscScalar *coeffs,PetscBool initial,Mat *S)
+PetscErrorCode STMatMAXPY_Private(ST st,PetscScalar alpha,PetscScalar beta,PetscInt k,PetscScalar *coeffs,PetscBool initial,PetscBool precond,Mat *S)
 {
-  PetscErrorCode ierr;
   PetscInt       *matIdx=NULL,nmat,i,ini=-1;
   PetscScalar    t=1.0,ta,gamma;
   PetscBool      nz=PETSC_FALSE;
+  Mat            *A=precond?st->Psplit:st->A;
+  MatStructure   str=precond?st->strp:st->str;
 
   PetscFunctionBegin;
   nmat = st->nmat-k;
   switch (st->matmode) {
   case ST_MATMODE_INPLACE:
-    if (st->nmat>2) SETERRQ(PetscObjectComm((PetscObject)st),PETSC_ERR_SUP,"ST_MATMODE_INPLACE not supported for polynomial eigenproblems");
+    PetscCheck(st->nmat<=2,PetscObjectComm((PetscObject)st),PETSC_ERR_SUP,"ST_MATMODE_INPLACE not supported for polynomial eigenproblems");
+    PetscCheck(!precond,PetscObjectComm((PetscObject)st),PETSC_ERR_SUP,"ST_MATMODE_INPLACE not supported for split preconditioner");
     if (initial) {
-      ierr = PetscObjectReference((PetscObject)st->A[0]);CHKERRQ(ierr);
-      *S = st->A[0];
+      PetscCall(PetscObjectReference((PetscObject)A[0]));
+      *S = A[0];
       gamma = alpha;
     } else gamma = alpha-beta;
     if (gamma != 0.0) {
-      if (st->nmat>1) {
-        ierr = MatAXPY(*S,gamma,st->A[1],st->str);CHKERRQ(ierr);
-      } else {
-        ierr = MatShift(*S,gamma);CHKERRQ(ierr);
-      }
+      if (st->nmat>1) PetscCall(MatAXPY(*S,gamma,A[1],str));
+      else PetscCall(MatShift(*S,gamma));
     }
     break;
   case ST_MATMODE_SHELL:
+    PetscCheck(!precond,PetscObjectComm((PetscObject)st),PETSC_ERR_SUP,"ST_MATMODE_SHELL not supported for split preconditioner");
     if (initial) {
       if (st->nmat>2) {
-        ierr = PetscMalloc1(nmat,&matIdx);CHKERRQ(ierr);
+        PetscCall(PetscMalloc1(nmat,&matIdx));
         for (i=0;i<nmat;i++) matIdx[i] = k+i;
       }
-      ierr = STMatShellCreate(st,alpha,nmat,matIdx,coeffs,S);CHKERRQ(ierr);
-      ierr = PetscLogObjectParent((PetscObject)st,(PetscObject)*S);CHKERRQ(ierr);
-      if (st->nmat>2) { ierr = PetscFree(matIdx);CHKERRQ(ierr); }
-    } else {
-      ierr = STMatShellShift(*S,alpha);CHKERRQ(ierr);
-    }
+      PetscCall(STMatShellCreate(st,alpha,nmat,matIdx,coeffs,S));
+      PetscCall(PetscLogObjectParent((PetscObject)st,(PetscObject)*S));
+      if (st->nmat>2) PetscCall(PetscFree(matIdx));
+    } else PetscCall(STMatShellShift(*S,alpha));
     break;
   case ST_MATMODE_COPY:
     if (coeffs) {
@@ -643,38 +600,33 @@ PetscErrorCode STMatMAXPY_Private(ST st,PetscScalar alpha,PetscScalar beta,Petsc
       for (i=ini+1;i<nmat&&!nz;i++) if (coeffs[i]!=0.0) nz = PETSC_TRUE;
     } else { nz = PETSC_TRUE; ini = 0; }
     if ((alpha == 0.0 || !nz) && t==1.0) {
-      ierr = PetscObjectReference((PetscObject)st->A[k+ini]);CHKERRQ(ierr);
-      ierr = MatDestroy(S);CHKERRQ(ierr);
-      *S = st->A[k+ini];
+      PetscCall(PetscObjectReference((PetscObject)A[k+ini]));
+      PetscCall(MatDestroy(S));
+      *S = A[k+ini];
     } else {
-      if (*S && *S!=st->A[k+ini]) {
-        ierr = MatSetOption(*S,MAT_NEW_NONZERO_ALLOCATION_ERR,PETSC_FALSE);CHKERRQ(ierr);
-        ierr = MatCopy(st->A[k+ini],*S,DIFFERENT_NONZERO_PATTERN);CHKERRQ(ierr);
+      if (*S && *S!=A[k+ini]) {
+        PetscCall(MatSetOption(*S,MAT_NEW_NONZERO_ALLOCATION_ERR,PETSC_FALSE));
+        PetscCall(MatCopy(A[k+ini],*S,DIFFERENT_NONZERO_PATTERN));
       } else {
-        ierr = MatDestroy(S);CHKERRQ(ierr);
-        ierr = MatDuplicate(st->A[k+ini],MAT_COPY_VALUES,S);CHKERRQ(ierr);
-        ierr = MatSetOption(*S,MAT_NEW_NONZERO_ALLOCATION_ERR,PETSC_FALSE);CHKERRQ(ierr);
-        ierr = PetscLogObjectParent((PetscObject)st,(PetscObject)*S);CHKERRQ(ierr);
-      }
-      if (coeffs && coeffs[ini]!=1.0) {
-        ierr = MatScale(*S,coeffs[ini]);CHKERRQ(ierr);
+        PetscCall(MatDestroy(S));
+        PetscCall(MatDuplicate(A[k+ini],MAT_COPY_VALUES,S));
+        PetscCall(MatSetOption(*S,MAT_NEW_NONZERO_ALLOCATION_ERR,PETSC_FALSE));
+        PetscCall(PetscLogObjectParent((PetscObject)st,(PetscObject)*S));
       }
+      if (coeffs && coeffs[ini]!=1.0) PetscCall(MatScale(*S,coeffs[ini]));
       for (i=ini+k+1;i<PetscMax(2,st->nmat);i++) {
         t *= alpha;
         ta = t;
         if (coeffs) ta *= coeffs[i-k];
         if (ta!=0.0) {
-          if (st->nmat>1) {
-            ierr = MatAXPY(*S,ta,st->A[i],st->str);CHKERRQ(ierr);
-          } else {
-            ierr = MatShift(*S,ta);CHKERRQ(ierr);
-          }
+          if (st->nmat>1) PetscCall(MatAXPY(*S,ta,A[i],str));
+          else PetscCall(MatShift(*S,ta));
         }
       }
     }
   }
-  ierr = MatSetOption(*S,MAT_SYMMETRIC,st->asymm);CHKERRQ(ierr);
-  ierr = MatSetOption(*S,MAT_HERMITIAN,(PetscImaginaryPart(st->sigma)==0.0)?st->aherm:PETSC_FALSE);CHKERRQ(ierr);
+  PetscCall(MatSetOption(*S,MAT_SYMMETRIC,st->asymm));
+  PetscCall(MatSetOption(*S,MAT_HERMITIAN,(PetscImaginaryPart(st->sigma)==0.0)?st->aherm:PETSC_FALSE));
   PetscFunctionReturn(0);
 }
 
@@ -714,14 +666,10 @@ PetscErrorCode STCoeffs_Monomial(ST st, PetscScalar *coeffs)
 @*/
 PetscErrorCode STPostSolve(ST st)
 {
-  PetscErrorCode ierr;
-
   PetscFunctionBegin;
   PetscValidHeaderSpecific(st,ST_CLASSID,1);
   PetscValidType(st,1);
-  if (st->ops->postsolve) {
-    ierr = (*st->ops->postsolve)(st);CHKERRQ(ierr);
-  }
+  if (st->ops->postsolve) PetscCall((*st->ops->postsolve)(st));
   PetscFunctionReturn(0);
 }
 
@@ -734,8 +682,9 @@ PetscErrorCode STPostSolve(ST st)
 
    Input Parameters:
 +  st   - the spectral transformation context
-   eigr - real part of a computed eigenvalue
--  eigi - imaginary part of a computed eigenvalue
+.  n    - number of eigenvalues
+.  eigr - real part of a computed eigenvalues
+-  eigi - imaginary part of a computed eigenvalues
 
    Level: developer
 
@@ -743,14 +692,10 @@ PetscErrorCode STPostSolve(ST st)
 @*/
 PetscErrorCode STBackTransform(ST st,PetscInt n,PetscScalar* eigr,PetscScalar* eigi)
 {
-  PetscErrorCode ierr;
-
   PetscFunctionBegin;
   PetscValidHeaderSpecific(st,ST_CLASSID,1);
   PetscValidType(st,1);
-  if (st->ops->backtransform) {
-    ierr = (*st->ops->backtransform)(st,n,eigr,eigi);CHKERRQ(ierr);
-  }
+  if (st->ops->backtransform) PetscCall((*st->ops->backtransform)(st,n,eigr,eigi));
   PetscFunctionReturn(0);
 }
 
@@ -773,7 +718,6 @@ PetscErrorCode STBackTransform(ST st,PetscInt n,PetscScalar* eigr,PetscScalar* e
 @*/
 PetscErrorCode STIsInjective(ST st,PetscBool* is)
 {
-  PetscErrorCode ierr;
   PetscBool      shell;
 
   PetscFunctionBegin;
@@ -781,10 +725,9 @@ PetscErrorCode STIsInjective(ST st,PetscBool* is)
   PetscValidType(st,1);
   PetscValidBoolPointer(is,2);
 
-  ierr = PetscObjectTypeCompare((PetscObject)st,STSHELL,&shell);CHKERRQ(ierr);
-  if (shell) {
-    ierr = STIsInjective_Shell(st,is);CHKERRQ(ierr);
-  } else *is = st->ops->backtransform? PETSC_TRUE: PETSC_FALSE;
+  PetscCall(PetscObjectTypeCompare((PetscObject)st,STSHELL,&shell));
+  if (shell) PetscCall(STIsInjective_Shell(st,is));
+  else *is = st->ops->backtransform? PETSC_TRUE: PETSC_FALSE;
   PetscFunctionReturn(0);
 }
 
@@ -802,8 +745,8 @@ PetscErrorCode STIsInjective(ST st,PetscBool* is)
    This function is not intended to be called by end users, but by SLEPc
    solvers that use ST. It builds matrix st->P as follows, then calls KSPSetUp().
 .vb
-    If (coeffs):  st->P = Sum_{i=0:nmat-1} coeffs[i]*sigma^i*A_i.
-    else          st->P = Sum_{i=0:nmat-1} sigma^i*A_i
+    If (coeffs)  st->P = Sum_{i=0..nmat-1} coeffs[i]*sigma^i*A_i
+    else         st->P = Sum_{i=0..nmat-1} sigma^i*A_i
 .ve
 
    Level: developer
@@ -812,18 +755,17 @@ PetscErrorCode STIsInjective(ST st,PetscBool* is)
 @*/
 PetscErrorCode STMatSetUp(ST st,PetscScalar sigma,PetscScalar *coeffs)
 {
-  PetscErrorCode ierr;
-
   PetscFunctionBegin;
   PetscValidHeaderSpecific(st,ST_CLASSID,1);
   PetscValidLogicalCollectiveScalar(st,sigma,2);
   STCheckMatrices(st,1);
 
-  ierr = PetscLogEventBegin(ST_MatSetUp,st,0,0,0);CHKERRQ(ierr);
-  ierr = STMatMAXPY_Private(st,sigma,0.0,0,coeffs,PETSC_TRUE,&st->P);CHKERRQ(ierr);
-  ierr = STKSPSetOperators(st,st->P,st->Pmat?st->Pmat:st->P);CHKERRQ(ierr);
-  ierr = KSPSetUp(st->ksp);CHKERRQ(ierr);
-  ierr = PetscLogEventEnd(ST_MatSetUp,st,0,0,0);CHKERRQ(ierr);
+  PetscCall(PetscLogEventBegin(ST_MatSetUp,st,0,0,0));
+  PetscCall(STMatMAXPY_Private(st,sigma,0.0,0,coeffs,PETSC_TRUE,PETSC_FALSE,&st->P));
+  if (st->Psplit) PetscCall(STMatMAXPY_Private(st,sigma,0.0,0,coeffs,PETSC_TRUE,PETSC_TRUE,&st->Pmat));
+  PetscCall(ST_KSPSetOperators(st,st->P,st->Pmat?st->Pmat:st->P));
+  PetscCall(KSPSetUp(st->ksp));
+  PetscCall(PetscLogEventEnd(ST_MatSetUp,st,0,0,0));
   PetscFunctionReturn(0);
 }
 
@@ -836,27 +778,27 @@ PetscErrorCode STMatSetUp(ST st,PetscScalar sigma,PetscScalar *coeffs)
 +  st - the spectral transformation context
 -  nw - number of work vectors to allocate
 
-   Developers Note:
+   Developer Notes:
    This is SLEPC_EXTERN because it may be required by shell STs.
 
    Level: developer
+
+.seealso: STMatCreateVecs()
 @*/
 PetscErrorCode STSetWorkVecs(ST st,PetscInt nw)
 {
-  PetscErrorCode ierr;
   PetscInt       i;
 
   PetscFunctionBegin;
   PetscValidHeaderSpecific(st,ST_CLASSID,1);
   PetscValidLogicalCollectiveInt(st,nw,2);
-  if (nw <= 0) SETERRQ1(PetscObjectComm((PetscObject)st),PETSC_ERR_ARG_OUTOFRANGE,"nw must be > 0: nw = %D",nw);
+  PetscCheck(nw>0,PetscObjectComm((PetscObject)st),PETSC_ERR_ARG_OUTOFRANGE,"nw must be > 0: nw = %" PetscInt_FMT,nw);
   if (st->nwork < nw) {
-    ierr = VecDestroyVecs(st->nwork,&st->work);CHKERRQ(ierr);
+    PetscCall(VecDestroyVecs(st->nwork,&st->work));
     st->nwork = nw;
-    ierr = PetscMalloc1(nw,&st->work);CHKERRQ(ierr);
-    for (i=0;i<nw;i++) { ierr = STMatCreateVecs(st,&st->work[i],NULL);CHKERRQ(ierr); }
-    ierr = PetscLogObjectParents(st,nw,st->work);CHKERRQ(ierr);
+    PetscCall(PetscMalloc1(nw,&st->work));
+    for (i=0;i<nw;i++) PetscCall(STMatCreateVecs(st,&st->work[i],NULL));
+    PetscCall(PetscLogObjectParents(st,nw,st->work));
   }
   PetscFunctionReturn(0);
 }
-
