@@ -1,7 +1,7 @@
 /*
    - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
    SLEPc - Scalable Library for Eigenvalue Problem Computations
-   Copyright (c) 2002-2021, Universitat Politecnica de Valencia, Spain
+   Copyright (c) 2002-, Universitat Politecnica de Valencia, Spain
 
    This file is part of SLEPc.
    SLEPc is distributed under a 2-clause BSD license (see LICENSE).
@@ -33,13 +33,11 @@ SLEPC_EXTERN PetscErrorCode PCCreate_HPDDM(PC);
 @*/
 PetscErrorCode SlepcGetVersion(char version[],size_t len)
 {
-  PetscErrorCode ierr;
-
   PetscFunctionBegin;
 #if (SLEPC_VERSION_RELEASE == 1)
-  ierr = PetscSNPrintf(version,len,"SLEPc Release Version %d.%d.%d, %s",SLEPC_VERSION_MAJOR,SLEPC_VERSION_MINOR,SLEPC_VERSION_SUBMINOR,SLEPC_VERSION_DATE);CHKERRQ(ierr);
+  PetscCall(PetscSNPrintf(version,len,"SLEPc Release Version %d.%d.%d, %s",SLEPC_VERSION_MAJOR,SLEPC_VERSION_MINOR,SLEPC_VERSION_SUBMINOR,SLEPC_VERSION_DATE));
 #else
-  ierr = PetscSNPrintf(version,len,"SLEPc Development GIT revision: %s  GIT Date: %s",SLEPC_VERSION_GIT,SLEPC_VERSION_DATE_GIT);CHKERRQ(ierr);
+  PetscCall(PetscSNPrintf(version,len,"SLEPc Development GIT revision: %s  GIT Date: %s",SLEPC_VERSION_GIT,SLEPC_VERSION_DATE_GIT));
 #endif
   PetscFunctionReturn(0);
 }
@@ -84,15 +82,14 @@ PetscErrorCode SlepcGetVersionNumber(PetscInt *major,PetscInt *minor,PetscInt *s
 */
 static PetscErrorCode SlepcPrintVersion(MPI_Comm comm)
 {
-  PetscErrorCode ierr;
   char           version[256];
 
   PetscFunctionBegin;
-  ierr = SlepcGetVersion(version,256);CHKERRQ(ierr);
-  ierr = (*PetscHelpPrintf)(comm,"%s\n",version);CHKERRQ(ierr);
-  ierr = (*PetscHelpPrintf)(comm,SLEPC_AUTHOR_INFO);CHKERRQ(ierr);
-  ierr = (*PetscHelpPrintf)(comm,"See docs/manual.html for help.\n");CHKERRQ(ierr);
-  ierr = (*PetscHelpPrintf)(comm,"SLEPc libraries linked from %s\n",SLEPC_LIB_DIR);CHKERRQ(ierr);
+  PetscCall(SlepcGetVersion(version,256));
+  PetscCall((*PetscHelpPrintf)(comm,"%s\n",version));
+  PetscCall((*PetscHelpPrintf)(comm,SLEPC_AUTHOR_INFO));
+  PetscCall((*PetscHelpPrintf)(comm,"See docs/manual.html for help.\n"));
+  PetscCall((*PetscHelpPrintf)(comm,"SLEPc libraries linked from %s\n",SLEPC_LIB_DIR));
   PetscFunctionReturn(0);
 }
 
@@ -103,12 +100,10 @@ static PetscErrorCode SlepcPrintVersion(MPI_Comm comm)
 */
 static PetscErrorCode SlepcPrintHelpIntro(MPI_Comm comm)
 {
-  PetscErrorCode  ierr;
-
   PetscFunctionBegin;
-  ierr = (*PetscHelpPrintf)(comm,"SLEPc help information includes that for the PETSc libraries, which provide\n");CHKERRQ(ierr);
-  ierr = (*PetscHelpPrintf)(comm,"low-level system infrastructure and linear algebra tools.\n");CHKERRQ(ierr);
-  ierr = (*PetscHelpPrintf)(comm,"----------------------------------------\n");CHKERRQ(ierr);
+  PetscCall((*PetscHelpPrintf)(comm,"SLEPc help information includes that for the PETSc libraries, which provide\n"));
+  PetscCall((*PetscHelpPrintf)(comm,"low-level system infrastructure and linear algebra tools.\n"));
+  PetscCall((*PetscHelpPrintf)(comm,"----------------------------------------\n"));
   PetscFunctionReturn(0);
 }
 
@@ -125,16 +120,13 @@ PetscBool SlepcFinalizeCalled   = PETSC_FALSE;
 static PetscErrorCode SlepcLoadDynamicLibrary(const char *name,PetscBool *found)
 {
   char           libs[PETSC_MAX_PATH_LEN],dlib[PETSC_MAX_PATH_LEN];
-  PetscErrorCode ierr;
 
   PetscFunctionBegin;
-  ierr = PetscStrcpy(libs,SLEPC_LIB_DIR);CHKERRQ(ierr);
-  ierr = PetscStrlcat(libs,"/libslepc",sizeof(libs));CHKERRQ(ierr);
-  ierr = PetscStrlcat(libs,name,sizeof(libs));CHKERRQ(ierr);
-  ierr = PetscDLLibraryRetrieve(PETSC_COMM_WORLD,libs,dlib,sizeof(dlib),found);CHKERRQ(ierr);
-  if (*found) {
-    ierr = PetscDLLibraryAppend(PETSC_COMM_WORLD,&PetscDLLibrariesLoaded,dlib);CHKERRQ(ierr);
-  }
+  PetscCall(PetscStrcpy(libs,SLEPC_LIB_DIR));
+  PetscCall(PetscStrlcat(libs,"/libslepc",sizeof(libs)));
+  PetscCall(PetscStrlcat(libs,name,sizeof(libs)));
+  PetscCall(PetscDLLibraryRetrieve(PETSC_COMM_WORLD,libs,dlib,sizeof(dlib),found));
+  if (*found) PetscCall(PetscDLLibraryAppend(PETSC_COMM_WORLD,&PetscDLLibrariesLoaded,dlib));
   PetscFunctionReturn(0);
 }
 #endif
@@ -159,7 +151,6 @@ SLEPC_EXTERN PetscErrorCode LMEInitializePackage(void);
 */
 PetscErrorCode SlepcInitialize_DynamicLibraries(void)
 {
-  PetscErrorCode ierr;
   PetscBool      preload = PETSC_FALSE;
 
   PetscFunctionBegin;
@@ -168,42 +159,42 @@ PetscErrorCode SlepcInitialize_DynamicLibraries(void)
   preload = PETSC_TRUE;
 #endif
 
-  ierr = PetscOptionsGetBool(NULL,NULL,"-library_preload",&preload,NULL);CHKERRQ(ierr);
+  PetscCall(PetscOptionsGetBool(NULL,NULL,"-library_preload",&preload,NULL));
   if (preload) {
 #if defined(PETSC_HAVE_DYNAMIC_LIBRARIES) && defined(PETSC_USE_SHARED_LIBRARIES)
     PetscBool found;
 #if defined(PETSC_USE_SINGLE_LIBRARY)
-    ierr = SlepcLoadDynamicLibrary("",&found);CHKERRQ(ierr);
-    if (!found) SETERRQ(PETSC_COMM_SELF,PETSC_ERR_FILE_OPEN,"Unable to locate SLEPc dynamic library\nYou cannot move the dynamic libraries!");
+    PetscCall(SlepcLoadDynamicLibrary("",&found));
+    PetscCheck(found,PETSC_COMM_SELF,PETSC_ERR_FILE_OPEN,"Unable to locate SLEPc dynamic library\nYou cannot move the dynamic libraries!");
 #else
-    ierr = SlepcLoadDynamicLibrary("sys",&found);CHKERRQ(ierr);
-    if (!found) SETERRQ(PETSC_COMM_SELF,PETSC_ERR_FILE_OPEN,"Unable to locate SLEPc sys dynamic library\nYou cannot move the dynamic libraries!");
-    ierr = SlepcLoadDynamicLibrary("eps",&found);CHKERRQ(ierr);
-    if (!found) SETERRQ(PETSC_COMM_SELF,PETSC_ERR_FILE_OPEN,"Unable to locate SLEPc EPS dynamic library\nYou cannot move the dynamic libraries!");
-    ierr = SlepcLoadDynamicLibrary("pep",&found);CHKERRQ(ierr);
-    if (!found) SETERRQ(PETSC_COMM_SELF,PETSC_ERR_FILE_OPEN,"Unable to locate SLEPc PEP dynamic library\nYou cannot move the dynamic libraries!");
-    ierr = SlepcLoadDynamicLibrary("nep",&found);CHKERRQ(ierr);
-    if (!found) SETERRQ(PETSC_COMM_SELF,PETSC_ERR_FILE_OPEN,"Unable to locate SLEPc NEP dynamic library\nYou cannot move the dynamic libraries!");
-    ierr = SlepcLoadDynamicLibrary("svd",&found);CHKERRQ(ierr);
-    if (!found) SETERRQ(PETSC_COMM_SELF,PETSC_ERR_FILE_OPEN,"Unable to locate SLEPc SVD dynamic library\nYou cannot move the dynamic libraries!");
-    ierr = SlepcLoadDynamicLibrary("mfn",&found);CHKERRQ(ierr);
-    if (!found) SETERRQ(PETSC_COMM_SELF,PETSC_ERR_FILE_OPEN,"Unable to locate SLEPc MFN dynamic library\nYou cannot move the dynamic libraries!");
-    ierr = SlepcLoadDynamicLibrary("lme",&found);CHKERRQ(ierr);
-    if (!found) SETERRQ(PETSC_COMM_SELF,PETSC_ERR_FILE_OPEN,"Unable to locate SLEPc LME dynamic library\nYou cannot move the dynamic libraries!");
+    PetscCall(SlepcLoadDynamicLibrary("sys",&found));
+    PetscCheck(found,PETSC_COMM_SELF,PETSC_ERR_FILE_OPEN,"Unable to locate SLEPc sys dynamic library\nYou cannot move the dynamic libraries!");
+    PetscCall(SlepcLoadDynamicLibrary("eps",&found));
+    PetscCheck(found,PETSC_COMM_SELF,PETSC_ERR_FILE_OPEN,"Unable to locate SLEPc EPS dynamic library\nYou cannot move the dynamic libraries!");
+    PetscCall(SlepcLoadDynamicLibrary("pep",&found));
+    PetscCheck(found,PETSC_COMM_SELF,PETSC_ERR_FILE_OPEN,"Unable to locate SLEPc PEP dynamic library\nYou cannot move the dynamic libraries!");
+    PetscCall(SlepcLoadDynamicLibrary("nep",&found));
+    PetscCheck(found,PETSC_COMM_SELF,PETSC_ERR_FILE_OPEN,"Unable to locate SLEPc NEP dynamic library\nYou cannot move the dynamic libraries!");
+    PetscCall(SlepcLoadDynamicLibrary("svd",&found));
+    PetscCheck(found,PETSC_COMM_SELF,PETSC_ERR_FILE_OPEN,"Unable to locate SLEPc SVD dynamic library\nYou cannot move the dynamic libraries!");
+    PetscCall(SlepcLoadDynamicLibrary("mfn",&found));
+    PetscCheck(found,PETSC_COMM_SELF,PETSC_ERR_FILE_OPEN,"Unable to locate SLEPc MFN dynamic library\nYou cannot move the dynamic libraries!");
+    PetscCall(SlepcLoadDynamicLibrary("lme",&found));
+    PetscCheck(found,PETSC_COMM_SELF,PETSC_ERR_FILE_OPEN,"Unable to locate SLEPc LME dynamic library\nYou cannot move the dynamic libraries!");
 #endif
 #else /* defined(PETSC_HAVE_DYNAMIC_LIBRARIES) && defined(PETSC_USE_SHARED_LIBRARIES) */
 #if defined(PETSC_USE_SINGLE_LIBRARY)
-  ierr = STInitializePackage();CHKERRQ(ierr);
-  ierr = DSInitializePackage();CHKERRQ(ierr);
-  ierr = FNInitializePackage();CHKERRQ(ierr);
-  ierr = BVInitializePackage();CHKERRQ(ierr);
-  ierr = RGInitializePackage();CHKERRQ(ierr);
-  ierr = EPSInitializePackage();CHKERRQ(ierr);
-  ierr = SVDInitializePackage();CHKERRQ(ierr);
-  ierr = PEPInitializePackage();CHKERRQ(ierr);
-  ierr = NEPInitializePackage();CHKERRQ(ierr);
-  ierr = MFNInitializePackage();CHKERRQ(ierr);
-  ierr = LMEInitializePackage();CHKERRQ(ierr);
+  PetscCall(STInitializePackage());
+  PetscCall(DSInitializePackage());
+  PetscCall(FNInitializePackage());
+  PetscCall(BVInitializePackage());
+  PetscCall(RGInitializePackage());
+  PetscCall(EPSInitializePackage());
+  PetscCall(SVDInitializePackage());
+  PetscCall(PEPInitializePackage());
+  PetscCall(NEPInitializePackage());
+  PetscCall(MFNInitializePackage());
+  PetscCall(LMEInitializePackage());
 #else
   SETERRQ(PETSC_COMM_WORLD,PETSC_ERR_SUP,"Cannot use -library_preload with multiple static SLEPc libraries");
 #endif
@@ -211,18 +202,16 @@ PetscErrorCode SlepcInitialize_DynamicLibraries(void)
   }
 
 #if defined(SLEPC_HAVE_HPDDM)
-  ierr = KSPRegister(KSPHPDDM,KSPCreate_HPDDM);CHKERRQ(ierr);
-  ierr = PCRegister(PCHPDDM,PCCreate_HPDDM);CHKERRQ(ierr);
+  PetscCall(KSPRegister(KSPHPDDM,KSPCreate_HPDDM));
+  PetscCall(PCRegister(PCHPDDM,PCCreate_HPDDM));
 #endif
   PetscFunctionReturn(0);
 }
 
 PetscErrorCode SlepcCitationsInitialize()
 {
-  PetscErrorCode ierr;
-
   PetscFunctionBegin;
-  ierr = PetscCitationsRegister("@Article{slepc-toms,\n"
+  PetscCall(PetscCitationsRegister("@Article{slepc-toms,\n"
     "   author = \"Vicente Hernandez and Jose E. Roman and Vicente Vidal\",\n"
     "   title = \"{SLEPc}: A Scalable and Flexible Toolkit for the Solution of Eigenvalue Problems\",\n"
     "   journal = \"{ACM} Trans. Math. Software\",\n"
@@ -231,14 +220,14 @@ PetscErrorCode SlepcCitationsInitialize()
     "   pages = \"351--362\",\n"
     "   year = \"2005,\"\n"
     "   doi = \"https://doi.org/10.1145/1089014.1089019\"\n"
-    "}\n",NULL);CHKERRQ(ierr);
-  ierr = PetscCitationsRegister("@TechReport{slepc-manual,\n"
+    "}\n",NULL));
+  PetscCall(PetscCitationsRegister("@TechReport{slepc-manual,\n"
     "   author = \"J. E. Roman and C. Campos and L. Dalcin and E. Romero and A. Tomas\",\n"
     "   title = \"{SLEPc} Users Manual\",\n"
-    "   number = \"DSIC-II/24/02 - Revision 3.16\",\n"
+    "   number = \"DSIC-II/24/02 - Revision 3.17\",\n"
     "   institution = \"D. Sistemes Inform\\`atics i Computaci\\'o, Universitat Polit\\`ecnica de Val\\`encia\",\n"
-    "   year = \"2021\"\n"
-    "}\n",NULL);CHKERRQ(ierr);
+    "   year = \"2022\"\n"
+    "}\n",NULL));
   PetscFunctionReturn(0);
 }
 
@@ -256,7 +245,7 @@ PetscErrorCode SlepcCitationsInitialize()
           (use NULL for default)
 -  help - [optional] Help message to print, use NULL for no message
 
-   Fortran Note:
+   Fortran Notes:
    Fortran syntax is very similar to that of PetscInitialize()
 
    Level: beginner
@@ -265,26 +254,26 @@ PetscErrorCode SlepcCitationsInitialize()
 @*/
 PetscErrorCode SlepcInitialize(int *argc,char ***args,const char file[],const char help[])
 {
-  PetscErrorCode ierr;
   PetscBool      flg;
 
-  if (SlepcInitializeCalled) return 0;
-  ierr = PetscSetHelpVersionFunctions(SlepcPrintHelpIntro,SlepcPrintVersion);if (ierr) return ierr;
-  ierr = PetscInitialized(&flg);if (ierr) return ierr;
+  PetscFunctionBegin;
+  if (SlepcInitializeCalled) PetscFunctionReturn(0);
+  PetscCall(PetscSetHelpVersionFunctions(SlepcPrintHelpIntro,SlepcPrintVersion));
+  PetscCall(PetscInitialized(&flg));
   if (!flg) {
-    ierr = PetscInitialize(argc,args,file,help);CHKERRQ(ierr);
+    PetscCall(PetscInitialize(argc,args,file,help));
     SlepcBeganPetsc = PETSC_TRUE;
   }
 
-  ierr = SlepcCitationsInitialize();CHKERRQ(ierr);
+  PetscCall(SlepcCitationsInitialize());
 
   /* Load the dynamic libraries (on machines that support them), this registers all the solvers etc. */
-  ierr = SlepcInitialize_DynamicLibraries();CHKERRQ(ierr);
+  PetscCall(SlepcInitialize_DynamicLibraries());
 
   SlepcInitializeCalled = PETSC_TRUE;
   SlepcFinalizeCalled   = PETSC_FALSE;
-  ierr = PetscInfo(0,"SLEPc successfully started\n");CHKERRQ(ierr);
-  return 0;
+  PetscCall(PetscInfo(0,"SLEPc successfully started\n"));
+  PetscFunctionReturn(0);
 }
 
 /*@C
@@ -299,24 +288,22 @@ PetscErrorCode SlepcInitialize(int *argc,char ***args,const char file[],const ch
 @*/
 PetscErrorCode SlepcFinalize(void)
 {
-  PetscErrorCode ierr = 0;
-
   PetscFunctionBegin;
   if (PetscUnlikely(!SlepcInitializeCalled)) {
     fprintf(PETSC_STDOUT,"SlepcInitialize() must be called before SlepcFinalize()\n");
     PetscStackClearTop;
     return PETSC_ERR_ARG_WRONGSTATE;
   }
-  ierr = PetscInfo(NULL,"SlepcFinalize() called\n");CHKERRQ(ierr);
+  PetscCall(PetscInfo(NULL,"SlepcFinalize() called\n"));
   if (SlepcBeganPetsc) {
-    ierr = PetscFinalize();
+    PetscCall(PetscFinalize());
     SlepcBeganPetsc = PETSC_FALSE;
   }
   SlepcInitializeCalled = PETSC_FALSE;
   SlepcFinalizeCalled   = PETSC_TRUE;
   /* To match PetscFunctionBegin() at the beginning of this function */
   PetscStackClearTop;
-  return ierr;
+  return 0;
 }
 
 /*@C
@@ -331,18 +318,20 @@ PetscErrorCode SlepcFinalize(void)
 @*/
 PetscErrorCode SlepcInitializeNoArguments(void)
 {
-  PetscErrorCode ierr;
-  int            argc = 0;
-  char           **args = 0;
+  int  argc = 0;
+  char **args = 0;
 
   PetscFunctionBegin;
-  ierr = SlepcInitialize(&argc,&args,NULL,NULL);
-  PetscFunctionReturn(ierr);
+  PetscCall(SlepcInitialize(&argc,&args,NULL,NULL));
+  PetscFunctionReturn(0);
 }
 
 /*@
    SlepcInitialized - Determine whether SLEPc is initialized.
 
+   Output Parameter:
+.  isInitialized - the result
+
    Level: beginner
 
 .seealso: SlepcInitialize(), SlepcInitializeFortran()
@@ -357,6 +346,9 @@ PetscErrorCode SlepcInitialized(PetscBool *isInitialized)
 /*@
    SlepcFinalized - Determine whether SlepcFinalize() has been called.
 
+   Output Parameter:
+.  isFinalized - the result
+
    Level: developer
 
 .seealso: SlepcFinalize()
@@ -370,26 +362,31 @@ PetscErrorCode SlepcFinalized(PetscBool *isFinalized)
 
 PETSC_EXTERN PetscBool PetscBeganMPI;
 
-/*
+/*@C
    SlepcInitializeNoPointers - Calls SlepcInitialize() from C/C++ without the pointers
    to argc and args (analogue to PetscInitializeNoPointers).
 
    Collective
 
+   Input Parameters:
++  argc - count of number of command line arguments
+.  args - the command line arguments
+.  file - [optional] PETSc database file, defaults to ~username/.petscrc
+          (use NULL for default)
+-  help - [optional] Help message to print, use NULL for no message
+
    Level: advanced
 
 .seealso: SlepcInitialize()
-*/
-PetscErrorCode SlepcInitializeNoPointers(int argc,char **args,const char *filename,const char *help)
+@*/
+PetscErrorCode SlepcInitializeNoPointers(int argc,char **args,const char *file,const char *help)
 {
-  PetscErrorCode ierr;
   int            myargc = argc;
   char           **myargs = args;
 
   PetscFunctionBegin;
-  ierr = SlepcInitialize(&myargc,&myargs,filename,help);CHKERRQ(ierr);
-  ierr = PetscPopSignalHandler();CHKERRQ(ierr);
+  PetscCall(SlepcInitialize(&myargc,&myargs,file,help));
+  PetscCall(PetscPopSignalHandler());
   PetscBeganMPI = PETSC_FALSE;
   PetscFunctionReturn(0);
 }
-
