@@ -1,7 +1,7 @@
 /*
    - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
    SLEPc - Scalable Library for Eigenvalue Problem Computations
-   Copyright (c) 2002-2021, Universitat Politecnica de Valencia, Spain
+   Copyright (c) 2002-, Universitat Politecnica de Valencia, Spain
 
    This file is part of SLEPc.
    SLEPc is distributed under a 2-clause BSD license (see LICENSE).
@@ -16,9 +16,9 @@ static PetscBool VecCompInitialized = PETSC_FALSE;
 MPI_Op MPIU_NORM2_SUM=0;
 
 /* Private functions */
-PETSC_STATIC_INLINE void SumNorm2(PetscReal*,PetscReal*,PetscReal*,PetscReal*);
-PETSC_STATIC_INLINE PetscReal GetNorm2(PetscReal,PetscReal);
-PETSC_STATIC_INLINE void AddNorm2(PetscReal*,PetscReal*,PetscReal);
+static inline void SumNorm2(PetscReal*,PetscReal*,PetscReal*,PetscReal*);
+static inline PetscReal GetNorm2(PetscReal,PetscReal);
+static inline void AddNorm2(PetscReal*,PetscReal*,PetscReal);
 static PetscErrorCode VecCompSetSubVecs_Comp(Vec,PetscInt,Vec*);
 static PetscErrorCode VecCompGetSubVecs_Comp(Vec,PetscInt*,const Vec**);
 
@@ -27,7 +27,7 @@ static PetscErrorCode VecCompGetSubVecs_Comp(Vec,PetscInt*,const Vec**);
 #define __WITH_MPI__
 #include "veccomp0.h"
 
-PETSC_STATIC_INLINE void SumNorm2(PetscReal *ssq0,PetscReal *scale0,PetscReal *ssq1,PetscReal *scale1)
+static inline void SumNorm2(PetscReal *ssq0,PetscReal *scale0,PetscReal *ssq1,PetscReal *scale1)
 {
   PetscReal q;
   if (*scale0 > *scale1) {
@@ -40,12 +40,12 @@ PETSC_STATIC_INLINE void SumNorm2(PetscReal *ssq0,PetscReal *scale0,PetscReal *s
   }
 }
 
-PETSC_STATIC_INLINE PetscReal GetNorm2(PetscReal ssq,PetscReal scale)
+static inline PetscReal GetNorm2(PetscReal ssq,PetscReal scale)
 {
   return scale*PetscSqrtReal(ssq);
 }
 
-PETSC_STATIC_INLINE void AddNorm2(PetscReal *ssq,PetscReal *scale,PetscReal x)
+static inline void AddNorm2(PetscReal *ssq,PetscReal *scale,PetscReal x)
 {
   PetscReal absx,q;
   if (x != 0.0) {
@@ -85,27 +85,23 @@ SLEPC_EXTERN void MPIAPI SlepcSumNorm2_Local(void *in,void *out,PetscMPIInt *cnt
 
 static PetscErrorCode VecCompNormEnd(void)
 {
-  PetscErrorCode ierr;
-
   PetscFunctionBegin;
-  ierr = MPI_Type_free(&MPIU_NORM2);CHKERRMPI(ierr);
-  ierr = MPI_Type_free(&MPIU_NORM1_AND_2);CHKERRMPI(ierr);
-  ierr = MPI_Op_free(&MPIU_NORM2_SUM);CHKERRMPI(ierr);
+  PetscCallMPI(MPI_Type_free(&MPIU_NORM2));
+  PetscCallMPI(MPI_Type_free(&MPIU_NORM1_AND_2));
+  PetscCallMPI(MPI_Op_free(&MPIU_NORM2_SUM));
   VecCompInitialized = PETSC_FALSE;
   PetscFunctionReturn(0);
 }
 
 static PetscErrorCode VecCompNormInit(void)
 {
-  PetscErrorCode ierr;
-
   PetscFunctionBegin;
-  ierr = MPI_Type_contiguous(2,MPIU_REAL,&MPIU_NORM2);CHKERRMPI(ierr);
-  ierr = MPI_Type_commit(&MPIU_NORM2);CHKERRMPI(ierr);
-  ierr = MPI_Type_contiguous(3,MPIU_REAL,&MPIU_NORM1_AND_2);CHKERRMPI(ierr);
-  ierr = MPI_Type_commit(&MPIU_NORM1_AND_2);CHKERRMPI(ierr);
-  ierr = MPI_Op_create(SlepcSumNorm2_Local,PETSC_TRUE,&MPIU_NORM2_SUM);CHKERRMPI(ierr);
-  ierr = PetscRegisterFinalize(VecCompNormEnd);CHKERRQ(ierr);
+  PetscCallMPI(MPI_Type_contiguous(2,MPIU_REAL,&MPIU_NORM2));
+  PetscCallMPI(MPI_Type_commit(&MPIU_NORM2));
+  PetscCallMPI(MPI_Type_contiguous(3,MPIU_REAL,&MPIU_NORM1_AND_2));
+  PetscCallMPI(MPI_Type_commit(&MPIU_NORM1_AND_2));
+  PetscCallMPI(MPI_Op_create(SlepcSumNorm2_Local,PETSC_TRUE,&MPIU_NORM2_SUM));
+  PetscCall(PetscRegisterFinalize(VecCompNormEnd));
   PetscFunctionReturn(0);
 }
 
@@ -113,138 +109,142 @@ PetscErrorCode VecDestroy_Comp(Vec v)
 {
   Vec_Comp       *vs = (Vec_Comp*)v->data;
   PetscInt       i;
-  PetscErrorCode ierr;
 
   PetscFunctionBegin;
 #if defined(PETSC_USE_LOG)
-  PetscLogObjectState((PetscObject)v,"Length=%D",v->map->n);
+  PetscLogObjectState((PetscObject)v,"Length=%" PetscInt_FMT,v->map->n);
 #endif
-  for (i=0;i<vs->nx;i++) {
-    ierr = VecDestroy(&vs->x[i]);CHKERRQ(ierr);
-  }
-  if (--vs->n->friends <= 0) {
-    ierr = PetscFree(vs->n);CHKERRQ(ierr);
-  }
-  ierr = PetscFree(vs->x);CHKERRQ(ierr);
-  ierr = PetscFree(vs);CHKERRQ(ierr);
-  ierr = PetscObjectComposeFunction((PetscObject)v,"VecCompSetSubVecs_C",NULL);CHKERRQ(ierr);
-  ierr = PetscObjectComposeFunction((PetscObject)v,"VecCompGetSubVecs_C",NULL);CHKERRQ(ierr);
+  for (i=0;i<vs->nx;i++) PetscCall(VecDestroy(&vs->x[i]));
+  if (--vs->n->friends <= 0) PetscCall(PetscFree(vs->n));
+  PetscCall(PetscFree(vs->x));
+  PetscCall(PetscFree(vs));
+  PetscCall(PetscObjectComposeFunction((PetscObject)v,"VecCompSetSubVecs_C",NULL));
+  PetscCall(PetscObjectComposeFunction((PetscObject)v,"VecCompGetSubVecs_C",NULL));
   PetscFunctionReturn(0);
 }
 
-static struct _VecOps DvOps = {VecDuplicate_Comp, /* 1 */
-            VecDuplicateVecs_Comp,
-            VecDestroyVecs_Comp,
-            VecDot_Comp_MPI,
-            VecMDot_Comp_MPI,
-            VecNorm_Comp_MPI,
-            VecTDot_Comp_MPI,
-            VecMTDot_Comp_MPI,
-            VecScale_Comp,
-            VecCopy_Comp, /* 10 */
-            VecSet_Comp,
-            VecSwap_Comp,
-            VecAXPY_Comp,
-            VecAXPBY_Comp,
-            VecMAXPY_Comp,
-            VecAYPX_Comp,
-            VecWAXPY_Comp,
-            VecAXPBYPCZ_Comp,
-            VecPointwiseMult_Comp,
-            VecPointwiseDivide_Comp,
-            0, /* 20 */
-            0,0,
-            0 /*VecGetArray_Seq*/,
-            VecGetSize_Comp,
-            VecGetLocalSize_Comp,
-            0/*VecRestoreArray_Seq*/,
-            VecMax_Comp,
-            VecMin_Comp,
-            VecSetRandom_Comp,
-            0, /* 30 */
-            0,
-            VecDestroy_Comp,
-            VecView_Comp,
-            0/*VecPlaceArray_Seq*/,
-            0/*VecReplaceArray_Seq*/,
-            VecDot_Comp_Seq,
-            VecTDot_Comp_Seq,
-            VecNorm_Comp_Seq,
-            VecMDot_Comp_Seq,
-            VecMTDot_Comp_Seq, /* 40 */
-            0,
-            VecReciprocal_Comp,
-            VecConjugate_Comp,
-            0,0,
-            0/*VecResetArray_Seq*/,
-            0,
-            VecMaxPointwiseDivide_Comp,
-            VecPointwiseMax_Comp,
-            VecPointwiseMaxAbs_Comp,
-            VecPointwiseMin_Comp,
-            0,
-            VecSqrtAbs_Comp,
-            VecAbs_Comp,
-            VecExp_Comp,
-            VecLog_Comp,
-            VecShift_Comp,
-            0,
-            0,
-            0,
-            VecDotNorm2_Comp_MPI
-          };
+static struct _VecOps DvOps = {
+  PetscDesignatedInitializer(duplicate,VecDuplicate_Comp),
+  PetscDesignatedInitializer(duplicatevecs,VecDuplicateVecs_Comp),
+  PetscDesignatedInitializer(destroyvecs,VecDestroyVecs_Comp),
+  PetscDesignatedInitializer(dot,VecDot_Comp_MPI),
+  PetscDesignatedInitializer(mdot,VecMDot_Comp_MPI),
+  PetscDesignatedInitializer(norm,VecNorm_Comp_MPI),
+  PetscDesignatedInitializer(tdot,VecTDot_Comp_MPI),
+  PetscDesignatedInitializer(mtdot,VecMTDot_Comp_MPI),
+  PetscDesignatedInitializer(scale,VecScale_Comp),
+  PetscDesignatedInitializer(copy,VecCopy_Comp),
+  PetscDesignatedInitializer(set,VecSet_Comp),
+  PetscDesignatedInitializer(swap,VecSwap_Comp),
+  PetscDesignatedInitializer(axpy,VecAXPY_Comp),
+  PetscDesignatedInitializer(axpby,VecAXPBY_Comp),
+  PetscDesignatedInitializer(maxpy,VecMAXPY_Comp),
+  PetscDesignatedInitializer(aypx,VecAYPX_Comp),
+  PetscDesignatedInitializer(waxpy,VecWAXPY_Comp),
+  PetscDesignatedInitializer(axpbypcz,VecAXPBYPCZ_Comp),
+  PetscDesignatedInitializer(pointwisemult,VecPointwiseMult_Comp),
+  PetscDesignatedInitializer(pointwisedivide,VecPointwiseDivide_Comp),
+  PetscDesignatedInitializer(setvalues,NULL),
+  PetscDesignatedInitializer(assemblybegin,NULL),
+  PetscDesignatedInitializer(assemblyend,NULL),
+  PetscDesignatedInitializer(getarray,NULL),
+  PetscDesignatedInitializer(getsize,VecGetSize_Comp),
+  PetscDesignatedInitializer(getlocalsize,VecGetLocalSize_Comp),
+  PetscDesignatedInitializer(restorearray,NULL),
+  PetscDesignatedInitializer(max,VecMax_Comp),
+  PetscDesignatedInitializer(min,VecMin_Comp),
+  PetscDesignatedInitializer(setrandom,VecSetRandom_Comp),
+  PetscDesignatedInitializer(setoption,NULL),
+  PetscDesignatedInitializer(setvaluesblocked,NULL),
+  PetscDesignatedInitializer(destroy,VecDestroy_Comp),
+  PetscDesignatedInitializer(view,VecView_Comp),
+  PetscDesignatedInitializer(placearray,NULL),
+  PetscDesignatedInitializer(replacearray,NULL),
+  PetscDesignatedInitializer(dot_local,VecDot_Comp_Seq),
+  PetscDesignatedInitializer(tdot_local,VecTDot_Comp_Seq),
+  PetscDesignatedInitializer(norm_local,VecNorm_Comp_Seq),
+  PetscDesignatedInitializer(mdot_local,VecMDot_Comp_Seq),
+  PetscDesignatedInitializer(mtdot_local,VecMTDot_Comp_Seq),
+  PetscDesignatedInitializer(load,NULL),
+  PetscDesignatedInitializer(reciprocal,VecReciprocal_Comp),
+  PetscDesignatedInitializer(conjugate,VecConjugate_Comp),
+  PetscDesignatedInitializer(setlocaltoglobalmapping,NULL),
+  PetscDesignatedInitializer(setvalueslocal,NULL),
+  PetscDesignatedInitializer(resetarray,NULL),
+  PetscDesignatedInitializer(setfromoptions,NULL),
+  PetscDesignatedInitializer(maxpointwisedivide,VecMaxPointwiseDivide_Comp),
+  PetscDesignatedInitializer(pointwisemax,VecPointwiseMax_Comp),
+  PetscDesignatedInitializer(pointwisemaxabs,VecPointwiseMaxAbs_Comp),
+  PetscDesignatedInitializer(pointwisemin,VecPointwiseMin_Comp),
+  PetscDesignatedInitializer(getvalues,NULL),
+  PetscDesignatedInitializer(sqrt,VecSqrtAbs_Comp),
+  PetscDesignatedInitializer(abs,VecAbs_Comp),
+  PetscDesignatedInitializer(exp,VecExp_Comp),
+  PetscDesignatedInitializer(log,VecLog_Comp),
+  PetscDesignatedInitializer(shift,VecShift_Comp),
+  PetscDesignatedInitializer(create,NULL),
+  PetscDesignatedInitializer(stridegather,NULL),
+  PetscDesignatedInitializer(stridescatter,NULL),
+  PetscDesignatedInitializer(dotnorm2,VecDotNorm2_Comp_MPI),
+  PetscDesignatedInitializer(getsubvector,NULL),
+  PetscDesignatedInitializer(restoresubvector,NULL),
+  PetscDesignatedInitializer(getarrayread,NULL),
+  PetscDesignatedInitializer(restorearrayread,NULL),
+  PetscDesignatedInitializer(stridesubsetgather,NULL),
+  PetscDesignatedInitializer(stridesubsetscatter,NULL),
+  PetscDesignatedInitializer(viewnative,NULL),
+  PetscDesignatedInitializer(loadnative,NULL),
+  PetscDesignatedInitializer(getlocalvector,NULL)
+};
 
 PetscErrorCode VecDuplicateVecs_Comp(Vec w,PetscInt m,Vec *V[])
 {
-  PetscErrorCode ierr;
   PetscInt       i;
 
   PetscFunctionBegin;
   PetscValidHeaderSpecific(w,VEC_CLASSID,1);
   PetscValidPointer(V,3);
-  if (m<=0) SETERRQ1(PetscObjectComm((PetscObject)w),PETSC_ERR_ARG_OUTOFRANGE,"m must be > 0: m = %D",m);
-  ierr = PetscMalloc1(m,V);CHKERRQ(ierr);
-  for (i=0;i<m;i++) { ierr = VecDuplicate(w,*V+i);CHKERRQ(ierr); }
+  PetscCheck(m>0,PetscObjectComm((PetscObject)w),PETSC_ERR_ARG_OUTOFRANGE,"m must be > 0: m = %" PetscInt_FMT,m);
+  PetscCall(PetscMalloc1(m,V));
+  for (i=0;i<m;i++) PetscCall(VecDuplicate(w,*V+i));
   PetscFunctionReturn(0);
 }
 
 PetscErrorCode VecDestroyVecs_Comp(PetscInt m,Vec v[])
 {
-  PetscErrorCode ierr;
   PetscInt       i;
 
   PetscFunctionBegin;
   PetscValidPointer(v,2);
-  if (m<=0) SETERRQ1(PETSC_COMM_SELF,PETSC_ERR_ARG_OUTOFRANGE,"m must be > 0: m = %D",m);
-  for (i=0;i<m;i++) { ierr = VecDestroy(&v[i]);CHKERRQ(ierr); }
-  ierr = PetscFree(v);CHKERRQ(ierr);
+  PetscCheck(m>0,PETSC_COMM_SELF,PETSC_ERR_ARG_OUTOFRANGE,"m must be > 0: m = %" PetscInt_FMT,m);
+  for (i=0;i<m;i++) PetscCall(VecDestroy(&v[i]));
+  PetscCall(PetscFree(v));
   PetscFunctionReturn(0);
 }
 
 static PetscErrorCode VecCreate_Comp_Private(Vec v,Vec *x,PetscInt nx,PetscBool x_to_me,Vec_Comp_N *n)
 {
   Vec_Comp       *s;
-  PetscErrorCode ierr;
   PetscInt       N=0,lN=0,i,k;
 
   PetscFunctionBegin;
   if (!VecCompInitialized) {
     VecCompInitialized = PETSC_TRUE;
-    ierr = VecRegister(VECCOMP,VecCreate_Comp);CHKERRQ(ierr);
-    ierr = VecCompNormInit();CHKERRQ(ierr);
+    PetscCall(VecRegister(VECCOMP,VecCreate_Comp));
+    PetscCall(VecCompNormInit());
   }
 
   /* Allocate a new Vec_Comp */
-  if (v->data) { ierr = PetscFree(v->data);CHKERRQ(ierr); }
-  ierr = PetscNewLog(v,&s);CHKERRQ(ierr);
-  ierr = PetscMemcpy(v->ops,&DvOps,sizeof(DvOps));CHKERRQ(ierr);
+  if (v->data) PetscCall(PetscFree(v->data));
+  PetscCall(PetscNewLog(v,&s));
+  PetscCall(PetscMemcpy(v->ops,&DvOps,sizeof(DvOps)));
   v->data        = (void*)s;
   v->petscnative = PETSC_FALSE;
 
   /* Allocate the array of Vec, if it is needed to be done */
   if (!x_to_me) {
-    if (nx) { ierr = PetscMalloc1(nx,&s->x);CHKERRQ(ierr); }
-    if (x) { ierr = PetscArraycpy(s->x,x,nx);CHKERRQ(ierr); }
+    if (nx) PetscCall(PetscMalloc1(nx,&s->x));
+    if (x) PetscCall(PetscArraycpy(s->x,x,nx));
   } else s->x = x;
 
   s->nx = nx;
@@ -253,12 +253,12 @@ static PetscErrorCode VecCreate_Comp_Private(Vec v,Vec *x,PetscInt nx,PetscBool
     /* Allocate the shared structure, if it is not given */
     if (!n) {
       for (i=0;i<nx;i++) {
-        ierr = VecGetSize(x[i],&k);CHKERRQ(ierr);
+        PetscCall(VecGetSize(x[i],&k));
         N+= k;
-        ierr = VecGetLocalSize(x[i],&k);CHKERRQ(ierr);
+        PetscCall(VecGetLocalSize(x[i],&k));
         lN+= k;
       }
-      ierr = PetscNewLog(v,&n);CHKERRQ(ierr);
+      PetscCall(PetscNewLog(v,&n));
       s->n = n;
       n->n = nx;
       n->N = N;
@@ -270,21 +270,19 @@ static PetscErrorCode VecCreate_Comp_Private(Vec v,Vec *x,PetscInt nx,PetscBool
     }
 
     /* Set the virtual sizes as the real sizes of the vector */
-    ierr = VecSetSizes(v,s->n->lN,s->n->N);CHKERRQ(ierr);
+    PetscCall(VecSetSizes(v,s->n->lN,s->n->N));
   }
 
-  ierr = PetscObjectChangeTypeName((PetscObject)v,VECCOMP);CHKERRQ(ierr);
-  ierr = PetscObjectComposeFunction((PetscObject)v,"VecCompSetSubVecs_C",VecCompSetSubVecs_Comp);CHKERRQ(ierr);
-  ierr = PetscObjectComposeFunction((PetscObject)v,"VecCompGetSubVecs_C",VecCompGetSubVecs_Comp);CHKERRQ(ierr);
+  PetscCall(PetscObjectChangeTypeName((PetscObject)v,VECCOMP));
+  PetscCall(PetscObjectComposeFunction((PetscObject)v,"VecCompSetSubVecs_C",VecCompSetSubVecs_Comp));
+  PetscCall(PetscObjectComposeFunction((PetscObject)v,"VecCompGetSubVecs_C",VecCompGetSubVecs_Comp));
   PetscFunctionReturn(0);
 }
 
 SLEPC_EXTERN PetscErrorCode VecCreate_Comp(Vec V)
 {
-  PetscErrorCode ierr;
-
   PetscFunctionBegin;
-  ierr = VecCreate_Comp_Private(V,NULL,0,PETSC_FALSE,NULL);CHKERRQ(ierr);
+  PetscCall(VecCreate_Comp_Private(V,NULL,0,PETSC_FALSE,NULL));
   PetscFunctionReturn(0);
 }
 
@@ -314,20 +312,19 @@ SLEPC_EXTERN PetscErrorCode VecCreate_Comp(Vec V)
 @*/
 PetscErrorCode VecCreateComp(MPI_Comm comm,PetscInt *Nx,PetscInt n,VecType t,Vec Vparent,Vec *V)
 {
-  PetscErrorCode ierr;
   Vec            *x;
   PetscInt       i;
 
   PetscFunctionBegin;
-  ierr = VecCreate(comm,V);CHKERRQ(ierr);
-  ierr = PetscMalloc1(n,&x);CHKERRQ(ierr);
-  ierr = PetscLogObjectMemory((PetscObject)*V,n*sizeof(Vec));CHKERRQ(ierr);
+  PetscCall(VecCreate(comm,V));
+  PetscCall(PetscMalloc1(n,&x));
+  PetscCall(PetscLogObjectMemory((PetscObject)*V,n*sizeof(Vec)));
   for (i=0;i<n;i++) {
-    ierr = VecCreate(comm,&x[i]);CHKERRQ(ierr);
-    ierr = VecSetSizes(x[i],PETSC_DECIDE,Nx[i]);CHKERRQ(ierr);
-    ierr = VecSetType(x[i],t);CHKERRQ(ierr);
+    PetscCall(VecCreate(comm,&x[i]));
+    PetscCall(VecSetSizes(x[i],PETSC_DECIDE,Nx[i]));
+    PetscCall(VecSetType(x[i],t));
   }
-  ierr = VecCreate_Comp_Private(*V,x,n,PETSC_TRUE,Vparent?((Vec_Comp*)Vparent->data)->n:NULL);CHKERRQ(ierr);
+  PetscCall(VecCreate_Comp_Private(*V,x,n,PETSC_TRUE,Vparent?((Vec_Comp*)Vparent->data)->n:NULL));
   PetscFunctionReturn(0);
 }
 
@@ -351,39 +348,34 @@ PetscErrorCode VecCreateComp(MPI_Comm comm,PetscInt *Nx,PetscInt n,VecType t,Vec
 @*/
 PetscErrorCode VecCreateCompWithVecs(Vec *x,PetscInt n,Vec Vparent,Vec *V)
 {
-  PetscErrorCode ierr;
   PetscInt       i;
 
   PetscFunctionBegin;
   PetscValidPointer(x,1);
   PetscValidHeaderSpecific(*x,VEC_CLASSID,1);
   PetscValidLogicalCollectiveInt(*x,n,2);
-  ierr = VecCreate(PetscObjectComm((PetscObject)x[0]),V);CHKERRQ(ierr);
-  for (i=0;i<n;i++) {
-    ierr = PetscObjectReference((PetscObject)x[i]);CHKERRQ(ierr);
-  }
-  ierr = VecCreate_Comp_Private(*V,x,n,PETSC_FALSE,Vparent?((Vec_Comp*)Vparent->data)->n:NULL);CHKERRQ(ierr);
+  PetscCall(VecCreate(PetscObjectComm((PetscObject)x[0]),V));
+  for (i=0;i<n;i++) PetscCall(PetscObjectReference((PetscObject)x[i]));
+  PetscCall(VecCreate_Comp_Private(*V,x,n,PETSC_FALSE,Vparent?((Vec_Comp*)Vparent->data)->n:NULL));
   PetscFunctionReturn(0);
 }
 
 PetscErrorCode VecDuplicate_Comp(Vec win,Vec *V)
 {
-  PetscErrorCode ierr;
   Vec            *x;
   PetscInt       i;
   Vec_Comp       *s = (Vec_Comp*)win->data;
 
   PetscFunctionBegin;
   SlepcValidVecComp(win,1);
-  ierr = VecCreate(PetscObjectComm((PetscObject)win),V);CHKERRQ(ierr);
-  ierr = PetscMalloc1(s->nx,&x);CHKERRQ(ierr);
-  ierr = PetscLogObjectMemory((PetscObject)*V,s->nx*sizeof(Vec));CHKERRQ(ierr);
+  PetscCall(VecCreate(PetscObjectComm((PetscObject)win),V));
+  PetscCall(PetscMalloc1(s->nx,&x));
+  PetscCall(PetscLogObjectMemory((PetscObject)*V,s->nx*sizeof(Vec)));
   for (i=0;i<s->nx;i++) {
-    if (s->x[i]) {
-      ierr = VecDuplicate(s->x[i],&x[i]);CHKERRQ(ierr);
-    } else x[i] = NULL;
+    if (s->x[i]) PetscCall(VecDuplicate(s->x[i],&x[i]));
+    else x[i] = NULL;
   }
-  ierr = VecCreate_Comp_Private(*V,x,s->nx,PETSC_TRUE,s->n);CHKERRQ(ierr);
+  PetscCall(VecCreate_Comp_Private(*V,x,s->nx,PETSC_TRUE,s->n));
   PetscFunctionReturn(0);
 }
 
@@ -416,11 +408,9 @@ static PetscErrorCode VecCompGetSubVecs_Comp(Vec win,PetscInt *n,const Vec **x)
 @*/
 PetscErrorCode VecCompGetSubVecs(Vec win,PetscInt *n,const Vec **x)
 {
-  PetscErrorCode ierr;
-
   PetscFunctionBegin;
   PetscValidHeaderSpecific(win,VEC_CLASSID,1);
-  ierr = PetscUseMethod(win,"VecCompGetSubVecs_C",(Vec,PetscInt*,const Vec**),(win,n,x));CHKERRQ(ierr);
+  PetscUseMethod(win,"VecCompGetSubVecs_C",(Vec,PetscInt*,const Vec**),(win,n,x));
   PetscFunctionReturn(0);
 }
 
@@ -429,35 +419,32 @@ static PetscErrorCode VecCompSetSubVecs_Comp(Vec win,PetscInt n,Vec *x)
   Vec_Comp       *s = (Vec_Comp*)win->data;
   PetscInt       i,N,nlocal;
   Vec_Comp_N     *nn;
-  PetscErrorCode ierr;
 
   PetscFunctionBegin;
-  if (!s) SETERRQ(PetscObjectComm((PetscObject)win),PETSC_ERR_ORDER,"Must call VecSetSizes first");
+  PetscCheck(s,PetscObjectComm((PetscObject)win),PETSC_ERR_ORDER,"Must call VecSetSizes first");
   if (!s->nx) {
     /* vector has been created via VecCreate+VecSetType+VecSetSizes, so allocate data structures */
-    ierr = PetscMalloc1(n,&s->x);CHKERRQ(ierr);
-    ierr = PetscLogObjectMemory((PetscObject)win,n*sizeof(Vec));CHKERRQ(ierr);
-    ierr = VecGetSize(win,&N);CHKERRQ(ierr);
-    if (N%n) SETERRQ2(PetscObjectComm((PetscObject)win),1,"Global dimension %D is not divisible by %D",N,n);
-    ierr = VecGetLocalSize(win,&nlocal);CHKERRQ(ierr);
-    if (nlocal%n) SETERRQ2(PetscObjectComm((PetscObject)win),1,"Local dimension %D is not divisible by %D",nlocal,n);
+    PetscCall(PetscMalloc1(n,&s->x));
+    PetscCall(PetscLogObjectMemory((PetscObject)win,n*sizeof(Vec)));
+    PetscCall(VecGetSize(win,&N));
+    PetscCheck(N%n==0,PetscObjectComm((PetscObject)win),PETSC_ERR_SUP,"Global dimension %" PetscInt_FMT " is not divisible by %" PetscInt_FMT,N,n);
+    PetscCall(VecGetLocalSize(win,&nlocal));
+    PetscCheck(nlocal%n==0,PetscObjectComm((PetscObject)win),PETSC_ERR_SUP,"Local dimension %" PetscInt_FMT " is not divisible by %" PetscInt_FMT,nlocal,n);
     s->nx = n;
     for (i=0;i<n;i++) {
-      ierr = VecCreate(PetscObjectComm((PetscObject)win),&s->x[i]);CHKERRQ(ierr);
-      ierr = VecSetSizes(s->x[i],nlocal/n,N/n);CHKERRQ(ierr);
-      ierr = VecSetFromOptions(s->x[i]);CHKERRQ(ierr);
+      PetscCall(VecCreate(PetscObjectComm((PetscObject)win),&s->x[i]));
+      PetscCall(VecSetSizes(s->x[i],nlocal/n,N/n));
+      PetscCall(VecSetFromOptions(s->x[i]));
     }
     if (!s->n) {
-      ierr = PetscNewLog(win,&nn);CHKERRQ(ierr);
+      PetscCall(PetscNewLog(win,&nn));
       s->n = nn;
       nn->N = N;
       nn->lN = nlocal;
       nn->friends = 1;
     }
-  } else if (n > s->nx) SETERRQ1(PetscObjectComm((PetscObject)win),PETSC_ERR_SUP,"Number of child vectors cannot be larger than %D",s->nx);
-  if (x) {
-    ierr = PetscArraycpy(s->x,x,n);CHKERRQ(ierr);
-  }
+  } else PetscCheck(n<=s->nx,PetscObjectComm((PetscObject)win),PETSC_ERR_SUP,"Number of child vectors cannot be larger than %" PetscInt_FMT,s->nx);
+  if (x) PetscCall(PetscArraycpy(s->x,x,n));
   s->n->n = n;
   PetscFunctionReturn(0);
 }
@@ -483,63 +470,51 @@ static PetscErrorCode VecCompSetSubVecs_Comp(Vec win,PetscInt n,Vec *x)
 @*/
 PetscErrorCode VecCompSetSubVecs(Vec win,PetscInt n,Vec *x)
 {
-  PetscErrorCode ierr;
-
   PetscFunctionBegin;
   PetscValidHeaderSpecific(win,VEC_CLASSID,1);
   PetscValidLogicalCollectiveInt(win,n,2);
-  ierr = PetscTryMethod(win,"VecCompSetSubVecs_C",(Vec,PetscInt,Vec*),(win,n,x));CHKERRQ(ierr);
+  PetscTryMethod(win,"VecCompSetSubVecs_C",(Vec,PetscInt,Vec*),(win,n,x));
   PetscFunctionReturn(0);
 }
 
 PetscErrorCode VecAXPY_Comp(Vec v,PetscScalar alpha,Vec w)
 {
-  PetscErrorCode ierr;
   Vec_Comp       *vs = (Vec_Comp*)v->data,*ws = (Vec_Comp*)w->data;
   PetscInt       i;
 
   PetscFunctionBegin;
   SlepcValidVecComp(v,1);
   SlepcValidVecComp(w,3);
-  for (i=0;i<vs->n->n;i++) {
-    ierr = VecAXPY(vs->x[i],alpha,ws->x[i]);CHKERRQ(ierr);
-  }
+  for (i=0;i<vs->n->n;i++) PetscCall(VecAXPY(vs->x[i],alpha,ws->x[i]));
   PetscFunctionReturn(0);
 }
 
 PetscErrorCode VecAYPX_Comp(Vec v,PetscScalar alpha,Vec w)
 {
-  PetscErrorCode ierr;
   Vec_Comp       *vs = (Vec_Comp*)v->data,*ws = (Vec_Comp*)w->data;
   PetscInt       i;
 
   PetscFunctionBegin;
   SlepcValidVecComp(v,1);
   SlepcValidVecComp(w,3);
-  for (i=0;i<vs->n->n;i++) {
-    ierr = VecAYPX(vs->x[i],alpha,ws->x[i]);CHKERRQ(ierr);
-  }
+  for (i=0;i<vs->n->n;i++) PetscCall(VecAYPX(vs->x[i],alpha,ws->x[i]));
   PetscFunctionReturn(0);
 }
 
 PetscErrorCode VecAXPBY_Comp(Vec v,PetscScalar alpha,PetscScalar beta,Vec w)
 {
-  PetscErrorCode ierr;
   Vec_Comp       *vs = (Vec_Comp*)v->data,*ws = (Vec_Comp*)w->data;
   PetscInt       i;
 
   PetscFunctionBegin;
   SlepcValidVecComp(v,1);
   SlepcValidVecComp(w,4);
-  for (i=0;i<vs->n->n;i++) {
-    ierr = VecAXPBY(vs->x[i],alpha,beta,ws->x[i]);CHKERRQ(ierr);
-  }
+  for (i=0;i<vs->n->n;i++) PetscCall(VecAXPBY(vs->x[i],alpha,beta,ws->x[i]));
   PetscFunctionReturn(0);
 }
 
 PetscErrorCode VecMAXPY_Comp(Vec v,PetscInt n,const PetscScalar *alpha,Vec *w)
 {
-  PetscErrorCode ierr;
   Vec_Comp       *vs = (Vec_Comp*)v->data;
   Vec            *wx;
   PetscInt       i,j;
@@ -548,20 +523,19 @@ PetscErrorCode VecMAXPY_Comp(Vec v,PetscInt n,const PetscScalar *alpha,Vec *w)
   SlepcValidVecComp(v,1);
   for (i=0;i<n;i++) SlepcValidVecComp(w[i],4);
 
-  ierr = PetscMalloc1(n,&wx);CHKERRQ(ierr);
+  PetscCall(PetscMalloc1(n,&wx));
 
   for (j=0;j<vs->n->n;j++) {
     for (i=0;i<n;i++) wx[i] = ((Vec_Comp*)w[i]->data)->x[j];
-    ierr = VecMAXPY(vs->x[j],n,alpha,wx);CHKERRQ(ierr);
+    PetscCall(VecMAXPY(vs->x[j],n,alpha,wx));
   }
 
-  ierr = PetscFree(wx);CHKERRQ(ierr);
+  PetscCall(PetscFree(wx));
   PetscFunctionReturn(0);
 }
 
 PetscErrorCode VecWAXPY_Comp(Vec v,PetscScalar alpha,Vec w,Vec z)
 {
-  PetscErrorCode ierr;
   Vec_Comp       *vs = (Vec_Comp*)v->data,*ws = (Vec_Comp*)w->data,*zs = (Vec_Comp*)z->data;
   PetscInt       i;
 
@@ -569,15 +543,12 @@ PetscErrorCode VecWAXPY_Comp(Vec v,PetscScalar alpha,Vec w,Vec z)
   SlepcValidVecComp(v,1);
   SlepcValidVecComp(w,3);
   SlepcValidVecComp(z,4);
-  for (i=0;i<vs->n->n;i++) {
-    ierr = VecWAXPY(vs->x[i],alpha,ws->x[i],zs->x[i]);CHKERRQ(ierr);
-  }
+  for (i=0;i<vs->n->n;i++) PetscCall(VecWAXPY(vs->x[i],alpha,ws->x[i],zs->x[i]));
   PetscFunctionReturn(0);
 }
 
 PetscErrorCode VecAXPBYPCZ_Comp(Vec v,PetscScalar alpha,PetscScalar beta,PetscScalar gamma,Vec w,Vec z)
 {
-  PetscErrorCode  ierr;
   Vec_Comp        *vs = (Vec_Comp*)v->data,*ws = (Vec_Comp*)w->data,*zs = (Vec_Comp*)z->data;
   PetscInt        i;
 
@@ -585,9 +556,7 @@ PetscErrorCode VecAXPBYPCZ_Comp(Vec v,PetscScalar alpha,PetscScalar beta,PetscSc
   SlepcValidVecComp(v,1);
   SlepcValidVecComp(w,5);
   SlepcValidVecComp(z,6);
-  for (i=0;i<vs->n->n;i++) {
-    ierr = VecAXPBYPCZ(vs->x[i],alpha,beta,gamma,ws->x[i],zs->x[i]);CHKERRQ(ierr);
-  }
+  for (i=0;i<vs->n->n;i++) PetscCall(VecAXPBYPCZ(vs->x[i],alpha,beta,gamma,ws->x[i],zs->x[i]));
   PetscFunctionReturn(0);
 }
 
@@ -619,7 +588,6 @@ PetscErrorCode VecGetLocalSize_Comp(Vec v,PetscInt *size)
 
 PetscErrorCode VecMax_Comp(Vec v,PetscInt *idx,PetscReal *z)
 {
-  PetscErrorCode ierr;
   Vec_Comp       *vs = (Vec_Comp*)v->data;
   PetscInt       idxp,s=0,s0;
   PetscReal      zp,z0;
@@ -629,16 +597,15 @@ PetscErrorCode VecMax_Comp(Vec v,PetscInt *idx,PetscReal *z)
   SlepcValidVecComp(v,1);
   if (!idx && !z) PetscFunctionReturn(0);
 
-  if (vs->n->n > 0) {
-    ierr = VecMax(vs->x[0],idx?&idxp:NULL,&zp);CHKERRQ(ierr);
-  } else {
+  if (vs->n->n > 0) PetscCall(VecMax(vs->x[0],idx?&idxp:NULL,&zp));
+  else {
     zp = PETSC_MIN_REAL;
     if (idx) idxp = -1;
   }
   for (i=1;i<vs->n->n;i++) {
-    ierr = VecGetSize(vs->x[i-1],&s0);CHKERRQ(ierr);
+    PetscCall(VecGetSize(vs->x[i-1],&s0));
     s += s0;
-    ierr = VecMax(vs->x[i],idx?&idxp:NULL,&z0);CHKERRQ(ierr);
+    PetscCall(VecMax(vs->x[i],idx?&idxp:NULL,&z0));
     if (zp < z0) {
       if (idx) *idx = s+idxp;
       zp = z0;
@@ -650,7 +617,6 @@ PetscErrorCode VecMax_Comp(Vec v,PetscInt *idx,PetscReal *z)
 
 PetscErrorCode VecMin_Comp(Vec v,PetscInt *idx,PetscReal *z)
 {
-  PetscErrorCode ierr;
   Vec_Comp       *vs = (Vec_Comp*)v->data;
   PetscInt       idxp,s=0,s0;
   PetscReal      zp,z0;
@@ -660,16 +626,15 @@ PetscErrorCode VecMin_Comp(Vec v,PetscInt *idx,PetscReal *z)
   SlepcValidVecComp(v,1);
   if (!idx && !z) PetscFunctionReturn(0);
 
-  if (vs->n->n > 0) {
-    ierr = VecMin(vs->x[0],idx?&idxp:NULL,&zp);CHKERRQ(ierr);
-  } else {
+  if (vs->n->n > 0) PetscCall(VecMin(vs->x[0],idx?&idxp:NULL,&zp));
+  else {
     zp = PETSC_MAX_REAL;
     if (idx) idxp = -1;
   }
   for (i=1;i<vs->n->n;i++) {
-    ierr = VecGetSize(vs->x[i-1],&s0);CHKERRQ(ierr);
+    PetscCall(VecGetSize(vs->x[i-1],&s0));
     s += s0;
-    ierr = VecMin(vs->x[i],idx?&idxp:NULL,&z0);CHKERRQ(ierr);
+    PetscCall(VecMin(vs->x[i],idx?&idxp:NULL,&z0));
     if (zp > z0) {
       if (idx) *idx = s+idxp;
       zp = z0;
@@ -681,7 +646,6 @@ PetscErrorCode VecMin_Comp(Vec v,PetscInt *idx,PetscReal *z)
 
 PetscErrorCode VecMaxPointwiseDivide_Comp(Vec v,Vec w,PetscReal *m)
 {
-  PetscErrorCode ierr;
   Vec_Comp       *vs = (Vec_Comp*)v->data,*ws = (Vec_Comp*)w->data;
   PetscReal      work;
   PetscInt       i;
@@ -690,9 +654,9 @@ PetscErrorCode VecMaxPointwiseDivide_Comp(Vec v,Vec w,PetscReal *m)
   SlepcValidVecComp(v,1);
   SlepcValidVecComp(w,2);
   if (!m || vs->n->n == 0) PetscFunctionReturn(0);
-  ierr = VecMaxPointwiseDivide(vs->x[0],ws->x[0],m);CHKERRQ(ierr);
+  PetscCall(VecMaxPointwiseDivide(vs->x[0],ws->x[0],m));
   for (i=1;i<vs->n->n;i++) {
-    ierr = VecMaxPointwiseDivide(vs->x[i],ws->x[i],&work);CHKERRQ(ierr);
+    PetscCall(VecMaxPointwiseDivide(vs->x[i],ws->x[i],&work));
     *m = PetscMax(*m,work);
   }
   PetscFunctionReturn(0);
@@ -705,14 +669,13 @@ PetscErrorCode VecMaxPointwiseDivide_Comp(Vec v,Vec w,PetscReal *m)
 #define __FUNC_TEMPLATE1__(NAME) \
 PetscErrorCode __COMPOSE3__(Vec,NAME,_Comp)(Vec v) \
 { \
-  PetscErrorCode  ierr; \
   Vec_Comp        *vs = (Vec_Comp*)v->data; \
   PetscInt        i; \
 \
   PetscFunctionBegin; \
   SlepcValidVecComp(v,1); \
   for (i=0;i<vs->n->n;i++) { \
-    ierr = __COMPOSE2__(Vec,NAME)(vs->x[i]);CHKERRQ(ierr); \
+    PetscCall(__COMPOSE2__(Vec,NAME)(vs->x[i])); \
   } \
   PetscFunctionReturn(0);\
 }
@@ -727,14 +690,13 @@ __FUNC_TEMPLATE1__(Log)
 #define __FUNC_TEMPLATE2__(NAME,T0) \
 PetscErrorCode __COMPOSE3__(Vec,NAME,_Comp)(Vec v,T0 __a) \
 { \
-  PetscErrorCode  ierr; \
   Vec_Comp        *vs = (Vec_Comp*)v->data; \
   PetscInt        i; \
 \
   PetscFunctionBegin; \
   SlepcValidVecComp(v,1); \
   for (i=0;i<vs->n->n;i++) { \
-    ierr = __COMPOSE2__(Vec,NAME)(vs->x[i],__a);CHKERRQ(ierr); \
+    PetscCall(__COMPOSE2__(Vec,NAME)(vs->x[i],__a)); \
   } \
   PetscFunctionReturn(0);\
 }
@@ -748,7 +710,6 @@ __FUNC_TEMPLATE2__(Shift,PetscScalar)
 #define __FUNC_TEMPLATE3__(NAME) \
 PetscErrorCode __COMPOSE3__(Vec,NAME,_Comp)(Vec v,Vec w) \
 { \
-  PetscErrorCode  ierr; \
   Vec_Comp        *vs = (Vec_Comp*)v->data,\
                   *ws = (Vec_Comp*)w->data; \
   PetscInt        i; \
@@ -757,7 +718,7 @@ PetscErrorCode __COMPOSE3__(Vec,NAME,_Comp)(Vec v,Vec w) \
   SlepcValidVecComp(v,1); \
   SlepcValidVecComp(w,2); \
   for (i=0;i<vs->n->n;i++) { \
-    ierr = __COMPOSE2__(Vec,NAME)(vs->x[i],ws->x[i]);CHKERRQ(ierr); \
+    PetscCall(__COMPOSE2__(Vec,NAME)(vs->x[i],ws->x[i])); \
   } \
   PetscFunctionReturn(0);\
 }
@@ -768,7 +729,6 @@ __FUNC_TEMPLATE3__(Swap)
 #define __FUNC_TEMPLATE4__(NAME) \
 PetscErrorCode __COMPOSE3__(Vec,NAME,_Comp)(Vec v,Vec w,Vec z) \
 { \
-  PetscErrorCode  ierr; \
   Vec_Comp        *vs = (Vec_Comp*)v->data, \
                   *ws = (Vec_Comp*)w->data, \
                   *zs = (Vec_Comp*)z->data; \
@@ -779,7 +739,7 @@ PetscErrorCode __COMPOSE3__(Vec,NAME,_Comp)(Vec v,Vec w,Vec z) \
   SlepcValidVecComp(w,2); \
   SlepcValidVecComp(z,3); \
   for (i=0;i<vs->n->n;i++) { \
-    ierr = __COMPOSE2__(Vec,NAME)(vs->x[i],ws->x[i],zs->x[i]);CHKERRQ(ierr); \
+    PetscCall(__COMPOSE2__(Vec,NAME)(vs->x[i],ws->x[i],zs->x[i])); \
   } \
   PetscFunctionReturn(0);\
 }
